"""Test SnvAnnotationDeserializer class with KRAS A18V."""

import unittest

from snvannotators.snvannotation.snvannotation import SnvAnnotation
from snvannotators.snvannotation.snvannotationdeserializer import (
    SnvAnnotationDeserializer,
)


class SnvAnnotationDeserializerKrasA18vTestCase(unittest.TestCase):
    """Test SnvAnnotationDeserializer class with KRAS A18V."""

    @classmethod
    def setUpClass(cls) -> None:
        super().setUpClass()
        cls.data = {
            "snv": {
                "ac": "NC_000012.11",
                "pos": 25398266,
                "ref": "G",
                "alt": "A",
                "chrom": "chr12",
            },
            "hgvs_annotation": {
                "hgvs_g": "NC_000012.11:g.25398266G>A",
                "hgvs_g_normalized": "NC_000012.11:g.25398266G>A",
                "hgvs_tp_annotations": [
                    {
                        "tx_ac": "NM_001369787.1",
                        "hgvs_t": "NM_001369787.1(KRAS):c.53C>T",
                        "hgvs_p": "NP_001356716.1:p.Ala18Val",
                    },
                    {
                        "tx_ac": "NM_033360.2",
                        "hgvs_t": "NM_033360.2(KRAS):c.53C>T",
                        "hgvs_p": "NP_203524.1:p.Ala18Val",
                    },
                    {
                        "tx_ac": "NM_001369786.1",
                        "hgvs_t": "NM_001369786.1(KRAS):c.53C>T",
                        "hgvs_p": "NP_001356715.1:p.Ala18Val",
                    },
                    {
                        "tx_ac": "NM_033360.3",
                        "hgvs_t": "NM_033360.3(KRAS):c.53C>T",
                        "hgvs_p": "NP_203524.1:p.Ala18Val",
                    },
                    {
                        "tx_ac": "NM_004985.4",
                        "hgvs_t": "NM_004985.4(KRAS):c.53C>T",
                        "hgvs_p": "NP_004976.2:p.Ala18Val",
                    },
                    {
                        "tx_ac": "NM_033360.4",
                        "hgvs_t": "NM_033360.4(KRAS):c.53C>T",
                        "hgvs_p": "NP_203524.1:p.Ala18Val",
                    },
                    {
                        "tx_ac": "NM_004985.5",
                        "hgvs_t": "NM_004985.5(KRAS):c.53C>T",
                        "hgvs_p": "NP_004976.2:p.Ala18Val",
                    },
                    {
                        "tx_ac": "NM_004985.3",
                        "hgvs_t": "NM_004985.3(KRAS):c.53C>T",
                        "hgvs_p": "NP_004976.2:p.Ala18Val",
                    },
                ],
            },
            "myvariant_annotation": {
                "hgvs_chr": "chr12:g.25398266G>A",
                "raw": {
                    "_id": "chr12:g.25398266G>A",
                    "_version": 2,
                    "cadd": {
                        "_license": "http://bit.ly/2TIuab9",
                        "alt": "A",
                        "anc": "G",
                        "annotype": "CodingTranscript",
                        "bstatistic": 696,
                        "chmm": {
                            "bivflnk": 0.0,
                            "enh": 0.0,
                            "enhbiv": 0.0,
                            "het": 0.0,
                            "quies": 0.079,
                            "reprpc": 0.0,
                            "reprpcwk": 0.0,
                            "tssa": 0.0,
                            "tssaflnk": 0.0,
                            "tssbiv": 0.0,
                            "tx": 0.189,
                            "txflnk": 0.0,
                            "txwk": 0.701,
                            "znfrpts": 0.0,
                        },
                        "chrom": 12,
                        "consdetail": "missense",
                        "consequence": "NON_SYNONYMOUS",
                        "consscore": 7,
                        "cpg": 0.04,
                        "dna": {
                            "helt": -1.75,
                            "mgw": -0.21,
                            "prot": 0.91,
                            "roll": -1.16,
                        },
                        "encode": {
                            "exp": 238.03,
                            "h3k27ac": 3.0,
                            "h3k4me1": 12.28,
                            "h3k4me3": 5.08,
                            "nucleo": 0.8,
                        },
                        "exon": "2/6",
                        "fitcons": 0.723164,
                        "gc": 0.37,
                        "gene": {
                            "ccds_id": "CCDS8703.1",
                            "cds": {
                                "cdna_pos": 117,
                                "cds_pos": 53,
                                "rel_cdna_pos": 0.1,
                                "rel_cds_pos": 0.09,
                            },
                            "feature_id": "ENST00000256078",
                            "gene_id": "ENSG00000133703",
                            "genename": "KRAS",
                            "prot": {
                                "domain": "ndomain",
                                "protpos": 18,
                                "rel_prot_pos": 0.1,
                            },
                        },
                        "gerp": {
                            "n": 5.68,
                            "rs": 662.8,
                            "rs_pval": 7.10496e-183,
                            "s": 5.68,
                        },
                        "grantham": 64,
                        "isderived": "TRUE",
                        "isknownvariant": "FALSE",
                        "istv": "FALSE",
                        "length": 0,
                        "mapability": {"20bp": 1, "35bp": 1},
                        "min_dist_tse": 11513,
                        "min_dist_tss": 5472,
                        "mutindex": 28,
                        "naa": "V",
                        "oaa": "A",
                        "phast_cons": {
                            "mammalian": 1.0,
                            "primate": 0.998,
                            "vertebrate": 1.0,
                        },
                        "phred": 32,
                        "phylop": {
                            "mammalian": 2.664,
                            "primate": 0.559,
                            "vertebrate": 5.859,
                        },
                        "polyphen": {"cat": "probably_damaging", "val": 0.985},
                        "pos": 25398266,
                        "rawscore": 6.801703,
                        "ref": "G",
                        "segway": "R4",
                        "sift": {"cat": "deleterious", "val": 0},
                        "type": "SNV",
                    },
                    "chrom": "12",
                    "clinvar": {
                        "_license": "http://bit.ly/2SQdcI0",
                        "allele_id": 1687832,
                        "alt": "A",
                        "chrom": "12",
                        "cytogenic": "12p12.1",
                        "gene": {"id": "3845", "symbol": "KRAS"},
                        "hg19": {"end": 25398266, "start": 25398266},
                        "hg38": {"end": 25245332, "start": 25245332},
                        "hgvs": {
                            "coding": [
                                "LRG_344t1:c.53C>T",
                                "LRG_344t2:c.53C>T",
                                "NM_001369786.1:c.53C>T",
                                "NM_001369787.1:c.53C>T",
                                "NM_004985.5:c.53C>T",
                                "NM_033360.4:c.53C>T",
                            ],
                            "genomic": [
                                "LRG_344:g.10672C>T",
                                "NC_000012.11:g.25398266G>A",
                                "NC_000012.12:g.25245332G>A",
                                "NG_007524.2:g.10672C>T",
                            ],
                            "protein": [
                                "LRG_344p1:p.Ala18Val",
                                "LRG_344p2:p.Ala18Val",
                                "NP_001356715.1:p.Ala18Val",
                                "NP_001356716.1:p.Ala18Val",
                                "NP_004976.2:p.Ala18Val",
                                "NP_203524.1:p.Ala18Val",
                            ],
                        },
                        "rcv": {
                            "accession": "RCV002264903",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C1860991",
                                    "mondo": "MONDO:0012371",
                                    "omim": "609942",
                                    "orphanet": "648",
                                },
                                "name": "Noonan syndrome 3 (NS3)",
                                "synonyms": ["KRAS gene related Noonan syndrome"],
                            },
                            "number_submitters": 1,
                            "origin": "de novo",
                            "preferred_name": "NM_004985.5(KRAS):c.53C>T (p.Ala18Val)",
                            "review_status": "criteria provided, single submitter",
                        },
                        "ref": "G",
                        "rsid": "rs2135806030",
                        "type": "single nucleotide variant",
                        "variant_id": 1695421,
                    },
                    "dbnsfp": {
                        "_license": "http://bit.ly/2VLnQBz",
                        "aa": {
                            "alt": "V",
                            "codon_degeneracy": [0, 0, 0, 0],
                            "codonpos": [2, 2, 2, 2],
                            "pos": [18, 18, 18, 18],
                            "ref": "A",
                            "refcodon": ["GCC", "GCC", "GCC", "GCC"],
                        },
                        "alphamissense": {
                            "pred": ["P", "P", "P", "P"],
                            "rankscore": 0.95577,
                            "score": [0.9951, 0.9862, 0.9951, 0.7008],
                        },
                        "alt": "A",
                        "ancestral_allele": "G",
                        "appris": ["alternative1", "principal4"],
                        "bayesdel": {
                            "add_af": {
                                "pred": "D",
                                "rankscore": 0.91206,
                                "score": 0.42359,
                            },
                            "no_af": {
                                "pred": "D",
                                "rankscore": 0.91097,
                                "score": 0.370681,
                            },
                        },
                        "bstatistic": {
                            "converted_rankscore": 0.57054,
                            "score": 707.0,
                        },
                        "chrom": "12",
                        "clinpred": {
                            "pred": "D",
                            "rankscore": 0.81922,
                            "score": 0.991609394550323,
                        },
                        "clinvar": {
                            "clinvar_id": "1695421",
                            "clnsig": "Pathogenic",
                            "hgvs": "NC_000012.12:g.25245332G>A",
                            "medgen": "C1860991",
                            "omim": "609942",
                            "orphanet": "648",
                            "review": "criteria_provided,_single_submitter",
                            "trait": "Noonan_syndrome_3",
                        },
                        "dann": {"rankscore": 0.98518, "score": 0.999173161627483},
                        "deogen2": {
                            "pred": "D",
                            "rankscore": 0.97794,
                            "score": 0.891291,
                        },
                        "eigen": {
                            "phred_coding": 14.91392,
                            "raw_coding": 1.03070516408223,
                            "raw_coding_rankscore": 0.96612,
                        },
                        "eigen-pc": {
                            "phred_coding": 17.52826,
                            "raw_coding": 0.97751439147273,
                            "raw_coding_rankscore": 0.98143,
                        },
                        "ensembl": {
                            "geneid": [
                                "ENSG00000133703",
                                "ENSG00000133703",
                                "ENSG00000133703",
                                "ENSG00000133703",
                            ],
                            "proteinid": [
                                "ENSP00000308495",
                                "ENSP00000452512",
                                "ENSP00000256078",
                                "ENSP00000451856",
                            ],
                            "transcriptid": [
                                "ENST00000311936",
                                "ENST00000557334",
                                "ENST00000256078",
                                "ENST00000556131",
                            ],
                        },
                        "esm1b": {
                            "pred": ["D", "D"],
                            "rankscore": 0.98564,
                            "score": [-16.632, -16.115],
                        },
                        "eve": {
                            "class10_pred": "U",
                            "class20_pred": "U",
                            "class25_pred": "U",
                            "class30_pred": "U",
                            "class40_pred": "U",
                            "class50_pred": "U",
                            "class60_pred": "U",
                            "class70_pred": "U",
                            "class75_pred": "P",
                            "class80_pred": "P",
                            "class90_pred": "P",
                            "rankscore": 0.72008,
                            "score": 0.6483115419004939,
                        },
                        "fathmm": {
                            "converted_rankscore": 0.80387,
                            "pred": ["T", "T", "T", "T"],
                            "score": [-1.39, -0.53, -0.53, -0.53],
                        },
                        "fathmm-mkl": {
                            "coding_group": "AEFBI",
                            "coding_pred": "D",
                            "coding_rankscore": 0.88157,
                            "coding_score": 0.98885,
                        },
                        "fathmm-xf": {
                            "coding_pred": "D",
                            "coding_rankscore": 0.85047,
                            "coding_score": 0.902509,
                        },
                        "fitcons": {
                            "gm12878": {
                                "confidence_value": 0,
                                "rankscore": 0.81188,
                                "score": 0.709663,
                            },
                            "h1-hesc": {
                                "confidence_value": 0,
                                "rankscore": 0.96076,
                                "score": 0.743671,
                            },
                            "huvec": {
                                "confidence_value": 0,
                                "rankscore": 0.4955,
                                "score": 0.631631,
                            },
                            "integrated": {
                                "confidence_value": 0,
                                "rankscore": 0.92422,
                                "score": 0.732398,
                            },
                        },
                        "gencode_basic": ["Y", "Y", "Y", "Y"],
                        "genename": ["KRAS", "KRAS", "KRAS", "KRAS"],
                        "genocanyon": {"rankscore": 0.98316, "score": 1.0},
                        "gerp++": {"nr": 5.68, "rs": 5.68, "rs_rankscore": 0.88021},
                        "gmvp": {"rankscore": 0.96401, "score": 0.9641457346713307},
                        "hg18": {"end": 25289533, "start": 25289533},
                        "hg19": {"end": 25398266, "start": 25398266},
                        "hg38": {"end": 25245332, "start": 25245332},
                        "hgvsc": "c.53C>T",
                        "hgvsp": ["p.Ala18Val", "p.A18V"],
                        "interpro": {
                            "domain": [
                                "Small GTP-binding protein domain",
                                "Small GTP-binding protein domain",
                            ]
                        },
                        "list-s2": {
                            "pred": ["D", "D", "D", "D"],
                            "rankscore": 0.94559,
                            "score": [0.979335, 0.981385, 0.979335, 0.984002],
                        },
                        "lrt": {
                            "converted_rankscore": 0.8433,
                            "omega": 0.0,
                            "pred": "D",
                            "score": 0.0,
                        },
                        "m-cap": {
                            "pred": "D",
                            "rankscore": 0.88087,
                            "score": 0.227357,
                        },
                        "metalr": {
                            "pred": "D",
                            "rankscore": 0.91865,
                            "score": 0.7611,
                        },
                        "metarnn": {
                            "pred": ["D", "D", "D", "D"],
                            "rankscore": 0.90261,
                            "score": [0.9089627, 0.9089627, 0.9089627, 0.9089627],
                        },
                        "metasvm": {
                            "pred": "D",
                            "rankscore": 0.93471,
                            "score": 0.7239,
                        },
                        "mpc": {"rankscore": 0.985, "score": 2.6732094712},
                        "mutationassessor": {
                            "pred": ["M", "M"],
                            "rankscore": 0.76484,
                            "score": [2.615, 2.615],
                        },
                        "mutationtaster": {
                            "aae": ["A18V", "A18V", "A18V", "A18V"],
                            "converted_rankscore": 0.81001,
                            "model": [
                                "simple_aae",
                                "simple_aae",
                                "simple_aae",
                                "simple_aae",
                            ],
                            "pred": ["D", "D", "D", "D"],
                            "score": [1.0, 1.0, 1.0, 1.0],
                        },
                        "mutpred": {
                            "aa_change": ["A18V", "A18V", "A18V", "A18V"],
                            "accession": ["P01116", "P01116", "P01116", "P01116"],
                            "pred": [
                                {
                                    "mechanism": "Gain of catalytic residue at S17",
                                    "p_val": 0.0,
                                },
                                {
                                    "mechanism": "Gain of catalytic residue at S17",
                                    "p_val": 0.0,
                                },
                                {
                                    "mechanism": "Gain of catalytic residue at S17",
                                    "p_val": 0.0,
                                },
                                {
                                    "mechanism": "Gain of catalytic residue at S17",
                                    "p_val": 0.0,
                                },
                            ],
                            "rankscore": 0.87821,
                            "score": [0.747, 0.747, 0.747, 0.747],
                        },
                        "mvp": {
                            "rankscore": 0.98622,
                            "score": [
                                0.986379006677,
                                0.986379006677,
                                0.986379006677,
                                0.986379006677,
                            ],
                        },
                        "phastcons": {
                            "100way_vertebrate": {
                                "rankscore": 0.71638,
                                "score": 1.0,
                            },
                            "17way_primate": {"rankscore": 0.97212, "score": 1.0},
                            "470way_mammalian": {
                                "rankscore": 0.68203,
                                "score": 1.0,
                            },
                        },
                        "phylop": {
                            "100way_vertebrate": {
                                "rankscore": 0.99183,
                                "score": 9.985,
                            },
                            "17way_primate": {"rankscore": 0.53741, "score": 0.654},
                            "470way_mammalian": {
                                "rankscore": 0.98601,
                                "score": 11.872,
                            },
                        },
                        "polyphen2": {
                            "hdiv": {
                                "pred": ["D", "D"],
                                "rankscore": 0.90584,
                                "score": [0.999, 1.0],
                            },
                            "hvar": {
                                "pred": ["P", "D"],
                                "rankscore": 0.74104,
                                "score": [0.893, 0.978],
                            },
                        },
                        "primateai": {
                            "pred": "D",
                            "rankscore": 0.94572,
                            "score": 0.884602069855,
                        },
                        "provean": {
                            "converted_rankscore": 0.7224,
                            "pred": ["D", "D", "D", "D"],
                            "score": [-3.31, -3.84, -3.21, -3.81],
                        },
                        "ref": "G",
                        "reliability_index": 10,
                        "revel": {
                            "rankscore": 0.94989,
                            "score": [0.84, 0.84, 0.84, 0.84],
                        },
                        "rsid": "rs2135806030",
                        "sift": {
                            "converted_rankscore": 0.7849,
                            "pred": ["D", "D", "D", "D"],
                            "score": [0.001, 0.001, 0.001, 0.001],
                        },
                        "sift4g": {
                            "converted_rankscore": 0.83351,
                            "pred": ["D", "D", "D", "D"],
                            "score": [0.001, 0.001, 0.001, 0.001],
                        },
                        "siphy_29way": {
                            "logodds_rankscore": 0.90353,
                            "logodds_score": 18.3719,
                            "pi": {"a": 0.0, "c": 0.0, "g": 1.0, "t": 0.0},
                        },
                        "tsl": [1, 5, 1, 1],
                        "uniprot": [
                            {"acc": "P01116-2", "entry": "RASK_HUMAN"},
                            {"acc": "G3V5T7", "entry": "G3V5T7_HUMAN"},
                            {"acc": "P01116", "entry": "RASK_HUMAN"},
                            {"acc": "G3V4K2", "entry": "G3V4K2_HUMAN"},
                        ],
                        "varity": {
                            "er": {"rankscore": 0.99266, "score": 0.96570957},
                            "er_loo": {"rankscore": 0.99266, "score": 0.96570957},
                            "r": {"rankscore": 0.99706, "score": 0.98890454},
                            "r_loo": {"rankscore": 0.99706, "score": 0.98890454},
                        },
                        "vep_canonical": "YES",
                        "vest4": {
                            "rankscore": 0.93959,
                            "score": [0.906, 0.89, 0.934, 0.906],
                        },
                    },
                    "dbsnp": {
                        "_license": "http://bit.ly/2AqoLOc",
                        "alt": "A",
                        "chrom": "12",
                        "dbsnp_build": 156,
                        "gene": {
                            "geneid": 3845,
                            "is_pseudo": False,
                            "name": "KRAS proto-oncogene, GTPase",
                            "rnas": [
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "GCC",
                                        "inserted_sequence": "GCC",
                                        "position": 228,
                                        "seq_id": "NM_001369786.1",
                                    },
                                    "hgvs": "NM_001369786.1:c.53=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "A",
                                                "inserted_sequence": "A",
                                                "position": 17,
                                                "seq_id": "NP_001356715.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_001356715.1"},
                                    "refseq": "NM_001369786.1",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "GCC",
                                        "inserted_sequence": "GCC",
                                        "position": 228,
                                        "seq_id": "NM_001369787.1",
                                    },
                                    "hgvs": "NM_001369787.1:c.53=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "A",
                                                "inserted_sequence": "A",
                                                "position": 17,
                                                "seq_id": "NP_001356716.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_001356716.1"},
                                    "refseq": "NM_001369787.1",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "GCC",
                                        "inserted_sequence": "GCC",
                                        "position": 241,
                                        "seq_id": "NM_004985.5",
                                    },
                                    "hgvs": "NM_004985.5:c.53=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "A",
                                                "inserted_sequence": "A",
                                                "position": 17,
                                                "seq_id": "NP_004976.2",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_004976.2"},
                                    "refseq": "NM_004985.5",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "GCC",
                                        "inserted_sequence": "GCC",
                                        "position": 241,
                                        "seq_id": "NM_033360.4",
                                    },
                                    "hgvs": "NM_033360.4:c.53=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "A",
                                                "inserted_sequence": "A",
                                                "position": 17,
                                                "seq_id": "NP_203524.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_203524.1"},
                                    "refseq": "NM_033360.4",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "GCC",
                                        "inserted_sequence": "GCC",
                                        "position": 228,
                                        "seq_id": "XM_047428826.1",
                                    },
                                    "hgvs": "XM_047428826.1:c.53=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "A",
                                                "inserted_sequence": "A",
                                                "position": 17,
                                                "seq_id": "XP_047284782.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "XP_047284782.1"},
                                    "refseq": "XM_047428826.1",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                            ],
                            "strand": "-",
                            "symbol": "KRAS",
                        },
                        "hg19": {"end": 25398266, "start": 25398266},
                        "ref": "G",
                        "rsid": "rs2135806030",
                        "vartype": "snv",
                    },
                    "hg19": {"end": 25398266, "start": 25398266},
                    "observed": True,
                    "snpeff": {
                        "_license": "http://bit.ly/2suyRKt",
                        "ann": [
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4L8G:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LDJ:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LPK:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LPK:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LUC:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LUC:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LV6:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LV6:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LYF:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LYF:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LYF:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LYH:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LYH:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LYH:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1O:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1O:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1O:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1S:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1S:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1S:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1T:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1T:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1T:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1W:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1W:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1W:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1Y:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1Y:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M1Y:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M21:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M21:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M21:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M22:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M22:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4M22:C_18-C_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4OBE:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4OBE:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4PZZ:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4Q01:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4Q01:B_18-B_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4Q03:A_18-A_146:NM_033360.3",
                                "feature_type": "interaction",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "putative_impact": "HIGH",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "cdna": {"length": "5889", "position": "245"},
                                "cds": {"length": "570", "position": "53"},
                                "effect": "missense_variant",
                                "feature_id": "NM_033360.3",
                                "feature_type": "transcript",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "hgvs_p": "p.Ala18Val",
                                "protein": {"length": "189", "position": "18"},
                                "putative_impact": "MODERATE",
                                "rank": "2",
                                "total": "6",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "cdna": {"length": "5765", "position": "245"},
                                "cds": {"length": "567", "position": "53"},
                                "effect": "missense_variant",
                                "feature_id": "NM_004985.4",
                                "feature_type": "transcript",
                                "gene_id": "KRAS",
                                "genename": "KRAS",
                                "hgvs_c": "c.53C>T",
                                "hgvs_p": "p.Ala18Val",
                                "protein": {"length": "188", "position": "18"},
                                "putative_impact": "MODERATE",
                                "rank": "2",
                                "total": "5",
                                "transcript_biotype": "protein_coding",
                            },
                        ],
                    },
                    "vcf": {"alt": "A", "position": "25398266", "ref": "G"},
                },
            },
            "indicator_query_resp": {
                "allele_exist": True,
                "data_version": "v4.22",
                "diagnostic_implications": [
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "description": "",
                        "level_of_evidence": "LEVEL_Dx3",
                        "pmids": ["22237106"],
                        "tumor_type": {
                            "id": 857,
                            "code": "ETPLL",
                            "name": "Early T-Cell Precursor Lymphoblastic Leukemia",
                            "main_type": {
                                "id": None,
                                "name": "T-Lymphoblastic Leukemia/Lymphoma",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Lymphoid",
                            "children": {},
                            "parent": "TLL",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "description": "",
                        "level_of_evidence": "LEVEL_Dx2",
                        "pmids": [
                            "10049057",
                            "23832011",
                            "25691160",
                            "26457647",
                            "12717436",
                        ],
                        "tumor_type": {
                            "id": 692,
                            "code": "JMML",
                            "name": "Juvenile Myelomonocytic Leukemia",
                            "main_type": {
                                "id": None,
                                "name": "Myelodysplastic/Myeloproliferative Neoplasms",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "MDS/MPN",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "description": "",
                        "level_of_evidence": "LEVEL_Dx2",
                        "pmids": ["22934674", "23512829"],
                        "tumor_type": {
                            "id": 355,
                            "code": "MDS",
                            "name": "Myelodysplastic Syndromes",
                            "main_type": {
                                "id": None,
                                "name": "Myelodysplastic Syndromes",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "MNM",
                            "level": 3,
                            "tumor_form": "LIQUID",
                        },
                    },
                ],
                "diagnostic_summary": "",
                "gene_exist": True,
                "gene_summary": "KRAS, a GTPase which functions as an upstream regulator of the MAPK pathway, is frequently mutated in various cancer types including lung, colorectal and pancreatic cancers.",
                "highest_diagnostic_implication_level": "LEVEL_Dx2",
                "highest_fda_level": "LEVEL_Fda2",
                "highest_prognostic_implication_level": None,
                "highest_resistance_level": "LEVEL_R1",
                "highest_sensitive_level": "LEVEL_2",
                "hotspot": False,
                "last_update": "02/24/2023",
                "mutation_effect": {
                    "citations": {
                        "abstracts": [],
                        "pmids": ["23319568", "26648538", "19490892", "25207766"],
                    },
                    "description": "The KRAS A18V mutation has not specifically been reviewed by the OncoKB team. However, the mutation effect description for KRAS A18D, an alternate allele of KRAS A18V, is: The KRAS A18D mutation is located in the catalytic G-domain of the protein. This mutation has been found in leukemia (PMID: 26648538, 23319568, 25207766). Expression of this mutation in a fibroblast cell line and in Ba/F3 cells demonstrated that it is activating, as measured by increased IL3-independent proliferation and colony-formation compared to wildtype (PMID: 19490892).",
                    "known_effect": "Likely Gain-of-function",
                },
                "oncogenic": "Likely Oncogenic",
                "other_significant_resistance_levels": [],
                "other_significant_sensitive_levels": [],
                "prognostic_implications": [],
                "prognostic_summary": "",
                "query": {
                    "alteration": "A18V",
                    "alteration_type": None,
                    "consequence": "missense_variant",
                    "entrez_gene_id": 3845,
                    "hgvs": None,
                    "hugo_symbol": "KRAS",
                    "id": None,
                    "protein_end": 18,
                    "protein_start": 18,
                    "reference_genome": "GRCh37",
                    "sv_type": None,
                    "tumor_type": None,
                },
                "treatments": [
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Cetuximab and panitumumab are anti-EGFR monoclonal antibodies that are FDA-approved for patients with EGFR expressing, RAS-wildtype colorectal cancer. Patients with metastatic colorectal cancer (mCRC) harboring either exon 2 (e.g. G12, G13) or non-exon 2 (e.g Q61, K117, A146) KRAS mutations do not respond favorably to the anti-EGFR therapies cetuximab (PMID: 21228335, 20619739) or panitumumab (PMID: 18316791, 20921465, 24024839).",
                        "drugs": [
                            {
                                "drug_name": "Cetuximab",
                                "ncit_code": "C1723",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda2",
                        "level": "LEVEL_R1",
                        "level_associated_cancer_type": {
                            "id": 935,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "Colorectal Cancer",
                                "tumor_form": "SOLID",
                            },
                            "tissue": "Bowel",
                            "children": {},
                            "parent": None,
                            "level": 0,
                            "tumor_form": "SOLID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": [
                            "20921465",
                            "21228335",
                            "20619739",
                            "24024839",
                            "18316791",
                        ],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Cetuximab and panitumumab are anti-EGFR monoclonal antibodies that are FDA-approved for patients with EGFR expressing, RAS-wildtype colorectal cancer. Patients with metastatic colorectal cancer (mCRC) harboring either exon 2 (e.g. G12, G13) or non-exon 2 (e.g Q61, K117, A146) KRAS mutations do not respond favorably to the anti-EGFR therapies cetuximab (PMID: 21228335, 20619739) or panitumumab (PMID: 18316791, 20921465, 24024839).",
                        "drugs": [
                            {
                                "drug_name": "Panitumumab",
                                "ncit_code": "C1857",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda2",
                        "level": "LEVEL_R1",
                        "level_associated_cancer_type": {
                            "id": 935,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "Colorectal Cancer",
                                "tumor_form": "SOLID",
                            },
                            "tissue": "Bowel",
                            "children": {},
                            "parent": None,
                            "level": 0,
                            "tumor_form": "SOLID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": [
                            "20921465",
                            "21228335",
                            "20619739",
                            "24024839",
                            "18316791",
                        ],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Tucatinib, a small molecular inhibitor of HER2, and trastuzumab, a HER2-targeted antibody, are FDA-approved in combination for the treatment of patients with HER2 amplified metastatic colorectal cancer whose tumors are also RAS and BRAF wildtype. Patients with metastatic colorectal cancer harboring KRAS mutations do not respond favorably to trastuzumab as seen in the MyPath trial. In the multiple basket MyPath Phase IIa trial of pertuzumab and trastuzumab in which 56 metastatic colorectal cancer patients with HER2 amplification received combination therapy, the objective response rate for patients with KRAS wildtype colorectal cancer (43/56 patients) compared to KRAS mutated colorectal cancer (13/56 patients) was 40% (17/43, 95% CI, 25%–56%) versus 8% (1/13, 95% CI 0.2%–36%), respectively (PMID: 30857956).",
                        "drugs": [
                            {
                                "drug_name": "Tucatinib",
                                "ncit_code": "C77896",
                                "uuid": None,
                                "synonyms": None,
                            },
                            {
                                "drug_name": "Trastuzumab",
                                "ncit_code": "C1647",
                                "uuid": None,
                                "synonyms": None,
                            },
                        ],
                        "fda_level": "LEVEL_Fda2",
                        "level": "LEVEL_R1",
                        "level_associated_cancer_type": {
                            "id": 935,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "Colorectal Cancer",
                                "tumor_form": "SOLID",
                            },
                            "tissue": "Bowel",
                            "children": {},
                            "parent": None,
                            "level": 0,
                            "tumor_form": "SOLID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["30857956"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with Erdheim-Chester Disease (ECD). In an open-label, phase II trial (NCT02649972) of cobimetinib in eighteen adult patients with histiocytoses of any mutational status (n = 12/18 patients with ECD, n = 1/12 patients with KRAS R149G, n = 1/12 patients with KRAS G12R), the overall response rate was 89% (90% CI= 73–100), 100% of responses were ongoing at one year, and 94% of patients remained progression-free (PMID: 30867592).",
                        "drugs": [
                            {
                                "drug_name": "Cobimetinib",
                                "ncit_code": "C68923",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_2",
                        "level_associated_cancer_type": {
                            "id": 611,
                            "code": "ECD",
                            "name": "Erdheim-Chester Disease",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "HDCN",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["30867592"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with Langerhans Cell Histiocytosis (LCH). In an open-label, phase II trial (NCT02649972) of cobimetinib in eighteen adult patients with histiocytoses of any mutational status (n = 2/18 patients with LCH, n = 1/2 patients with KRAS G13C), the overall response rate was 89% (90% CI= 73–100), 100% of responses were ongoing at one year, and 94% of patients remained progression-free (PMID: 30867592). In a study of three patients with LCH who were treated with trametinib, two patients harbored BRAF N486_P490del mutations, of which one had no reactivation and the other had a partial response, and the third patient with a MEK1 K57_G61del mutation had a complete response with no active disease after 22 months (PMID: 32991018).",
                        "drugs": [
                            {
                                "drug_name": "Cobimetinib",
                                "ncit_code": "C68923",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_2",
                        "level_associated_cancer_type": {
                            "id": 862,
                            "code": "LCH",
                            "name": "Langerhans Cell Histiocytosis",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "HDCN",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["32991018", "30867592"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with Rosai-Dorfman Disease. One adult patient with Rosai-Dorfman Disease with an activating KRAS G12R mutation was treated with cobimetinib and a follow-up CT scan two months after treatment showed a substantial response (PMID: 29236635).",
                        "drugs": [
                            {
                                "drug_name": "Cobimetinib",
                                "ncit_code": "C68923",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_2",
                        "level_associated_cancer_type": {
                            "id": 367,
                            "code": "RDD",
                            "name": "Rosai-Dorfman Disease",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "HDCN",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["29236635"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with Erdheim-Chester Disease (ECD). In an open-label, phase II trial (NCT02649972) of cobimetinib in eighteen adult patients with histiocytoses of any mutational status (n = 12/18 patients with ECD, n = 1/12 patients with KRAS R149G, n = 1/12 patients with KRAS G12R), the overall response rate was 89% (90% CI= 73–100), 100% of responses were ongoing at one year, and 94% of patients remained progression-free (PMID: 30867592).",
                        "drugs": [
                            {
                                "drug_name": "Trametinib",
                                "ncit_code": "C77908",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_2",
                        "level_associated_cancer_type": {
                            "id": 611,
                            "code": "ECD",
                            "name": "Erdheim-Chester Disease",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "HDCN",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["30867592"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with Langerhans Cell Histiocytosis (LCH). In an open-label, phase II trial (NCT02649972) of cobimetinib in eighteen adult patients with histiocytoses of any mutational status (n = 2/18 patients with LCH, n = 1/2 patients with KRAS G13C), the overall response rate was 89% (90% CI= 73–100), 100% of responses were ongoing at one year, and 94% of patients remained progression-free (PMID: 30867592). In a study of three patients with LCH who were treated with trametinib, two patients harbored BRAF N486_P490del mutations, of which one had no reactivation and the other had a partial response, and the third patient with a MEK1 K57_G61del mutation had a complete response with no active disease after 22 months (PMID: 32991018).",
                        "drugs": [
                            {
                                "drug_name": "Trametinib",
                                "ncit_code": "C77908",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_2",
                        "level_associated_cancer_type": {
                            "id": 862,
                            "code": "LCH",
                            "name": "Langerhans Cell Histiocytosis",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "HDCN",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["32991018", "30867592"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with Rosai-Dorfman Disease. One adult patient with Rosai-Dorfman Disease with an activating KRAS G12R mutation was treated with cobimetinib and a follow-up CT scan two months after treatment showed a substantial response (PMID: 29236635).",
                        "drugs": [
                            {
                                "drug_name": "Trametinib",
                                "ncit_code": "C77908",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_2",
                        "level_associated_cancer_type": {
                            "id": 367,
                            "code": "RDD",
                            "name": "Rosai-Dorfman Disease",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": "HDCN",
                            "level": 4,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["29236635"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with histiocytic neoplasms harboring MAPK pathway mutations. In a Phase II trial of cobimetinib in eighteen patients with histiocytoses, the overall response rate was 89%, with 13/18 patients (72%) having a complete response and 15/18 patients harboring a MAPK pathway mutation (PMID: 30867592). All three patients harboring KRAS mutations had a partial or complete response to treatment with cobimetinib (PMID: 30867592). Small case studies have also demonstrated the clinical efficacy of MEK inhibition in patients with histiocytic neoplasms (PMID: 29236635). In a case study of one eighteen-year-old patient with refractory histiocytic sarcoma harboring a pathogenic variant of MAP2K1 (F53L), the patient was treated with trametinib and showed an excellent response prior to treatment interruption due to severe adverse events (PMID: 30361829).",
                        "drugs": [
                            {
                                "drug_name": "Cobimetinib",
                                "ncit_code": "C68923",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_3A",
                        "level_associated_cancer_type": {
                            "id": 934,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": None,
                            "level": 0,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["30361829", "29236635", "30867592"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib and cobimetinib are MEK1/2 kinase inhibitors that are FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations and are NCCN-listed for patients with histiocytic neoplasms harboring MAPK pathway mutations. In a Phase II trial of cobimetinib in eighteen patients with histiocytoses, the overall response rate was 89%, with 13/18 patients (72%) having a complete response and 15/18 patients harboring a MAPK pathway mutation (PMID: 30867592). All three patients harboring KRAS mutations had a partial or complete response to treatment with cobimetinib (PMID: 30867592). Small case studies have also demonstrated the clinical efficacy of MEK inhibition in patients with histiocytic neoplasms (PMID: 29236635). In a case study of one eighteen-year-old patient with refractory histiocytic sarcoma harboring a pathogenic variant of MAP2K1 (F53L), the patient was treated with trametinib and showed an excellent response prior to treatment interruption due to severe adverse events (PMID: 30361829).",
                        "drugs": [
                            {
                                "drug_name": "Trametinib",
                                "ncit_code": "C77908",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_3A",
                        "level_associated_cancer_type": {
                            "id": 934,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "Histiocytosis",
                                "tumor_form": "LIQUID",
                            },
                            "tissue": "Myeloid",
                            "children": {},
                            "parent": None,
                            "level": 0,
                            "tumor_form": "LIQUID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["30361829", "29236635", "30867592"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib, cobimetinib, and binimetinib are MEK1/2 kinase inhibitors that are NCCN-listed and FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations. In a multicenter, single-arm, open-label, phase IB trial (NCT02964689) of binimetinib in combination with cisplatin and pemetrexed in fourteen evaluable patients with stage III-IV NSCLC with KRAS (codon 12, 13 or 61) mutations, the overall response rate was 33% (95% CI=7–70) among the nine patients that received binimetinib, where three of nine patients had a partial response, two of nine had stable disease, three of nine had progressive disease, and one of nine was not assessable for response (PMID: 33933896). On average, in vitro studies have shown that trametinib inhibits the proliferation of KRAS mutant cancer cell lines (n = 50) with lower IC50s than other MEK inhibitors, including selumetinib (PMID: 24746704). Cobimetinib, which inhibits the kinase activity of MEK but allows the induction of RAF-dependent feedback phosphorylation of MEK, was demonstrated to be less effective in KRAS-mutant tumors than in BRAF-mutant tumors (PMID: 25435214, 23934108).",
                        "drugs": [
                            {
                                "drug_name": "Trametinib",
                                "ncit_code": "C77908",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_4",
                        "level_associated_cancer_type": {
                            "id": 984,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "All Solid Tumors",
                                "tumor_form": "SOLID",
                            },
                            "tissue": "",
                            "children": {},
                            "parent": None,
                            "level": -1,
                            "tumor_form": "SOLID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["33933896", "25435214", "24746704", "23934108"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib, cobimetinib, and binimetinib are MEK1/2 kinase inhibitors that are NCCN-listed and FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations. In a multicenter, single-arm, open-label, phase IB trial (NCT02964689) of binimetinib in combination with cisplatin and pemetrexed in fourteen evaluable patients with stage III-IV NSCLC with KRAS (codon 12, 13 or 61) mutations, the overall response rate was 33% (95% CI=7–70) among the nine patients that received binimetinib, where three of nine patients had a partial response, two of nine had stable disease, three of nine had progressive disease, and one of nine was not assessable for response (PMID: 33933896). On average, in vitro studies have shown that trametinib inhibits the proliferation of KRAS mutant cancer cell lines (n = 50) with lower IC50s than other MEK inhibitors, including selumetinib (PMID: 24746704). Cobimetinib, which inhibits the kinase activity of MEK but allows the induction of RAF-dependent feedback phosphorylation of MEK, was demonstrated to be less effective in KRAS-mutant tumors than in BRAF-mutant tumors (PMID: 25435214, 23934108).",
                        "drugs": [
                            {
                                "drug_name": "Cobimetinib",
                                "ncit_code": "C68923",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_4",
                        "level_associated_cancer_type": {
                            "id": 984,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "All Solid Tumors",
                                "tumor_form": "SOLID",
                            },
                            "tissue": "",
                            "children": {},
                            "parent": None,
                            "level": -1,
                            "tumor_form": "SOLID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["33933896", "25435214", "24746704", "23934108"],
                    },
                    {
                        "abstracts": [],
                        "alterations": ["Oncogenic Mutations"],
                        "approved_indications": [],
                        "description": "Trametinib, cobimetinib, and binimetinib are MEK1/2 kinase inhibitors that are NCCN-listed and FDA-approved for patients with unresectable or metastatic melanoma with BRAF V600E or V600K mutations. In a multicenter, single-arm, open-label, phase IB trial (NCT02964689) of binimetinib in combination with cisplatin and pemetrexed in fourteen evaluable patients with stage III-IV NSCLC with KRAS (codon 12, 13 or 61) mutations, the overall response rate was 33% (95% CI=7–70) among the nine patients that received binimetinib, where three of nine patients had a partial response, two of nine had stable disease, three of nine had progressive disease, and one of nine was not assessable for response (PMID: 33933896). On average, in vitro studies have shown that trametinib inhibits the proliferation of KRAS mutant cancer cell lines (n = 50) with lower IC50s than other MEK inhibitors, including selumetinib (PMID: 24746704). Cobimetinib, which inhibits the kinase activity of MEK but allows the induction of RAF-dependent feedback phosphorylation of MEK, was demonstrated to be less effective in KRAS-mutant tumors than in BRAF-mutant tumors (PMID: 25435214, 23934108).",
                        "drugs": [
                            {
                                "drug_name": "Binimetinib",
                                "ncit_code": "C84865",
                                "uuid": None,
                                "synonyms": None,
                            }
                        ],
                        "fda_level": "LEVEL_Fda3",
                        "level": "LEVEL_4",
                        "level_associated_cancer_type": {
                            "id": 984,
                            "code": "",
                            "name": "",
                            "main_type": {
                                "id": None,
                                "name": "All Solid Tumors",
                                "tumor_form": "SOLID",
                            },
                            "tissue": "",
                            "children": {},
                            "parent": None,
                            "level": -1,
                            "tumor_form": "SOLID",
                        },
                        "level_excluded_cancer_types": [],
                        "pmids": ["33933896", "25435214", "24746704", "23934108"],
                    },
                ],
                "tumor_type_summary": "",
                "variant_exist": False,
                "variant_summary": "The KRAS A18V mutation has not specifically been reviewed by the OncoKB team. However, KRAS A18D is likely oncogenic, and therefore KRAS A18V is considered likely oncogenic.",
                "vus": False,
            },
            "transcript_feature_range_annotations": [
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_001369787.1",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25358179,
                            "end": 25405363,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25358179,
                                "end": 25362845,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403697,
                                "end": 25403863,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403697,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403863,
                            "end": 25405363,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_033360.2",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25358179,
                            "end": 25405354,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25358179,
                                "end": 25362845,
                                "name": "exon 6",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368370,
                                "end": 25368494,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403684,
                                "end": 25403854,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25368370,
                                "name": "intron 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368494,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403684,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403854,
                            "end": 25405354,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_001369786.1",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25358179,
                            "end": 25405363,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25358179,
                                "end": 25362845,
                                "name": "exon 6",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368370,
                                "end": 25368494,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403697,
                                "end": 25403863,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25368370,
                                "name": "intron 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368494,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403697,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403863,
                            "end": 25405363,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_033360.3",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25357722,
                            "end": 25405365,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25357722,
                                "end": 25362845,
                                "name": "exon 6",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368370,
                                "end": 25368494,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403684,
                                "end": 25403865,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25368370,
                                "name": "intron 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368494,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403684,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403865,
                            "end": 25405365,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_004985.4",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25357722,
                            "end": 25405365,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25357722,
                                "end": 25362845,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403684,
                                "end": 25403865,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403684,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403865,
                            "end": 25405365,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_033360.4",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25358179,
                            "end": 25405363,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25358179,
                                "end": 25362845,
                                "name": "exon 6",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368370,
                                "end": 25368494,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403684,
                                "end": 25403863,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25368370,
                                "name": "intron 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25368494,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403684,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403863,
                            "end": 25405363,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_004985.5",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25358179,
                            "end": 25405363,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25358179,
                                "end": 25362845,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403684,
                                "end": 25403863,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403684,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403863,
                            "end": 25405363,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
                {
                    "range": {
                        "ac": "NC_000012.11",
                        "start": 25398266,
                        "end": 25398266,
                        "name": "",
                    },
                    "transcript_features": {
                        "tx_ac": "NM_004985.3",
                        "genome_ac": "NC_000012.11",
                        "strand": -1,
                        "body": {
                            "ac": "NC_000012.11",
                            "start": 25358179,
                            "end": 25405354,
                            "name": "Gene body",
                        },
                        "exons": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25358179,
                                "end": 25362845,
                                "name": "exon 5",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378547,
                                "end": 25378707,
                                "name": "exon 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380167,
                                "end": 25380346,
                                "name": "exon 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398207,
                                "end": 25398329,
                                "name": "exon 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25403684,
                                "end": 25403854,
                                "name": "exon 1",
                            },
                        ],
                        "introns": [
                            {
                                "ac": "NC_000012.11",
                                "start": 25362845,
                                "end": 25378547,
                                "name": "intron 4",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25378707,
                                "end": 25380167,
                                "name": "intron 3",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25380346,
                                "end": 25398207,
                                "name": "intron 2",
                            },
                            {
                                "ac": "NC_000012.11",
                                "start": 25398329,
                                "end": 25403684,
                                "name": "intron 1",
                            },
                        ],
                        "promoter": {
                            "ac": "NC_000012.11",
                            "start": 25403854,
                            "end": 25405354,
                            "name": "promoter",
                        },
                    },
                    "start_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                    "end_feature": {
                        "ac": "NC_000012.11",
                        "start": 25398207,
                        "end": 25398329,
                        "name": "exon 2",
                    },
                },
            ],
            "meta": {
                "cpra": {"chrom": "chr12", "pos": 25398266, "ref": "G", "alt": "A"},
                "cspra": {
                    "ac": "NC_000012.11",
                    "pos": 25398266,
                    "ref": "G",
                    "alt": "A",
                    "chrom": "chr12",
                },
                "alt_aln_method": "splign",
                "tss_upstream_limit": 20000,
                "uncertain": False,
                "promoter_tss_upstream_offset": 1500,
            },
        }
        cls.snv_annotation_deserializer = SnvAnnotationDeserializer()

    def test_deeserialize(self):
        snv_annotation = self.snv_annotation_deserializer.deserialize(data=self.data)
        self.assertTrue(isinstance(snv_annotation, SnvAnnotation))
