"""Test CpraGrch37Annotator class with EGFR E746_A750del."""

import unittest

from pyoncokb.models.indicatorqueryresp import IndicatorQueryResp
from pyoncokb.models.indicatorquerytreatment import IndicatorQueryTreatment
from pyoncokb.oncokbapi import OncokbApi
from snvannotators.cpraannotators.cpragrch37annotator import CpraGrch37Annotator
from snvannotators.hgvsplus.annotators.hgvsannotation import HgvsAnnotation
from snvannotators.hgvsplus.models import HgvsG, HgvsP, HgvsT
from snvannotators.myvariant.annotation import MyvariantAnnotation
from snvmodels.cpra import Cpra

from tests.testconfig import TestConfig


class CpraGrch37AnnotatorEgfrE746a750delTestCase(unittest.TestCase):
    """Test CpraGrch37Annotator class with EGFR E746_A750del."""

    @classmethod
    def setUpClass(cls) -> None:
        super().setUpClass()
        config = TestConfig()
        cpra = Cpra(chrom="chr7", pos=55242464, ref="AGGAATTAAGAGAAGC", alt="A")
        oncokb_auth = config.get_oncokb_authorization()
        oncokb_api = OncokbApi(auth=oncokb_auth)
        cpra_annotator = CpraGrch37Annotator(
            cpra=cpra,
            oncokb_api=oncokb_api,
            alt_aln_method="splign",
            tss_upstream_limit=20000,
            uncertain=False,
            promoter_tss_upstream_offset=1500,
        )
        snv_annotation = cpra_annotator.annotate()
        cls.indicator_query_resp = snv_annotation.indicator_query_resp
        cls.myvariant_annotation = snv_annotation.myvariant_annotation
        cls.hgvs_annotation = snv_annotation.hgvs_annotation
        cls.transcript_feature_range_annotations = (
            snv_annotation.transcript_feature_range_annotations
        )
        cls.tx_ac = "NM_005228.3"

    def test_hgvs_annotation(self):
        self.assertTrue(isinstance(self.hgvs_annotation, HgvsAnnotation))

    def test_hgvs_annotation_hgvs_g(self):
        self.assertTrue(isinstance(self.hgvs_annotation.hgvs_g, HgvsG))
        self.assertEqual(
            str(self.hgvs_annotation.hgvs_g), "NC_000007.13:g.55242464_55242479delinsA"
        )

    def test_hgvs_annotation_hgvs_g_normalized(self):
        self.assertTrue(isinstance(self.hgvs_annotation.hgvs_g_normalized, HgvsG))
        self.assertEqual(
            str(self.hgvs_annotation.hgvs_g_normalized),
            "NC_000007.13:g.55242465_55242479del",
        )

    def test_hgvs_annotation_hgvs_t(self):
        for hgvs_tp_annotation in self.hgvs_annotation.hgvs_tp_annotations:
            self.assertTrue(
                hgvs_tp_annotation.hgvs_t is None
                or isinstance(hgvs_tp_annotation.hgvs_t, HgvsT)
            )
            if hgvs_tp_annotation.tx_ac == self.tx_ac:
                self.assertEqual(
                    str(hgvs_tp_annotation.hgvs_t), f"{self.tx_ac}(EGFR):c.2235_2249del"
                )

    def test_hgvs_annotation_hgvs_p(self):
        for hgvs_tp_annotation in self.hgvs_annotation.hgvs_tp_annotations:
            self.assertTrue(
                hgvs_tp_annotation.hgvs_p is None
                or isinstance(hgvs_tp_annotation.hgvs_p, HgvsP)
            )
            if hgvs_tp_annotation.tx_ac == self.tx_ac:
                self.assertEqual(
                    str(hgvs_tp_annotation.hgvs_p), "NP_005219.2:p.Glu746_Ala750del"
                )

    def test_transcript_feature_range_annotation(self):
        for (
            transcript_feature_range_annotation
        ) in self.transcript_feature_range_annotations:
            if (
                transcript_feature_range_annotation.transcript_features.tx_ac
                == self.tx_ac
            ):
                self.assertEqual(
                    transcript_feature_range_annotation.format(), "exon 19"
                )

    def test_allele_exist(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertFalse(self.indicator_query_resp.allele_exist)

    def test_query_alteration(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(self.indicator_query_resp.query.alteration, "E746_A750del")

    def test_query_entrez_gene_id(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(self.indicator_query_resp.query.entrez_gene_id, 1956)

    def test_gene_exist(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertTrue(self.indicator_query_resp.gene_exist)

    def test_query_hugo_symbol(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(self.indicator_query_resp.query.hugo_symbol, "EGFR")

    def test_highest_diagnostic_implication_level(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNone(
                self.indicator_query_resp.highest_diagnostic_implication_level
            )

    def test_highest_fda_level(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(self.indicator_query_resp.highest_fda_level, "LEVEL_Fda2")

    def test_highest_prognostic_implication_level(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNone(
                self.indicator_query_resp.highest_prognostic_implication_level
            )

    def test_highest_resistance_level(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNone(self.indicator_query_resp.highest_resistance_level)

    def test_highest_sensitive_level(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(
                self.indicator_query_resp.highest_sensitive_level, "LEVEL_1"
            )

    def test_hotspot(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertTrue(self.indicator_query_resp.hotspot)

    def test_mutation_effect_known_effect(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(
                self.indicator_query_resp.mutation_effect.known_effect,
                "Gain-of-function",
            )

    def test_oncogenic(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(self.indicator_query_resp.oncogenic, "Oncogenic")

    def test_query_tumor_type(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNone(self.indicator_query_resp.query.tumor_type)

    def test_tumor_type_summary(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertEqual(self.indicator_query_resp.tumor_type_summary, "")

    def test_variant_exist(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertTrue(self.indicator_query_resp.variant_exist)

    def test_vus(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertFalse(self.indicator_query_resp.vus)

    def test_treatments(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNotNone(self.indicator_query_resp.treatments)
            for treatment in self.indicator_query_resp.treatments:
                self.assertTrue(isinstance(treatment, IndicatorQueryTreatment))

    def test_summarize_treatments_of_level_1(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNotNone(self.indicator_query_resp.treatments)
            treatments_level_1 = (
                self.indicator_query_resp.summarize_treatments_of_level_1()
            )
            self.assertGreaterEqual(len(treatments_level_1), 6)

    def test_summarize_treatments_of_level_1_have_fields(self):
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNotNone(self.indicator_query_resp.treatments)
            treatments_level_1 = (
                self.indicator_query_resp.summarize_treatments_of_level_1()
            )
            for treatment in treatments_level_1:
                self.check_treatment(treatment)

    def test_summarize_treatments_of_level_2(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNotNone(self.indicator_query_resp.treatments)
            treatments_level_2 = (
                self.indicator_query_resp.summarize_treatments_of_level_2()
            )
            self.assertGreaterEqual(len(treatments_level_2), 0)

    def test_summarize_treatments_of_level_r1(self):
        self.assertTrue(isinstance(self.indicator_query_resp, IndicatorQueryResp))
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNotNone(self.indicator_query_resp.treatments)
            treatments_level_r1 = (
                self.indicator_query_resp.summarize_treatments_of_level_r1()
            )
            self.assertEqual(len(treatments_level_r1), 0)

    def check_treatment(self, treatment: dict):
        self.assertTrue("alterations" in treatment)
        self.assertTrue("approved_indications" in treatment)
        self.assertTrue("description" in treatment)
        self.assertTrue("drug_names" in treatment)
        self.assertTrue("pmids" in treatment)
        self.assertTrue("level" in treatment)
        self.assertTrue("level_associated_cancer_type_name" in treatment)

    def test_treatments_level_1_has_a_specific_treatment(self):
        flag = False
        if isinstance(self.indicator_query_resp, IndicatorQueryResp):
            self.assertIsNotNone(self.indicator_query_resp.treatments)
            treatments_level_1 = (
                self.indicator_query_resp.summarize_treatments_of_level_1()
            )
            for treatment in treatments_level_1:
                if (
                    treatment["level_associated_cancer_type_name"]
                    == "Non-Small Cell Lung Cancer"
                    and treatment["approved_indications"]
                    == "Erlotinib is FDA-approved for (1) First-line treatment of metastatic non-small cell lung cancer with EGFR exon 19 deletions or exon 21 (L858R) substitution mutations as detected by an FDA-approved test, (2) maintenance treatment of non small cell lung cancer (NSCLC) that has stabilized after platinum-based chemotherapy, (3) locally advanced or metastatic NSCLC after failure of chemotherapy."
                ):
                    flag = True
                    break
        self.assertTrue(flag)

    def test_is_met_splice_variant(self):
        self.assertFalse(self.indicator_query_resp.is_met_splice_variant())

    def test_is_resistant(self):
        """Is the variant related to therapy resistance?"""
        self.assertFalse(self.indicator_query_resp.is_resistant())

    def test_is_oncogenic(self):
        """Is the variant oncogenic?"""
        self.assertTrue(self.indicator_query_resp.is_oncogenic())

    def test_is_likely_neutral(self):
        """Is the variant likely neutral?"""
        self.assertFalse(self.indicator_query_resp.is_likely_neutral())

    def test_is_inconclusive(self):
        """Is the variant pathogenecity inconclusive?"""
        self.assertFalse(self.indicator_query_resp.is_inconclusive())

    def test_is_unknown(self):
        """Is the variant pathogenecity unknown?"""
        self.assertFalse(self.indicator_query_resp.is_unknown())

    @unittest.skip("annotation changes over time")
    def test_myvariant_annotation(self):
        """Test MyVariantAnnotation."""
        self.assertEqual(
            self.myvariant_annotation,
            MyvariantAnnotation(
                hgvs_chr="chr7:g.55242465_55242479del",
                raw={
                    "_id": "chr7:g.55242465_55242479del",
                    "_version": 2,
                    "chrom": "7",
                    "civic": {
                        "_license": "http://bit.ly/2FqS871",
                        "allele_registry_hgvs": "NC_000007.13:g.55242465_55242479del",
                        "allele_registry_id": "CA175996",
                        "civic_actionability_score": 17.5,
                        "clinvar_entries": "163343",
                        "coordinates": {
                            "chromosome": "7",
                            "ensembl_version": 75,
                            "reference_bases": "GGAATTAAGAGAAGC",
                            "reference_build": "GRCh37",
                            "representative_transcript": "ENST00000275493.2",
                            "start": 55242465,
                            "stop": 55242479,
                        },
                        "entrez_id": 1956,
                        "entrez_name": "EGFR",
                        "evidence_items": [
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In a phase 3 clinical trial of Japanese NSCLC patients with EGFR mutations (n=230), patients treated with gefitinib were associated with improved progression free survival (10.8 months vs 5.4 months, HR: 0.30, 95% CI: 0.22-0.41, P<0.001), compared to patients treated with carboplatin and paclitaxel combination therapy. The frequency of mutation of exon 19 deletion and L858R was 25.2% (58/230) and 21.3% (49/230), respectively.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "ZD1839",
                                            "ZD 1839",
                                            "N-(3-chloro-4-fluorophenyl)-7-methoxy-6-[3-(4-morpholin) Propoxy]-4-quinazolinamine",
                                            "Iressa",
                                            "4-(3'-Chloro-4'-fluoroanilino)-7-methoxy-6-(3-morpholinopropoxy)quinazoline",
                                        ],
                                        "id": 14,
                                        "name": "Gefitinib",
                                        "ncit_id": "C1855",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2510,
                                "name": "EID2510",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Maemondo et al., 2010, N. Engl. J. Med.",
                                    "full_journal_title": "The New England journal of medicine",
                                    "id": 1508,
                                    "is_review": False,
                                    "journal": "N. Engl. J. Med.",
                                    "name": "Gefitinib or chemotherapy for non-small-cell lung cancer with mutated EGFR.",
                                    "publication_date": {
                                        "day": 24,
                                        "month": 6,
                                        "year": 2010,
                                    },
                                    "pubmed": 20573926,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20573926",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-03-30T22:10:11.208Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In a phase 3 clinical trial of Japanese NSCLC patients with EGFR mutations (n=177), patients treated with gefitinib were associated with improved progression free survival (9.2 months vs 6.3 months, HR:0.49, 95% CI: 0.34-0.71, P<0.0001), compared to cisplatin plus docetaxel treatment. The frequency of mutation in exon 19 deletion and L858R was 50.6% (87/172) and 49.4% (85/172), respectively, in evaluable cases.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "ZD1839",
                                            "ZD 1839",
                                            "N-(3-chloro-4-fluorophenyl)-7-methoxy-6-[3-(4-morpholin) Propoxy]-4-quinazolinamine",
                                            "Iressa",
                                            "4-(3'-Chloro-4'-fluoroanilino)-7-methoxy-6-(3-morpholinopropoxy)quinazoline",
                                        ],
                                        "id": 14,
                                        "name": "Gefitinib",
                                        "ncit_id": "C1855",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2511,
                                "name": "EID2511",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Mitsudomi et al., 2010, Lancet Oncol.",
                                    "full_journal_title": "The Lancet. Oncology",
                                    "id": 1358,
                                    "is_review": False,
                                    "journal": "Lancet Oncol.",
                                    "name": "Gefitinib versus cisplatin plus docetaxel in patients with non-small-cell lung cancer harbouring mutations of the epidermal growth factor receptor (WJTOG3405): an open label, randomised phase 3 trial.",
                                    "publication_date": {"month": 2, "year": 2010},
                                    "pubmed": 20022809,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20022809",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-03-30T22:10:11.059Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study using PC9 cells (EGFR exon 19 deletion), inhibition of cell viability was used as an assay to determine sensitivity to EGFR tyrosine kinase inhibitors. PC9 cells demonstrated an increased sensitivity to gefitinib  (IC50: 23.0 nmol/L vs 200.0 nmol/L) compared to NCI-H2073 cells (EGFR wild type).",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "ZD1839",
                                            "ZD 1839",
                                            "N-(3-chloro-4-fluorophenyl)-7-methoxy-6-[3-(4-morpholin) Propoxy]-4-quinazolinamine",
                                            "Iressa",
                                            "4-(3'-Chloro-4'-fluoroanilino)-7-methoxy-6-(3-morpholinopropoxy)quinazoline",
                                        ],
                                        "id": 14,
                                        "name": "Gefitinib",
                                        "ncit_id": "C1855",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2514,
                                "name": "EID2514",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Cross et al., 2014, Cancer Discov",
                                    "full_journal_title": "Cancer discovery",
                                    "id": 665,
                                    "is_review": False,
                                    "journal": "Cancer Discov",
                                    "name": "AZD9291, an irreversible EGFR TKI, overcomes T790M-mediated resistance to EGFR inhibitors in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC4315625",
                                    "publication_date": {"month": 9, "year": 2014},
                                    "pubmed": 24893891,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24893891",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-03-30T22:05:21.777Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In a phase 2b/3 study of 585 lung adenocarcinoma patients who had a previous round of EGFR-TKI treatment, archival material was available for 141 patients. EGFR mutational analysis revealed that 96 tumors had an EGFR mutation, of which 76 (79%) were positive for either L858R or a deletion in exon 19. These mutations were associated with improved progression-free survival (median 3.3 months  vs 1.0 month ; HR:0.51, 95% CI:0.31-0.85, P<0.009) compared to placebo control.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "BIBW2992",
                                            "BIBW 2992",
                                            "(2e)-N-(4-(3-Chloro-4-Fluoroanilino)-7-(((3s)-Oxolan-3-yl)Oxy)Quinoxazolin-6-yl)-4-(Dimethylamino)But-2-Enamide",
                                        ],
                                        "id": 146,
                                        "name": "Afatinib",
                                        "ncit_id": "C66940",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2515,
                                "name": "EID2515",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Miller et al., 2012, Lancet Oncol.",
                                    "clinical_trials": [
                                        {
                                            "clinical_trial_url": "https://clinicaltrials.gov/show/NCT00656136",
                                            "description": "This randomized, double-blind, multi-center Phase IIb/III trial will be performed in patients with NSCLC who have received previous treatment with at least one but not more than two lines of cytotoxic chemotherapy (one line must have been a platinum-containing regimen) and either gefitinib or erlotinib for a period of at least 12 weeks and then progressed. The primary objective of this randomized trial is to determine the efficacy of BIBW 2992 as a single agent (Arm A) as compared to a matching placebo (Arm B) in this patient population. Patients on both treatment arms will receive best supportive care in addition to study treatment. Patients enrolled into the trial will be treated and followed until death or lost to follow-up.",
                                            "name": "BIBW 2992 and BSC Versus Placebo and BSC in Non-small Cell Lung Cancer Patients Failing Erlotinib or Gefitinib (LUX-LUNG 1)",
                                            "nct_id": "NCT00656136",
                                        }
                                    ],
                                    "full_journal_title": "The Lancet. Oncology",
                                    "id": 1510,
                                    "is_review": False,
                                    "journal": "Lancet Oncol.",
                                    "name": "Afatinib versus placebo for patients with advanced, metastatic non-small-cell lung cancer after failure of erlotinib, gefitinib, or both, and one or two lines of chemotherapy (LUX-Lung 1): a phase 2b/3 randomised trial.",
                                    "publication_date": {"month": 5, "year": 2012},
                                    "pubmed": 22452896,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22452896",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-03-30T22:10:10.183Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "A phase 3 study of 345 stage IIIB-IV lung adenocarcinoma patients, reported improved median progression free survival (13.6 months vs. 6.9 months, HR: 0.47, 95% CI: 0.34-0.65, P=0.001) in EGFR mutation positive patients (n=308; exon 19 deletion and L858R mutation) treated with afatinib, as compared to patients treated with standard chemotherapy (cisplatin plus pemetrexed).",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "BIBW2992",
                                            "BIBW 2992",
                                            "(2e)-N-(4-(3-Chloro-4-Fluoroanilino)-7-(((3s)-Oxolan-3-yl)Oxy)Quinoxazolin-6-yl)-4-(Dimethylamino)But-2-Enamide",
                                        ],
                                        "id": 146,
                                        "name": "Afatinib",
                                        "ncit_id": "C66940",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2516,
                                "name": "EID2516",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Sequist et al., 2013, J. Clin. Oncol.",
                                    "clinical_trials": [
                                        {
                                            "clinical_trial_url": "https://clinicaltrials.gov/show/NCT00949650",
                                            "description": "This randomised, open label phase III trial will be performed in patients with adenocarcinoma of the lung with tumours harbouring an Epidermal Growth Factor Receptor activating mutation. The objectives of the trial are to compare the efficacy of single agent BIBW 2992, Arm A, with Pemetrexed/Cisplatin chemotherapy, Arm B, as first line treatment for this group of patients.",
                                            "name": "BIBW 2992 (Afatinib) Versus Chemotherapy as First Line Treatment in NSCLC With EGFR Mutation",
                                            "nct_id": "NCT00949650",
                                        }
                                    ],
                                    "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                    "id": 592,
                                    "is_review": False,
                                    "journal": "J. Clin. Oncol.",
                                    "name": "Phase III study of afatinib or cisplatin plus pemetrexed in patients with metastatic lung adenocarcinoma with EGFR mutations.",
                                    "publication_date": {
                                        "day": 20,
                                        "month": 9,
                                        "year": 2013,
                                    },
                                    "pubmed": 23816960,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23816960",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-03-30T22:10:09.813Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study using PC9 cells (EGFR exon 19 deletion), inhibition of cell viability was used as an assay to determine sensitivity to EGFR tyrosine kinase inhibitors. PC9 cells demonstrated an increased sensitivity to gefitinib (IC50: 23.0 nmol/L vs 200.0 nmol/L) compared to NCI-H2073 cells (EGFR wild type).",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "MEDI4736",
                                            "MEDI-4736",
                                            "Immunoglobulin G1, Anti-(Human Protein B7-H1) (Human Monoclonal MEDI4736 Heavy Chain), Disulfide With Human Monoclonal MEDI4736 Kappa-chain, Dimer",
                                            "Imfinzi",
                                        ],
                                        "id": 427,
                                        "name": "Durvalumab",
                                        "ncit_id": "C103194",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2518,
                                "name": "EID2518",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Cross et al., 2014, Cancer Discov",
                                    "full_journal_title": "Cancer discovery",
                                    "id": 665,
                                    "is_review": False,
                                    "journal": "Cancer Discov",
                                    "name": "AZD9291, an irreversible EGFR TKI, overcomes T790M-mediated resistance to EGFR inhibitors in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC4315625",
                                    "publication_date": {"month": 9, "year": 2014},
                                    "pubmed": 24893891,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24893891",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2020-12-10T20:03:38.771Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study using PC9 cells (EGFR exon 19 deletion), inhibition of cell viability was used as an assay to determine sensitivity to EGFR tyrosine kinase inhibitors. PC9 cells demonstrated an increased sensitivity to gefitinib (IC50: 23.0 nmol/L vs 200.0 nmol/L) compared to NCI-H2073 cells (EGFR wild type).",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "ZD1839",
                                            "ZD 1839",
                                            "N-(3-chloro-4-fluorophenyl)-7-methoxy-6-[3-(4-morpholin) Propoxy]-4-quinazolinamine",
                                            "Iressa",
                                            "4-(3'-Chloro-4'-fluoroanilino)-7-methoxy-6-(3-morpholinopropoxy)quinazoline",
                                        ],
                                        "id": 14,
                                        "name": "Gefitinib",
                                        "ncit_id": "C1855",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2625,
                                "name": "EID2625",
                                "open_change_count": 1,
                                "rating": 2,
                                "source": {
                                    "citation": "Cross et al., 2014, Cancer Discov",
                                    "full_journal_title": "Cancer discovery",
                                    "id": 665,
                                    "is_review": False,
                                    "journal": "Cancer Discov",
                                    "name": "AZD9291, an irreversible EGFR TKI, overcomes T790M-mediated resistance to EGFR inhibitors in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC4315625",
                                    "publication_date": {"month": 9, "year": 2014},
                                    "pubmed": 24893891,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24893891",
                                    "status": "partially curated",
                                },
                                "status": "accepted",
                                "type": "evidence",
                                "updated_at": "2021-02-03T23:17:23.932Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study,  PC9 cells (EGFR E746_A750del) demonstrated increased sensitivity  to erlotinib (IC50:28.0 nmol/L vs 692.0 nmol/L) compared to NCI-H2073 cells (EGFR wild-type).",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4199,
                                "name": "EID4199",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Cross et al., 2014, Cancer Discov",
                                    "full_journal_title": "Cancer discovery",
                                    "id": 665,
                                    "is_review": False,
                                    "journal": "Cancer Discov",
                                    "name": "AZD9291, an irreversible EGFR TKI, overcomes T790M-mediated resistance to EGFR inhibitors in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC4315625",
                                    "publication_date": {"month": 9, "year": 2014},
                                    "pubmed": 24893891,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24893891",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-06-02T04:42:28.583Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study, a HCC827 cell line expressing EGFR E746_A750delELREA demonstrated increased sensitivity to erlotinib treatment compared to QG56 cells expressing EGFR wild-type. Sensitivity was determined by assessing cell viability, the mean IC50 of erlotinib EGFR E746_A750delELREA expressing cells was 4 nM vs. 8.9 �M for EGFR wild-type expressing cells (P<0.001).",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4202,
                                "name": "EID4202",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Abourbeh et al., 2015, EJNMMI Res",
                                    "full_journal_title": "EJNMMI research",
                                    "id": 1992,
                                    "is_review": False,
                                    "journal": "EJNMMI Res",
                                    "name": "Identifying erlotinib-sensitive non-small cell lung carcinoma tumors in mice using [(11)C]erlotinib PET.",
                                    "open_access": True,
                                    "pmc_id": "PMC4385014",
                                    "publication_date": {"year": 2015},
                                    "pubmed": 25853010,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25853010",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-06-02T04:42:31.137Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study, HCC827 and PC9 cell lines expressing EGFR E746_A750del demonstrated increased sensitivity to erlotinib treatment (IC50=0.017�M and 0.071�M, respectively), comparable to NCI-H3255 cells expressing EGFR L858R (a known sensitizing mutation to EGFR tyrosine kinase inhibitors; IC50=0.068�M). Sensitivity was determined by assessing cell proliferation, EGFR, AKT and ERK phosphorylation, levels of BIM (a marker of EGFR TKI-induced cell killing) and cell viability.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4203,
                                "name": "EID4203",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Yasuda et al., 2013, Sci Transl Med",
                                    "full_journal_title": "Science translational medicine",
                                    "id": 1230,
                                    "is_review": False,
                                    "journal": "Sci Transl Med",
                                    "name": "Structural, biochemical, and clinical characterization of epidermal growth factor receptor (EGFR) exon 20 insertion mutations in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC3954775",
                                    "publication_date": {
                                        "day": 18,
                                        "month": 12,
                                        "year": 2013,
                                    },
                                    "pubmed": 24353160,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24353160",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-06-02T04:42:32.086Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study, HCC827 cells expressing EGFR E746_A750del mutation were associated with sensitivity to erlotinib treatment. Sensitivity was determined by assessing cell density and ERK phosphorylation.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4204,
                                "name": "EID4204",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Ray et al., 2016, Oncotarget",
                                    "full_journal_title": "Oncotarget",
                                    "id": 2070,
                                    "is_review": False,
                                    "journal": "Oncotarget",
                                    "name": "Differential protein stability of EGFR mutants determines responsiveness to tyrosine kinase inhibitors.",
                                    "open_access": True,
                                    "pmc_id": "PMC5356576",
                                    "publication_date": {
                                        "day": 18,
                                        "month": 10,
                                        "year": 2016,
                                    },
                                    "pubmed": 27612423,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27612423",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-06-02T04:42:33.005Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In a Taiwanese stage IV lung adenocarcinoma patient with brain metastasis harboring EGFR E746_A750del mutation, EGFR E746_A750del was reported to be sensitive to erlotinib treatment. The patient was treated with 6 cycles of 1st-line standard chemotherapy, 2nd-line standard chemotherapy, and 9 months of gefitinib monotherapy when tumor progression occurred, subsequently the patient achieved tumor regression with 2 years of erlotinib monotherapy until the tumor progressed again.",
                                "disease": {
                                    "display_name": "Lung Adenocarcinoma",
                                    "doid": "DOID:3910",
                                    "id": 30,
                                    "name": "Lung Adenocarcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3910",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4205,
                                "name": "EID4205",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Chang et al., 2007, Lung Cancer",
                                    "full_journal_title": "Lung cancer (Amsterdam, Netherlands)",
                                    "id": 2071,
                                    "is_review": False,
                                    "journal": "Lung Cancer",
                                    "name": "Erlotinib response of EGFR-mutant gefitinib-resistant non-small-cell lung cancer.",
                                    "publication_date": {"month": 12, "year": 2007},
                                    "pubmed": 17618013,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/17618013",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2020-08-12T15:43:10.460Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In lung adenocarcinoma patients with EGFR E746_A750del mutation (n=2), EGFR E746_A750del was associated with improved response to erlotinib treatment. The patients were treated with erlotinib monotherapy and achieved 9 and 10 month response rates, respectively.",
                                "disease": {
                                    "display_name": "Lung Adenocarcinoma",
                                    "doid": "DOID:3910",
                                    "id": 30,
                                    "name": "Lung Adenocarcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3910",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4206,
                                "name": "EID4206",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Balak et al., 2006, Clin. Cancer Res.",
                                    "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                    "id": 1331,
                                    "is_review": False,
                                    "journal": "Clin. Cancer Res.",
                                    "name": "Novel D761Y and common secondary T790M mutations in epidermal growth factor receptor-mutant lung adenocarcinomas with acquired resistance to kinase inhibitors.",
                                    "publication_date": {
                                        "day": 1,
                                        "month": 11,
                                        "year": 2006,
                                    },
                                    "pubmed": 17085664,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/17085664",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2020-08-12T15:43:10.465Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In a retrospective study of 46 advanced non-small cell lung cancer patients, two patients harboring EGFR E746_A750del mutation were associated with resistance to erlotinib treatment. One patient survived 0.9 months and the other patient survived 3.7 months, as compared to the overall 24 months median overall survival of the other patients.",
                                "disease": {
                                    "display_name": "Lung Adenocarcinoma",
                                    "doid": "DOID:3910",
                                    "id": 30,
                                    "name": "Lung Adenocarcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3910",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4207,
                                "name": "EID4207",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "De Grève et al., 2016, PLoS ONE",
                                    "clinical_trials": [
                                        {
                                            "clinical_trial_url": "https://clinicaltrials.gov/show/NCT00339586",
                                            "description": "Current chemotherapy for advanced non-small cell lung cancer, not amenable for curative local treatment (surgery or chemoradiotherapy), has a modest life-prolonging effect and can improve quality of life. There is however no potential for long-term cure for these patients. Chemotherapy also produces variable and often significant toxicity. Current retrospective evidence suggests that significant clinical responses can be obtained when patients whose cancer cells have an EGFR TKD mutation are treated with an EGFR TKI. The ease of administration and toxicity profile of TKI compare favourably with that of chemotherapy, even single agents such as for example gemcitabine The present study will establish the clinical benefit rate of TKI as a first line treatment in patients with EGFR mutations and thus estimate the proportion of patients who might benefit for a prolonged period from a treatment with a modest toxicity profile.",
                                            "name": "First-Line EGFR-1 Tyrosine Kinase Inhibition in Patients With NSCLC With Mutant EGFR Gene",
                                            "nct_id": "NCT00339586",
                                        }
                                    ],
                                    "full_journal_title": "PloS one",
                                    "id": 2067,
                                    "is_review": False,
                                    "journal": "PLoS ONE",
                                    "name": "Prospective Evaluation of First-Line Erlotinib in Advanced Non-Small Cell Lung Cancer (NSCLC) Carrying an Activating EGFR Mutation: A Multicenter Academic Phase II Study in Caucasian Patients (FIELT).",
                                    "open_access": True,
                                    "pmc_id": "PMC4816447",
                                    "publication_date": {"year": 2016},
                                    "pubmed": 27032107,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27032107",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2020-08-12T15:43:10.471Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "A study of five clinical trials reported that chemotherapy na�ve non-small cell lung cancer patients with EGFR sensitizing mutations (exon 19 deletion, L858R, L861Q, or G719X) treated with erlotinib or gefitinib were associated with improved response rate (59% vs 4%; P<0.0001) and increased median overall survival (24.5 months vs 11.8 months P=0.002) as compared to patients without EGFR sensitizing mutations.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4215,
                                "name": "EID4215",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Jackman et al., 2009, Clin. Cancer Res.",
                                    "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                    "id": 1988,
                                    "is_review": False,
                                    "journal": "Clin. Cancer Res.",
                                    "name": "Impact of epidermal growth factor receptor and KRAS mutations on clinical outcomes in previously untreated non-small cell lung cancer patients: results of an online tumor registry of clinical trials.",
                                    "open_access": True,
                                    "pmc_id": "PMC3219530",
                                    "publication_date": {
                                        "day": 15,
                                        "month": 8,
                                        "year": 2009,
                                    },
                                    "pubmed": 19671843,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19671843",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-06-02T04:57:15.639Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study, a HCC827 cell line expressing an EGFR exon 19 deletion mutation demonstrated sensitivity to cetuximab treatment, compared to A549, H460, H322 cell lines expressing wild-type EGFR. Sensitivity was determined by assessing cell viability, EGFR-stimulated VEGF production, and EGFR, AKT and ERK phosphorylation. Further, an in vivo an HCC827 xenograft expressing EGFR exon 19 deletion was reportedly sensitive to cetuximab, as assessed by tumor volume.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4216,
                                "name": "EID4216",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Kang et al., 2016, Lung Cancer",
                                    "full_journal_title": "Lung cancer (Amsterdam, Netherlands)",
                                    "id": 2074,
                                    "is_review": False,
                                    "journal": "Lung Cancer",
                                    "name": "ER2, a novel human anti-EGFR monoclonal antibody inhibit tumor activity in non-small cell lung cancer models.",
                                    "publication_date": {"month": 5, "year": 2016},
                                    "pubmed": 27040853,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27040853",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-06-02T04:43:05.507Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "In an in vitro study, a Ba/F3 cell line expressing EGFR L747_A750insP demonstrated increased sensitivity to erlotinib treatment (IC50=5nM), comparable to Ba/F3 cells expressing EGFR L858R (a known sensitizing mutation to EGFR tyrosine kinase inhibitors; IC50=16nM). Sensitivity was determined by IL-3 independent cell survival.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4642,
                                "name": "EID4642",
                                "open_change_count": 1,
                                "source": {
                                    "citation": "de Gunst et al., 2007, Mol. Cancer",
                                    "full_journal_title": "Molecular cancer",
                                    "id": 1991,
                                    "is_review": False,
                                    "journal": "Mol. Cancer",
                                    "name": "Functional analysis of cancer-associated EGFR mutants using a cellular assay with YFP-tagged EGFR intracellular domain.",
                                    "open_access": True,
                                    "pmc_id": "PMC2064929",
                                    "publication_date": {
                                        "day": 18,
                                        "month": 9,
                                        "year": 2007,
                                    },
                                    "pubmed": 17877814,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/17877814",
                                    "status": "fully curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2017-08-25T00:20:22.788Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "HCC827 and PC9 NSCLC cell lines containing delE746_A750 mutation had growth inhibition IC50 with erlotinib of 0.017 and 0.071 micro molar respectively. In comparison, NCI-H3255 EGFR L858R NSCLC cell line had IC50 0.068 micro molar, and NCI-H1975 cell line with L858R and T790M resistance mutation had IC50 4.282 micro molar, suggesting sensitivity to erlotinib of delE746_A750. Incubation of PC9 and HCC827 cells with 1 micro molar erlotinib reduced phospho-EGFR and phospho-ERK in comparison to controls, and this effect was not seen in a cell line with T790M resistance mutation.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 5945,
                                "name": "EID5945",
                                "open_change_count": 0,
                                "rating": 4,
                                "source": {
                                    "citation": "Yasuda et al., 2013, Sci Transl Med",
                                    "full_journal_title": "Science translational medicine",
                                    "id": 1230,
                                    "is_review": False,
                                    "journal": "Sci Transl Med",
                                    "name": "Structural, biochemical, and clinical characterization of epidermal growth factor receptor (EGFR) exon 20 insertion mutations in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC3954775",
                                    "publication_date": {
                                        "day": 18,
                                        "month": 12,
                                        "year": 2013,
                                    },
                                    "pubmed": 24353160,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24353160",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2020-08-20T05:23:46.328Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "HCC827 and PC9 NSCLC cell lines containing delE746_A750 mutation had growth inhibition IC50 with afatinib of 0.0010 and 0.0015 micro molar respectively. In comparison, NCI-H3255 EGFR L858R NSCLC cell line had IC50 0.0007 micro molar, and NCI-H1975 cell line with L858R and T790M resistance mutation had IC50 0.1397 micro molar, suggesting sensitivity to afatinib of delE746_A750.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "BIBW2992",
                                            "BIBW 2992",
                                            "(2e)-N-(4-(3-Chloro-4-Fluoroanilino)-7-(((3s)-Oxolan-3-yl)Oxy)Quinoxazolin-6-yl)-4-(Dimethylamino)But-2-Enamide",
                                        ],
                                        "id": 146,
                                        "name": "Afatinib",
                                        "ncit_id": "C66940",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 5946,
                                "name": "EID5946",
                                "open_change_count": 0,
                                "rating": 3,
                                "source": {
                                    "citation": "Yasuda et al., 2013, Sci Transl Med",
                                    "full_journal_title": "Science translational medicine",
                                    "id": 1230,
                                    "is_review": False,
                                    "journal": "Sci Transl Med",
                                    "name": "Structural, biochemical, and clinical characterization of epidermal growth factor receptor (EGFR) exon 20 insertion mutations in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC3954775",
                                    "publication_date": {
                                        "day": 18,
                                        "month": 12,
                                        "year": 2013,
                                    },
                                    "pubmed": 24353160,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24353160",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2020-09-24T19:29:38.237Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "Mutational profiling was performed on EGFR exons 18-24 from a group of 10 retrospectively chosen patients who had shown partial response or clinical improvement in response to gefitinib. Of 7 tumors with EGFR mutations, 4 were del E746-A750. 3 had adenocarcinoma with bronchioloalveolar carcinoma (BAC) features, with response duration and overall survival of 8 and 15 months, 5+ and 5+ months (treatment ongoing at study end) and 28 and 30+ months (alive at study end), and one former smoker with adenocarcinoma with BAC features, who had response duration of 5+ months with treatment ongoing at study end.",
                                "disease": {
                                    "display_name": "Lung Non-small Cell Carcinoma",
                                    "doid": "DOID:3908",
                                    "id": 8,
                                    "name": "Lung Non-small Cell Carcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:3908",
                                },
                                "drugs": [
                                    {
                                        "aliases": [
                                            "ZD1839",
                                            "ZD 1839",
                                            "N-(3-chloro-4-fluorophenyl)-7-methoxy-6-[3-(4-morpholin) Propoxy]-4-quinazolinamine",
                                            "Iressa",
                                            "4-(3'-Chloro-4'-fluoroanilino)-7-methoxy-6-(3-morpholinopropoxy)quinazoline",
                                        ],
                                        "id": 14,
                                        "name": "Gefitinib",
                                        "ncit_id": "C1855",
                                    }
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4198,
                                "name": "EID4198",
                                "open_change_count": 0,
                                "rating": 4,
                                "source": {
                                    "citation": "Pao et al., 2004, Proc. Natl. Acad. Sci. U.S.A.",
                                    "full_journal_title": "Proceedings of the National Academy of Sciences of the United States of America",
                                    "id": 1509,
                                    "is_review": False,
                                    "journal": "Proc. Natl. Acad. Sci. U.S.A.",
                                    "name": 'EGF receptor gene mutations are common in lung cancers from "never smokers" and are associated with sensitivity of tumors to gefitinib and erlotinib.',
                                    "open_access": True,
                                    "pmc_id": "PMC516528",
                                    "publication_date": {
                                        "day": 7,
                                        "month": 9,
                                        "year": 2004,
                                    },
                                    "pubmed": 15329413,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/15329413",
                                    "status": "partially curated",
                                },
                                "status": "accepted",
                                "type": "evidence",
                                "updated_at": "2020-04-17T23:04:18.723Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "EGFR exons 18-24 were analyzed in 7 patients who had shown a partial response to erlotinib in a phase II trial for bronchioloalveolar carcinoma (BAC, or in situ pulmonary adenocarcinoma). One patient (Patient E2) had the E746_A750del mutation. The patient was a male never smoker, and demonstrated response for 8.5 months. Overall survival was 21+ months as the patient was alive at study end.",
                                "disease": {
                                    "display_name": "Bronchiolo-alveolar Adenocarcinoma",
                                    "doid": "DOID:4926",
                                    "id": 1163,
                                    "name": "Bronchiolo-alveolar Adenocarcinoma",
                                    "url": "http://disease-ontology.org/?id=DOID:4926",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "C",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 2513,
                                "name": "EID2513",
                                "open_change_count": 0,
                                "rating": 3,
                                "source": {
                                    "citation": "Pao et al., 2004, Proc. Natl. Acad. Sci. U.S.A.",
                                    "full_journal_title": "Proceedings of the National Academy of Sciences of the United States of America",
                                    "id": 1509,
                                    "is_review": False,
                                    "journal": "Proc. Natl. Acad. Sci. U.S.A.",
                                    "name": 'EGF receptor gene mutations are common in lung cancers from "never smokers" and are associated with sensitivity of tumors to gefitinib and erlotinib.',
                                    "open_access": True,
                                    "pmc_id": "PMC516528",
                                    "publication_date": {
                                        "day": 7,
                                        "month": 9,
                                        "year": 2004,
                                    },
                                    "pubmed": 15329413,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/15329413",
                                    "status": "partially curated",
                                },
                                "status": "accepted",
                                "type": "evidence",
                                "updated_at": "2020-04-19T20:12:11.610Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                            {
                                "clinical_significance": "Sensitivity/Response",
                                "description": "EGFR E746_A750del mutation has been associated with sensitivity to first generation EGFR tyrosine kinase inhibitors, including erlotinib. In an in vitro study, PC9 cells (EGFR E746_A750del) demonstrated increased sensitivity to erlotinib (IC50:28.0 nmol/L vs 692.0 nmol/L) compared to NCI-H2073 cells (EGFR wild-type).",
                                "disease": {
                                    "display_name": "Hematologic Cancer",
                                    "doid": "DOID:2531",
                                    "id": 217,
                                    "name": "Hematologic Cancer",
                                    "url": "http://disease-ontology.org/?id=DOID:2531",
                                },
                                "drugs": [
                                    {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"}
                                ],
                                "evidence_direction": "Supports",
                                "evidence_level": "D",
                                "evidence_type": "Predictive",
                                "flagged": False,
                                "id": 4208,
                                "name": "EID4208",
                                "open_change_count": 0,
                                "source": {
                                    "citation": "Cross et al., 2014, Cancer Discov",
                                    "full_journal_title": "Cancer discovery",
                                    "id": 665,
                                    "is_review": False,
                                    "journal": "Cancer Discov",
                                    "name": "AZD9291, an irreversible EGFR TKI, overcomes T790M-mediated resistance to EGFR inhibitors in lung cancer.",
                                    "open_access": True,
                                    "pmc_id": "PMC4315625",
                                    "publication_date": {"month": 9, "year": 2014},
                                    "pubmed": 24893891,
                                    "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24893891",
                                    "status": "partially curated",
                                },
                                "status": "submitted",
                                "type": "evidence",
                                "updated_at": "2020-12-09T23:38:06.701Z",
                                "variant_id": 1002,
                                "variant_origin": "Somatic",
                            },
                        ],
                        "flagged": False,
                        "gene_id": 19,
                        "lifecycle_actions": {
                            "last_commented_on": {
                                "organization": {
                                    "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                    "id": 1,
                                    "name": "The McDonnell Genome Institute",
                                    "parent": {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    "profile_image": {
                                        "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                        "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                        "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                        "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                        "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                    },
                                    "url": "http://genome.wustl.edu/",
                                },
                                "timestamp": "2020-04-22T21:47:44.528Z",
                                "user": {
                                    "area_of_expertise": "Research Scientist",
                                    "avatar_url": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                    "avatars": {
                                        "x128": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=128",
                                        "x14": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=14",
                                        "x32": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                        "x64": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=64",
                                    },
                                    "bio": "Dr. Danos is a Postdoctoral Researcher in the Griffith Lab, with research interests in developing data and knowledge models which can describe and give structure to clinical and preclinical cancer variant knowledge, and in developing standards to enable efficient trasnfer and communication of this information between groups who are generating and curating this data, as well as with the medical and research community at large, in order to address the curation bottleneck which has arisen with increasing incorporation of NGS technology into clinical as well as research contexts. Dr. Danos is also interested in elucidation of the regulatory structure of the genome, and the role of non-coding mutations in cancer.",
                                    "conflict_of_interest": {
                                        "coi_valid": "expired",
                                        "details": {
                                            "coi_present": False,
                                            "created_at": "2021-10-20T09:19:34.199Z",
                                            "expires_at": "2022-10-20T09:19:34.199Z",
                                        },
                                    },
                                    "country": {
                                        "id": 214,
                                        "iso": "US",
                                        "name": "United States",
                                    },
                                    "created_at": "2016-01-27T00:20:51.218Z",
                                    "display_name": "ArpadDanos",
                                    "featured_expert": True,
                                    "id": 110,
                                    "last_seen_at": "2022-04-08T09:33:34.645Z",
                                    "most_recent_organization": {
                                        "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                        "id": 1,
                                        "name": "The McDonnell Genome Institute",
                                        "parent": {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                            "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                            "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                            "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                            "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                        },
                                        "url": "http://genome.wustl.edu/",
                                    },
                                    "name": "Arpad Danos",
                                    "orcid": "0000-0001-9815-2288",
                                    "organizations": [
                                        {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        {
                                            "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                            "id": 1,
                                            "name": "The McDonnell Genome Institute",
                                            "parent": {
                                                "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                                "id": 12,
                                                "name": "Washington University in Saint Louis",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                    "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                    "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                    "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                    "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                                },
                                                "url": "https://wustl.edu/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                                "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                                "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                                "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                                "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                            },
                                            "url": "http://genome.wustl.edu/",
                                        },
                                        {
                                            "description": "Pediatric Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically relevant somatic variants in pediatric cancers. ",
                                            "id": 9,
                                            "name": "Pediatric Cancer Taskforce",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/009/x128/clingen-vcep-1.png?1596737215",
                                                "x14": "/system/organizations/profile_images/000/000/009/x14/clingen-vcep-1.png?1596737215",
                                                "x256": "/system/organizations/profile_images/000/000/009/x256/clingen-vcep-1.png?1596737215",
                                                "x32": "/system/organizations/profile_images/000/000/009/x32/clingen-vcep-1.png?1596737215",
                                                "x64": "/system/organizations/profile_images/000/000/009/x64/clingen-vcep-1.png?1596737215",
                                            },
                                            "url": "https://www.clinicalgenome.org/working-groups/somatic/pediatric-task-team/\r\n",
                                        },
                                        {
                                            "description": "The Hematologic Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically significant somatic variants in hematological malignancies.",
                                            "id": 11,
                                            "name": "Hematologic Cancer Taskforce",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/011/x128/clingen-vcep-3.png?1596737121",
                                                "x14": "/system/organizations/profile_images/000/000/011/x14/clingen-vcep-3.png?1596737121",
                                                "x256": "/system/organizations/profile_images/000/000/011/x256/clingen-vcep-3.png?1596737121",
                                                "x32": "/system/organizations/profile_images/000/000/011/x32/clingen-vcep-3.png?1596737121",
                                                "x64": "/system/organizations/profile_images/000/000/011/x64/clingen-vcep-3.png?1596737121",
                                            },
                                            "url": "https://clinicalgenome.org/working-groups/somatic/hematological-cancers/",
                                        },
                                        {
                                            "description": "Dedicated to the systematic curation of the genes and variants associated with the BCR-ABL1-like (Philadelphia (Ph)-like) genetics subtype of B-lymphoblastic leukemia (B-ALL).",
                                            "id": 16,
                                            "name": "Ph-like B-ALL",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/016/x128/clingen-vcep-4.png?1616506588",
                                                "x14": "/system/organizations/profile_images/000/000/016/x14/clingen-vcep-4.png?1616506588",
                                                "x256": "/system/organizations/profile_images/000/000/016/x256/clingen-vcep-4.png?1616506588",
                                                "x32": "/system/organizations/profile_images/000/000/016/x32/clingen-vcep-4.png?1616506588",
                                                "x64": "/system/organizations/profile_images/000/000/016/x64/clingen-vcep-4.png?1616506588",
                                            },
                                            "url": "https://clinicalgenome.org/working-groups/somatic/",
                                        },
                                        {
                                            "description": "The ClinGen NTRK expert panel will develop a sustainable process for systematic consensus review of fusions and associated secondary alterations in NTRK1, NTRK2, and NTRK3 genes that drive oncogenesis and response to targeted therapy. The group will focus on further specifying and piloting the AMP/ASCO/CAP guidelines (PMID: 27993330) for somatic variant classification and the diagnostic and therapeutic significance of NTRK fusions in cancers. After consensus classification, the panel will make these interpretations publicly available through the CIViC knowledgebase.",
                                            "id": 14,
                                            "name": "NTRK SC-VCEP",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/014/x128/clingen-vcep-2.png?1596737246",
                                                "x14": "/system/organizations/profile_images/000/000/014/x14/clingen-vcep-2.png?1596737246",
                                                "x256": "/system/organizations/profile_images/000/000/014/x256/clingen-vcep-2.png?1596737246",
                                                "x32": "/system/organizations/profile_images/000/000/014/x32/clingen-vcep-2.png?1596737246",
                                                "x64": "/system/organizations/profile_images/000/000/014/x64/clingen-vcep-2.png?1596737246",
                                            },
                                            "url": "https://clinicalgenome.org/affiliation/50089/",
                                        },
                                        {
                                            "description": "The Genitourinary Cancer Taskforce will embark on variant curation for FGFR and AR genes, using Clinical Interpretations of Variants in Cancer (CIViC) platform for variant curation.  The somatic variants should be examined and curated for the clinical significance/clinical management of patients, i.e. their role in the diagnosis, prognosis, therapeutic outcomes, prevention of the disease, or disease surveillance.",
                                            "id": 13,
                                            "name": "FGFR mutation SC-VCEP",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/013/x128/clingen-vcep-6.png?1596737087",
                                                "x14": "/system/organizations/profile_images/000/000/013/x14/clingen-vcep-6.png?1596737087",
                                                "x256": "/system/organizations/profile_images/000/000/013/x256/clingen-vcep-6.png?1596737087",
                                                "x32": "/system/organizations/profile_images/000/000/013/x32/clingen-vcep-6.png?1596737087",
                                                "x64": "/system/organizations/profile_images/000/000/013/x64/clingen-vcep-6.png?1596737087",
                                            },
                                            "url": "https://clinicalgenome.org/affiliation/50098/",
                                        },
                                        {
                                            "description": "\r\nDedicated to the systematic curation of the Histone H3 mutations in brain cancer.",
                                            "id": 19,
                                            "name": "Histone H3 mutations",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/019/x128/grey.png?1635440615",
                                                "x14": "/system/organizations/profile_images/000/000/019/x14/grey.png?1635440615",
                                                "x256": "/system/organizations/profile_images/000/000/019/x256/grey.png?1635440615",
                                                "x32": "/system/organizations/profile_images/000/000/019/x32/grey.png?1635440615",
                                                "x64": "/system/organizations/profile_images/000/000/019/x64/grey.png?1635440615",
                                            },
                                        },
                                    ],
                                    "role": "admin",
                                    "username": "ArpadDanos",
                                },
                            },
                            "last_modified": {
                                "organization": {
                                    "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                    "id": 1,
                                    "name": "The McDonnell Genome Institute",
                                    "parent": {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    "profile_image": {
                                        "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                        "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                        "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                        "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                        "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                    },
                                    "url": "http://genome.wustl.edu/",
                                },
                                "timestamp": "2017-07-27T21:24:27.547Z",
                                "user": {
                                    "area_of_expertise": "Research Scientist",
                                    "avatar_url": "https://secure.gravatar.com/avatar/2424ad9c18ccc94cfb7b6522ac5f5c28.png?d=identicon&r=pg&s=32",
                                    "avatars": {
                                        "x128": "https://secure.gravatar.com/avatar/2424ad9c18ccc94cfb7b6522ac5f5c28.png?d=identicon&r=pg&s=128",
                                        "x14": "https://secure.gravatar.com/avatar/2424ad9c18ccc94cfb7b6522ac5f5c28.png?d=identicon&r=pg&s=14",
                                        "x32": "https://secure.gravatar.com/avatar/2424ad9c18ccc94cfb7b6522ac5f5c28.png?d=identicon&r=pg&s=32",
                                        "x64": "https://secure.gravatar.com/avatar/2424ad9c18ccc94cfb7b6522ac5f5c28.png?d=identicon&r=pg&s=64",
                                    },
                                    "bio": "Zachary Skidmore is a staff scientist at the McDonell Genome Institute, Washington University in Saint Louis. His focus is in data analysis, visualization, and interpretation of NGS data in relation to cancer.",
                                    "conflict_of_interest": {"coi_valid": "missing"},
                                    "country": {
                                        "id": 214,
                                        "iso": "US",
                                        "name": "United States",
                                    },
                                    "created_at": "2015-02-26T16:04:50.200Z",
                                    "display_name": "ZachSkidmore",
                                    "featured_expert": False,
                                    "id": 8,
                                    "last_seen_at": "2022-03-18T20:02:41.733Z",
                                    "linkedin_profile": "zachary-skidmore-0799653a",
                                    "most_recent_organization": {
                                        "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                        "id": 1,
                                        "name": "The McDonnell Genome Institute",
                                        "parent": {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                            "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                            "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                            "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                            "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                        },
                                        "url": "http://genome.wustl.edu/",
                                    },
                                    "name": "Zachary Skidmore",
                                    "orcid": "0000-0003-1928-7139",
                                    "organizations": [
                                        {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        {
                                            "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                            "id": 1,
                                            "name": "The McDonnell Genome Institute",
                                            "parent": {
                                                "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                                "id": 12,
                                                "name": "Washington University in Saint Louis",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                    "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                    "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                    "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                    "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                                },
                                                "url": "https://wustl.edu/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                                "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                                "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                                "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                                "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                            },
                                            "url": "http://genome.wustl.edu/",
                                        },
                                    ],
                                    "role": "curator",
                                    "twitter_handle": "@zlskidmore",
                                    "username": "ZachSkidmore",
                                },
                            },
                            "last_reviewed": {
                                "organization": {
                                    "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                    "id": 1,
                                    "name": "The McDonnell Genome Institute",
                                    "parent": {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    "profile_image": {
                                        "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                        "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                        "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                        "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                        "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                    },
                                    "url": "http://genome.wustl.edu/",
                                },
                                "timestamp": "2020-04-22T21:47:44.528Z",
                                "user": {
                                    "area_of_expertise": "Research Scientist",
                                    "avatar_url": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                    "avatars": {
                                        "x128": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=128",
                                        "x14": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=14",
                                        "x32": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                        "x64": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=64",
                                    },
                                    "bio": "Dr. Danos is a Postdoctoral Researcher in the Griffith Lab, with research interests in developing data and knowledge models which can describe and give structure to clinical and preclinical cancer variant knowledge, and in developing standards to enable efficient trasnfer and communication of this information between groups who are generating and curating this data, as well as with the medical and research community at large, in order to address the curation bottleneck which has arisen with increasing incorporation of NGS technology into clinical as well as research contexts. Dr. Danos is also interested in elucidation of the regulatory structure of the genome, and the role of non-coding mutations in cancer.",
                                    "conflict_of_interest": {
                                        "coi_valid": "expired",
                                        "details": {
                                            "coi_present": False,
                                            "created_at": "2021-10-20T09:19:34.199Z",
                                            "expires_at": "2022-10-20T09:19:34.199Z",
                                        },
                                    },
                                    "country": {
                                        "id": 214,
                                        "iso": "US",
                                        "name": "United States",
                                    },
                                    "created_at": "2016-01-27T00:20:51.218Z",
                                    "display_name": "ArpadDanos",
                                    "featured_expert": True,
                                    "id": 110,
                                    "last_seen_at": "2022-04-08T09:33:34.645Z",
                                    "most_recent_organization": {
                                        "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                        "id": 1,
                                        "name": "The McDonnell Genome Institute",
                                        "parent": {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                            "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                            "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                            "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                            "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                        },
                                        "url": "http://genome.wustl.edu/",
                                    },
                                    "name": "Arpad Danos",
                                    "orcid": "0000-0001-9815-2288",
                                    "organizations": [
                                        {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        {
                                            "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                            "id": 1,
                                            "name": "The McDonnell Genome Institute",
                                            "parent": {
                                                "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                                "id": 12,
                                                "name": "Washington University in Saint Louis",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                    "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                    "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                    "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                    "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                                },
                                                "url": "https://wustl.edu/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                                "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                                "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                                "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                                "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                            },
                                            "url": "http://genome.wustl.edu/",
                                        },
                                        {
                                            "description": "Pediatric Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically relevant somatic variants in pediatric cancers. ",
                                            "id": 9,
                                            "name": "Pediatric Cancer Taskforce",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/009/x128/clingen-vcep-1.png?1596737215",
                                                "x14": "/system/organizations/profile_images/000/000/009/x14/clingen-vcep-1.png?1596737215",
                                                "x256": "/system/organizations/profile_images/000/000/009/x256/clingen-vcep-1.png?1596737215",
                                                "x32": "/system/organizations/profile_images/000/000/009/x32/clingen-vcep-1.png?1596737215",
                                                "x64": "/system/organizations/profile_images/000/000/009/x64/clingen-vcep-1.png?1596737215",
                                            },
                                            "url": "https://www.clinicalgenome.org/working-groups/somatic/pediatric-task-team/\r\n",
                                        },
                                        {
                                            "description": "The Hematologic Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically significant somatic variants in hematological malignancies.",
                                            "id": 11,
                                            "name": "Hematologic Cancer Taskforce",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/011/x128/clingen-vcep-3.png?1596737121",
                                                "x14": "/system/organizations/profile_images/000/000/011/x14/clingen-vcep-3.png?1596737121",
                                                "x256": "/system/organizations/profile_images/000/000/011/x256/clingen-vcep-3.png?1596737121",
                                                "x32": "/system/organizations/profile_images/000/000/011/x32/clingen-vcep-3.png?1596737121",
                                                "x64": "/system/organizations/profile_images/000/000/011/x64/clingen-vcep-3.png?1596737121",
                                            },
                                            "url": "https://clinicalgenome.org/working-groups/somatic/hematological-cancers/",
                                        },
                                        {
                                            "description": "Dedicated to the systematic curation of the genes and variants associated with the BCR-ABL1-like (Philadelphia (Ph)-like) genetics subtype of B-lymphoblastic leukemia (B-ALL).",
                                            "id": 16,
                                            "name": "Ph-like B-ALL",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/016/x128/clingen-vcep-4.png?1616506588",
                                                "x14": "/system/organizations/profile_images/000/000/016/x14/clingen-vcep-4.png?1616506588",
                                                "x256": "/system/organizations/profile_images/000/000/016/x256/clingen-vcep-4.png?1616506588",
                                                "x32": "/system/organizations/profile_images/000/000/016/x32/clingen-vcep-4.png?1616506588",
                                                "x64": "/system/organizations/profile_images/000/000/016/x64/clingen-vcep-4.png?1616506588",
                                            },
                                            "url": "https://clinicalgenome.org/working-groups/somatic/",
                                        },
                                        {
                                            "description": "The ClinGen NTRK expert panel will develop a sustainable process for systematic consensus review of fusions and associated secondary alterations in NTRK1, NTRK2, and NTRK3 genes that drive oncogenesis and response to targeted therapy. The group will focus on further specifying and piloting the AMP/ASCO/CAP guidelines (PMID: 27993330) for somatic variant classification and the diagnostic and therapeutic significance of NTRK fusions in cancers. After consensus classification, the panel will make these interpretations publicly available through the CIViC knowledgebase.",
                                            "id": 14,
                                            "name": "NTRK SC-VCEP",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/014/x128/clingen-vcep-2.png?1596737246",
                                                "x14": "/system/organizations/profile_images/000/000/014/x14/clingen-vcep-2.png?1596737246",
                                                "x256": "/system/organizations/profile_images/000/000/014/x256/clingen-vcep-2.png?1596737246",
                                                "x32": "/system/organizations/profile_images/000/000/014/x32/clingen-vcep-2.png?1596737246",
                                                "x64": "/system/organizations/profile_images/000/000/014/x64/clingen-vcep-2.png?1596737246",
                                            },
                                            "url": "https://clinicalgenome.org/affiliation/50089/",
                                        },
                                        {
                                            "description": "The Genitourinary Cancer Taskforce will embark on variant curation for FGFR and AR genes, using Clinical Interpretations of Variants in Cancer (CIViC) platform for variant curation.  The somatic variants should be examined and curated for the clinical significance/clinical management of patients, i.e. their role in the diagnosis, prognosis, therapeutic outcomes, prevention of the disease, or disease surveillance.",
                                            "id": 13,
                                            "name": "FGFR mutation SC-VCEP",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/013/x128/clingen-vcep-6.png?1596737087",
                                                "x14": "/system/organizations/profile_images/000/000/013/x14/clingen-vcep-6.png?1596737087",
                                                "x256": "/system/organizations/profile_images/000/000/013/x256/clingen-vcep-6.png?1596737087",
                                                "x32": "/system/organizations/profile_images/000/000/013/x32/clingen-vcep-6.png?1596737087",
                                                "x64": "/system/organizations/profile_images/000/000/013/x64/clingen-vcep-6.png?1596737087",
                                            },
                                            "url": "https://clinicalgenome.org/affiliation/50098/",
                                        },
                                        {
                                            "description": "\r\nDedicated to the systematic curation of the Histone H3 mutations in brain cancer.",
                                            "id": 19,
                                            "name": "Histone H3 mutations",
                                            "parent": {
                                                "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                                "id": 2,
                                                "name": "ClinGen",
                                                "profile_image": {
                                                    "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                    "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                    "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                    "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                    "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                                },
                                                "url": "https://www.clinicalgenome.org/",
                                            },
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/019/x128/grey.png?1635440615",
                                                "x14": "/system/organizations/profile_images/000/000/019/x14/grey.png?1635440615",
                                                "x256": "/system/organizations/profile_images/000/000/019/x256/grey.png?1635440615",
                                                "x32": "/system/organizations/profile_images/000/000/019/x32/grey.png?1635440615",
                                                "x64": "/system/organizations/profile_images/000/000/019/x64/grey.png?1635440615",
                                            },
                                        },
                                    ],
                                    "role": "admin",
                                    "username": "ArpadDanos",
                                },
                            },
                        },
                        "name": "E746_A750del",
                        "type": "variant",
                        "updated_at": "2020-04-23T00:07:19.852Z",
                        "variant_aliases": ["RS121913421", "E746_A750DELELREA"],
                        "variant_id": 1002,
                        "variant_types": {
                            "description": "An inframe non synonymous variant that deletes bases from the coding sequence.",
                            "display_name": "Inframe Deletion",
                            "id": 107,
                            "name": "inframe_deletion",
                            "root_concept": {
                                "name": "Sequence Variant",
                                "so_id": "SO:0001060",
                            },
                            "so_id": "SO:0001822",
                            "url": "http://www.sequenceontology.org/browser/current_svn/term/SO:0001822",
                        },
                    },
                    "clinvar": {
                        "_license": "http://bit.ly/2SQdcI0",
                        "allele_id": 174234,
                        "alt": "A",
                        "chrom": "7",
                        "cytogenic": "7p11.2",
                        "gene": {"id": "1956", "symbol": "EGFR"},
                        "hg19": {"end": 55242479, "start": 55242465},
                        "hg38": {"end": 55174786, "start": 55174772},
                        "hgvs": {
                            "coding": [
                                "NM_001346897.2:c.2100_2114del",
                                "NM_001346898.2:c.2235_2249del",
                                "NM_001346899.2:c.2100_2114del",
                                "NM_001346900.2:c.2076_2090del",
                                "NM_001346941.2:c.1434_1448del",
                                "NM_005228.5:c.2235_2249del",
                            ],
                            "genomic": [
                                "LRG_304:g.160741_160755del",
                                "NC_000007.13:g.55242465_55242479del",
                                "NC_000007.14:g.55174772_55174786del",
                                "NG_007726.3:g.160741_160755del",
                            ],
                            "protein": [
                                "NP_001333826.1:p.Glu701_Ala705del",
                                "NP_001333827.1:p.Glu746_Ala750del",
                                "NP_001333828.1:p.Glu701_Ala705del",
                                "NP_001333829.1:p.Glu693_Ala697del",
                                "NP_001333870.1:p.Glu479_Ala483del",
                                "NP_005219.2:p.Glu746_Ala750del",
                            ],
                        },
                        "rcv": [
                            {
                                "accession": "RCV000150617",
                                "clinical_significance": "drug response",
                                "conditions": {
                                    "identifiers": {"medgen": "CN225347"},
                                    "name": "Tyrosine kinase inhibitor response",
                                    "synonyms": [
                                        "Protein-tyrosine kinase inhibitor response"
                                    ],
                                },
                                "last_evaluated": "2006-10-28",
                                "number_submitters": 1,
                                "origin": "somatic",
                                "preferred_name": "NM_005228.5(EGFR):c.2235_2249del (p.Glu746_Ala750del)",
                                "review_status": "no assertion criteria provided",
                            },
                            {
                                "accession": "RCV002514895",
                                "clinical_significance": "Uncertain significance",
                                "conditions": {
                                    "identifiers": {"medgen": "CN130014"},
                                    "name": "EGFR-related lung cancer (EGFR)",
                                },
                                "last_evaluated": "2022-08-27",
                                "number_submitters": 1,
                                "origin": "germline",
                                "preferred_name": "NM_005228.5(EGFR):c.2235_2249del (p.Glu746_Ala750del)",
                                "review_status": "criteria provided, single submitter",
                            },
                            {
                                "accession": "RCV003128584",
                                "clinical_significance": "Pathogenic",
                                "conditions": {
                                    "identifiers": {
                                        "human_phenotype_ontology": "HP:0030078",
                                        "medgen": "C0152013",
                                        "mesh": "D000077192",
                                        "mondo": "MONDO:0005061",
                                    },
                                    "name": "Lung adenocarcinoma",
                                    "synonyms": [
                                        "Adenocarcinoma of lung",
                                        "Adenocarcinoma of lung, somatic",
                                    ],
                                },
                                "last_evaluated": "2022-06-06",
                                "number_submitters": 1,
                                "origin": "somatic",
                                "preferred_name": "NM_005228.5(EGFR):c.2235_2249del (p.Glu746_Ala750del)",
                                "review_status": "criteria provided, single submitter",
                            },
                        ],
                        "ref": "AGGAATTAAGAGAAGC",
                        "rsid": "rs121913421",
                        "type": "Deletion",
                        "variant_id": 163343,
                    },
                    "dbsnp": {
                        "_license": "http://bit.ly/2AqoLOc",
                        "alt": "",
                        "chrom": "7",
                        "citations": [15118073, 15118125],
                        "dbsnp_build": 156,
                        "gene": {
                            "geneid": 1956,
                            "is_pseudo": False,
                            "name": "epidermal growth factor receptor",
                            "rnas": [
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 2358,
                                        "seq_id": "NM_001346897.2",
                                    },
                                    "hgvs": "NM_001346897.2:c.2100_2114=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 699,
                                                "seq_id": "NP_001333826.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_001333826.1"},
                                    "refseq": "NM_001346897.2",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 2493,
                                        "seq_id": "NM_001346898.2",
                                    },
                                    "hgvs": "NM_001346898.2:c.2235_2249=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 744,
                                                "seq_id": "NP_001333827.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_001333827.1"},
                                    "refseq": "NM_001346898.2",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 2358,
                                        "seq_id": "NM_001346899.2",
                                    },
                                    "hgvs": "NM_001346899.2:c.2100_2114=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 699,
                                                "seq_id": "NP_001333828.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_001333828.1"},
                                    "refseq": "NM_001346899.2",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 2264,
                                        "seq_id": "NM_001346900.2",
                                    },
                                    "hgvs": "NM_001346900.2:c.2076_2090=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 691,
                                                "seq_id": "NP_001333829.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_001333829.1"},
                                    "refseq": "NM_001346900.2",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 1692,
                                        "seq_id": "NM_001346941.2",
                                    },
                                    "hgvs": "NM_001346941.2:c.1434_1448=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 477,
                                                "seq_id": "NP_001333870.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_001333870.1"},
                                    "refseq": "NM_001346941.2",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 2493,
                                        "seq_id": "NM_005228.5",
                                    },
                                    "hgvs": "NM_005228.5:c.2235_2249=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 744,
                                                "seq_id": "NP_005219.2",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "NP_005219.2"},
                                    "refseq": "NM_005228.5",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "protein_product": {"refseq": "NP_958439.1"},
                                    "refseq": "NM_201282.2",
                                    "so": [
                                        {
                                            "accession": "SO:0002152",
                                            "name": "genic_downstream_transcript_variant",
                                        }
                                    ],
                                },
                                {
                                    "protein_product": {"refseq": "NP_958440.1"},
                                    "refseq": "NM_201283.2",
                                    "so": [
                                        {
                                            "accession": "SO:0002152",
                                            "name": "genic_downstream_transcript_variant",
                                        }
                                    ],
                                },
                                {
                                    "protein_product": {"refseq": "NP_958441.1"},
                                    "refseq": "NM_201284.2",
                                    "so": [
                                        {
                                            "accession": "SO:0002152",
                                            "name": "genic_downstream_transcript_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 41042,
                                        "seq_id": "XM_047419952.1",
                                    },
                                    "hgvs": "XM_047419952.1:c.2076_2090=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 691,
                                                "seq_id": "XP_047275908.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "XP_047275908.1"},
                                    "refseq": "XM_047419952.1",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                                {
                                    "codon_aligned_transcript_change": {
                                        "deleted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "inserted_sequence": "AAGGAATTAAGAGAAGCA",
                                        "position": 3219,
                                        "seq_id": "XM_047419953.1",
                                    },
                                    "hgvs": "XM_047419953.1:c.2076_2090=",
                                    "protein": {
                                        "variant": {
                                            "spdi": {
                                                "deleted_sequence": "KELREA",
                                                "inserted_sequence": "KELREA",
                                                "position": 691,
                                                "seq_id": "XP_047275909.1",
                                            }
                                        }
                                    },
                                    "protein_product": {"refseq": "XP_047275909.1"},
                                    "refseq": "XM_047419953.1",
                                    "so": [
                                        {
                                            "accession": "SO:0001580",
                                            "name": "coding_sequence_variant",
                                        }
                                    ],
                                },
                            ],
                            "strand": "+",
                            "symbol": "EGFR",
                        },
                        "hg19": {"end": 55242479, "start": 55242465},
                        "ref": "GGAATTAAGAGAAGC",
                        "rsid": "rs121913421",
                        "vartype": "del",
                    },
                    "hg19": {"end": 55242479, "start": 55242465},
                    "observed": True,
                    "snpeff": {
                        "_license": "http://bit.ly/2suyRKt",
                        "ann": [
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "1XKK:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2EB2:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2EB3:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITN:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITP:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITQ:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITT:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITU:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITV:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITW:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITX:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITZ:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2J5F:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2RGP:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2RGP:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3BEL:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3BEL:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:B_723-B_745:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:B_745-B_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3POZ:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3POZ:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3UG1:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3UG2:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3VJN:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3VJO:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2O:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2P:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2Q:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2R:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2R:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2S:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2S:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W32:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W32:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W33:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W33:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I1Z:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I22:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I22:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I23:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:A_745-A_855:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:B_723-B_745:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:B_745-B_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:B_745-B_858:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LI5:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LQM:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4R5S:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4RJ4:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4RJ6:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4RJ7:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4RJ8:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4WKQ:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4WRG:A_745-A_788:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "1XKK:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2EB3:A_746-A_787:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITT:A_714-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITU:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITV:A_714-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITZ:A_746-A_787:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2J5F:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2J5F:A_746-A_787:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2RGP:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:B_725-B_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:B_746-B_787:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3POZ:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3UG1:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3VJO:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2O:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2Q:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2R:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2S:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W32:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W32:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W33:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W33:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4G5J:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I1Z:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I1Z:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I22:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I22:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I23:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:A_746-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:B_746-B_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LI5:A_714-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LI5:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LI5:A_746-A_787:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LQM:A_746-A_787:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4R5S:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4R5S:A_746-A_787:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4RJ4:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4RJ8:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4WKQ:A_725-A_746:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2EB2:A_747-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITQ:A_723-A_747:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITW:A_723-A_747:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITZ:A_723-A_747:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3POZ:A_747-A_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2O:A_747-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2P:A_747-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2Q:A_747-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2R:A_747-A_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2S:A_747-A_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W32:A_747-A_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W33:A_747-A_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I22:A_747-A_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:A_747-A_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:B_747-B_786:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LQM:A_747-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4R5S:A_723-A_747:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4R5S:A_747-A_785:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "1XKK:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITP:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITP:A_724-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITQ:A_724-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITU:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITV:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITW:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITZ:A_722-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITZ:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "2ITZ:A_724-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:B_721-B_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2O:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2P:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2Q:A_721-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W2S:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W32:A_721-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3W33:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I1Z:A_721-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I1Z:A_722-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I1Z:A_724-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I22:A_722-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:B_720-B_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4I24:B_721-B_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "4LI5:A_723-A_748:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "structural_interaction_variant",
                                "feature_id": "3IKA:A_749-A_784:NM_005228.3",
                                "feature_type": "interaction",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "HIGH",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "cdna": {"length": "5600", "position": "2481"},
                                "cds": {"length": "3633", "position": "2235"},
                                "effect": "disruptive_inframe_deletion",
                                "feature_id": "NM_005228.3",
                                "feature_type": "transcript",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "hgvs_p": "p.Glu746_Ala750del",
                                "protein": {"length": "1210", "position": "745"},
                                "putative_impact": "MODERATE",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "sequence_feature",
                                "feature_id": "NM_005228.3",
                                "feature_type": "binding-site:ATP",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "LOW",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "effect": "sequence_feature",
                                "feature_id": "NM_005228.3",
                                "feature_type": "beta-strand:combinatorial_evidence_used_in_manual_assertion",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.2235_2249del",
                                "putative_impact": "LOW",
                                "rank": "19",
                                "total": "28",
                                "transcript_biotype": "protein_coding",
                            },
                            {
                                "distance_to_feature": "4978",
                                "effect": "downstream_gene_variant",
                                "feature_id": "NR_047551.1",
                                "feature_type": "transcript",
                                "gene_id": "EGFR-AS1",
                                "genename": "EGFR-AS1",
                                "hgvs_c": "n.*4964_*4978del",
                                "putative_impact": "MODIFIER",
                                "transcript_biotype": "pseudogene",
                            },
                            {
                                "distance_to_feature": "3727",
                                "effect": "downstream_gene_variant",
                                "feature_id": "NM_201284.1",
                                "feature_type": "transcript",
                                "gene_id": "EGFR",
                                "genename": "EGFR",
                                "hgvs_c": "c.*4228_*4242del",
                                "putative_impact": "MODIFIER",
                                "transcript_biotype": "protein_coding",
                            },
                        ],
                    },
                    "vcf": {
                        "alt": "A",
                        "position": "55242464",
                        "ref": "AGGAATTAAGAGAAGC",
                    },
                },
            ),
        )
