"""Test MyvariantCpraAnnotator class with BRAF V600E, c.1799T>A, chr7:g.140453136A>T."""

import unittest

from snvmodels.cpra import Cpra

from snvannotators.myvariant.annotators import MyvariantCpraAnnotator
from snvannotators.myvariant.annotation import MyvariantAnnotation


class MyvariantCpraAnnotatorBrafV600eC1799TaTestCase(unittest.TestCase):
    """Test MyvariantCpraAnnotator class with BRAF V600E, c.1799T>A, chr7:g.140453136A>T."""

    @classmethod
    def setUpClass(cls):
        annotator = MyvariantCpraAnnotator()
        cpra = Cpra(chrom="chr7", pos=140453136, ref="A", alt="T")
        myvariant_annotation = annotator.annotate(cpra=cpra)
        cls.annotator = annotator
        cls.myvariant_annotation = myvariant_annotation

    def test_myvariant_annotation_is_of_correct_class(self):
        self.assertTrue(isinstance(self.myvariant_annotation, MyvariantAnnotation))

    def test_format_cadd_polyphen(self):
        formatted_cadd_polyphen = self.myvariant_annotation.format_cadd_polyphen()
        self.assertEqual(formatted_cadd_polyphen, "probably damaging")

    def test_format_gnomad_allele_frequency_percentage(self):
        self.assertEqual(self.myvariant_annotation.format_gnomad_allele_frequency_percentage(), '0.000398%')

    def test_genetic_ancestry_group_allele_frequencies(self):
        genetic_ancestry_group_allele_frequencies = []
        gnomad_allele_frequency = self.myvariant_annotation.get_gnomad_allele_frequency()
        if gnomad_allele_frequency:
            gagafs = (
                gnomad_allele_frequency.get_genetic_ancestry_group_allele_frequency_greater_than()
            )
            if gagafs:
                for gagaf in gagafs:
                    genetic_ancestry_group_allele_frequencies.append(
                        {
                            "label": gagaf.label,
                            "allele_frequency_percentage": gagaf.format_allele_frequency_percentage(),
                        }
                    )
        expected = [
            {"label": "South Asian, XY", "allele_frequency_percentage": "0.004335%"},
            {"label": "South Asian", "allele_frequency_percentage": "0.003267%"},
            {"label": "XY", "allele_frequency_percentage": "0.000736%"},
        ]
        self.assertEqual(expected, genetic_ancestry_group_allele_frequencies)

    @unittest.skip("annotation changes over time")
    def test_myvariant_annotation(self):
        expected = MyvariantAnnotation(
            hgvs_chr="chr7:g.140453136A>T",
            raw={
                "_id": "chr7:g.140453136A>T",
                "_version": 2,
                "cadd": {
                    "_license": "http://bit.ly/2TIuab9",
                    "alt": "T",
                    "anc": "A",
                    "annotype": "CodingTranscript",
                    "bstatistic": 570,
                    "chmm": {
                        "bivflnk": 0.0,
                        "enh": 0.0,
                        "enhbiv": 0.0,
                        "het": 0.0,
                        "quies": 0.102,
                        "reprpc": 0.0,
                        "reprpcwk": 0.0,
                        "tssa": 0.0,
                        "tssaflnk": 0.0,
                        "tssbiv": 0.0,
                        "tx": 0.11,
                        "txflnk": 0.0,
                        "txwk": 0.78,
                        "znfrpts": 0.0,
                    },
                    "chrom": 7,
                    "consdetail": "missense",
                    "consequence": "NON_SYNONYMOUS",
                    "consscore": 7,
                    "cpg": 0.01,
                    "dna": {"helt": -0.55, "mgw": 0.7, "prot": 3.19, "roll": 8.98},
                    "encode": {
                        "exp": 21.94,
                        "h3k27ac": 6.0,
                        "h3k4me1": 17.72,
                        "h3k4me3": 4.08,
                        "nucleo": 1.6,
                    },
                    "exon": "15/18",
                    "fitcons": 0.666978,
                    "gc": 0.4,
                    "gene": {
                        "ccds_id": "CCDS5863.1",
                        "cds": {
                            "cdna_pos": 1860,
                            "cds_pos": 1799,
                            "rel_cdna_pos": 0.75,
                            "rel_cds_pos": 0.78,
                        },
                        "feature_id": "ENST00000288602",
                        "gene_id": "ENSG00000157764",
                        "genename": "BRAF",
                        "prot": {
                            "domain": "ndomain",
                            "protpos": 600,
                            "rel_prot_pos": 0.78,
                        },
                    },
                    "gerp": {"n": 5.65, "rs": 771, "rs_pval": 4.53805e-225, "s": 5.65},
                    "grantham": 121,
                    "isderived": "TRUE",
                    "isknownvariant": "FALSE",
                    "istv": "TRUE",
                    "length": 0,
                    "mapability": {"20bp": 1, "35bp": 1},
                    "min_dist_tse": 18739,
                    "min_dist_tss": 876,
                    "mutindex": -13,
                    "naa": "E",
                    "oaa": "V",
                    "phast_cons": {
                        "mammalian": 1.0,
                        "primate": 0.998,
                        "vertebrate": 1.0,
                    },
                    "phred": 32,
                    "phylop": {
                        "mammalian": 2.167,
                        "primate": 0.525,
                        "vertebrate": 5.101,
                    },
                    "polyphen": {"cat": "probably_damaging", "val": 0.967},
                    "pos": 140453136,
                    "rawscore": 6.641785,
                    "ref": "A",
                    "segway": "GE1",
                    "sift": {"cat": "deleterious", "val": 0},
                    "type": "SNV",
                },
                "cgi": [
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "PLX4720 (BRAF inhibitor)",
                        "evidence_level": "Pre-clinical",
                        "gene": "BRAF",
                        "primary_tumor_type": "Malignant astrocytoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMC3638050",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "BRAF inhibitor + MEK inhibitors",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Thyroid",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "ASCO 2013 (abstr 9029)",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Pan-RAF inhibitors",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "ESMO 2015 (abstract 300);AACR 2016 (abstr CT005);AACR 2017 (abstr  CT002)",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "BRAF inhibitors",
                        "evidence_level": "Case report",
                        "gene": "BRAF",
                        "primary_tumor_type": "Ovary",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22608338",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Resistant",
                        "cdna": "c.1799T>A",
                        "drug": "EGFR TK inhibitors",
                        "evidence_level": "Case report",
                        "gene": "BRAF",
                        "primary_tumor_type": "Lung adenocarcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22773810",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Trametinib (MEK inhibitor)",
                        "evidence_level": "FDA guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "FDA",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "BRAF inhibitors",
                        "evidence_level": "Pre-clinical",
                        "gene": "BRAF",
                        "primary_tumor_type": "Glioma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22038996;PMID:22586120",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Vemurafenib + Cobimetinib (BRAF inhibitor + MEK inhibitor)",
                        "evidence_level": "FDA guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "FDA",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "BRAF inhibitor + PI3K pathway inhibitors",
                        "evidence_level": "Pre-clinical",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22389471;PMID:21156289",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Resistant",
                        "cdna": "c.1799T>A",
                        "drug": "Cetuximab (EGFR mAb inhibitor)",
                        "evidence_level": "Late trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Colorectal adenocarcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:20619739;PMID:21163703;PMID:23325582",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "ERK inhibitors",
                        "evidence_level": "Pre-clinical",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:23614898;PMID:22997239",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "MEK inhibitors",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Thyroid",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22241789",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Vemurafenib (BRAF inhibitor)",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Thyroid carcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22608338;PMID:20818844;PMID:23489023",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Vemurafenib (BRAF inhibitor)",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Malignant astrocytoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22586120",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Resistant",
                        "cdna": "c.1799T>A",
                        "drug": "Panitumumab (EGFR mAb inhibitor)",
                        "evidence_level": "Late trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Colorectal adenocarcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:20619739;PMID:21163703;PMID:23325582",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib (BRAF inhibitor)",
                        "evidence_level": "Case report",
                        "gene": "BRAF",
                        "primary_tumor_type": "Gastrointestinal stromal",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:23470635;PMID:22608338",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Vemurafenib (BRAF inhibitor)",
                        "evidence_level": "NCCN guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Non-small cell lung;Lagerhans cell histiocytosis;Erdheim-Chester histiocytosis",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:26287849",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib + Trametinib (BRAF inhibitor + MEK inhibitor)",
                        "evidence_level": "FDA guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "FDA",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "ERK inhibitors",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Lung adenocarcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "ASCO 2017 (abstr 2508)",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib (BRAF inhibitor)",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Lung adenocarcinoma;Thyroid",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:23524406;PMID:22608338;ASCO 2013 (abstr 8009);ESMO 2014 (abstr LBA38_PR);PMID:20818844;PMID:23489023;PMID:27080216",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "BRAF inhibitor + CDK2/4 inhibitors",
                        "evidence_level": "Pre-clinical",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22997239",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Vemurafenib (BRAF inhibitor)",
                        "evidence_level": "FDA guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "FDA",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib (BRAF inhibitor)",
                        "evidence_level": "NCCN guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Non-small cell lung",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "NCCN",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib + Trametinib (BRAF inhibitor + MEK inhibitor)",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Colorectal adenocarcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:26392102;ASCO 2015 (abstr 8006)",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Selumetinib (MEK inhibitor)",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Pediatric glioma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "NCT01089101",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib + Trametinib (BRAF inhibitor + MEK inhibitor)",
                        "evidence_level": "Case report",
                        "gene": "BRAF",
                        "primary_tumor_type": "Neuroendocrine",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:27048246",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib + Trametinib (BRAF inhibitor + MEK inhibitor)",
                        "evidence_level": "FDA guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Lung adenocarcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:27283860",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "MEK inhibitors",
                        "evidence_level": "Pre-clinical",
                        "gene": "BRAF",
                        "primary_tumor_type": "Ovary",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:19018267",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "BRAF inhibitor + HSP90 inhibitors",
                        "evidence_level": "Pre-clinical",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22351686",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Dabrafenib (BRAF inhibitor)",
                        "evidence_level": "FDA guidelines",
                        "gene": "BRAF",
                        "primary_tumor_type": "Cutaneous melanoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "FDA",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Panitumumab + Dabrafenib + Trametinib (EGFR mAb inhibitor + BRAF inhibitor + MEK inhibitor)",
                        "evidence_level": "Early trials",
                        "gene": "BRAF",
                        "primary_tumor_type": "Colorectal adenocarcinoma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "ASCO 2014 (abstr 3515);ASCO 2015 (abstr 103)",
                        "transcript": "ENST00000288602",
                    },
                    {
                        "_license": "http://bit.ly/2FqS871",
                        "association": "Responsive",
                        "cdna": "c.1799T>A",
                        "drug": "Vemurafenib (BRAF inhibitor)",
                        "evidence_level": "Case report",
                        "gene": "BRAF",
                        "primary_tumor_type": "Lung adenocarcinoma;Hairy-Cell leukemia;Myeloma",
                        "protein_change": "BRAF:V600E",
                        "region": "inside_[cds_in_exon_15]",
                        "source": "PMID:22743296;PMID:22621641;PMID:23612012",
                        "transcript": "ENST00000288602",
                    },
                ],
                "chrom": "7",
                "civic": {
                    "_license": "http://bit.ly/2FqS871",
                    "allele_registry_hgvs": "NC_000007.13:g.140453136A>T",
                    "allele_registry_id": "CA123643",
                    "assertions": [
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "BRAF V600E was associated with worse prognosis in Phase II and III colorectal cancer, with a stronger effect in MSI-Low or MSI-Stable tumors. In metastatic CRC, V600E was associated with worse prognosis, and meta-analysis showed BRAF mutation in CRC associated with multiple negative prognostic markers. \nNCCN Guidelines state that that\nmutations in BRAF are a strong prognostic marker, and recommend BRAF genotyping of either primary or metastatic tumor tissue at diagnosis of stage IV disease.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "evidence_direction": "Supports",
                            "evidence_item_count": 6,
                            "evidence_type": "Prognostic",
                            "fda_regulatory_approval": False,
                            "flagged": False,
                            "gene": {"id": 5, "name": "BRAF"},
                            "id": 20,
                            "name": "AID20",
                            "open_change_count": 0,
                            "pending_evidence_count": 0,
                            "status": "accepted",
                            "summary": "BRAF V600E indicates poor prognosis in advanced colorectal cancer",
                            "type": "assertion",
                            "updated_at": "2020-01-16T19:05:22.140Z",
                            "variant": {"id": 12, "name": "V600E"},
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Vemurafenib and cobimetinib combination is an FDA approved and NCCN Category 1 first line treatment for BRAF V600E mutant metastatic melanoma based on clinical data including the Phase III coBRIM trial. NCCN guidelines recommend combination BRAF/MEK inhibitor therapy over BRAF inhibitor monotherapy in this treatment context. Vemurafenib and cobimetinib combination is recommend as Category 2A treatment in second-line or later contexts, and it is recommended to use treatment options different from those used with the patient during first-line therapy. The cobas 4800 BRAF V600 Mutation Test is approved as an FDA companion test for Cotellic (cobimetinib) in combination with Zelboraf (vemurafenib).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {
                                    "aliases": [
                                        "XL518",
                                        "MEK Inhibitor GDC-0973",
                                        "GDC-0973",
                                        "Cotellic",
                                    ],
                                    "id": 342,
                                    "name": "Cobimetinib",
                                    "ncit_id": "C68923",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_item_count": 3,
                            "evidence_type": "Predictive",
                            "fda_regulatory_approval": True,
                            "flagged": False,
                            "gene": {"id": 5, "name": "BRAF"},
                            "id": 10,
                            "name": "AID10",
                            "open_change_count": 0,
                            "pending_evidence_count": 0,
                            "status": "accepted",
                            "summary": "BRAF V600E mutant melanoma is sensitive to vemurafenib and cobimetinib combination therapy",
                            "type": "assertion",
                            "updated_at": "2020-01-16T19:05:22.107Z",
                            "variant": {"id": 12, "name": "V600E"},
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Combination treatment of BRAF inhibitor dabrafenib and MEK inhibitor trametinib is recommended for adjuvant treatment of stage III or recurrent melanoma with BRAF V600E mutation detected by the approved THxID kit, as well as first line treatment for metastatic melanoma. The treatments are FDA approved and NCCN guidelines recommend these treatments as category 1 based on studies including the Phase III COMBI-V, COMBI-D and COMBI-AD Trials. Combination therapy is now recommended above BRAF inhibitor monotherapy. Dabrafenib and trametinib are recommend as NCCN Category 2A for second line therapy in metastatic melanoma due to lack of clear Phase III trial data for this use case. Cutaneous squamous-cell carcinoma and keratoacanthoma occur at lower rates with combination therapy.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_item_count": 8,
                            "evidence_type": "Predictive",
                            "fda_regulatory_approval": True,
                            "flagged": False,
                            "gene": {"id": 5, "name": "BRAF"},
                            "id": 12,
                            "name": "AID12",
                            "open_change_count": 0,
                            "pending_evidence_count": 0,
                            "status": "rejected",
                            "summary": "BRAF V600E mutant melanoma is sensitive to dabrafenib and trametinib combination therapy",
                            "type": "assertion",
                            "updated_at": "2020-01-16T19:05:22.116Z",
                            "variant": {"id": 12, "name": "V600E"},
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Combination treatment of BRAF inhibitor dabrafenib and MEK inhibitor trametinib is recommended for adjuvant treatment of stage III or recurrent melanoma with BRAF V600E mutation detected by the approved THxID kit, as well as first line treatment for metastatic melanoma. The treatments are FDA approved and NCCN guidelines recommend these treatments as category 1 based on studies including the Phase III COMBI-V, COMBI-D and COMBI-AD Trials. Combination therapy is now recommended above BRAF inhibitor monotherapy. Dabrafenib and trametinib are recommend as NCCN Category 2A for second line therapy in metastatic melanoma due to lack of clear Phase III trial data for this use case. Cutaneous squamous-cell carcinoma and keratoacanthoma occur at lower rates with combination therapy than with BRAF inhibitor alone.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_item_count": 4,
                            "evidence_type": "Predictive",
                            "fda_regulatory_approval": True,
                            "flagged": False,
                            "gene": {"id": 5, "name": "BRAF"},
                            "id": 7,
                            "name": "AID7",
                            "open_change_count": 0,
                            "pending_evidence_count": 0,
                            "status": "accepted",
                            "summary": "BRAF V600E mutant melanoma is sensitive to dabrafenib and trametinib combination therapy",
                            "type": "assertion",
                            "updated_at": "2020-01-16T19:05:22.131Z",
                            "variant": {"id": 12, "name": "V600E"},
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Encorafenib + binimetinib + (Cetuximab or Panitumumab)  or Dabrafenib + Trametinib + (Cetuximab or Panitumumab) are recommended as subsequent therapy for BRAF V600E mutation positive colorectal cancer.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "LGX818",
                                        "LGX-818",
                                        "LGX 818",
                                        "Braftovi",
                                    ],
                                    "id": 483,
                                    "name": "Encorafenib",
                                    "ncit_id": "C98283",
                                },
                                {
                                    "aliases": [
                                        "Mektovi",
                                        "MEK162",
                                        "ARRY-438162",
                                        "ARRY-162",
                                    ],
                                    "id": 485,
                                    "name": "Binimetinib",
                                    "ncit_id": "C84865",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_item_count": 1,
                            "evidence_type": "Predictive",
                            "fda_regulatory_approval": False,
                            "flagged": False,
                            "gene": {"id": 5, "name": "BRAF"},
                            "id": 23,
                            "name": "AID23",
                            "open_change_count": 0,
                            "pending_evidence_count": 0,
                            "status": "submitted",
                            "summary": "BRAFi + MEKi + EGFRi combination is recommended for BRAF V600E mutation positive colorectal cancer",
                            "type": "assertion",
                            "updated_at": "2020-01-16T19:05:22.149Z",
                            "variant": {"id": 12, "name": "V600E"},
                        },
                    ],
                    "civic_actionability_score": 1353.5,
                    "clinvar_entries": ["376069", "13961"],
                    "coordinates": {
                        "chromosome": "7",
                        "ensembl_version": 75,
                        "reference_bases": "A",
                        "reference_build": "GRCh37",
                        "representative_transcript": "ENST00000288602.6",
                        "start": 140453136,
                        "stop": 140453136,
                        "variant_bases": "T",
                    },
                    "description": "BRAF V600E has been shown to be recurrent in many cancer types. It is one of the most widely studied variants in cancer. This variant is correlated with poor prognosis in certain cancer types, including colorectal cancer and papillary thyroid cancer. The targeted therapeutic dabrafenib has been shown to be effective in clinical trials with an array of BRAF mutations and cancer types. Dabrafenib has also shown to be effective when combined with the MEK inhibitor trametinib in colorectal cancer and melanoma. However, in patients with TP53, CDKN2A and KRAS mutations, dabrafenib resistance has been reported. Ipilimumab, regorafenib, vemurafenib, and a number of combination therapies have been successful in treating V600E mutations. However, cetuximab and panitumumab have been largely shown to be ineffective without supplementary treatment.",
                    "entrez_id": 673,
                    "entrez_name": "BRAF",
                    "evidence_items": [
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "This in vivo study examined the efficacy of various treatments on athymic nude mice xenografted with colorectal cancer HT29 cells, which harbor BRAF V600E. The authors sought to understand whether the addition of vemurafenib (a BRAF V600E inhibitor) to agents approved for the treatment of metastatic colorectal cancer increased therapeutic efficacy, and which combinations worked best. Capecitabine, bevacizumab and vemurafenib combination therapy resulted in 100% tumor growth inhibition (TGI) and 190% increased lifespan (ILS) compared to vehicle treated controls. Seven mice experienced partial response and two experienced complete response. Triplet therapy resulted in better TGI and ILS compared to any agent in isolation or capecitabine + vemurafenib doublet therapy (p <0.05, p <0.0001, for all comparisons).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {
                                    "aliases": [
                                        "Xeloda",
                                        "Ro 09-1978/000",
                                        "5'-Deoxy-5-fluoro-N-[(pentyloxy)carbonyl]-cytidine",
                                    ],
                                    "id": 32,
                                    "name": "Capecitabine",
                                    "ncit_id": "C1794",
                                },
                                {
                                    "aliases": [
                                        "MYL-1402O",
                                        "Bevacizumab Biosimilar MYL-1402O",
                                        "Bevacizumab Biosimilar ABP 215",
                                        "ABP 215",
                                        "Zirabev",
                                        "Mvasi",
                                        "Bevacizumab-bvzr",
                                        "Bevacizumab-awwb",
                                        "Bevacizumab Biosimilar Zirabev",
                                        "Bevacizumab Biosimilar Mvasi",
                                        "Bevacizumab Biosimilar GB-222",
                                        "SCT501",
                                        "RhuMab-VEGF",
                                        "Recombinant Humanized Anti-VEGF Monoclonal Antibody",
                                        "Immunoglobulin G1 (Human-Mouse Monoclonal RhuMab-VEGF Gamma-Chain Anti-Human Vascular Endothelial Growth Factor), Disulfide With Human-Mouse Monoclonal RhuMab-VEGF Light Chain, Dimer",
                                        "HD204",
                                        "BP102 Biosimilar",
                                        "BP102",
                                        "Bevacizumab Biosimilar SCT501",
                                        "Bevacizumab Biosimilar RPH-001",
                                        "Bevacizumab Biosimilar QL 1101",
                                        "Bevacizumab Biosimilar MIL60",
                                        "Bevacizumab Biosimilar LY01008",
                                        "Bevacizumab Biosimilar IBI305",
                                        "Bevacizumab Biosimilar HLX04",
                                        "Bevacizumab Biosimilar HD204",
                                        "Bevacizumab Biosimilar FKB238",
                                        "Bevacizumab Biosimilar CT-P16",
                                        "Bevacizumab Biosimilar CBT 124",
                                        "Bevacizumab Biosimilar BI 695502",
                                        "Bevacizumab Biosimilar BEVZ92",
                                        "Bevacizumab Awwb",
                                        "Avastin",
                                        "Anti-VEGF RhuMAb",
                                        "Anti-VEGF Humanized Monoclonal Antibody",
                                        "Anti-VEGF",
                                    ],
                                    "id": 33,
                                    "name": "Bevacizumab",
                                    "ncit_id": "C2039",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 98,
                            "name": "EID98",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Yang et al., 2012, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 108,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Antitumor activity of BRAF inhibitor vemurafenib in preclinical models of BRAF-mutant colorectal cancer.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 2,
                                    "year": 2012,
                                },
                                "pubmed": 22180495,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22180495",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-07-09T21:26:14.507Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a case report, a hairy cell leukemia (HCL) patient harboring BRAF V600E mutation was associated with a complete response to vemurafenib monotherapy after 3 months of treatment, which was sustained after 21 days of therapy. Prior to vemurafenib treatment, the patient had been diagnosed with HCL and achieved a complete hematologic response to splenectomy and interferon treatment, however, the patient subsequently relapsed and was treated with standard chemotherapy with further disease progression. As a follow-up to a previous study (23300174), a hairy cell leukemia patient harboring BRAF V600E mutation was associated with response to vemurafenib monotherapy. The patient was previously treated with vemurafenib and obtained a complete response, but then experienced disease progression. Subsequently, the patient was re-treated with vemurafenib and again achieved a complete hematological response.",
                            "disease": {
                                "display_name": "Hairy Cell Leukemia",
                                "doid": "DOID:285",
                                "id": 665,
                                "name": "Hairy Cell Leukemia",
                                "url": "http://disease-ontology.org/?id=DOID:285",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3767,
                            "name": "EID3767",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Peyrade et al., 2013, Haematologica",
                                "full_journal_title": "Haematologica",
                                "id": 1964,
                                "is_review": False,
                                "journal": "Haematologica",
                                "name": "Low-dose vemurafenib induces complete remission in a case of hairy-cell leukemia with a V600E mutation.",
                                "open_access": True,
                                "pmc_id": "PMC3561446",
                                "publication_date": {"month": 2, "year": 2013},
                                "pubmed": 23300174,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23300174",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:07.249Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a hairy cell leukemia patient harboring BRAF V600E mutation, BRAF V600E mutation was associated with improved response to vemurafenib treatment. The patient was treated with 3 lines of chemotherapy, including 6 cycles of pentostatin and rituximab combination therapy, but experience progressive disease; subsequently, the patient was treated with vemurafenib monotherapy for 58 days and achieved a partial response.",
                            "disease": {
                                "display_name": "Hairy Cell Leukemia",
                                "doid": "DOID:285",
                                "id": 665,
                                "name": "Hairy Cell Leukemia",
                                "url": "http://disease-ontology.org/?id=DOID:285",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3768,
                            "name": "EID3768",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Follows et al., 2013, Br. J. Haematol.",
                                "full_journal_title": "British journal of haematology",
                                "id": 1965,
                                "is_review": False,
                                "journal": "Br. J. Haematol.",
                                "name": "Rapid response of biallelic BRAF V600E mutated hairy cell leukaemia to low dose vemurafenib.",
                                "publication_date": {"month": 4, "year": 2013},
                                "pubmed": 23278307,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23278307",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:07.969Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "As a follow-up to a previous study (23300174), a hairy cell leukemia patient harboring BRAF V600E mutation was associated with response to vemurafenib monotherapy. The patient was previously treated with vemurafenib and obtained a complete response, but then experienced disease progression. Subsequently, the patient was re-treated with vemurafenib and again achieved a complete hematological response.",
                            "disease": {
                                "display_name": "Hairy Cell Leukemia",
                                "doid": "DOID:285",
                                "id": 665,
                                "name": "Hairy Cell Leukemia",
                                "url": "http://disease-ontology.org/?id=DOID:285",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3769,
                            "name": "EID3769",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Bailleux et al., 2015, Oncoscience",
                                "full_journal_title": "Oncoscience",
                                "id": 1966,
                                "is_review": False,
                                "journal": "Oncoscience",
                                "name": "Successful re-treatment of a relapsed V600E mutated HCL patient with low-dose vemurafenib.",
                                "open_access": True,
                                "pmc_id": "PMC4341463",
                                "publication_date": {"year": 2015},
                                "pubmed": 25815361,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25815361",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:08.602Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A hairy cell leukemia patient with extensive CNS involvement patient harboring BRAF V600E mutation was associated with complete response to vemurafenib monotherapy. Upon identification of the BRAF V600E mutation, the patient was treated with cytarabine, rituximab and methotrexate but quickly progressed; subsequently, the patient was treated with 2 rounds of vemurafenib and achieved complete response.",
                            "disease": {
                                "display_name": "Hairy Cell Leukemia",
                                "doid": "DOID:285",
                                "id": 665,
                                "name": "Hairy Cell Leukemia",
                                "url": "http://disease-ontology.org/?id=DOID:285",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3770,
                            "name": "EID3770",
                            "open_change_count": 0,
                            "source": {
                                "citation": "McDowell et al., 2016, Leuk. Lymphoma",
                                "full_journal_title": "Leukemia & lymphoma",
                                "id": 1967,
                                "is_review": False,
                                "journal": "Leuk. Lymphoma",
                                "name": "Response of relapsed central nervous system hairy cell leukemia to vemurafenib.",
                                "publication_date": {"month": 12, "year": 2016},
                                "pubmed": 27116997,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27116997",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:09.302Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a case study, a pediatric grade IV glioblastoma multiforme patient harboring BRAF V600E mutation was associated with a complete response to vemurafenib monotherapy after 4 months of treatment, which was sustained at 6 month of therapy; the patient was undergoing the 7th cycle of therapy at the time of publication of this study.",
                            "disease": {
                                "display_name": "Glioblastoma",
                                "doid": "DOID:3068",
                                "id": 19,
                                "name": "Glioblastoma",
                                "url": "http://disease-ontology.org/?id=DOID:3068",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3771,
                            "name": "EID3771",
                            "open_change_count": 1,
                            "source": {
                                "citation": "Robinson et al., 2014, BMC Cancer",
                                "full_journal_title": "BMC cancer",
                                "id": 1968,
                                "is_review": False,
                                "journal": "BMC Cancer",
                                "name": "Complete clinical regression of a BRAF V600E-mutant pediatric glioblastoma multiforme after BRAF inhibitor therapy.",
                                "open_access": True,
                                "pmc_id": "PMC3996187",
                                "publication_date": {
                                    "day": 12,
                                    "month": 4,
                                    "year": 2014,
                                },
                                "pubmed": 24725538,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24725538",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:10.114Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A pediatric pilocytic astrocytoma patient harboring BRAF V600E mutation, BRAF V600E mutation was associated with response to vemurafenib monotherapy. The patient was treated with standard chemotherapy regimens prior to the identification of the BRAF V600E mutation; subsequently, vemurafenib was administered (initially in combination with standard chemotherapy) and an overall regression achieved, with lack of disease progression noted at 15 months of vemurafenib therapy.",
                            "disease": {
                                "display_name": "Pilocytic Astrocytoma",
                                "doid": "DOID:4851",
                                "id": 166,
                                "name": "Pilocytic Astrocytoma",
                                "url": "http://disease-ontology.org/?id=DOID:4851",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3772,
                            "name": "EID3772",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Skrypek et al., 2014, Pediatr Blood Cancer",
                                "full_journal_title": "Pediatric blood & cancer",
                                "id": 1969,
                                "is_review": False,
                                "journal": "Pediatr Blood Cancer",
                                "name": "Pilomyxoid astrocytoma treated successfully with vemurafenib.",
                                "publication_date": {"month": 11, "year": 2014},
                                "pubmed": 24821190,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24821190",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:11.174Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a retrospective study of 17 papillary thyroid cancer patients, patients with BRAF V600E mutation (n=6) were associated with a 47% (7/15) partial response rate and a 53% (8/15) stable disease rate.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3773,
                            "name": "EID3773",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Dadu et al., 2015, J. Clin. Endocrinol. Metab.",
                                "full_journal_title": "The Journal of clinical endocrinology and metabolism",
                                "id": 1970,
                                "is_review": False,
                                "journal": "J. Clin. Endocrinol. Metab.",
                                "name": "Efficacy and tolerability of vemurafenib in patients with BRAF(V600E) -positive papillary thyroid cancer: M.D. Anderson Cancer Center off label experience.",
                                "open_access": True,
                                "pmc_id": "PMC4283003",
                                "publication_date": {"month": 1, "year": 2015},
                                "pubmed": 25353071,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25353071",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:11.882Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a clinical trial (NCT01286753) of 55 cancer patients with BRAF V600E mutation, patients with metastatic papillary thyroid cancer (n=3) were associated with sensitivity to vemurafenib treatment. One patient achieved partial response (31% reduction by RECIST) and two patients achieved stable disease (9% and 16% reduction by RECIST criteria), the time to progression for these three patients was 11.7, 13.2 and 11.4 months, and the overall survival was 15 months (patient was subsequently treated with radiation therapy), at least 31.7 months (patient subsequently underwent laryngectomy) and 24.9 months (patient was subsequently treated with sorafenib, followed by sunitinib monotherapy), respectively.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3774,
                            "name": "EID3774",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Kim et al., 2013, Thyroid",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT00215605",
                                        "description": "The purpose of this study is to determine the best and safest dose of XL184 administered orally. XL184 is a new chemical entity that inhibits VEGFR2, MET and RET, kinases implicated in tumor formation, growth and migration. To determine the highest safe dose, subjects will receive different amounts of the drug. The first group of subjects will receive the lowest dose of XL184. As long as no medically unacceptable side effects are noted, the dose will be increased for the next group. When the maximum tolerated dose (MTD) is reached, at least 20 subjects with Medullary Thyroid Cancer (MTC) will be enrolled to evaluate the effect of XL184 in this population.",
                                        "name": "Study of XL184 (Cabozantinib) in Adults With Advanced Malignancies",
                                        "nct_id": "NCT00215605",
                                    }
                                ],
                                "full_journal_title": "Thyroid : official journal of the American Thyroid Association",
                                "id": 1971,
                                "is_review": False,
                                "journal": "Thyroid",
                                "name": "Clinical responses to vemurafenib in patients with metastatic papillary thyroid cancer harboring BRAF(V600E) mutation.",
                                "open_access": True,
                                "pmc_id": "PMC3967415",
                                "publication_date": {"month": 10, "year": 2013},
                                "pubmed": 23489023,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23489023",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:12.607Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "This in vivo study examined the efficacy of various treatments on athymic nude mice xenografted with colorectal cancer HT29 cells, which harbor BRAF V600E. The authors sought to understand whether the addition of vemurafenib (a BRAF V600E inhibitor) to agents approved for the treatment of metastatic colorectal cancer increased therapeutic efficacy, and which combinations worked best. Erlotinib and vemurafenib combination therapy resulted in >100% tumor growth inhibition (TGI) and 142% increased lifespan (ILS) compared to vehicle treated controls. Of ten treated mice, 9 experienced partial response. Doublet therapy produced a greater increase in TGI and ILS than either agent in isolation.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {"id": 15, "name": "Erlotinib", "ncit_id": "C65530"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 8507,
                            "name": "EID8507",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Yang et al., 2012, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 108,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Antitumor activity of BRAF inhibitor vemurafenib in preclinical models of BRAF-mutant colorectal cancer.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 2,
                                    "year": 2012,
                                },
                                "pubmed": 22180495,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22180495",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-07-09T21:32:43.675Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a case report, a 28 month old patient with a cervicomedullary low grade glioma compatible with pilocytic astrocytoma which was resected had a second lesion consistent with a ganglioglioma 3 years later. This mass progressed under treatment at which point PCR amplification of BRAF exon 15 and subsequent Sanger sequencing the initial biopsy revealed the tumor harbored a BRAF V600E mutation. Based on these results, vemurafenib monotherapy was started and radiological and clinical response was noted after 3 months of treatment, which was sustained after 6 months of therapy. Prior to vemurafenib treatment, the patient had undergone tracheotomy, was treated with standard chemotherapy and underwent another surgery, but had developed progressive disease.",
                            "disease": {
                                "display_name": "Childhood Pilocytic Astrocytoma",
                                "doid": "DOID:6812",
                                "id": 1673,
                                "name": "Childhood Pilocytic Astrocytoma",
                                "url": "http://disease-ontology.org/?id=DOID:6812",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3777,
                            "name": "EID3777",
                            "open_change_count": 2,
                            "rating": 3,
                            "source": {
                                "citation": "del Bufalo et al., 2014, J Transl Med",
                                "full_journal_title": "Journal of translational medicine",
                                "id": 1974,
                                "is_review": False,
                                "journal": "J Transl Med",
                                "name": "Response of recurrent BRAFV600E mutated ganglioglioma to Vemurafenib as single agent.",
                                "open_access": True,
                                "pmc_id": "PMC4279809",
                                "publication_date": {
                                    "day": 19,
                                    "month": 12,
                                    "year": 2014,
                                },
                                "pubmed": 25524464,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25524464",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-10-30T16:40:15.901Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A grade I refractory brainstem ganglioglioma patient harboring BRAF V600E mutation was associated with partial response to vemurafenib monotherapy. The patient experienced significant clinical improvement in response to vemurafenib and maintained a partial response for 12 months; however, disease progression occurred after vemurafenib was discontinued for three months, reintroduction of vemurafenib resulted in a rapid partial response, with continued response noted at time of publication.",
                            "disease": {
                                "display_name": "Ganglioglioma",
                                "doid": "DOID:5078",
                                "id": 2604,
                                "name": "Ganglioglioma",
                                "url": "http://disease-ontology.org/?id=DOID:5078",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3778,
                            "name": "EID3778",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Aguilera et al., 2016, Pediatr Blood Cancer",
                                "full_journal_title": "Pediatric blood & cancer",
                                "id": 1975,
                                "is_review": False,
                                "journal": "Pediatr Blood Cancer",
                                "name": "Successful Retreatment of a Child with a Refractory Brainstem Ganglioglioma with Vemurafenib.",
                                "publication_date": {"month": 3, "year": 2016},
                                "pubmed": 26579623,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26579623",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:16.369Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a case report, a clear cell sarcoma patient harboring BRAF V600E mutation with distant metastases was associated with a complete response to vemurafenib monotherapy at 8 weeks of treatment. Prior to the administration of vemurafenib, the patient had undergone surgery and was treated with radiation, and standard chemotherapy, but had developed progressive disease.",
                            "disease": {
                                "display_name": "Clear Cell Sarcoma",
                                "doid": "DOID:4233",
                                "id": 966,
                                "name": "Clear Cell Sarcoma",
                                "url": "http://disease-ontology.org/?id=DOID:4233",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3779,
                            "name": "EID3779",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Protsenko et al., 2015, Invest New Drugs",
                                "full_journal_title": "Investigational new drugs",
                                "id": 1976,
                                "is_review": False,
                                "journal": "Invest New Drugs",
                                "name": "BRAF-mutated clear cell sarcoma is sensitive to vemurafenib treatment.",
                                "publication_date": {"month": 10, "year": 2015},
                                "pubmed": 26286452,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26286452",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:17.001Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a lung adenocarcinoma patient with brain metastases harboring BRAF V600E mutation, BRAF V600E was associated with sensitivity to vemurafenib treatment. Upon treatment with vemurafenib monotherapy, the patient�s metastases demonstrated significant response and pleural right effusion improvement was observed; however, at 4 months the patient�s disease progressed resulting in death.",
                            "disease": {
                                "display_name": "Lung Adenocarcinoma",
                                "doid": "DOID:3910",
                                "id": 30,
                                "name": "Lung Adenocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3910",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3780,
                            "name": "EID3780",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Robinson et al., 2014, Lung Cancer",
                                "full_journal_title": "Lung cancer (Amsterdam, Netherlands)",
                                "id": 1977,
                                "is_review": False,
                                "journal": "Lung Cancer",
                                "name": "BRAF V600E-mutated lung adenocarcinoma with metastases to the brain responding to treatment with vemurafenib.",
                                "publication_date": {"month": 8, "year": 2014},
                                "pubmed": 24888229,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24888229",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-08-12T15:43:10.339Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a stage IV non-small cell lung cancer patient with a BRAF V600E mutation, who developed adenocarcinoma, BRAF V600E was associated with sensitivity to vemurafenib treatment. The patient was initially treated with four cycles of standard chemotherapy (cisplatin and pemetrexed) and achieved a partial response, subsequently a complete radiologic response was observed with 11 cycle of maintenance chemotherapy. However, the patient�s disease eventually progressed and lung adenocarcinoma and hepatic metastases were observed, the patient received radiotherapy, followed by the administration of vemurafenib monotherapy with concurrent radiotherapy, resulting in an excellent partial response followed by complete response.",
                            "disease": {
                                "display_name": "Lung Adenocarcinoma",
                                "doid": "DOID:3910",
                                "id": 30,
                                "name": "Lung Adenocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3910",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3781,
                            "name": "EID3781",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Peters et al., 2013, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 1978,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Dramatic response induced by vemurafenib in a BRAF V600E-mutated lung adenocarcinoma.",
                                "publication_date": {
                                    "day": 10,
                                    "month": 7,
                                    "year": 2013,
                                },
                                "pubmed": 23733758,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23733758",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-08-12T15:43:10.357Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a retrospective study of 35 lung adenocarcinoma patients (with chemotherapy previously administered in 86% of patients), patients harboring a BRAF V600E mutation and treated with vemurafenib monotherapy (n=29) were associated with an improved response rate; an overall survival (with 1st-line therapy) of 25.63 months, a 54% overall response rate and a 95% disease control rate were reported.",
                            "disease": {
                                "display_name": "Lung Adenocarcinoma",
                                "doid": "DOID:3910",
                                "id": 30,
                                "name": "Lung Adenocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3910",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3782,
                            "name": "EID3782",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Gautschi et al., 2015, J Thorac Oncol",
                                "full_journal_title": "Journal of thoracic oncology : official publication of the International Association for the Study of Lung Cancer",
                                "id": 1979,
                                "is_review": False,
                                "journal": "J Thorac Oncol",
                                "name": "Targeted Therapy for Patients with BRAF-Mutant Lung Cancer: Results from the European EURAF Cohort.",
                                "publication_date": {"month": 10, "year": 2015},
                                "pubmed": 26200454,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26200454",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-08-12T15:43:10.362Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A stage IV lung adenocarcinoma patient harboring a BRAF V600E mutation was associated with response to vemurafenib monotherapy. The patient�s prior treatment regimens were complex, including radiotherapy, standard chemotherapy and erlotinib; subsequently, the BRAF V600E mutation was identified and the patient was treated with vemurafenib monotherapy, achieving a favorable response for greater than 24 months.",
                            "disease": {
                                "display_name": "Lung Adenocarcinoma",
                                "doid": "DOID:3910",
                                "id": 30,
                                "name": "Lung Adenocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3910",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3783,
                            "name": "EID3783",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Myall et al., 2016, Clin Lung Cancer",
                                "full_journal_title": "Clinical lung cancer",
                                "id": 1980,
                                "is_review": False,
                                "journal": "Clin Lung Cancer",
                                "name": "Long-Term Survival of a Patient With Non-Small-Cell Lung Cancer Harboring a V600E Mutation in the BRAF Oncogene.",
                                "publication_date": {"month": 3, "year": 2016},
                                "pubmed": 26776917,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26776917",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-08-12T15:43:10.351Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, BRAF V600E expressing cell lines (BCPAP, OCUT1, K1 and SW1736) demonstrated increased sensitivity to vemurafenib treatment, compared to BRAF wild-type expressing cells (FTC133, KAT18, Hth74 and WRO). Sensitivity was determined by assessing cell proliferation (OCUT1, IC50: 0.41uM; SW1736, IC50: 0.12 uM; K1, IC50: 0.83 uM; BCPAP, IC50: 1.16 uM vs. FTC133, IC50: 56.67 uM; KAT18, 541.66 uM; Hth74, IC50: 1349.79 uM; and WRO IC50: 943.73 uM) and ERK phosphorylation.",
                            "disease": {
                                "display_name": "Thyroid Gland Carcinoma",
                                "doid": "DOID:3963",
                                "id": 155,
                                "name": "Thyroid Gland Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3963",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3784,
                            "name": "EID3784",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Xing et al., 2011, Biochem. Biophys. Res. Commun.",
                                "full_journal_title": "Biochemical and biophysical research communications",
                                "id": 1981,
                                "is_review": False,
                                "journal": "Biochem. Biophys. Res. Commun.",
                                "name": "The BRAFT1799A mutation confers sensitivity of thyroid cancer cells to the BRAFV600E inhibitor PLX4032 (RG7204).",
                                "open_access": True,
                                "pmc_id": "PMC4596240",
                                "publication_date": {
                                    "day": 28,
                                    "month": 1,
                                    "year": 2011,
                                },
                                "pubmed": 21185263,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21185263",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:20.424Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, the BCPAP cell line expressing a BRAF V600E mutation was associated with sensitivity to vemurafenib treatment. Sensitivity was determined by assessing cell viability and apoptotic cell death. However, the 8505C cell line expressing a BRAF V600E mutation and high MET protein phosphorylation levels was reported to be insensitive to vemurafenib treatment.",
                            "disease": {
                                "display_name": "Thyroid Gland Carcinoma",
                                "doid": "DOID:3963",
                                "id": 155,
                                "name": "Thyroid Gland Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3963",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3785,
                            "name": "EID3785",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Byeon et al., 2016, Mol. Carcinog.",
                                "full_journal_title": "Molecular carcinogenesis",
                                "id": 1982,
                                "is_review": False,
                                "journal": "Mol. Carcinog.",
                                "name": "c-Met-mediated reactivation of PI3K/AKT signaling contributes to insensitivity of BRAF(V600E) mutant thyroid cancer to BRAF inhibition.",
                                "publication_date": {"month": 11, "year": 2016},
                                "pubmed": 26456083,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26456083",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:21.061Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An anaplastic pleomorphic xanthoastrocytoma patient harboring BRAF V600E mutation was associated with improved response to vemurafenib treatment. The patient was treated with radiation and temozolomide before experiencing disease progression; subsequent treatment with vemurafenib monotherapy, for a 12 week period, resulted in a near complete response.",
                            "disease": {
                                "display_name": "Pleomorphic Xanthoastrocytoma",
                                "doid": "DOID:4852",
                                "id": 1124,
                                "name": "Pleomorphic Xanthoastrocytoma",
                                "url": "http://disease-ontology.org/?id=DOID:4852",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3786,
                            "name": "EID3786",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Lee et al., 2016, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02034110",
                                        "description": "This is a Phase II, open-label, non-randomized, multi-center study of oral Dabrafenib in combination with oral Trametinib in subjects with rare cancers including anaplastic thyroid cancer, biliary tract cancer, gastrointestinal stromal tumor, non-seminomatous germ cell tumor/non-geminomatous germ cell tumor, hairy cell leukemia, World Health Organization (WHO) Grade 1 or 2 glioma, WHO Grade 3 or 4 (high-grade) glioma, multiple myeloma, and adenocarcinoma of the small intestine, with BRAF V600E positive-mutations. This study is designed to determine the overall response rate (ORR) of oral Dabrafenib in combination with oral Trametinib in subjects with rare BRAF V600E mutated cancers. Subjects will need to have a fresh or frozen tumor tissue sample provided to confirm the BRAF V600E mutation status. Only subjects with histologically confirmed advanced disease and no available standard treatment options will be eligible for enrollment. Subjects will undergo screening assessments within 14 days (up to 35 days for ophthalmology exam, echocardiogram or disease assessments) prior to the start of treatment to determine their eligibility for enrollment in the study.",
                                        "name": "Efficacy and Safety of the Combination Therapy of Dabrafenib and Trametinib in Subjects With BRAF V600E- Mutated Rare Cancers",
                                        "nct_id": "NCT02034110",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 1983,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Successful Treatment of a Progressive BRAF V600E-Mutated Anaplastic Pleomorphic Xanthoastrocytoma With Vemurafenib Monotherapy.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 4,
                                    "year": 2016,
                                },
                                "pubmed": 25092772,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25092772",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:21.721Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A stage 4B, low-grade papillary serous ovarian adenocarcinoma patient, harboring a BRAF V600E mutation was associated with response to vemurafenib monotherapy. The patient was treated with standard chemotherapy, hormone therapy and bevacizumab prior to the identification of the BRAF V600E mutation; next, the patient was treated with paclitaxel and an anti-HER3 antibody and finally with vemurafenib, obtaining a partial response of greater than 1 year.",
                            "disease": {
                                "display_name": "Ovarian Serous Carcinoma",
                                "doid": "DOID:0050933",
                                "id": 87,
                                "name": "Ovarian Serous Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:0050933",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3787,
                            "name": "EID3787",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Combe et al., 2015, Invest New Drugs",
                                "full_journal_title": "Investigational new drugs",
                                "id": 1984,
                                "is_review": False,
                                "journal": "Invest New Drugs",
                                "name": "Sustained response to vemurafenib in a low grade serous ovarian cancer with a BRAF V600E mutation.",
                                "publication_date": {"month": 12, "year": 2015},
                                "pubmed": 26490654,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26490654",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-10-29T23:47:51.626Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a malignant peripheral nerve sheath tumor patient harboring a BRAF V600E mutation, response to vemurafenib monotherapy was reported. Upon identification of the BRAF V600E mutation, the patient was treated with sorafenib monotherapy, but quickly progressed; subsequently, the patient was treated with vemurafenib. 33 days after treatment was initiated, tumor response was reported, as evident by the disappearance of chest and abdominal skin lesions.",
                            "disease": {
                                "display_name": "Malignant Peripheral Nerve Sheath Tumor",
                                "doid": "DOID:5940",
                                "id": 326,
                                "name": "Malignant Peripheral Nerve Sheath Tumor",
                                "url": "http://disease-ontology.org/?id=DOID:5940",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3788,
                            "name": "EID3788",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Kaplan, 2013, J Natl Compr Canc Netw",
                                "full_journal_title": "Journal of the National Comprehensive Cancer Network : JNCCN",
                                "id": 1958,
                                "is_review": False,
                                "journal": "J Natl Compr Canc Netw",
                                "name": "Vemurafenib treatment of BRAF V600E-mutated malignant peripheral nerve sheath tumor.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 12,
                                    "year": 2013,
                                },
                                "pubmed": 24335681,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24335681",
                                "status": "submitted",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:23.213Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A primary central nervous system (CNS)-histiocytic sarcoma patient harboring BRAF V600E mutation was associated with improved response to vemurafenib treatment. The patient was treated with vemurafenib monotherapy and obtained a clinical, biological and radiologic response; subsequently, the patient developed progressive disease and died 6 months after initial treatment with vemurafenib.",
                            "disease": {
                                "display_name": "Histiocytoma",
                                "doid": "DOID:4231",
                                "id": 964,
                                "name": "Histiocytoma",
                                "url": "http://disease-ontology.org/?id=DOID:4231",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3789,
                            "name": "EID3789",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Idbaih et al., 2014, Neurology",
                                "full_journal_title": "Neurology",
                                "id": 1985,
                                "is_review": False,
                                "journal": "Neurology",
                                "name": "Dramatic response of a BRAF V600E-mutated primary CNS histiocytic sarcoma to vemurafenib.",
                                "publication_date": {
                                    "day": 14,
                                    "month": 10,
                                    "year": 2014,
                                },
                                "pubmed": 25209580,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25209580",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:23.858Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a conjunctival malignant melanoma patient harboring a BRAF V600E mutation, BRAF V600E was associated with response to vemurafenib treatment. Prior to identification of the BRAF V600E mutation, the patient was treated with cryotherapy, standard chemotherapy and whole brain radiotherapy; the patient achieved a 4 month progression free survival with vemurafenib treatment prior to disease progression.",
                            "disease": {
                                "display_name": "Malignant Conjunctival Melanoma",
                                "doid": "DOID:1751",
                                "id": 2605,
                                "name": "Malignant Conjunctival Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1751",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3790,
                            "name": "EID3790",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Maleka et al., 2016, BMC Cancer",
                                "full_journal_title": "BMC cancer",
                                "id": 1986,
                                "is_review": False,
                                "journal": "BMC Cancer",
                                "name": "A case report of a patient with metastatic ocular melanoma who experienced a response to treatment with the BRAF inhibitor vemurafenib.",
                                "open_access": True,
                                "pmc_id": "PMC4983009",
                                "publication_date": {
                                    "day": 12,
                                    "month": 8,
                                    "year": 2016,
                                },
                                "pubmed": 27520988,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27520988",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:24.516Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "This in vivo study examined the efficacy of various treatments on athymic nude mice xenografted with colorectal cancer HT29 cells, which harbor BRAF V600E. The authors sought to understand whether the addition of vemurafenib (a BRAF V600E inhibitor) to agents approved for the treatment of metastatic colorectal cancer increased therapeutic efficacy, and which combinations worked best. Irinotecan, cetuximab and vemurafenib combination therapy resulted in >100% tumor growth inhibition (TGI) and 250% increased lifespan (ILS) compared to vehicle treated controls. Of the ten treated mice, nine experienced partial response and one experienced a complete response. Compared to all doublet and single agent combinations of vemurafenib, irinotecan, and cetuximab, triplet therapy produced the best TGI and ILS (p<0.05, p <0.0001 for all comparisons).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "[1,4'-bipiperidine]-1'-carboxylic Acid (S)-4,11-diethyl-3,4,12,14-tetrahydro-4-hydroxy-3,14-dioxo-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinolin-9-yl Ester",
                                        "7-ethyl-10-[4-(1-piperidino)-1-piperidino]carbonyloxycamptothecin",
                                        "(+)-7-ethyl-10-hydroxycamptothecine 10-[1,4'-bipiperidine]-1'-carboxylate",
                                        "(+)-(4S)-4,11-diethyl-4-hydroxy-9-[(4-piperidino-piperidino)carbonyloxy]-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinol-3,14,(4H,12H)-dione",
                                    ],
                                    "id": 101,
                                    "name": "Irinotecan",
                                    "ncit_id": "C62040",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 8506,
                            "name": "EID8506",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Yang et al., 2012, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 108,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Antitumor activity of BRAF inhibitor vemurafenib in preclinical models of BRAF-mutant colorectal cancer.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 2,
                                    "year": 2012,
                                },
                                "pubmed": 22180495,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22180495",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-07-09T21:30:05.173Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "The BRIM-3 Phase III trial NCT01006980 assessed BRAF inhibitor vemurafenib versus dacarbazine in 598 patients with treatment naive metastatic melanoma and confirmed V600E mutation. Significant differences were seen in overall survival (13.3 months with vemurafenib vs. 10.0 months with dacarbazine) and median progression free survival (6.9 months  with vemurafenib vs. 1.6 months with dacarbazine)",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1398,
                            "name": "EID1398",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "McArthur et al., 2014, Lancet Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01006980",
                                        "description": "This randomized, open-label study evaluated the efficacy, safety and tolerability of vemurafenib (RO5185426) as compared to dacarbazine in previously untreated patients with metastatic melanoma. Patients were randomized to receive either vemurafenib 960 mg orally twice daily or dacarbazine 1000 mg/m2 intravenously every 3 weeks. Study treatment was continued until disease progression or unacceptable toxicity occurred. The data and safety monitoring board recommended that patients in the dacarbazine group be allowed to cross over to receive vemurafenib, and the protocol was amended accordingly on January 14, 2011, as both overall survival and progression-free survival endpoints had met the prespecified criteria for statistical significance in favor of vemurafenib.",
                                        "name": "A Study of Vemurafenib (RO5185426) in Comparison With Dacarbazine in Previously Untreated Patients With Metastatic Melanoma (BRIM 3)",
                                        "nct_id": "NCT01006980",
                                    }
                                ],
                                "full_journal_title": "The Lancet. Oncology",
                                "id": 947,
                                "is_review": False,
                                "journal": "Lancet Oncol.",
                                "name": "Safety and efficacy of vemurafenib in BRAF(V600E) and BRAF(V600K) mutation-positive melanoma (BRIM-3): extended follow-up of a phase 3, randomised, open-label study.",
                                "open_access": True,
                                "pmc_id": "PMC4382632",
                                "publication_date": {"month": 3, "year": 2014},
                                "pubmed": 24508103,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24508103",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-27T15:42:21.165Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In this Phase II pilot study (NCT00405587) of BRAF V600 inhibitor vemurafenib in 21 metastatic colorectal cancer (CRC) patients with BRAF V600E, one patient had a durable 21 week partial response, and seven patients had 8 week stable disease as best response. Median progression free survival was 2.1 months and median overall survival was 7.7 months. The authors conclude that single agent vemurafenib did not show meaningful activity in V600E CRC, in contrast to the significant vemurafenib activity against V600 in melanoma.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1405,
                            "name": "EID1405",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Kopetz et al., 2015, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT00405587",
                                        "description": "The primary objective of this FIH study is to assess the safety and pharmacokinetics of PLX4032 in patients with solid tumors. The secondary objective is to assess the pharmacodynamic activity in paired biopsy specimens obtained from patients with malignant melanoma who have the V600E BRAF oncogenic mutation.",
                                        "name": "Safety Study of PLX4032 in Patients With Solid Tumors",
                                        "nct_id": "NCT00405587",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 953,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Phase II Pilot Study of Vemurafenib in Patients With Metastatic BRAF-Mutated Colorectal Cancer.",
                                "open_access": True,
                                "pmc_id": "PMC4669589",
                                "publication_date": {
                                    "day": 1,
                                    "month": 12,
                                    "year": 2015,
                                },
                                "pubmed": 26460303,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26460303",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-27T23:41:26.274Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "5 of 7 colorectal cancer (CRC) cell lines with BRAF V600E mutation were resistant to treatment with the BRAF inhibitor vemurafenib. An RNAi screen in the WiDr cell line (a V600E CRC line) identified EGFR as an enhancer for survival when exposed to vemurafenib.  Treatment with vemurafenib and EGFR inhibitor (cetuximab or gefitinib) in V600E CRC cells (WiDr, VACO432 and KM20) showed inhibited growth as well as induction of the cleaved PARP apoptotic marker. WiDr and VACO432 cells were injected into immunodeficient mice. Modest response was seen with vemurafenib treatment, while combination treatment showed considerable tumor growth inhibition as compared to control.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {
                                    "aliases": [
                                        "ZD1839",
                                        "ZD 1839",
                                        "N-(3-chloro-4-fluorophenyl)-7-methoxy-6-[3-(4-morpholin) Propoxy]-4-quinazolinamine",
                                        "Iressa",
                                        "4-(3'-Chloro-4'-fluoroanilino)-7-methoxy-6-(3-morpholinopropoxy)quinazoline",
                                    ],
                                    "id": 14,
                                    "name": "Gefitinib",
                                    "ncit_id": "C1855",
                                },
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1408,
                            "name": "EID1408",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Prahallad et al., 2012, Nature",
                                "full_journal_title": "Nature",
                                "id": 344,
                                "is_review": False,
                                "journal": "Nature",
                                "name": "Unresponsiveness of colon cancer to BRAF(V600E) inhibition through feedback activation of EGFR.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 3,
                                    "year": 2012,
                                },
                                "pubmed": 22281684,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22281684",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-29T20:22:51.907Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Phase 3 randomized clinical trial comparing vemurafenib with dacarbazine in 675 patients with previously untreated, metastatic melanoma with the BRAF V600E mutation. At 6 months, overall survival was 84% (95% confidence interval [CI], 78 to 89) in the vemurafenib group and 64% (95% CI, 56 to 73) in the dacarbazine group. A relative reduction of 63% in the risk of death and of 74% in the risk of either death or disease progression was observed with vemurafenib as compared with dacarbazine (P<0.001 for both comparisons).",
                            "disease": {
                                "display_name": "Skin Melanoma",
                                "doid": "DOID:8923",
                                "id": 206,
                                "name": "Skin Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:8923",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "A",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1409,
                            "name": "EID1409",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Chapman et al., 2011, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01006980",
                                        "description": "This randomized, open-label study evaluated the efficacy, safety and tolerability of vemurafenib (RO5185426) as compared to dacarbazine in previously untreated patients with metastatic melanoma. Patients were randomized to receive either vemurafenib 960 mg orally twice daily or dacarbazine 1000 mg/m2 intravenously every 3 weeks. Study treatment was continued until disease progression or unacceptable toxicity occurred. The data and safety monitoring board recommended that patients in the dacarbazine group be allowed to cross over to receive vemurafenib, and the protocol was amended accordingly on January 14, 2011, as both overall survival and progression-free survival endpoints had met the prespecified criteria for statistical significance in favor of vemurafenib.",
                                        "name": "A Study of Vemurafenib (RO5185426) in Comparison With Dacarbazine in Previously Untreated Patients With Metastatic Melanoma (BRIM 3)",
                                        "nct_id": "NCT01006980",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 954,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Improved survival with vemurafenib in melanoma with BRAF V600E mutation.",
                                "open_access": True,
                                "pmc_id": "PMC3549296",
                                "publication_date": {
                                    "day": 30,
                                    "month": 6,
                                    "year": 2011,
                                },
                                "pubmed": 21639808,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21639808",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-27T15:39:43.784Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Phase 2 trial in 132 patients with previously treated metastatic melanoma with BRAF V600E mutation. \nConfirmed overall response rate was 53% (95% confidence interval [CI], 44 to 62; 6% with a complete response and 47% with a partial response), median duration of response was 6.7 months (95% CI, 5.6 to 8.6), and median progression-free survival was 6.8 months (95% CI, 5.6 to 8.1). Median overall survival was 15.9 months (95% CI, 11.6 to 18.3).",
                            "disease": {
                                "display_name": "Skin Melanoma",
                                "doid": "DOID:8923",
                                "id": 206,
                                "name": "Skin Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:8923",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1410,
                            "name": "EID1410",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Sosman et al., 2012, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT00949702",
                                        "description": "This open-label single arm study will assess the efficacy, safety and tolerability of Vemurafenib in previously treated patients with metastatic melanoma. Patients will receive oral Vemurafenib [RG7204; PLEXXIKON: PLX4032] at a dose of 960 mg b.i.d. continuously until disease progression or withdrawal from study and will be assessed at regular intervals for tumour response and tolerability. Target sample size is <100 patients.",
                                        "name": "A Study of Vemurafenib in Previously Treated Patients With Metastatic Melanoma",
                                        "nct_id": "NCT00949702",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 354,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Survival in BRAF V600-mutant advanced melanoma treated with vemurafenib.",
                                "open_access": True,
                                "pmc_id": "PMC3724515",
                                "publication_date": {
                                    "day": 23,
                                    "month": 2,
                                    "year": 2012,
                                },
                                "pubmed": 22356324,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22356324",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-27T18:13:09.179Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Treatment response to mutant BRAF inhibitor vemurafenib and EGFR inhibitor panitumumab was assayed in 12 patients with metastatic colorectal cancer (CRC) who had progressed on chemotherapy. Two patients had confirmed partial responses, and 2 showed stable disease over 6 months. The authors conclude that although some efficacy is seen, only a small subset of patients respond to this treatment and the responses are not durable.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                            ],
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1413,
                            "name": "EID1413",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Yaeger et al., 2015, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 957,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "Pilot trial of combined BRAF and EGFR inhibition in BRAF-mutant metastatic colorectal cancer patients.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 3,
                                    "year": 2015,
                                },
                                "pubmed": 25589621,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25589621",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-28T20:20:59.467Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A 73 year old patient with prior history of breast cancer presented with metastatic papillary thyroid carcinoma. After two treatments of I-131 a comprehensive tumor profile revealed BRAF V600E as the only genetic alteration on a near diploid genome with trisomy 1q. Vemurafenib treatment resulted in improvement of symptoms and considerable reductions in tumor mass, and after 23 months the patient remained on therapy with well controlled disease.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1414,
                            "name": "EID1414",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Ali et al., 2014, Case Rep Oncol",
                                "full_journal_title": "Case reports in oncology",
                                "id": 958,
                                "is_review": False,
                                "journal": "Case Rep Oncol",
                                "name": "Extended Antitumor Response of a BRAF V600E Papillary Thyroid Carcinoma to Vemurafenib.",
                                "open_access": True,
                                "pmc_id": "PMC4067722",
                                "publication_date": {"month": 5, "year": 2014},
                                "pubmed": 24987354,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24987354",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-28T19:21:56.081Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In this Phase III trial (coBRIM, NCT01689519) of 495 V600 mutant melanoma patients, 344 had V600E mutation. 174 patients were treated with vemurafenib and placebo, and 170 were treated with vemurafenib and cobimetinib and tested for progression free survival. 88 of 174 monotherapy group patients had an event with median progression free survival of 6.5 months. In the combination group 58 of 174 patients had an event with median progression-free survival not met, however, when in combination with other V600 mutations median progression-free survival was 9.9 months with combination treatment. Median time to followup for the whole cohort was 7.3 months. Hazard Ratio for progression or death was 0.57 (0.41-0.80).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {
                                    "aliases": [
                                        "XL518",
                                        "MEK Inhibitor GDC-0973",
                                        "GDC-0973",
                                        "Cotellic",
                                    ],
                                    "id": 342,
                                    "name": "Cobimetinib",
                                    "ncit_id": "C68923",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1421,
                            "name": "EID1421",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Larkin et al., 2014, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01689519",
                                        "description": "To evaluate the efficacy of vemurafenib in combination with cobimetinib (GDC-0973), compared with vemurafenib and placebo, in previously untreated BRAF V600 mutation-positive patients with unresectable locally advanced or metastatic melanoma, as measured by progression-free survival (PFS), assessed by the study site investigator.",
                                        "name": "A Study Comparing Vemurafenib Versus Vemurafenib Plus Cobimetinib in Participants With Metastatic Melanoma",
                                        "nct_id": "NCT01689519",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 963,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Combined vemurafenib and cobimetinib in BRAF-mutated melanoma.",
                                "publication_date": {
                                    "day": 13,
                                    "month": 11,
                                    "year": 2014,
                                },
                                "pubmed": 25265494,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25265494",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-11-08T16:29:15.533Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Off-label use of vemurafenib to treat BRAF V600E mutation-positive, refractory, childhood Langerhans cell histiocytosis (LCH) was evaluated.\nFifty-four patients from 12 countries were treated with vemurafenib 20 mg/kg/day.\nBecause LCH is a heterogeneous systemic disease, the quantitative Disease Activity Score (DAS), which reflects overall LCH extension, was used as an evaluation criterion.\nAt 8 weeks, 38 patients had CRs (non-active disease) and 16 PRs (active disease better).",
                            "disease": {
                                "display_name": "Langerhans Cell Sarcoma",
                                "doid": "DOID:7146",
                                "id": 1762,
                                "name": "Langerhans Cell Sarcoma",
                                "url": "http://disease-ontology.org/?id=DOID:7146",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7583,
                            "name": "EID7583",
                            "open_change_count": 1,
                            "rating": 4,
                            "source": {
                                "citation": "Donadieu et al., 2019, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 3012,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Vemurafenib for Refractory Multisystem Langerhans Cell Histiocytosis in Children: An International Observational Study.",
                                "open_access": True,
                                "pmc_id": "PMC6823889",
                                "publication_date": {
                                    "day": 1,
                                    "month": 11,
                                    "year": 2019,
                                },
                                "pubmed": 31513482,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/31513482",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-11-19T20:15:14.519Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In the setting of BRAF(V600E), NF1 loss resulted in elevated activation of RAS-GTP and resistance to RAF inhibitors.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 90,
                            "name": "EID90",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Nissan et al., 2014, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 98,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Loss of NF1 in cutaneous melanoma is associated with RAS activation and MEK dependence.",
                                "open_access": True,
                                "pmc_id": "PMC4005042",
                                "publication_date": {
                                    "day": 15,
                                    "month": 4,
                                    "year": 2014,
                                },
                                "pubmed": 24576830,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24576830",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-02-17T19:50:06.632Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "BRAF mutations were identified in 9% of 108 cases of high-grade colorectal neuroendocrine tumors (80% V600E). Two patients were treated with a combination of BRAF and MEK inhibition and exhibited durable response (beyond 7 and 9 months, respectively). Urinary BRAF V600E tumor DNA correlated with disease response in one of the patients. BRAF and MEK inhibition was either dabrafenib+trametinib (case 1) or vemurafenib+trametinib (case 2).",
                            "disease": {
                                "display_name": "Gastrointestinal Neuroendocrine Tumor",
                                "doid": "DOID:0050626",
                                "id": 53,
                                "name": "Gastrointestinal Neuroendocrine Tumor",
                                "url": "http://disease-ontology.org/?id=DOID:0050626",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1430,
                            "name": "EID1430",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Klempner et al., 2016, Cancer Discov",
                                "full_journal_title": "Cancer discovery",
                                "id": 969,
                                "is_review": False,
                                "journal": "Cancer Discov",
                                "name": "BRAFV600E Mutations in High-Grade Colorectal Neuroendocrine Tumors May Predict Responsiveness to BRAF-MEK Combination Therapy.",
                                "publication_date": {"month": 6, "year": 2016},
                                "pubmed": 27048246,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27048246",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-07-01T16:10:32.790Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Two clinical trials evaluated the effects of vemurafenib in 54 patients with BRAF (V600E) positive hairy-cell leukemia.  The overall response rate was 98% with 19/54 having a complete response and 34/54 having a partial response.  In the Italian study (n=25), the median relapse-free survival was 9 months and in the U.S. study (n=24), rate of progression-free survival was 73% with overall survival rate of 91%.",
                            "disease": {
                                "display_name": "Hairy Cell Leukemia",
                                "doid": "DOID:285",
                                "id": 665,
                                "name": "Hairy Cell Leukemia",
                                "url": "http://disease-ontology.org/?id=DOID:285",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1579,
                            "name": "EID1579",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Tiacci et al., 2015, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01711632",
                                        "description": "The purpose of this study is to find out what effects, good and/or bad, treatment with vemurafenib (also known as Zelboraf™) has on the patient and on leukemia. Specifically, the researchers want to know how well vemurafenib eliminates leukemia from the blood.",
                                        "name": "BRAF Inhibitor, Vemurafenib, in Patients With Relapsed or Refractory Hairy Cell Leukemia",
                                        "nct_id": "NCT01711632",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1043,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Targeting Mutant BRAF in Relapsed or Refractory Hairy-Cell Leukemia.",
                                "open_access": True,
                                "pmc_id": "PMC4811324",
                                "publication_date": {
                                    "day": 29,
                                    "month": 10,
                                    "year": 2015,
                                },
                                "pubmed": 26352686,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26352686",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-08-15T19:25:01.588Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Case report of a patient with BRAF V600E mutant metastatic colorectal cancer. Combined EGFR and BRAF inhibition (panitumumab and vemurafenib) showed an initial partial response for 4 months with subsequent disease progression.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1589,
                            "name": "EID1589",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Pietrantonio et al., 2016, Cancer Discov",
                                "full_journal_title": "Cancer discovery",
                                "id": 1050,
                                "is_review": False,
                                "journal": "Cancer Discov",
                                "name": "MET-Driven Resistance to Dual EGFR and BRAF Blockade May Be Overcome by Switching from EGFR to MET Inhibition in BRAF-Mutated Colorectal Cancer.",
                                "publication_date": {
                                    "day": 20,
                                    "month": 6,
                                    "year": 2016,
                                },
                                "pubmed": 27325282,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27325282",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-08-04T14:55:55.160Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Open-label non-randomised phase 2 trial in patients with recurrent or metastatic BRAF V600E mutant papillary thyroid cancer refractory to radioactive iodine. Patients had (cohort 2) or had not (cohort 1) previously been treated with VEGFR inhibitors.\n51 patients were enrolled (26 cohort 1, 25 cohort 2). In cohort 1, partial response was achieved in ten (38.5%) patients. Nine patients achieved stable disease for at least 6 months (35%). Median PFS was 18.2 months and median OS not reached after a median follow-up pf 18.8 months.\nIn cohort 2, six patients (27.3%) achieved a partial response and another six patients achieved stable disease for at least six months. Median PFS was 8.9 months and median OS was 14.4. months.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1591,
                            "name": "EID1591",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Brose et al., 2016, Lancet Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01286753",
                                        "description": "This open-label, multi-center study will evaluate the safety and efficacy of Vemurafenib (RO5185426) in participants with metastatic or unresectable papillary thyroid cancer (PTC) positive for the BRAF V600 mutation and resistant to radioactive iodine therapy. Participants will receive vemurafenib 960 milligrams (mg) orally twice daily until progressive disease or unacceptable toxicity occurs.",
                                        "name": "A Study of Vemurafenib (RO5185426) in Participants With Metastatic or Unresectable Papillary Thyroid Cancer Positive for the BRAF V600 Mutation",
                                        "nct_id": "NCT01286753",
                                    }
                                ],
                                "full_journal_title": "The Lancet. Oncology",
                                "id": 1052,
                                "is_review": False,
                                "journal": "Lancet Oncol.",
                                "name": "Vemurafenib in patients with BRAF(V600E)-positive metastatic or unresectable papillary thyroid cancer refractory to radioactive iodine: a non-randomised, multicentre, open-label, phase 2 trial.",
                                "publication_date": {
                                    "day": 22,
                                    "month": 7,
                                    "year": 2016,
                                },
                                "pubmed": 27460442,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27460442",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-08-16T07:40:06.547Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A 65-year-old man presented with stage II myeloma.  He was initially treated with chemotherapy and he received an autologous stem cell transplant. Sequencing of the recurrent tumor harbored BRAF V600E mutation and he was treated with vemurafenib.  After 7 weeks of treatment, the patient relapsed and died.",
                            "disease": {
                                "display_name": "Multiple Myeloma",
                                "doid": "DOID:9538",
                                "id": 41,
                                "name": "Multiple Myeloma",
                                "url": "http://disease-ontology.org/?id=DOID:9538",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1698,
                            "name": "EID1698",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Sharman et al., 2014, Clin Lymphoma Myeloma Leuk",
                                "full_journal_title": "Clinical lymphoma, myeloma & leukemia",
                                "id": 1147,
                                "is_review": False,
                                "journal": "Clin Lymphoma Myeloma Leuk",
                                "name": "Vemurafenib response in 2 patients with posttransplant refractory BRAF V600E-mutated multiple myeloma.",
                                "publication_date": {"month": 10, "year": 2014},
                                "pubmed": 24997557,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24997557",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-11-05T22:24:29.313Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A 54-year-old man presented with stage II myeloma.  He was initially treated with chemotherapy and received an autologous stem cell transplant.  Genomic profiling of the bone biopsy revealed BRAF V600E activating mutation and the patient was treated with vemurafenib.  At 4-months post treatment (time of case study report) the patient maintains near-resolution of hypermetabolic lesions.",
                            "disease": {
                                "display_name": "Multiple Myeloma",
                                "doid": "DOID:9538",
                                "id": 41,
                                "name": "Multiple Myeloma",
                                "url": "http://disease-ontology.org/?id=DOID:9538",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1699,
                            "name": "EID1699",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Sharman et al., 2014, Clin Lymphoma Myeloma Leuk",
                                "full_journal_title": "Clinical lymphoma, myeloma & leukemia",
                                "id": 1147,
                                "is_review": False,
                                "journal": "Clin Lymphoma Myeloma Leuk",
                                "name": "Vemurafenib response in 2 patients with posttransplant refractory BRAF V600E-mutated multiple myeloma.",
                                "publication_date": {"month": 10, "year": 2014},
                                "pubmed": 24997557,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24997557",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-11-05T22:24:12.711Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Multicenter, phase 1, dose-escalation trial of PLX4032 (Vemurafenib). Treatment of metastatic melanoma with PLX4032 in patients with tumors that carry the V600E BRAF mutation resulted in complete or partial tumor regression in the majority of patients (N=37/48). Patients without the V600E mutation had evidence of tumor regression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1749,
                            "name": "EID1749",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Flaherty et al., 2010, N. Engl. J. Med.",
                                "full_journal_title": "The New England journal of medicine",
                                "id": 352,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Inhibition of mutated, activated BRAF in metastatic melanoma.",
                                "open_access": True,
                                "pmc_id": "PMC3724529",
                                "publication_date": {
                                    "day": 26,
                                    "month": 8,
                                    "year": 2010,
                                },
                                "pubmed": 20818844,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20818844",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-08-12T05:48:37.299Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Phase 1b study of vemurafenib, cetuximab and irinotecan in 19 patients with colorectal cancer (1 with appendiceal cancer). Six of 17 evaluable patients achieved an objective response, 15 patients total had either stable disease or radiographic response (the patient with appendiceal cancer had disease progression). Estimated median PFS was 7.7 months. Effect of the combined treatment was also observed in xenograft and cell line studies.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "[1,4'-bipiperidine]-1'-carboxylic Acid (S)-4,11-diethyl-3,4,12,14-tetrahydro-4-hydroxy-3,14-dioxo-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinolin-9-yl Ester",
                                        "7-ethyl-10-[4-(1-piperidino)-1-piperidino]carbonyloxycamptothecin",
                                        "(+)-7-ethyl-10-hydroxycamptothecine 10-[1,4'-bipiperidine]-1'-carboxylate",
                                        "(+)-(4S)-4,11-diethyl-4-hydroxy-9-[(4-piperidino-piperidino)carbonyloxy]-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinol-3,14,(4H,12H)-dione",
                                    ],
                                    "id": 101,
                                    "name": "Irinotecan",
                                    "ncit_id": "C62040",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1902,
                            "name": "EID1902",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Hong et al., 2016, Cancer Discov",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01787500",
                                        "description": "This phase I trial studies the side effects and best dose of vemurafenib when given together with cetuximab and irinotecan hydrochloride in treating patients with solid tumors that have spread to other parts of the body or cannot be removed by surgery. Vemurafenib and irinotecan hydrochloride may stop the growth of tumor cells by blocking some of the enzymes needed for cell growth. Immunotherapy with monoclonal antibodies, such as cetuximab, may help the body's immune system attack the cancer, and may interfere with the ability of tumor cells to grow and spread. Giving vemurafenib with cetuximab and irinotecan hydrochloride may be a better treatment for solid tumors.",
                                        "name": "Vemurafenib, Cetuximab, and Irinotecan Hydrochloride in Treating Patients With Solid Tumors That Are Metastatic or That Cannot Be Removed by Surgery",
                                        "nct_id": "NCT01787500",
                                    }
                                ],
                                "full_journal_title": "Cancer discovery",
                                "id": 1336,
                                "is_review": False,
                                "journal": "Cancer Discov",
                                "name": "Phase IB Study of Vemurafenib in Combination with Irinotecan and Cetuximab in Patients with Metastatic Colorectal Cancer with BRAFV600E Mutation.",
                                "publication_date": {"month": 12, "year": 2016},
                                "pubmed": 27729313,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27729313",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2017-02-14T21:10:27.068Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase 2 “basket” study of vemurafenib in BRAF V600-positive non-melanoma cancers, seven patients with anaplastic thyroid cancer were enrolled. All 7 patients had V600E mutations. One complete response and one partial response was observed, for a response rate of 29%.",
                            "disease": {
                                "display_name": "Thyroid Gland Anaplastic Carcinoma",
                                "doid": "DOID:0080522",
                                "id": 3040,
                                "name": "Thyroid Gland Anaplastic Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:0080522",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 6045,
                            "name": "EID6045",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Hyman et al., 2015, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01524978",
                                        "description": "This open-label, multi-center study will assess the efficacy and safety of vemurafenib in participants with BRAF V600 mutation-positive cancers (solid tumors and multiple myeloma, except melanoma and papillary thyroid cancer) and for whom vemurafenib is deemed the best treatment option in the opinion of the investigator. Participants will receive twice daily oral doses of 960 mg vemurafenib until disease progression, unacceptable toxicity, or withdrawal of consent. The safety and efficacy of vemurafenib in combination with cetuximab in a subset of participants with colorectal cancer will also be assessed.",
                                        "name": "A Study of Vemurafenib in Participants With BRAF V600 Mutation-Positive Cancers",
                                        "nct_id": "NCT01524978",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1040,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Vemurafenib in Multiple Nonmelanoma Cancers with BRAF V600 Mutations.",
                                "open_access": True,
                                "pmc_id": "PMC4971773",
                                "publication_date": {
                                    "day": 20,
                                    "month": 8,
                                    "year": 2015,
                                },
                                "pubmed": 26287849,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26287849",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-12-11T07:19:07.864Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "The phase 2a MyPathway study assigned patients with HER2, EGFR, BRAF or SHH alterations to treatment with pertuzumab plus trastuzumab, erlotinib, vemurafenib, or vismodegib, respectively. One patient with BRAF V600E mutant laryngeal cancer had a partial response with vemurafenib.",
                            "disease": {
                                "display_name": "Laryngeal Squamous Cell Carcinoma",
                                "doid": "DOID:2876",
                                "id": 124,
                                "name": "Laryngeal Squamous Cell Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:2876",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5962,
                            "name": "EID5962",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Hainsworth et al., 2018, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02091141",
                                        "description": "This multicenter, non-randomized, open-label study will evaluate the efficacy and safety of six treatment regimens in participants with advanced solid tumors for whom therapies that will convey clinical benefit are not available and/or are not suitable options per the treating physician's judgment.",
                                        "name": "My Pathway: A Study Evaluating Herceptin/Perjeta, Tarceva, Zelboraf/Cotellic, Erivedge, Alecensa, and Tecentriq Treatment Targeted Against Certain Molecular Alterations in Participants With Advanced Solid Tumors",
                                        "nct_id": "NCT02091141",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 2414,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Targeted Therapy for Advanced Solid Tumors on the Basis of Molecular Profiles: Results From MyPathway, an Open-Label, Phase IIa Multiple Basket Study.",
                                "publication_date": {"day": 20, "year": 2018},
                                "pubmed": 29320312,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29320312",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-02-16T11:26:42.289Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "The phase 2a MyPathway study assigned patients with HER2, EGFR, BRAF or SHH alterations to treatment with pertuzumab plus trastuzumab, erlotinib, vemurafenib, or vismodegib, respectively. One patient with BRAF V600E mutant anaplastic thyroid cancer had a complete response.",
                            "disease": {
                                "display_name": "Thyroid Gland Anaplastic Carcinoma",
                                "doid": "DOID:0080522",
                                "id": 3040,
                                "name": "Thyroid Gland Anaplastic Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:0080522",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {
                                    "aliases": [
                                        "Pertuzumab Biosimilar HS627",
                                        "HS627",
                                        "RO4368451",
                                        "RhuMAb2C4",
                                        "Perjeta",
                                        "Omnitarg",
                                        "Monoclonal Antibody 2C4",
                                        "MoAb 2C4",
                                        "Immunoglobulin G1, Anti-(Human V (Receptor)) (Human-Mouse Monoclonal 2C4 Heavy Chain), Disulfide With Human-Mouse Monoclonal 2C4 Kappa-Chain, Dimer",
                                        "2C4 Antibody",
                                        "2C4",
                                    ],
                                    "id": 247,
                                    "name": "Pertuzumab",
                                    "ncit_id": "C38692",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5961,
                            "name": "EID5961",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Hainsworth et al., 2018, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02091141",
                                        "description": "This multicenter, non-randomized, open-label study will evaluate the efficacy and safety of six treatment regimens in participants with advanced solid tumors for whom therapies that will convey clinical benefit are not available and/or are not suitable options per the treating physician's judgment.",
                                        "name": "My Pathway: A Study Evaluating Herceptin/Perjeta, Tarceva, Zelboraf/Cotellic, Erivedge, Alecensa, and Tecentriq Treatment Targeted Against Certain Molecular Alterations in Participants With Advanced Solid Tumors",
                                        "nct_id": "NCT02091141",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 2414,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Targeted Therapy for Advanced Solid Tumors on the Basis of Molecular Profiles: Results From MyPathway, an Open-Label, Phase IIa Multiple Basket Study.",
                                "publication_date": {"day": 20, "year": 2018},
                                "pubmed": 29320312,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29320312",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-12-10T19:36:42.675Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Open label phase 2 (Clinical Level B) trial including patients from across the globe (USA, Italy, and the Netherlands) investigating sensitivity to Vemurafenib in patients that have BRAF V600E-positive papillary thyroid cancer that have become resistant to radioactive iodine (the standard treatment). There were 116 patients identified for this trial, 51 of which met the conditions to be included. These 51 patients were split into two cohorts: 1) patients that had never been treated with a multikinase inhibitor targeting VEGFR and 2) patients that have previously been treated with a VEGFR multikinase inhibitor. In cohort 1, ten of 26 patients had best overall response. Best overall response was defined as the proportion of patients with a complete or partial response, however these ten patients were all partial response. In the same cohort 1, nine had achieved stable disease control for at least six months; therefore, 19 patients achieved disease control (73% of total cohort 1, 95% CI 52-88). In cohort 2, of 23 eligible patients, six had a partial response as best overall response and six had stable disease control for at least six months; therefore, 12 patients achieved disease control. (55% of total cohort 2, 95% CI 32-76). The authors conclude that vemurafenib is a potential treatment option for late-stage BRAF V600E-positive papillary thyroid cancer for treatment in patients naïve to a multikinase inhibitor (Cohort 1) and to patients that have been previously treated with a multikinase inhibitor (Cohort 2).",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 9018,
                            "name": "EID9018",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Brose et al., 2016, Lancet Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01286753",
                                        "description": "This open-label, multi-center study will evaluate the safety and efficacy of Vemurafenib (RO5185426) in participants with metastatic or unresectable papillary thyroid cancer (PTC) positive for the BRAF V600 mutation and resistant to radioactive iodine therapy. Participants will receive vemurafenib 960 milligrams (mg) orally twice daily until progressive disease or unacceptable toxicity occurs.",
                                        "name": "A Study of Vemurafenib (RO5185426) in Participants With Metastatic or Unresectable Papillary Thyroid Cancer Positive for the BRAF V600 Mutation",
                                        "nct_id": "NCT01286753",
                                    }
                                ],
                                "full_journal_title": "The Lancet. Oncology",
                                "id": 1052,
                                "is_review": False,
                                "journal": "Lancet Oncol.",
                                "name": "Vemurafenib in patients with BRAF(V600E)-positive metastatic or unresectable papillary thyroid cancer refractory to radioactive iodine: a non-randomised, multicentre, open-label, phase 2 trial.",
                                "publication_date": {
                                    "day": 22,
                                    "month": 7,
                                    "year": 2016,
                                },
                                "pubmed": 27460442,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27460442",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-01-26T23:27:12.733Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "The phase 2a MyPathway study assigned patients with HER2, EGFR, BRAF or SHH alterations to treatment with pertuzumab plus trastuzumab, erlotinib, vemurafenib, or vismodegib, respectively. Among 2 patients with BRAF V600E mutant colorectal cancer, 1 had a partial response.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5960,
                            "name": "EID5960",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Hainsworth et al., 2018, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02091141",
                                        "description": "This multicenter, non-randomized, open-label study will evaluate the efficacy and safety of six treatment regimens in participants with advanced solid tumors for whom therapies that will convey clinical benefit are not available and/or are not suitable options per the treating physician's judgment.",
                                        "name": "My Pathway: A Study Evaluating Herceptin/Perjeta, Tarceva, Zelboraf/Cotellic, Erivedge, Alecensa, and Tecentriq Treatment Targeted Against Certain Molecular Alterations in Participants With Advanced Solid Tumors",
                                        "nct_id": "NCT02091141",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 2414,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Targeted Therapy for Advanced Solid Tumors on the Basis of Molecular Profiles: Results From MyPathway, an Open-Label, Phase IIa Multiple Basket Study.",
                                "publication_date": {"day": 20, "year": 2018},
                                "pubmed": 29320312,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29320312",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-02-16T11:12:26.485Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "This preclinical study examined vemurafenib efficacy on various colorectal cancer cell lines and in mouse xenograft experiments. Of the cell lines tested, six harbored BRAF V600E (and WT KRAS) and three harbored BRAF WT (but mutant KRAS). Of the six BRAF V600E expressing cell lines, four were sensitive to vemurafenib (IC50 ranging between 0.025 and 0.35 uM; HT29, Colo205, Colo741, LS411N). Cell lines expressing the BRAF V600E mutation responded better to vemurafenib treatment than cells wildtype for BRAF as measured by reduced cellular proliferation and inhibition of MET and ERK phosphorylation (none of the three BRAF wt cell lines had IC50s less than 10uM). Authors note that one of the vemurafenib-resistant cell lines harboring BRAF V600E (RKO) harbored a concurrent activating PIK3CA H1047R mutation. Nude, athymic mice with HT29 xenografts treated with vemurafenib experienced substantial tumor inhibition and increased lifespan at every dose tested, though authors found 75 mg/kg twice daily to be optimal (95% tumor growth inhibition, 90% increased lifespan compared to vehicle treated controls).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 99,
                            "name": "EID99",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Yang et al., 2012, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 108,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Antitumor activity of BRAF inhibitor vemurafenib in preclinical models of BRAF-mutant colorectal cancer.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 2,
                                    "year": 2012,
                                },
                                "pubmed": 22180495,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22180495",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-06-18T21:56:48.139Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A 31 year old patient with metastatic cholangiocarcinoma with BRAF V600E was treated with vemurafenib, panitumumab and irinotecan triplet therapy. By 2 months, 50% reduction of tumor volume was noted, including multiple lung metastases, complete clinical response was noted by CT 6 months post therapy and this treatment was continued.",
                            "disease": {
                                "display_name": "Cholangiocarcinoma",
                                "doid": "DOID:4947",
                                "id": 29,
                                "name": "Cholangiocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:4947",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                                {
                                    "aliases": [
                                        "[1,4'-bipiperidine]-1'-carboxylic Acid (S)-4,11-diethyl-3,4,12,14-tetrahydro-4-hydroxy-3,14-dioxo-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinolin-9-yl Ester",
                                        "7-ethyl-10-[4-(1-piperidino)-1-piperidino]carbonyloxycamptothecin",
                                        "(+)-7-ethyl-10-hydroxycamptothecine 10-[1,4'-bipiperidine]-1'-carboxylate",
                                        "(+)-(4S)-4,11-diethyl-4-hydroxy-9-[(4-piperidino-piperidino)carbonyloxy]-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinol-3,14,(4H,12H)-dione",
                                    ],
                                    "id": 101,
                                    "name": "Irinotecan",
                                    "ncit_id": "C62040",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5906,
                            "name": "EID5906",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Silkin et al., 2016, J Gastrointest Cancer",
                                "full_journal_title": "Journal of gastrointestinal cancer",
                                "id": 2382,
                                "is_review": False,
                                "journal": "J Gastrointest Cancer",
                                "name": "Complete Clinical Response of BRAF-Mutated Cholangiocarcinoma to Vemurafenib, Panitumumab, and Irinotecan.",
                                "publication_date": {"month": 12, "year": 2016},
                                "pubmed": 26687137,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26687137",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-05-14T19:05:37.249Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "The phase 2a MyPathway study assigned patients with HER2, EGFR, BRAF or SHH alterations to treatment with pertuzumab plus trastuzumab, erlotinib, vemurafenib, or vismodegib, respectively.\nAmong 4 patients with BRAF V600E mutant ovarian cancer, 2 had a partial response and one had stable disease > 120days.",
                            "disease": {
                                "display_name": "Ovarian Cancer",
                                "doid": "DOID:2394",
                                "id": 20,
                                "name": "Ovarian Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:2394",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5959,
                            "name": "EID5959",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Hainsworth et al., 2018, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02091141",
                                        "description": "This multicenter, non-randomized, open-label study will evaluate the efficacy and safety of six treatment regimens in participants with advanced solid tumors for whom therapies that will convey clinical benefit are not available and/or are not suitable options per the treating physician's judgment.",
                                        "name": "My Pathway: A Study Evaluating Herceptin/Perjeta, Tarceva, Zelboraf/Cotellic, Erivedge, Alecensa, and Tecentriq Treatment Targeted Against Certain Molecular Alterations in Participants With Advanced Solid Tumors",
                                        "nct_id": "NCT02091141",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 2414,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Targeted Therapy for Advanced Solid Tumors on the Basis of Molecular Profiles: Results From MyPathway, an Open-Label, Phase IIa Multiple Basket Study.",
                                "publication_date": {"day": 20, "year": 2018},
                                "pubmed": 29320312,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29320312",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-02-15T21:52:07.629Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "The phase 2a MyPathway study assigned patients with HER2, EGFR, BRAF or SHH alterations to treatment with pertuzumab plus trastuzumab, erlotinib, vemurafenib, or vismodegib, respectively.\nWithin the BRAF mutant group, fourteen patients had refractory BRAF V600E-mutated NSCLC (adenocarcinoma, n = 13; sarcomatoid, n = 1). Six patients (43%; 95% CI, 18% to 71%) had objective responses (one CR, five PR), and two additional patients had SD > 120 days. The median DOR was 5 months (range, 4 to 14 months).",
                            "disease": {
                                "display_name": "Lung Non-small Cell Carcinoma",
                                "doid": "DOID:3908",
                                "id": 8,
                                "name": "Lung Non-small Cell Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3908",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5958,
                            "name": "EID5958",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Hainsworth et al., 2018, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02091141",
                                        "description": "This multicenter, non-randomized, open-label study will evaluate the efficacy and safety of six treatment regimens in participants with advanced solid tumors for whom therapies that will convey clinical benefit are not available and/or are not suitable options per the treating physician's judgment.",
                                        "name": "My Pathway: A Study Evaluating Herceptin/Perjeta, Tarceva, Zelboraf/Cotellic, Erivedge, Alecensa, and Tecentriq Treatment Targeted Against Certain Molecular Alterations in Participants With Advanced Solid Tumors",
                                        "nct_id": "NCT02091141",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 2414,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Targeted Therapy for Advanced Solid Tumors on the Basis of Molecular Profiles: Results From MyPathway, an Open-Label, Phase IIa Multiple Basket Study.",
                                "publication_date": {"day": 20, "year": 2018},
                                "pubmed": 29320312,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29320312",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-02-15T21:50:44.200Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, WiDr, HT-29, LS411N, and SW1417 cell lines expressing BRAF V600E and treated with vemurafenib and erlotinib, or vemurafenib and gefitinib were associated with a reduction in cell viability (P<0.01), as compared to cells treated solely with vemurafenib or vehicle. WiDr and HT-29 cell lines expressing BRAF V600E were associated with a modest reduction in cell viability. Sensitivity was determined by assessing cell viability after 72h of vemurafenib treatement. In an in vivo study, WiDr and HT-29 xenografts expression BRAF V600E and treated with vemurafenib and erlotinib combination therapy were associated with reduced tumor volume (P<0.05) as compared to xenografts treated with vemurafenib alone, erlotinib alone, or vehicle alone.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3741,
                            "name": "EID3741",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Corcoran et al., 2012, Cancer Discov",
                                "full_journal_title": "Cancer discovery",
                                "id": 1947,
                                "is_review": False,
                                "journal": "Cancer Discov",
                                "name": "EGFR-mediated re-activation of MAPK signaling contributes to insensitivity of BRAF mutant colorectal cancers to RAF inhibition with vemurafenib.",
                                "open_access": True,
                                "pmc_id": "PMC3308191",
                                "publication_date": {"month": 3, "year": 2012},
                                "pubmed": 22448344,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22448344",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:44.640Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a clinical study of 122 cancer patients, including 37 previously treated colorectal cancer patients harboring BRAF V600 (V600E=32; V600 unknown=5) mutations, stable disease and progressive disease were reported in 50% of patients (n=5/10) treated with vemurafenib monotherapy, respectively.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3742,
                            "name": "EID3742",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hyman et al., 2015, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01524978",
                                        "description": "This open-label, multi-center study will assess the efficacy and safety of vemurafenib in participants with BRAF V600 mutation-positive cancers (solid tumors and multiple myeloma, except melanoma and papillary thyroid cancer) and for whom vemurafenib is deemed the best treatment option in the opinion of the investigator. Participants will receive twice daily oral doses of 960 mg vemurafenib until disease progression, unacceptable toxicity, or withdrawal of consent. The safety and efficacy of vemurafenib in combination with cetuximab in a subset of participants with colorectal cancer will also be assessed.",
                                        "name": "A Study of Vemurafenib in Participants With BRAF V600 Mutation-Positive Cancers",
                                        "nct_id": "NCT01524978",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1040,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Vemurafenib in Multiple Nonmelanoma Cancers with BRAF V600 Mutations.",
                                "open_access": True,
                                "pmc_id": "PMC4971773",
                                "publication_date": {
                                    "day": 20,
                                    "month": 8,
                                    "year": 2015,
                                },
                                "pubmed": 26287849,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26287849",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:45.562Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A 51 year old male anaplastic thyroid cancer patient harboring BRAF V600E experienced rapid improvement in response to vemurafenib. The patient was initially treated with paclitaxel and carboplatin but experienced disease progression; subsequently, the patient was treated concurrently with vemurafenib and radiation therapy and achieved near complete regression of metastatic disease.",
                            "disease": {
                                "display_name": "Thyroid Gland Anaplastic Carcinoma",
                                "doid": "DOID:0080522",
                                "id": 3040,
                                "name": "Thyroid Gland Anaplastic Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:0080522",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                },
                                {
                                    "aliases": [
                                        "ENERGY_TYPE",
                                        "Radiation Therapy, NOS",
                                        "Therapy, Radiation",
                                        "RT",
                                        "RADIOTHERAPY",
                                        "Radiotherapeutics",
                                        "RADIATION",
                                        "Irradiation",
                                        "Irradiated",
                                        "Irradiate",
                                        "Cancer Radiotherapy",
                                    ],
                                    "id": 360,
                                    "name": "Radiation Therapy",
                                    "ncit_id": "C15313",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3743,
                            "name": "EID3743",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Rosove et al., 2013, N. Engl. J. Med.",
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1948,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "BRAF V600E inhibition in anaplastic thyroid cancer.",
                                "publication_date": {
                                    "day": 14,
                                    "month": 2,
                                    "year": 2013,
                                },
                                "pubmed": 23406047,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23406047",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-12-10T20:05:17.568Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an 80 year old female anaplastic thyroid cancer patient harboring BRAF V600E and TP53 E180K co-mutations, BRAF V600E was associated with response to vemurafenib treatment. Prior to identification of the BRAF V600E mutation, the patient was treated with 6 cycles of standard chemotherapy plus radiation and experienced progressive disease; subsequently, the patient achieved an almost complete response with 61 weeks of vemurafenib monotherapy followed by disease progression.",
                            "disease": {
                                "display_name": "Thyroid Gland Anaplastic Carcinoma",
                                "doid": "DOID:0080522",
                                "id": 3040,
                                "name": "Thyroid Gland Anaplastic Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:0080522",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3744,
                            "name": "EID3744",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Prager et al., 2016, Thyroid",
                                "full_journal_title": "Thyroid : official journal of the American Thyroid Association",
                                "id": 1949,
                                "is_review": False,
                                "journal": "Thyroid",
                                "name": "Sustained Response to Vemurafenib in a BRAF(V600E)-Mutated Anaplastic Thyroid Carcinoma Patient.",
                                "publication_date": {"month": 10, "year": 2016},
                                "pubmed": 27532222,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27532222",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-12-10T21:45:23.416Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Acquired resistance to vemurafenib in BRAF V600E-positive melanomas frequently confound vemurafenib therapy. Proposed resistance mechanisms include PDGFRB upregulation or NRAS mutations resulting in MAPK pathway reactivation but not secondary mutations in BRAF. MEK inhibitors may demonstrate clinical benefit in vemurafenib resistant melanoma patients.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3745,
                            "name": "EID3745",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Johannessen et al., 2010, Nature",
                                "full_journal_title": "Nature",
                                "id": 1492,
                                "is_review": False,
                                "journal": "Nature",
                                "name": "COT drives resistance to RAF inhibition through MAP kinase pathway reactivation.",
                                "open_access": True,
                                "pmc_id": "PMC3058384",
                                "publication_date": {
                                    "day": 16,
                                    "month": 12,
                                    "year": 2010,
                                },
                                "pubmed": 21107320,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21107320",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:47.710Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Acquired resistance to vemurafenib in BRAF V600E-positive melanomas frequently confound vemurafenib therapy. Proposed resistance mechanisms include PDGFRB upregulation or NRAS mutations resulting in MAPK pathway reactivation but not secondary mutations in BRAF. MEK inhibitors may demonstrate clinical benefit in vemurafenib resistant melanoma patients.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3746,
                            "name": "EID3746",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Nazarian et al., 2010, Nature",
                                "full_journal_title": "Nature",
                                "id": 1491,
                                "is_review": False,
                                "journal": "Nature",
                                "name": "Melanomas acquire resistance to B-RAF(V600E) inhibition by RTK or N-RAS upregulation.",
                                "open_access": True,
                                "pmc_id": "PMC3143360",
                                "publication_date": {
                                    "day": 16,
                                    "month": 12,
                                    "year": 2010,
                                },
                                "pubmed": 21107323,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21107323",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:48.380Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, cell lines (including YUHUY and YUSAC2) expressing BRAF V600E were associated with increased sensitivity to vemurafenib (PLX4032) treatment, as compared to cell lines expressing wild-type BRAF. Sensitive was determined by assessing cellular proliferation, and ERK and MEK phosphorylation.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3747,
                            "name": "EID3747",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Halaban et al., 2010, Pigment Cell Melanoma Res",
                                "full_journal_title": "Pigment cell & melanoma research",
                                "id": 1482,
                                "is_review": False,
                                "journal": "Pigment Cell Melanoma Res",
                                "name": "PLX4032, a selective BRAF(V600E) kinase inhibitor, activates the ERK pathway and enhances cell migration and proliferation of BRAF melanoma cells.",
                                "open_access": True,
                                "pmc_id": "PMC2848976",
                                "publication_date": {"month": 4, "year": 2010},
                                "pubmed": 20149136,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20149136",
                                "status": "submitted",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:49.754Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An inducible BRAF-V600E mouse melanoma model shows a tight correlation between activated BRAF and disease progression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3748,
                            "name": "EID3748",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hoeflich et al., 2006, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1485,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF is required for tumor growth and maintenance in melanoma models.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16424035,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16424035",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:50.332Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a retrospective study of 30 metastatic melanoma patients with progressing metastases, patients with BRAF V600E mutation (n=8) treated with vemurafenib monotherapy achieved a partial response (n=5) and stable disease (n=1).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3749,
                            "name": "EID3749",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Rizos et al., 2014, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 1951,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "BRAF inhibitor resistance mechanisms in metastatic melanoma: spectrum and clinical impact.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 4,
                                    "year": 2014,
                                },
                                "pubmed": 24463458,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24463458",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:51.274Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase 2 clinical trial (NCT00949702) of 132 BRAF mutation positive metastatic melanoma patients treated with vemurafenib monotherapy, patients harboring BRAF V600E (n=123) or V600K (n=9) mutations were associated with a favorable objective response rate (53% per RECIST v1.1 criteria, 70/132), with 6% (8/132) and 47% (62/132) of patients achieving complete response and partial response, respectively.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3750,
                            "name": "EID3750",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Trunzer et al., 2013, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 60,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Pharmacodynamic effects and mechanisms of resistance to vemurafenib in patients with metastatic melanoma.",
                                "publication_date": {
                                    "day": 10,
                                    "month": 5,
                                    "year": 2013,
                                },
                                "pubmed": 23569304,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23569304",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-10-29T23:45:43.590Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, BRAF V600E expressing cell lines (COLO205, A375 and COLO829) demonstrated improved sensitivity to vemurafenib treatment, compared to BRAF wild-type expressing cells. Sensitivity was determined by assessing cell proliferation (COLO205, GI50: 0.31uM; A375, GI50: 0.50 uM; COLO829, GI50: 1.7 uM vs. BRAF expressing cells (n=9) GI50: 10-41uM) and ERK phosphorylation.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3751,
                            "name": "EID3751",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Tsai et al., 2008, Proc. Natl. Acad. Sci. U.S.A.",
                                "full_journal_title": "Proceedings of the National Academy of Sciences of the United States of America",
                                "id": 1952,
                                "is_review": False,
                                "journal": "Proc. Natl. Acad. Sci. U.S.A.",
                                "name": "Discovery of a selective inhibitor of oncogenic B-Raf kinase with potent antimelanoma activity.",
                                "open_access": True,
                                "pmc_id": "PMC2268581",
                                "publication_date": {
                                    "day": 26,
                                    "month": 2,
                                    "year": 2008,
                                },
                                "pubmed": 18287029,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/18287029",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:52.878Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, a MBA72 cell line expressing BRAF V600E demonstrated improved sensitivity to vemurafenib treatment, compared to LND-1 cells expression BRAF wild-type. Sensitivity was determined by assessing cell proliferation (MBA72, IC50: 3.2uM; vs. LND-1, IC50: 32.2 uM).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3752,
                            "name": "EID3752",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Porcelli et al., 2015, Cancer Chemother. Pharmacol.",
                                "full_journal_title": "Cancer chemotherapy and pharmacology",
                                "id": 1953,
                                "is_review": False,
                                "journal": "Cancer Chemother. Pharmacol.",
                                "name": "Metastatic melanoma cells with BRAF G469A mutation: nab-paclitaxel better than vemurafenib?",
                                "publication_date": {"month": 8, "year": 2015},
                                "pubmed": 26070258,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26070258",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:53.720Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, several cell lines (including MALME-3M, Colo829, Colo38, A375 and SK-MEK28) expressing BRAF V600E were associated with increased sensitivity to vemurafenib (RG7204) treatment, as compared to cell lines expressing BRAF wild-type. Sensitivity was determined by proliferation assay and by assessing MEK1/2 phosphorylation. Further, in an in vivo study, LOX, Colo829 and A375 xenografts were reportedly sensitive to vemurafenib treatment as assessed by tumor volume.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3753,
                            "name": "EID3753",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Yang et al., 2010, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 351,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "RG7204 (PLX4032), a selective BRAFV600E inhibitor, displays potent antitumor activity in preclinical melanoma models.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 7,
                                    "year": 2010,
                                },
                                "pubmed": 20551065,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20551065",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:54.404Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a stage I melanoma patient harboring a BRAF V600E mutation, response to vemurafenib monotherapy was reported. Upon identification of the BRAF V600E mutation, the patient enrolled in a clinical trial and was treated with vemurafenib monotherapy, a partial response was reported. However, novel hypermetabolic nodules developed and the patient enrolled in another clinical trial, undergoing combination therapy of vemurafenib and GDC-0973, but disease progression occurred at 5 months. Subsequently, the patient was treated with vemurafenib and ipilimumab, achieving a confirmed complete response.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3754,
                            "name": "EID3754",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Ashworth et al., 2014, J Natl Compr Canc Netw",
                                "full_journal_title": "Journal of the National Comprehensive Cancer Network : JNCCN",
                                "id": 1954,
                                "is_review": False,
                                "journal": "J Natl Compr Canc Netw",
                                "name": "Management of a patient with advanced BRAF-mutant melanoma.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 3,
                                    "year": 2014,
                                },
                                "pubmed": 24616537,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24616537",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:55.027Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a clinical study (NCT01307397) of Polish, stage IIIC/IV, melanoma patients with metastases (n=75) harboring BRAF V600 mutation (as detected by cobas 4800 BRAF V600 Mutation Test), median overall survival was 61.9% (95% CI: 50.1-73.6) and median progression free survival was 7.4 months (95% CI: 5.5-9.2). Median duration of response was 7.4 months (95% CI: 5.7-9.2), with 3% (2/75) and 43% (29/75) of patients achieving a complete and partial response, respectively.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3755,
                            "name": "EID3755",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Rutkowski et al., 2015, Contemp Oncol (Pozn)",
                                "full_journal_title": "Contemporary oncology (Poznan, Poland)",
                                "id": 1955,
                                "is_review": False,
                                "journal": "Contemp Oncol (Pozn)",
                                "name": "The outcomes of Polish patients with advanced BRAF-positive melanoma treated with vemurafenib in a safety clinical trial.",
                                "open_access": True,
                                "pmc_id": "PMC4631301",
                                "publication_date": {"year": 2015},
                                "pubmed": 26557775,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26557775",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-10-29T23:51:37.507Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study of 27 melanoma cell lines, 18 out of 20 cell lines expressing BRAF V600E mutation were associated with sensitivity to vemurafenib treatment (IC50: 0.01-1�M). Sensitivity was determined by assessing growth inhibition.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3756,
                            "name": "EID3756",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Vergani et al., 2011, Neoplasia",
                                "full_journal_title": "Neoplasia (New York, N.Y.)",
                                "id": 1956,
                                "is_review": False,
                                "journal": "Neoplasia",
                                "name": "Identification of MET and SRC activation in melanoma cell lines showing primary resistance to PLX4032.",
                                "open_access": True,
                                "pmc_id": "PMC3257188",
                                "publication_date": {"month": 12, "year": 2011},
                                "pubmed": 22241959,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22241959",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:56.284Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a retrospective study of 300 stage IV melanoma patients, patients with BRAF V600E mutation (n=175) were associated with a 4.8% (8/167) complete response, a 58.1% (97/167) partial response and stable disease in 22.2% (37/167) of cases, while 15% (25/167) of patients harboring BRAF V600E experienced progressive disease.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3757,
                            "name": "EID3757",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Ugurel et al., 2015, Ann. Oncol.",
                                "full_journal_title": "Annals of oncology : official journal of the European Society for Medical Oncology",
                                "id": 1957,
                                "is_review": False,
                                "journal": "Ann. Oncol.",
                                "name": "A multicenter DeCOG study on predictors of vemurafenib therapy outcome in melanoma: pretreatment impacts survival.",
                                "publication_date": {"month": 3, "year": 2015},
                                "pubmed": 25524477,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25524477",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-10-29T23:46:37.912Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Thyroid cancer cell lines with BRAF V600E mutations were more sensitive to vemurafenib than those with wildtype BRAF (IC50: 0.115� 1.156 uM vs. 56.674�1349.788 uM).",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3760,
                            "name": "EID3760",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Sala et al., 2008, Mol. Cancer Res.",
                                "full_journal_title": "Molecular cancer research : MCR",
                                "id": 1959,
                                "is_review": False,
                                "journal": "Mol. Cancer Res.",
                                "name": "BRAF silencing by short hairpin RNA or chemical blockade by PLX4032 leads to different responses in melanoma and thyroid carcinoma cells.",
                                "publication_date": {"month": 5, "year": 2008},
                                "pubmed": 18458053,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/18458053",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:00.692Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, the HCC364 cell line expressing a BRAF V600E mutation was associated with sensitivity to vemurafenib treatment. Sensitivity was determined by assessing cell viability, apoptosis and colony formation.",
                            "disease": {
                                "display_name": "Lung Non-small Cell Carcinoma",
                                "doid": "DOID:3908",
                                "id": 8,
                                "name": "Lung Non-small Cell Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3908",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3761,
                            "name": "EID3761",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Joshi et al., 2015, PLoS ONE",
                                "full_journal_title": "PloS one",
                                "id": 1960,
                                "is_review": False,
                                "journal": "PLoS ONE",
                                "name": "Trametinib with or without vemurafenib in BRAF mutated non-small cell lung cancer.",
                                "open_access": True,
                                "pmc_id": "PMC4338247",
                                "publication_date": {"year": 2015},
                                "pubmed": 25706985,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25706985",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:01.478Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a mouse xenograft model, tumors derived from the glioblastoma cell line AM-38 that were treated with vemurafenib had reduced tumor growth and improved survival compared to control treated mice (P=0.018 and 0.0002, respectively). In contrast, mice with wildtype BRAF xenografts did not respond vemurafenib compared to control treatment as measured by tumor size and survival (P=0.179 and P=0.225, respectively ). A malignant astrocytoma cell line that expressed BRAF V600E was more sensitive to growth inhibition by vemurafenib than a cell line with wildtype BRAF (EC50=1.75 vs. 31.2 umol/L).",
                            "disease": {
                                "display_name": "High Grade Glioma",
                                "doid": "DOID:3070",
                                "id": 695,
                                "name": "High Grade Glioma",
                                "url": "http://disease-ontology.org/?id=DOID:3070",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3762,
                            "name": "EID3762",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Nicolaides et al., 2011, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 348,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "Targeted therapy for BRAFV600E malignant astrocytoma.",
                                "open_access": True,
                                "pmc_id": "PMC3638050",
                                "publication_date": {
                                    "day": 15,
                                    "month": 12,
                                    "year": 2011,
                                },
                                "pubmed": 22038996,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22038996",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:02.242Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "A study of pediatric malignant astrocytomas found that tumors with BRAF V600E mutations also had homozygous deletions of CDKN2A more frequently than those with wildtype BRAF (71%  vs. 8% , P=0.0016, Fisher�s exact test).",
                            "disease": {
                                "display_name": "High Grade Glioma",
                                "doid": "DOID:3070",
                                "id": 695,
                                "name": "High Grade Glioma",
                                "url": "http://disease-ontology.org/?id=DOID:3070",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3763,
                            "name": "EID3763",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Schiffman et al., 2010, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1961,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF mutation with CDKN2A inactivation is characteristic of a subset of pediatric malignant astrocytomas.",
                                "open_access": True,
                                "pmc_id": "PMC2851233",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2010,
                                },
                                "pubmed": 20068183,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20068183",
                                "status": "fully curated",
                            },
                            "status": "rejected",
                            "type": "evidence",
                            "updated_at": "2018-02-15T14:35:49.808Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a study of  pilocytic astrocytomas, presence of the BRAF V600E mutation was more frequently detected in extra-cerebellar pilocytic astrocytomas than cerebellar ones (20%  vs. 2% , P=0.009, Fisher�s exact test).",
                            "disease": {
                                "display_name": "High Grade Glioma",
                                "doid": "DOID:3070",
                                "id": 695,
                                "name": "High Grade Glioma",
                                "url": "http://disease-ontology.org/?id=DOID:3070",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3764,
                            "name": "EID3764",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Schindler et al., 2011, Acta Neuropathol.",
                                "full_journal_title": "Acta neuropathologica",
                                "id": 1962,
                                "is_review": False,
                                "journal": "Acta Neuropathol.",
                                "name": "Analysis of BRAF V600E mutation in 1,320 nervous system tumors reveals high mutation frequencies in pleomorphic xanthoastrocytoma, ganglioglioma and extra-cerebellar pilocytic astrocytoma.",
                                "publication_date": {"month": 3, "year": 2011},
                                "pubmed": 21274720,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21274720",
                                "status": "fully curated",
                            },
                            "status": "rejected",
                            "type": "evidence",
                            "updated_at": "2018-02-15T14:38:05.250Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a study of low grade pediatric gliomas, 19 of 157 tumors had a BRAF V600E mutation. Tumors located in the cerebrum had a higher frequency of BRAF mutations than those in the cerebellum or midline (P<0.05). While it did not reach statistical significance, there was a trend between BRAF V600E mutation and reduced progression-free survival (HR:2.39, 95%CI:0.93-6.15, P=0.07, multivariate analysis).",
                            "disease": {
                                "display_name": "High Grade Glioma",
                                "doid": "DOID:3070",
                                "id": 695,
                                "name": "High Grade Glioma",
                                "url": "http://disease-ontology.org/?id=DOID:3070",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3765,
                            "name": "EID3765",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Horbinski et al., 2012, Neuro-oncology",
                                "full_journal_title": "Neuro-oncology",
                                "id": 1499,
                                "is_review": False,
                                "journal": "Neuro-oncology",
                                "name": "Interplay among BRAF, p16, p53, and MIB1 in pediatric low-grade gliomas.",
                                "open_access": True,
                                "pmc_id": "PMC3367847",
                                "publication_date": {"month": 6, "year": 2012},
                                "pubmed": 22492957,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22492957",
                                "status": "fully curated",
                            },
                            "status": "rejected",
                            "type": "evidence",
                            "updated_at": "2018-02-15T14:39:52.726Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a refractory hairy cell leukemia patient harboring BRAF V600E mutation, BRAF V600E was associated with sensitivity to vemurafenib treatment. The patient was initially treated with conventional treatments and failed to respond; subsequently, the patient was treated with vemurafenib monotherapy and achieved complete remission on day 43 with treatment being terminated at day 56.",
                            "disease": {
                                "display_name": "Hairy Cell Leukemia",
                                "doid": "DOID:285",
                                "id": 665,
                                "name": "Hairy Cell Leukemia",
                                "url": "http://disease-ontology.org/?id=DOID:285",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Zelboraf",
                                        "RO 5185426",
                                        "RG7204",
                                        "RG 7204",
                                        "PLX4032",
                                        "PLX-4032",
                                        "BRAF(V600E) Kinase Inhibitor RO5185426",
                                        "BRAF (V600E) Kinase Inhibitor RO5185426",
                                        "1-propanesulfonamide, N-(3-((5-(4-chlorophenyl)-1h-pyrrolo(2,3-b)pyridin-3-yl)carbonyl)-2,4-difluorophenyl)-",
                                    ],
                                    "id": 4,
                                    "name": "Vemurafenib",
                                    "ncit_id": "C64768",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3766,
                            "name": "EID3766",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Dietrich et al., 2012, N. Engl. J. Med.",
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1963,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "BRAF inhibition in refractory hairy-cell leukemia.",
                                "publication_date": {
                                    "day": 24,
                                    "month": 5,
                                    "year": 2012,
                                },
                                "pubmed": 22621641,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22621641",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:06.553Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An inducible BRAF-V600E mouse melanoma model has shown a tight correlation between activated BRAF and disease progression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Bay-439006",
                                        "BAY 43-9006",
                                        "BA4 43 9006",
                                    ],
                                    "id": 6,
                                    "name": "Sorafenib",
                                    "ncit_id": "C61948",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2123,
                            "name": "EID2123",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hoeflich et al., 2006, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1485,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF is required for tumor growth and maintenance in melanoma models.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16424035,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16424035",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:00.258Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a study of 102 papillary thyroid cancer patients with a 15 year median follow-up time, those with BRAF V600E mutations had reduced overall survival compared to those with wildtype BRAF (P=0.015, log-rank test). The presence of BRAF V600E was associated with poorer outcome as defined by persistent disease or death (Odds ratio:14.63, 95%CI:1.28-167.29, P=0.03, multivariate analysis.",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Bay-439006",
                                        "BAY 43-9006",
                                        "BA4 43 9006",
                                    ],
                                    "id": 6,
                                    "name": "Sorafenib",
                                    "ncit_id": "C61948",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2504,
                            "name": "EID2504",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Elisei et al., 2008, J. Clin. Endocrinol. Metab.",
                                "full_journal_title": "The Journal of clinical endocrinology and metabolism",
                                "id": 1494,
                                "is_review": False,
                                "journal": "J. Clin. Endocrinol. Metab.",
                                "name": "BRAF(V600E) mutation and outcome of patients with papillary thyroid carcinoma: a 15-year median follow-up study.",
                                "publication_date": {"month": 10, "year": 2008},
                                "pubmed": 18682506,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/18682506",
                                "status": "partially curated",
                            },
                            "status": "rejected",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:35:40.791Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a mouse in vivo study, the dual RAF and VEGF inhibitor sorafenib suppressed the growth of both UACC903 and 1205Lu cell line- generating  xenograft tumors harboring the BRAF-V600E mutation, which had a concomitant reduction of phosphorylated Erk-positive cells (P<0.05).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Bay-439006",
                                        "BAY 43-9006",
                                        "BA4 43 9006",
                                    ],
                                    "id": 6,
                                    "name": "Sorafenib",
                                    "ncit_id": "C61948",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2122,
                            "name": "EID2122",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Sharma et al., 2005, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1484,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Mutant V599EB-Raf regulates growth and vascular development of malignant melanoma tumors.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 3,
                                    "year": 2005,
                                },
                                "pubmed": 15781657,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/15781657",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:00.154Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Cetuximab or panitumumab may be ineffective in patients with BRAF mutation unless BRAF inhibitor such as Sorafenib is introduced.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Bay-439006",
                                        "BAY 43-9006",
                                        "BA4 43 9006",
                                    ],
                                    "id": 6,
                                    "name": "Sorafenib",
                                    "ncit_id": "C61948",
                                },
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 89,
                            "name": "EID89",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Di Nicolantonio et al., 2008, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 100,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.",
                                "publication_date": {
                                    "day": 10,
                                    "month": 12,
                                    "year": 2008,
                                },
                                "pubmed": 19001320,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19001320",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2017-09-16T01:20:46.591Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Cetuximab or panitumumab may be ineffective in patients with BRAF mutation unless BRAF inhibitor such as Sorafenib is introduced.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Bay-439006",
                                        "BAY 43-9006",
                                        "BA4 43 9006",
                                    ],
                                    "id": 6,
                                    "name": "Sorafenib",
                                    "ncit_id": "C61948",
                                },
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2894,
                            "name": "EID2894",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Di Nicolantonio et al., 2008, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 100,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.",
                                "publication_date": {
                                    "day": 10,
                                    "month": 12,
                                    "year": 2008,
                                },
                                "pubmed": 19001320,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19001320",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-04-02T01:23:03.453Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Following treatment with sorafenib, thyroid cancer cell lines with BRAF V600E mutations had severely reduced proliferation rates, but cells with wildtype BRAF were insensitive (P<0.0001).",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Bay-439006",
                                        "BAY 43-9006",
                                        "BA4 43 9006",
                                    ],
                                    "id": 6,
                                    "name": "Sorafenib",
                                    "ncit_id": "C61948",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2142,
                            "name": "EID2142",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Salvatore et al., 2006, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 1497,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "BRAF is a therapeutic target in aggressive thyroid carcinoma.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 3,
                                    "year": 2006,
                                },
                                "pubmed": 16533790,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16533790",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:06.156Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "This meta-analysis of 7 randomized control trials evaluating overall survival (OS) (8 for progression free survival) could not definitely state that survival benefit of anti-EGFR monoclonal antibodies is limited to patients with wild type BRAF. In other words, the authors believe that there is insufficient data to justify the exclusion of anti-EGFR monoclonal antibody therapy for patients with mutant BRAF. In these studies, mutant BRAF specifically meant the V600E mutation.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Substitutes",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                            ],
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 816,
                            "name": "EID816",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Rowland et al., 2015, Br. J. Cancer",
                                "full_journal_title": "British journal of cancer",
                                "id": 548,
                                "is_review": False,
                                "journal": "Br. J. Cancer",
                                "name": "Meta-analysis of BRAF mutation as a predictive biomarker of benefit from anti-EGFR monoclonal antibody therapy for RAS wild-type metastatic colorectal cancer.",
                                "open_access": True,
                                "pmc_id": "PMC4580381",
                                "publication_date": {
                                    "day": 9,
                                    "month": 6,
                                    "year": 2015,
                                },
                                "pubmed": 25989278,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25989278",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-02-18T19:56:58.899Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In a retrospective study of 53, KRAS exon 2 wild-type, metastatic colorectal cancer patients, patients harboring BRAF G466A (n=1), G469A (n=2), D594G (n=1), or V600E (n=2) mutations were reported to be non-responders to cetuximab in combination with irinotecan, (BRAF mutation positive: responders vs. non-responders = 0 vs. 6; BRAF wild-type: responders vs. non-responders 30 vs. 17; P=0.004), as compared to patients with wild-type BRAF.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"}
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3740,
                            "name": "EID3740",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hsu et al., 2016, Oncotarget",
                                "full_journal_title": "Oncotarget",
                                "id": 1946,
                                "is_review": False,
                                "journal": "Oncotarget",
                                "name": "Mutations of KRAS/NRAS/BRAF predict cetuximab resistance in metastatic colorectal cancer patients.",
                                "open_access": True,
                                "pmc_id": "PMC5008360",
                                "publication_date": {
                                    "day": 19,
                                    "month": 4,
                                    "year": 2016,
                                },
                                "pubmed": 26989027,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26989027",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:57:16.196Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "665 patients with BRAF V600E-mutated metastatic CRC were enrolled In this open-label, phase 3 trial. Patients were randomly assigned in a 1:1:1 ratio to receive encorafenib, binimetinib, and cetuximab (triplet-therapy group); encorafenib and cetuximab (doublet-therapy group); or the investigators’ choice of either cetuximab and irinotecan or cetuximab and FOLFIRI. The median overall survival was 9.0 months in the triplet-therapy group and 5.4 months in the control group (hazard ratio for death, 0.52; 95% confidence interval [CI], 0.39 to 0.70; P<0.001). The confirmed response rate was 26% (95% CI, 18 to 35) in the triplet-therapy group and 2% (95% CI, 0 to 7) in the control group (triplet group vs. control P<0.001). The median progression-free survival in the triplet-therapy group was 4.3 months (95% CI, 4.1 to 5.2) and 1.5 months (95% CI, 1.5 to 1.7) in the control group (hazard ratio for disease progression or death, 0.38; 95% CI, 0.29 to 0.49; P<0.001).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "LGX818",
                                        "LGX-818",
                                        "LGX 818",
                                        "Braftovi",
                                    ],
                                    "id": 483,
                                    "name": "Encorafenib",
                                    "ncit_id": "C98283",
                                },
                                {
                                    "aliases": [
                                        "Mektovi",
                                        "MEK162",
                                        "ARRY-438162",
                                        "ARRY-162",
                                    ],
                                    "id": 485,
                                    "name": "Binimetinib",
                                    "ncit_id": "C84865",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7612,
                            "name": "EID7612",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Kopetz et al., 2019, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02928224",
                                        "description": "This is a multicenter, randomized, open-label, 3-arm Phase 3 study to evaluate encorafenib + cetuximab plus or minus binimetinib versus Investigator's choice of either irinotecan/cetuximab or FOLFIRI/cetuximab, as controls, in patients with BRAFV600E mCRC whose disease has progressed after 1 or 2 prior regimens in the metastatic setting. The study contains a Safety Lead-in Phase in which the safety and tolerability of encorafenib + binimetinib + cetuximab will be assessed prior to the Phase 3 portion of the study.",
                                        "name": "Study of Encorafenib + Cetuximab Plus or Minus Binimetinib vs. Irinotecan/Cetuximab or Infusional 5-Fluorouracil (5-FU)/Folinic Acid (FA)/Irinotecan (FOLFIRI)/Cetuximab With a Safety Lead-in of Encorafenib + Binimetinib + Cetuximab in Patients With BRAF V600E-mutant Metastatic Colorectal Cancer",
                                        "nct_id": "NCT02928224",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 3025,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Encorafenib, Binimetinib, and Cetuximab in BRAF V600E-Mutated Colorectal Cancer.",
                                "publication_date": {"day": 24, "year": 2019},
                                "pubmed": 31566309,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/31566309",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2022-02-11T23:46:25.754Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "The open-label phase 3 BEACON CRC trial included 665 patients with BRAF V600E-mutated metastatic CRC. Patients were randomly assigned in a 1:1:1 ratio to receive encorafenib, binimetinib, and cetuximab (triplet-therapy group); encorafenib and cetuximab (doublet-therapy group); or the investigators’ choice of either cetuximab and irinotecan or cetuximab and FOLFIRI. The median overall survival was 8.4 months (95% CI, 7.5 to 11.0) in the doublet-therapy group and 5.4 months (95% CI, 4.8 to 6.6) in the control group, with a significantly lower risk of death compared to the control group (hazard ratio for death doublet-group vs. control, 0.60; 95% CI, 0.45 to 0.79; P<0.001). The confirmed response rate was 26% (95% CI, 18 to 35) in the triplet-therapy group, 20% in the doublet-therapy group (95% CI 13 to 29) and 2% (95% CI, 0 to 7) in the control group (doublet group vs. control P<0.001). Median PFS was 4.2 months (95% CI, 3.7 to 5.4) in the doublet-therapy group, and 1.5 months (95% CI, 1.5 to 1.7) in the control group (hazard ratio for disease progression doublet-group vs control, 0.40; 95% CI, 0.31 to 0.52, P<0.001).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "LGX818",
                                        "LGX-818",
                                        "LGX 818",
                                        "Braftovi",
                                    ],
                                    "id": 483,
                                    "name": "Encorafenib",
                                    "ncit_id": "C98283",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "A",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 9851,
                            "name": "EID9851",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Kopetz et al., 2019, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02928224",
                                        "description": "This is a multicenter, randomized, open-label, 3-arm Phase 3 study to evaluate encorafenib + cetuximab plus or minus binimetinib versus Investigator's choice of either irinotecan/cetuximab or FOLFIRI/cetuximab, as controls, in patients with BRAFV600E mCRC whose disease has progressed after 1 or 2 prior regimens in the metastatic setting. The study contains a Safety Lead-in Phase in which the safety and tolerability of encorafenib + binimetinib + cetuximab will be assessed prior to the Phase 3 portion of the study.",
                                        "name": "Study of Encorafenib + Cetuximab Plus or Minus Binimetinib vs. Irinotecan/Cetuximab or Infusional 5-Fluorouracil (5-FU)/Folinic Acid (FA)/Irinotecan (FOLFIRI)/Cetuximab With a Safety Lead-in of Encorafenib + Binimetinib + Cetuximab in Patients With BRAF V600E-mutant Metastatic Colorectal Cancer",
                                        "nct_id": "NCT02928224",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 3025,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Encorafenib, Binimetinib, and Cetuximab in BRAF V600E-Mutated Colorectal Cancer.",
                                "publication_date": {"day": 24, "year": 2019},
                                "pubmed": 31566309,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/31566309",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2022-02-11T23:51:32.630Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "This was a retrospective study of 691 cetuximab treated patients with metastatic, chemotherapy refractory colorectal cancer. Of those, 30 patients harbored BRAF V600E, were KRAS, NRAS and PIK3CA wt, and had individual response data. One patient (who harbored BRAF V600E in low copy number) responded, 11 had stable disease, and 18 progressed. Treatments included cetuximab + irinotecan (n=20), cetuximab monotherapy (n=5), cetuximab + FOLFIRI (n=4), and cetuximab + oxaliplatin + 5FU (n=1). Median PFS was 8 weeks (2-32 weeks), median OS was 25 weeks (4-237 weeks), and median number of previous chemotherapy lines was 2 (0-4). Median age was 61 years old (42-78) and there were 16 males and 14 females. Authors concluded that BRAF mutation (23/24 of mutants were BRAF V600E) was strongly associated with poor response to cetuximab and suggested that mutation status of BRAF is more informative than those of NRAS and PIK3CA exon 20 for predicting cetuximab response (second only to KRAS).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"}
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 126,
                            "name": "EID126",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "De Roock et al., 2010, Lancet Oncol.",
                                "full_journal_title": "The Lancet. Oncology",
                                "id": 76,
                                "is_review": False,
                                "journal": "Lancet Oncol.",
                                "name": "Effects of KRAS, BRAF, NRAS, and PIK3CA mutations on the efficacy of cetuximab plus chemotherapy in chemotherapy-refractory metastatic colorectal cancer: a retrospective consortium analysis.",
                                "publication_date": {"month": 8, "year": 2010},
                                "pubmed": 20619739,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20619739",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-11-13T22:27:02.618Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In metastatic colorectal cancer patients with wildtype KRAS status, those with a BRAF V600E mutation were less likely to respond to treatment with cetuximab or panitumumab than  those with wildtype BRAF (0%  vs. 32% , P=0.029). Regardless of KRAS status, patients with BRAF mutations had reduced progression-free and overall survival (P=0.0107 and P <0.0001, respectively). Transfection of the colorectal cancer cell line DiFi with a BRAF V600E expression vector conferred decreased sensitivity to cetuximab and panitumumab in comparison to cells transfected with empty vector.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Substitutes",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2115,
                            "name": "EID2115",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Di Nicolantonio et al., 2008, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 100,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.",
                                "publication_date": {
                                    "day": 10,
                                    "month": 12,
                                    "year": 2008,
                                },
                                "pubmed": 19001320,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19001320",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2017-05-12T03:37:33.362Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In a study of metastatic colorectal cancer patients treated with capecitabine, oxaliplatin, bevacizumab, and cetuximab those with BRAF V600E mutations had reduced progression-free survival (6.6mo vs. 10.4mo, P=0.01) and reduced overall survival (15.2mo vs. 21.5mo, P=0.001) compared to those with wildtype BRAF.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "Xeloda",
                                        "Ro 09-1978/000",
                                        "5'-Deoxy-5-fluoro-N-[(pentyloxy)carbonyl]-cytidine",
                                    ],
                                    "id": 32,
                                    "name": "Capecitabine",
                                    "ncit_id": "C1794",
                                },
                                {
                                    "aliases": [
                                        "MYL-1402O",
                                        "Bevacizumab Biosimilar MYL-1402O",
                                        "Bevacizumab Biosimilar ABP 215",
                                        "ABP 215",
                                        "Zirabev",
                                        "Mvasi",
                                        "Bevacizumab-bvzr",
                                        "Bevacizumab-awwb",
                                        "Bevacizumab Biosimilar Zirabev",
                                        "Bevacizumab Biosimilar Mvasi",
                                        "Bevacizumab Biosimilar GB-222",
                                        "SCT501",
                                        "RhuMab-VEGF",
                                        "Recombinant Humanized Anti-VEGF Monoclonal Antibody",
                                        "Immunoglobulin G1 (Human-Mouse Monoclonal RhuMab-VEGF Gamma-Chain Anti-Human Vascular Endothelial Growth Factor), Disulfide With Human-Mouse Monoclonal RhuMab-VEGF Light Chain, Dimer",
                                        "HD204",
                                        "BP102 Biosimilar",
                                        "BP102",
                                        "Bevacizumab Biosimilar SCT501",
                                        "Bevacizumab Biosimilar RPH-001",
                                        "Bevacizumab Biosimilar QL 1101",
                                        "Bevacizumab Biosimilar MIL60",
                                        "Bevacizumab Biosimilar LY01008",
                                        "Bevacizumab Biosimilar IBI305",
                                        "Bevacizumab Biosimilar HLX04",
                                        "Bevacizumab Biosimilar HD204",
                                        "Bevacizumab Biosimilar FKB238",
                                        "Bevacizumab Biosimilar CT-P16",
                                        "Bevacizumab Biosimilar CBT 124",
                                        "Bevacizumab Biosimilar BI 695502",
                                        "Bevacizumab Biosimilar BEVZ92",
                                        "Bevacizumab Awwb",
                                        "Avastin",
                                        "Anti-VEGF RhuMAb",
                                        "Anti-VEGF Humanized Monoclonal Antibody",
                                        "Anti-VEGF",
                                    ],
                                    "id": 33,
                                    "name": "Bevacizumab",
                                    "ncit_id": "C2039",
                                },
                                {
                                    "aliases": [
                                        "Trans-l Diaminocyclohexane Oxalatoplatinum",
                                        "Trans-l DACH Oxalatoplatinum",
                                        "SR-96669",
                                        "RP-54780",
                                        "RP 54780",
                                        "Oxalatoplatinum",
                                        "Oxalatoplatin",
                                        "Oxalato (trans-l-1,2-diaminocyclohexane)platinum(II)",
                                        "Oxalato (1R,2R-cyclohexanediamine)platinum(II)",
                                        "JM-83",
                                        "Eloxatine",
                                        "ELOXATIN",
                                        "Diaminocyclohexane Oxalatoplatinum",
                                        "DACPLAT",
                                        "Dacotin",
                                        "Aiheng",
                                        "Ai Heng",
                                        "[SP-4-2-(1R-trans)]-(1,2,cyclohexanediamine-N,N')[ethanedioato(2--)-O,O']platinum",
                                        "[(1R,-2R)-1,2-cyclohexanediamine-N,N'][oxalato (2--)-O,O']platinum",
                                        "1-OHP",
                                    ],
                                    "id": 237,
                                    "name": "Oxaliplatin",
                                    "ncit_id": "C1181",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 8646,
                            "name": "EID8646",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Tol et al., 2009, N. Engl. J. Med.",
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1481,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "BRAF mutation in metastatic colorectal cancer.",
                                "publication_date": {
                                    "day": 2,
                                    "month": 7,
                                    "year": 2009,
                                },
                                "pubmed": 19571295,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19571295",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-08-06T20:03:15.474Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In metastatic colorectal cancer patients with wildtype KRAS status who received cetuximab therapy, those with a BRAF V600E mutation had reduced progression-free survival (8.0wk vs. 31.4wk, P=0.001, log-rank test, univariate analysis) and reduced overall survival (6.5mo vs. 14.8mo, P=0.001, log-rank test, univariate analysis; HR:6.6, 95%CI:2.4-18.2, P<0.001, multivariate analysis. Similar associations have been found in independent studies.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"}
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3736,
                            "name": "EID3736",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Laurent-Puig et al., 2009, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 1945,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Analysis of PTEN, BRAF, and EGFR status in determining benefit from cetuximab therapy in wild-type KRAS metastatic colon cancer.",
                                "publication_date": {
                                    "day": 10,
                                    "month": 12,
                                    "year": 2009,
                                },
                                "pubmed": 19884556,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19884556",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:34:40.244Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In a retrospective study of 68 irinotecan-refractory metastatic colorectal cancer patients, the tumors of eight patients harbored BRAF V600E but were wildtype for KRAS codons 12, 13, 61 and 146 mutations. None of these patients responded to irinotecan and cetuximab combination therapy. Conversely, 22/60 (37%) patients with BRAF wildtype type disease responded (p = 0.047). Authors note that BRAF V600E was associated with a trend toward shorter progression free survival (PFS) and overall survival (OS) compared to patients whose tumors had same KRAS genotype but were wildtype for BRAF though the trend had not reached significance (median PFS: 3.9 vs 5.3 mo, p = 0.306; median OS 9.0 vs 14.8 mo, p = 0.279).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "[1,4'-bipiperidine]-1'-carboxylic Acid (S)-4,11-diethyl-3,4,12,14-tetrahydro-4-hydroxy-3,14-dioxo-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinolin-9-yl Ester",
                                        "7-ethyl-10-[4-(1-piperidino)-1-piperidino]carbonyloxycamptothecin",
                                        "(+)-7-ethyl-10-hydroxycamptothecine 10-[1,4'-bipiperidine]-1'-carboxylate",
                                        "(+)-(4S)-4,11-diethyl-4-hydroxy-9-[(4-piperidino-piperidino)carbonyloxy]-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinol-3,14,(4H,12H)-dione",
                                    ],
                                    "id": 101,
                                    "name": "Irinotecan",
                                    "ncit_id": "C62040",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3738,
                            "name": "EID3738",
                            "open_change_count": 1,
                            "rating": 3,
                            "source": {
                                "citation": "Loupakis et al., 2009, Br. J. Cancer",
                                "full_journal_title": "British journal of cancer",
                                "id": 1480,
                                "is_review": False,
                                "journal": "Br. J. Cancer",
                                "name": "KRAS codon 61, 146 and BRAF mutations predict resistance to cetuximab plus irinotecan in KRAS codon 12 and 13 wild-type metastatic colorectal cancer.",
                                "open_access": True,
                                "pmc_id": "PMC2736831",
                                "publication_date": {
                                    "day": 18,
                                    "month": 8,
                                    "year": 2009,
                                },
                                "pubmed": 19603018,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19603018",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-08-05T20:25:19.150Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In a retrospective study of 148 treatment naive metastatic colorectal cancer patients, patients with BRAF V600E and wildtype NRAS/KRAS (n=14) mutation treated with FOLFOX4 plus cetuximab were associated with a decreased progression free survival (7.2mo vs. 9.7mo, HR:0.39, 95% CI:0.21-0.72, P=0.0017), and decreased overall survival (11.7mo vs. 28.5mo, HR:0.23, 95% CI:0.12-0.41, P<0.0001), as compared to patients with wildtype BRAF, NRAS and KRAS.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "Folinic Acid-Fluororuracil-Oxaliplatin-4 Regimen"
                                    ],
                                    "id": 538,
                                    "name": "FOLFOX-4 Regimen",
                                    "ncit_id": "C63590",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3739,
                            "name": "EID3739",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Kaczirek et al., 2015, Clin Colorectal Cancer",
                                "full_journal_title": "Clinical colorectal cancer",
                                "id": 1920,
                                "is_review": False,
                                "journal": "Clin Colorectal Cancer",
                                "name": "FOLFOX4 Plus Cetuximab for Patients With Previously Untreated Metastatic Colorectal Cancer According to Tumor RAS and BRAF Mutation Status: Updated Analysis of the CECOG/CORE 1.2.002 Study.",
                                "publication_date": {"month": 6, "year": 2015},
                                "pubmed": 25666295,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25666295",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-11-20T23:11:26.468Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase III trial, patients with BRAF V600E mutated metastatic colorectal cancer received triplet combination with encorafenib + binimetinib + cetuximab in a second or third-line setting. In the safety-lead in part of this trial, 30 patients were given triplet therapy, of which 29 with V600E mutation were included in the efficacy analysis. The objective response rate was 48% [95%CI: 29.4 - 67.5], median PFS was 8.0 mo [95%CI: 5.6 - 9.3], and median OS was 15.3 mo [95%CI: 9.6 - not reached]. The author concluded that triplet therapy was well tolerated and PFS and OS were substantially improved over historical standard of care.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 16, "name": "Cetuximab", "ncit_id": "C1723"},
                                {
                                    "aliases": [
                                        "LGX818",
                                        "LGX-818",
                                        "LGX 818",
                                        "Braftovi",
                                    ],
                                    "id": 483,
                                    "name": "Encorafenib",
                                    "ncit_id": "C98283",
                                },
                                {
                                    "aliases": [
                                        "Mektovi",
                                        "MEK162",
                                        "ARRY-438162",
                                        "ARRY-162",
                                    ],
                                    "id": 485,
                                    "name": "Binimetinib",
                                    "ncit_id": "C84865",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7260,
                            "name": "EID7260",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "asco": 168986,
                                "asco_abstract_id": 688,
                                "citation": "Scott Kopetz, 2019, Gastrointestinal Cancers Symposium, Abstract 688",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02928224",
                                        "description": "This is a multicenter, randomized, open-label, 3-arm Phase 3 study to evaluate encorafenib + cetuximab plus or minus binimetinib versus Investigator's choice of either irinotecan/cetuximab or FOLFIRI/cetuximab, as controls, in patients with BRAFV600E mCRC whose disease has progressed after 1 or 2 prior regimens in the metastatic setting. The study contains a Safety Lead-in Phase in which the safety and tolerability of encorafenib + binimetinib + cetuximab will be assessed prior to the Phase 3 portion of the study.",
                                        "name": "Study of Encorafenib + Cetuximab Plus or Minus Binimetinib vs. Irinotecan/Cetuximab or Infusional 5-Fluorouracil (5-FU)/Folinic Acid (FA)/Irinotecan (FOLFIRI)/Cetuximab With a Safety Lead-in of Encorafenib + Binimetinib + Cetuximab in Patients With BRAF V600E-mutant Metastatic Colorectal Cancer",
                                        "nct_id": "NCT02928224",
                                    }
                                ],
                                "full_journal_title": "Journal of Clinical Oncology",
                                "id": 2858,
                                "is_review": False,
                                "journal": "J Clin Oncol 37, 2019 (suppl 4; abstr 688)",
                                "name": "Updated results of the BEACON CRC safety lead-in: Encorafenib (ENCO) + binimetinib (BINI) + cetuximab (CETUX) for BRAFV600E-mutant metastatic colorectal cancer (mCRC).",
                                "publication_date": {"month": 9, "year": 2019},
                                "source_url": "https://meetinglibrary.asco.org/record/168986/abstract",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-03-10T23:25:46.953Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Chemotherapy-refractory, metastatic cholangiocarcinoma with CNS involvement and a BRAF V600E mutation had a partial response at 8 weeks to dabrafenib and trametinib combination with complete radiologic regression at 12 weeks. At 6 months the patient was still on treatment.",
                            "disease": {
                                "display_name": "Cholangiocarcinoma",
                                "doid": "DOID:4947",
                                "id": 29,
                                "name": "Cholangiocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:4947",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5902,
                            "name": "EID5902",
                            "open_change_count": 1,
                            "rating": 3,
                            "source": {
                                "citation": "Kocsis et al., 2017, J Gastrointest Oncol",
                                "full_journal_title": "Journal of gastrointestinal oncology",
                                "id": 2381,
                                "is_review": False,
                                "journal": "J Gastrointest Oncol",
                                "name": "Combined dabrafenib and trametinib treatment in a case of chemotherapy-refractory extrahepatic BRAF V600E mutant cholangiocarcinoma: dramatic clinical and radiological response with a confusing synchronic new liver lesion.",
                                "open_access": True,
                                "pmc_id": "PMC5401859",
                                "publication_date": {"month": 4, "year": 2017},
                                "pubmed": 28480077,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/28480077",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-05-11T03:22:41.442Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Patients with BRAF V600E-mutant NSCLC (n=57) were enrolled into a phase 2, multicentre, non-randomised, open-label study, administering dabrafenib plus trametinib. The overall response rate was 36/57 (63.2%, [95% CI 49.3-75.6]) and the median progression-free survival was 9.7 months (95% CI 6.9-19.6). At data cutoff (11.6 months of follow-up), 18/36  (50%) confirmed responses were ongoing and 23/57 (40%) of patients had died.",
                            "disease": {
                                "display_name": "Lung Non-small Cell Carcinoma",
                                "doid": "DOID:3908",
                                "id": 8,
                                "name": "Lung Non-small Cell Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3908",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "A",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3017,
                            "name": "EID3017",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Planchard et al., 2016, Lancet Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01336634",
                                        "description": "Dabrafenib is a potent and selective inhibitor of BRAF kinase activity. This is a Phase II, non-randomized, open-label study to assess the efficacy, safety, and tolerability of dabrafenib administered as a single agent and in combination with trametinib in stage IV disease to subjects with BRAF mutant advanced non-small cell lung cancer. Subjects will receive dabrafenib 150 mg twice daily (BID) in monotherapy treatment and dabrafenib 150 mg bid and trametinib 2 mg once daily in combination therapy and continue on treatment until disease progression, death, or unacceptable adverse event.",
                                        "name": "Study of Selective BRAF Kinase Inhibitor Dabrafenib Monotherapy Twice Daily and in Combination With Dabrafenib Twice Daily and Trametinib Once Daily in Combination Therapy in Subjects With BRAF V600E Mutation Positive Metastatic (Stage IV) Non-small Cell Lung Cancer.",
                                        "nct_id": "NCT01336634",
                                    }
                                ],
                                "full_journal_title": "The Lancet. Oncology",
                                "id": 1296,
                                "is_review": False,
                                "journal": "Lancet Oncol.",
                                "name": "Dabrafenib plus trametinib in patients with previously treated BRAF(V600E)-mutant metastatic non-small cell lung cancer: an open-label, multicentre phase 2 trial.",
                                "open_access": True,
                                "pmc_id": "PMC4993103",
                                "publication_date": {"month": 7, "year": 2016},
                                "pubmed": 27283860,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27283860",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2017-06-29T14:37:21.924Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Adjuvant dual treatment with BRAF inhibitor dabrafenib and MEK inhibitor trametinib was administered to patients with stage III resected melenoma with V600E or V600K mutation in this stage III trial (COMBO-AD, NCT01682083). 792 (91%) patients had V600E, and were administered dabrafenib and trametinib or placebo for 12 months. In subsequent analysis, relapse or death occurred in 150/397 patients (38%) in the treatment group and 229/395 patients (58%) in the placebo group for a 95% CI Hazard Ratio of 0.48 (0.39-0.58).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 6178,
                            "name": "EID6178",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Long et al., 2017, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01682083",
                                        "description": "This is a two-arm, randomized, double-blind Phase III study of dabrafenib in combination with trametinib versus two placebos in the adjuvant treatment of melanoma after surgical resection. Patients with completely resected, histologically confirmed, BRAF V600E/K mutation-positive, high-risk [Stage IIIa (lymph node metastasis >1 mm), IIIb or IIIc] cutaneous melanoma will be screened for eligibility. Subjects will be randomized to receive either dabrafenib (150 milligram (mg) twice daily [BID]) and trametinib (2 mg once daily [QD]) combination therapy or two placebos for 12 months.",
                                        "name": "A Study of the BRAF Inhibitor Dabrafenib in Combination With the MEK Inhibitor Trametinib in the Adjuvant Treatment of High-risk BRAF V600 Mutation-positive Melanoma After Surgical Resection.",
                                        "nct_id": "NCT01682083",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 2475,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Adjuvant Dabrafenib plus Trametinib in Stage III BRAF-Mutated Melanoma.",
                                "publication_date": {"day": 9, "year": 2017},
                                "pubmed": 28891408,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/28891408",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-05-23T17:55:59.136Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In the setting of BRAF(V600E), NF1 loss resulted in elevated activation of RAS-GTP but does not show resistance to MEK inhibitors.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drug_interaction_type": "Substitutes",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "PD 901",
                                        "MEK Inhibitor PD0325901",
                                        "PD0325901",
                                        "PD-0325901",
                                    ],
                                    "id": 29,
                                    "name": "Mirdametinib",
                                    "ncit_id": "C52195",
                                },
                            ],
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 86,
                            "name": "EID86",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Nissan et al., 2014, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 98,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Loss of NF1 in cutaneous melanoma is associated with RAS activation and MEK dependence.",
                                "open_access": True,
                                "pmc_id": "PMC4005042",
                                "publication_date": {
                                    "day": 15,
                                    "month": 4,
                                    "year": 2014,
                                },
                                "pubmed": 24576830,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24576830",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-02-18T18:20:58.058Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase 2 trial, patients with radioiodine refractory papillary thyroid carcinoma harboring BRAF mutation were treated with dabrafenib alone or combination with trametinib. 94% of patients had BRAF V600E.\nThe response rate was 50% (11/22) for dabrafenib and 54% (13/24) for dabrafenb and trametinib combination.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7762,
                            "name": "EID7762",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "asco": 145877,
                                "asco_abstract_id": 6022,
                                "citation": "Manisha H. Shah, 2017, ASCO Annual Meeting, Abstract 6022",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01723202",
                                        "description": "This randomized phase II trial studies how well dabrafenib works with or without trametinib in treating patients with recurrent thyroid cancer. Dabrafenib and trametinib may stop the growth of tumor cells by blocking some of the enzymes needed for cell growth. It is not yet known whether dabrafenib is more effective when given with or without trametinib in treating thyroid cancer",
                                        "name": "Dabrafenib With or Without Trametinib in Treating Patients With Recurrent Thyroid Cancer",
                                        "nct_id": "NCT01723202",
                                    }
                                ],
                                "full_journal_title": "Journal of Clinical Oncology",
                                "id": 3096,
                                "is_review": False,
                                "journal": "J Clin Oncol 35, 2017 (suppl; abstr 6022)",
                                "name": "Results of randomized phase II trial of dabrafenib versus dabrafenib plus trametinib in BRAF-mutated papillary thyroid carcinoma.",
                                "publication_date": {
                                    "day": 12,
                                    "month": 1,
                                    "year": 2017,
                                },
                                "source_url": "https://meetinglibrary.asco.org/record/145877/abstract",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2019-12-05T12:51:38.854Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An inducible BRAF-V600E mouse melanoma model shows a tight correlation between activated BRAF and disease progression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2131,
                            "name": "EID2131",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hoeflich et al., 2006, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1485,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF is required for tumor growth and maintenance in melanoma models.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16424035,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16424035",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:02.467Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Dabrafenib with trametinib provides higher response rate and lower toxicity (as compared to chemotherapy) in patients with melanoma.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 95,
                            "name": "EID95",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Menzies et al., 2014, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 105,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "Dabrafenib and trametinib, alone and in combination for BRAF-mutant metastatic melanoma.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 4,
                                    "year": 2014,
                                },
                                "pubmed": 24583796,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24583796",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-02-18T21:13:57.532Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Dabrafenib and trametinib combination showed durable response for a patient with standard chemotherapy and radiation refractory, poorly differentiated, intrahepatic cholangiocarcinoma harboring BRAF V600E. At time of publication, 8.5 months, the patient was still on treatment.",
                            "disease": {
                                "display_name": "Intrahepatic Cholangiocarcinoma",
                                "doid": "DOID:4928",
                                "id": 1165,
                                "name": "Intrahepatic Cholangiocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:4928",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5904,
                            "name": "EID5904",
                            "open_change_count": 1,
                            "rating": 3,
                            "source": {
                                "citation": "Loaiza-Bonilla et al., 2014, Ecancermedicalscience",
                                "full_journal_title": "Ecancermedicalscience",
                                "id": 2379,
                                "is_review": False,
                                "journal": "Ecancermedicalscience",
                                "name": "Dramatic response to dabrafenib and trametinib combination in a BRAF V600E-mutated cholangiocarcinoma: implementation of a molecular tumour board and next-generation sequencing for personalized medicine.",
                                "open_access": True,
                                "pmc_id": "PMC4239128",
                                "publication_date": {"year": 2014},
                                "pubmed": 25435907,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25435907",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-05-13T16:22:59.441Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In NCI-MATCH trial, patients with advanced solid tumors, lymphoma or multiple myeloma harboring BRAF V600E mutation were treated with dabrafenib and trametinib.\nPatients with melanoma, thyroid carcinoma, colorectal cancer or NSCLC were excluded.\nThe response rate was 100% (4/4) in patients cholangiocarcinoma and 83% (5/6) in patients with low-grade papillary serous adenocarcinoma of the ovary or mucinous-papillary serous adenocarcinoma of the peritoneum.",
                            "disease": {
                                "display_name": "Ovarian Cancer",
                                "doid": "DOID:2394",
                                "id": 20,
                                "name": "Ovarian Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:2394",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7454,
                            "name": "EID7454",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "asco": 172039,
                                "asco_abstract_id": 3002,
                                "citation": "April K.S. Salama, 2019, ASCO Annual Meeting, Abstract 3002",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02465060",
                                        "description": "This phase II MATCH trial studies how well treatment that is directed by genetic testing works in patients with solid tumors or lymphomas that have progressed following at least one line of standard treatment or for which no agreed upon treatment approach exists. Genetic tests look at the unique genetic material (genes) of patients' tumor cells. Patients with genetic abnormalities (such as mutations, amplifications, or translocations) may benefit more from treatment which targets their tumor's particular genetic abnormality. Identifying these genetic abnormalities first may help doctors plan better treatment for patients with solid tumors, lymphomas, or multiple myeloma.",
                                        "name": "Targeted Therapy Directed by Genetic Testing in Treating Patients With Advanced Refractory Solid Tumors, Lymphomas, or Multiple Myeloma (The MATCH Screening Trial)",
                                        "nct_id": "NCT02465060",
                                    }
                                ],
                                "full_journal_title": "Journal of Clinical Oncology",
                                "id": 2954,
                                "is_review": False,
                                "journal": "J Clin Oncol 37, 2019 (suppl; abstr 3002)",
                                "name": "Dabrafenib and trametinib in patients with tumors with BRAF V600E/K mutations: Results from the molecular analysis for therapy choice (MATCH) Arm H.",
                                "publication_date": {"month": 6, "year": 2019},
                                "source_url": "https://meetinglibrary.asco.org/record/172039/abstract",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2019-08-05T12:34:56.624Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Two cases of patients with BRAF V600E positive, refractory intrahepatic cholangiocarcinoma showed excellent clinical and radiographic response to combination dabrafenib and trametinib treatment. One patient achieved complete remission at 6 months with progression at 9 months and the other partial remission at 2 months and no progression as of 5 months.",
                            "disease": {
                                "display_name": "Intrahepatic Cholangiocarcinoma",
                                "doid": "DOID:4928",
                                "id": 1165,
                                "name": "Intrahepatic Cholangiocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:4928",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 5903,
                            "name": "EID5903",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Lavingia et al., 2016, J Gastrointest Oncol",
                                "full_journal_title": "Journal of gastrointestinal oncology",
                                "id": 2380,
                                "is_review": False,
                                "journal": "J Gastrointest Oncol",
                                "name": "Impressive response to dual BRAF and MEK inhibition in patients with BRAF mutant intrahepatic cholangiocarcinoma-2 case reports and a brief review.",
                                "open_access": True,
                                "pmc_id": "PMC5177579",
                                "publication_date": {"month": 12, "year": 2016},
                                "pubmed": 28078132,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/28078132",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-05-12T17:53:12.943Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In NCI-MATCH trial, patients with advanced solid tumors, lymphoma or multiple myeloma harboring BRAF V600E mutation were treated with dabrafenib and trametinib.\nPatients with melanoma, thyroid carcinoma, colorectal cancer or NSCLC were excluded.\nThe response rate was 100% (4/4) in patients cholangiocarcinoma and 83% (5/6) in patients with low-grade papillary serous adenocarcinoma of the ovary or mucinous-papillary serous adenocarcinoma of the peritoneum.",
                            "disease": {
                                "display_name": "Cholangiocarcinoma",
                                "doid": "DOID:4947",
                                "id": 29,
                                "name": "Cholangiocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:4947",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7453,
                            "name": "EID7453",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "asco": 172039,
                                "asco_abstract_id": 3002,
                                "citation": "April K.S. Salama, 2019, ASCO Annual Meeting, Abstract 3002",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02465060",
                                        "description": "This phase II MATCH trial studies how well treatment that is directed by genetic testing works in patients with solid tumors or lymphomas that have progressed following at least one line of standard treatment or for which no agreed upon treatment approach exists. Genetic tests look at the unique genetic material (genes) of patients' tumor cells. Patients with genetic abnormalities (such as mutations, amplifications, or translocations) may benefit more from treatment which targets their tumor's particular genetic abnormality. Identifying these genetic abnormalities first may help doctors plan better treatment for patients with solid tumors, lymphomas, or multiple myeloma.",
                                        "name": "Targeted Therapy Directed by Genetic Testing in Treating Patients With Advanced Refractory Solid Tumors, Lymphomas, or Multiple Myeloma (The MATCH Screening Trial)",
                                        "nct_id": "NCT02465060",
                                    }
                                ],
                                "full_journal_title": "Journal of Clinical Oncology",
                                "id": 2954,
                                "is_review": False,
                                "journal": "J Clin Oncol 37, 2019 (suppl; abstr 3002)",
                                "name": "Dabrafenib and trametinib in patients with tumors with BRAF V600E/K mutations: Results from the molecular analysis for therapy choice (MATCH) Arm H.",
                                "publication_date": {"month": 6, "year": 2019},
                                "source_url": "https://meetinglibrary.asco.org/record/172039/abstract",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2019-08-05T12:33:13.478Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An inducible BRAF-V600E mouse melanoma model shows a tight correlation between activated BRAF and disease progression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2134,
                            "name": "EID2134",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hoeflich et al., 2006, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1485,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF is required for tumor growth and maintenance in melanoma models.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16424035,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16424035",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:03.562Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a study of 322 advanced melanoma patients with BRAF-V600E (N=281), BRAF-V600K (N=40), or both mutations (N=1), treatment with trametinib was associated with improved progression-free survival (4.8mo vs. 1.5mo; HR: 0.45, 95% CI: 0.33-0.63, P<0.001) compared to chemotherapy control group. Additionally, treatment with trametinib was associated with increased 6-month overall survival (HR: 0.54, 95% CI: 0.32-0.92, P=0.01). The authors note similar outcomes for the primary efficacy population (V600E only) and the intention-to-treat population.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2135,
                            "name": "EID2135",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Flaherty et al., 2012, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01245062",
                                        "description": "This is a two-arm, open-label, randomized Phase III study comparing single agent GSK1120212 to chemotherapy (either dacarbazine or paclitaxel) in subjects with Stage IIIc or Stage IV malignant cutaneous melanoma. All subjects must have a BRAF mutation-positive tumour sample. Subjects who have received up to one prior regimen of chemotherapy in the advanced or metastatic melanoma setting will be enrolled into the study. Subjects with any prior BRAF or MEK inhibitor use will be excluded. Approximately 297 subjects will be enrolled with 2:1 randomization (198 subjects into the GSK1120212 arm and 99 subjects into the chemotherapy arm). The primary endpoint for the statistical analysis will be a comparison of progression free survival for subjects receiving GSK1120212 compared to chemotherapy. Subjects who have progression on chemotherapy will be offered the option to receive GSK1120212.",
                                        "name": "GSK1120212 vs Chemotherapy in Advanced or Metastatic BRAF V600E/K Mutation-positive Melanoma",
                                        "nct_id": "NCT01245062",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1210,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Improved survival with MEK inhibition in BRAF-mutated melanoma.",
                                "publication_date": {
                                    "day": 12,
                                    "month": 7,
                                    "year": 2012,
                                },
                                "pubmed": 22663011,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22663011",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-12-30T18:28:15.123Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In this trial, 142 patients with metastatic, BRAF V600E mutant colorectal cancer were randomized to receive either BRAF inhibitor dabrafenib (D) + EGFR inhibitor panitumumab (P); or a triple therapy of D + P and MEK inhibition with trametinib (T) or T + P. Confirmed response rates for D+P (n=20), D+T+P (n=91), and T+P (n=31) were 10%, 21%, and 0%, respectively.",
                            "disease": {
                                "display_name": "Colorectal Adenocarcinoma",
                                "doid": "DOID:0050861",
                                "id": 57,
                                "name": "Colorectal Adenocarcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:0050861",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                            ],
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 6124,
                            "name": "EID6124",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Corcoran et al., 2018, Cancer Discov",
                                "full_journal_title": "Cancer discovery",
                                "id": 2468,
                                "is_review": False,
                                "journal": "Cancer Discov",
                                "name": "Combined BRAF, EGFR, and MEK Inhibition in Patients with BRAFV600E-Mutant Colorectal Cancer.",
                                "open_access": True,
                                "pmc_id": "PMC5882509",
                                "publication_date": {"year": 2018},
                                "pubmed": 29431699,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29431699",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-05-23T18:47:37.224Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase II trial, 33 patients with advanced or metastatic biliary tract cancer (BTC) received dabrafenib (D) and trametinib (T) in a second or higher line therapeutic context. Of the 33 patients, 30 had BRAF V600E mutated tumors, and 32 were evaluable. Objective response rate was 41% (13/32; 95% CI, 24 - 59%). Median PFS was 7.2 months (95% CI, 4.6 - 10.1 months), and median OS was 11.3 months (95% CI, 7.3 - 17.6 months). The author concluded that D+T therapy should be considered for patients with BRAF V600E mutated BTC.",
                            "disease": {
                                "display_name": "Biliary Tract Cancer",
                                "doid": "DOID:4607",
                                "id": 1065,
                                "name": "Biliary Tract Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:4607",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7264,
                            "name": "EID7264",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "asco": 169315,
                                "asco_abstract_id": 187,
                                "citation": "Zev A. Wainberg, 2019, Gastrointestinal Cancers Symposium, Abstract 187",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02034110",
                                        "description": "This is a Phase II, open-label, non-randomized, multi-center study of oral Dabrafenib in combination with oral Trametinib in subjects with rare cancers including anaplastic thyroid cancer, biliary tract cancer, gastrointestinal stromal tumor, non-seminomatous germ cell tumor/non-geminomatous germ cell tumor, hairy cell leukemia, World Health Organization (WHO) Grade 1 or 2 glioma, WHO Grade 3 or 4 (high-grade) glioma, multiple myeloma, and adenocarcinoma of the small intestine, with BRAF V600E positive-mutations. This study is designed to determine the overall response rate (ORR) of oral Dabrafenib in combination with oral Trametinib in subjects with rare BRAF V600E mutated cancers. Subjects will need to have a fresh or frozen tumor tissue sample provided to confirm the BRAF V600E mutation status. Only subjects with histologically confirmed advanced disease and no available standard treatment options will be eligible for enrollment. Subjects will undergo screening assessments within 14 days (up to 35 days for ophthalmology exam, echocardiogram or disease assessments) prior to the start of treatment to determine their eligibility for enrollment in the study.",
                                        "name": "Efficacy and Safety of the Combination Therapy of Dabrafenib and Trametinib in Subjects With BRAF V600E- Mutated Rare Cancers",
                                        "nct_id": "NCT02034110",
                                    }
                                ],
                                "full_journal_title": "Journal of Clinical Oncology",
                                "id": 2860,
                                "is_review": False,
                                "journal": "J Clin Oncol 37, 2019 (suppl 4; abstr 187)",
                                "name": "Efficacy and safety of dabrafenib (D) and trametinib (T) in patients (pts) with <i>BRAF</i> V600E&#x2013;mutated biliary tract cancer (BTC): A cohort of the ROAR basket trial.",
                                "publication_date": {
                                    "day": 10,
                                    "month": 3,
                                    "year": 2019,
                                },
                                "source_url": "https://meetinglibrary.asco.org/record/169315/abstract",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-11-19T20:29:00.953Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In this trial, 142 patients with metastatic, BRAF V600E mutant colorectal cancer were randomized to receive either BRAF inhibitor dabrafenib (D) + EGFR inhibitor panitumumab (P); or a triple therapy of D + P and MEK inhibition with trametinib (T) or T + P. Confirmed response rates for D+P (n=20), D+T+P (n=91), and T+P (n=31) were 10%, 21%, and 0%, respectively.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 6123,
                            "name": "EID6123",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Corcoran et al., 2018, Cancer Discov",
                                "full_journal_title": "Cancer discovery",
                                "id": 2468,
                                "is_review": False,
                                "journal": "Cancer Discov",
                                "name": "Combined BRAF, EGFR, and MEK Inhibition in Patients with BRAFV600E-Mutant Colorectal Cancer.",
                                "open_access": True,
                                "pmc_id": "PMC5882509",
                                "publication_date": {"year": 2018},
                                "pubmed": 29431699,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29431699",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-05-23T18:47:26.658Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In this Phase III trial (NCT01584648 COMBI-d), previously untreated patients with unresectable stage IIIC or IV melanoma with BRAF V600E (359 patients) or V600K (61 patients) received dabrafenib and trametinib or dabrafenib alone with primary endpoint of progression free survival and secondary endpoints including disease response. The hazard ratio for progression or death in the V600E group was 0.81 for dabrafenib-trametinib vs dabrafenib-alone. Of 179 V600E patients in the dabrafenib-trametinib group, 68% of patients had a response, which was 15 percentage points higher than in the dabrafenib-alone group (95% CI, 4 to 24; P=0.006).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 6938,
                            "name": "EID6938",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Long et al., 2014, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01584648",
                                        "description": "This is a two-arm, double-blinded, randomized, Phase III study comparing dabrafenib (GSK2118436) and trametinib (GSK1120212) combination therapy to dabrafenib administered with a trametinib placebo (dabrafenib monotherapy). Subjects with histologically confirmed cutaneous melanoma that is either Stage IIIC (unresectable) or Stage IV, and BRAF V600E/K mutation positive will be screened for eligibility. Subjects who have had prior systemic anti-cancer treatment in the advanced or metastatic setting will not be eligible although prior systemic treatment in the adjuvant setting will be allowed. Approximately 340 subjects will be randomized 1:1 (combination therapy: dabrafenib monotherapy). Subjects will be stratified by lactate dehydrogenase (LDH) level (> the upper limit of normal (ULN) versus less than or equal to the ULN) and BRAF mutation (V600E versus V600K). The primary endpoint is investigator-assessed, progression-free survival for subjects receiving the combination therapy compared with those receiving dabrafenib monotherapy. Subjects will be followed for overall survival; crossover will not be permitted.",
                                        "name": "A Study Comparing Trametinib and Dabrafenib Combination Therapy to Dabrafenib Monotherapy in Subjects With BRAF-mutant Melanoma",
                                        "nct_id": "NCT01584648",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 2671,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Combined BRAF and MEK inhibition versus BRAF inhibition alone in melanoma.",
                                "publication_date": {
                                    "day": 13,
                                    "month": 11,
                                    "year": 2014,
                                },
                                "pubmed": 25265492,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25265492",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-11-08T17:54:34.531Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a clinical trial (NCT01597908) of 704 metastatic melanoma patients, patients harboring a BRAF V600E mutation and treated with vemurafenib (n=317) were associated with a 51% response rate, as compared to a 64% response rate (p<0.001) in V600E mutation positive patients treated with dabrafenib and trametinib combination therapy (n=312). Median progression-free survival was 11.4 months in the combination-therapy group and 7.3 months in the vemurafenib group (hazard ratio, 0.56; 95% CI, 0.46 to 0.69; P<0.001).",
                            "disease": {
                                "display_name": "Skin Melanoma",
                                "doid": "DOID:8923",
                                "id": 206,
                                "name": "Skin Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:8923",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3758,
                            "name": "EID3758",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Robert et al., 2015, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01597908",
                                        "description": "This is a two-arm, open-label, randomised, Phase III study comparing dabrafenib (GSK2118436) and trametinib (GSK1120212) combination therapy to vemurafenib. Subjects with histologically confirmed cutaneous melanoma that is either stage IIIc (unresectable) or stage IV, and BRAF V600E/K mutation positive will be screened for eligibility. Subjects who have had prior systemic anti-cancer treatment in the advanced or metastatic setting will not be eligible although prior systemic treatment in the adjuvant setting will be allowed. Approximately 694 subjects will be randomised 1:1 (combination therapy:vemurafenib). The primary endpoint is overall survival (OS) for subjects receiving the combination therapy compared with those receiving vemurafenib.",
                                        "name": "Dabrafenib Plus Trametinib vs Vemurafenib Alone in Unresectable or Metastatic BRAF V600E/K Cutaneous Melanoma",
                                        "nct_id": "NCT01597908",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 353,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Improved overall survival in melanoma with combined dabrafenib and trametinib.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 1,
                                    "year": 2015,
                                },
                                "pubmed": 25399551,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25399551",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-11-08T18:02:40.633Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Interim analysis of a basket trial evaluating the combination of dabrafenib (BRAF inhibitor) and trametinib (MEK inhibitor) in previously treated V600E-mutated patients showed 11/16 patients with anaplastic thyroid carcinoma responded to treatment (overall response rate 69%; 95% CI, 41% to 89%). Seven patients had ongoing responses. Median duration of response, progression-free survival, and overall survival were not reached after 120 weeks.",
                            "disease": {
                                "display_name": "Thyroid Gland Anaplastic Carcinoma",
                                "doid": "DOID:0080522",
                                "id": 3040,
                                "name": "Thyroid Gland Anaplastic Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:0080522",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 6975,
                            "name": "EID6975",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Subbiah et al., 2018, J. Clin. Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT02034110",
                                        "description": "This is a Phase II, open-label, non-randomized, multi-center study of oral Dabrafenib in combination with oral Trametinib in subjects with rare cancers including anaplastic thyroid cancer, biliary tract cancer, gastrointestinal stromal tumor, non-seminomatous germ cell tumor/non-geminomatous germ cell tumor, hairy cell leukemia, World Health Organization (WHO) Grade 1 or 2 glioma, WHO Grade 3 or 4 (high-grade) glioma, multiple myeloma, and adenocarcinoma of the small intestine, with BRAF V600E positive-mutations. This study is designed to determine the overall response rate (ORR) of oral Dabrafenib in combination with oral Trametinib in subjects with rare BRAF V600E mutated cancers. Subjects will need to have a fresh or frozen tumor tissue sample provided to confirm the BRAF V600E mutation status. Only subjects with histologically confirmed advanced disease and no available standard treatment options will be eligible for enrollment. Subjects will undergo screening assessments within 14 days (up to 35 days for ophthalmology exam, echocardiogram or disease assessments) prior to the start of treatment to determine their eligibility for enrollment in the study.",
                                        "name": "Efficacy and Safety of the Combination Therapy of Dabrafenib and Trametinib in Subjects With BRAF V600E- Mutated Rare Cancers",
                                        "nct_id": "NCT02034110",
                                    }
                                ],
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 2686,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Dabrafenib and Trametinib Treatment in Patients With Locally Advanced or Metastatic BRAF V600-Mutant Anaplastic Thyroid Cancer.",
                                "open_access": True,
                                "pmc_id": "PMC5791845",
                                "publication_date": {"day": 1, "year": 2018},
                                "pubmed": 29072975,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29072975",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-12-11T07:18:39.572Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In this Phase I and II study (NCT01072175) patients with metastatic melanoma were given dabrafenib and trametinib combination therapy vs. dabrafenib monotherapy. From V600E patients, 45 received monotherapy and 92 received combination therapy. Hazard ratio for progression or death was 0.43 (95% CI, 0.27-0.71). Both patients with the BRAF V600E and V600K mutation showed significant improvement in progression-free survival.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "N-(3-{3-cyclopropyl-5-[(2-fluoro-4-iodophenyl)amino]-6,8-dimethyl-2,4,7-trioxo-3,4,6,7-tetrahydropyrido[4,3-d]pyrimidin-1(2H)-yl}phenyl)acetamide",
                                        "Mekinist",
                                        "MEK Inhibitor GSK1120212",
                                        "JTP-74057",
                                        "GSK1120212",
                                    ],
                                    "id": 19,
                                    "name": "Trametinib",
                                    "ncit_id": "C77908",
                                },
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 6940,
                            "name": "EID6940",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Flaherty et al., 2012, N. Engl. J. Med.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01072175",
                                        "description": "This was an open-label, dose escalation study to investigate the safety, pharmacokinetics, pharmacodynamics and clinical activity of GSK2118436 and GSK1120212 in combination. This study was designed in four parts. In Part A, the effect of repeat doses of GSK1120212 on the pharmacokinetics of single dose GSK2118436 was investigated prior to evaluating combination regimens. In Part B, the range of tolerated dose combinations was identified using a dose-escalation procedure. In Part C, different dose combinations of GSK2118436 and GSK1120212 were evaluated, based on results from the dose escalation cohorts. In Part D, the pharmacokinetics and safety of GSK2118436 administered as HPMC capsules alone and in combination with GSK1120212 was evaluated.",
                                        "name": "Investigate Safety, Pharmacokinetics and Pharmacodynamics of GSK2118436 & GSK1120212",
                                        "nct_id": "NCT01072175",
                                    }
                                ],
                                "full_journal_title": "The New England journal of medicine",
                                "id": 103,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Combined BRAF and MEK inhibition in melanoma with BRAF V600 mutations.",
                                "open_access": True,
                                "pmc_id": "PMC3549295",
                                "publication_date": {"month": 11, "year": 2012},
                                "pubmed": 23020132,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23020132",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-11-08T17:18:57.287Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In an in vitro study, a melanoma cell line, A375, expressing the BRAF V600E mutation was associated with resistance to dasatinib treatment, comparable to melanoma MEWO cells expressing wild-type BRAF. Resistance was determined by assessing cell viability.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Sprycel",
                                        "Dasatinib Monohydrate",
                                        "Dasatinib Hydrate",
                                        "BMS-354825",
                                        "5-Thiazolecarboxamide, N-(2-chloro-6-methylphenyl)-2-((6-(4-(2-hydroxyethyl)-1-piperazinyl)-2-methyl-4-pyrimidinyl)amino)-, Monohydrate",
                                    ],
                                    "id": 20,
                                    "name": "Dasatinib",
                                    "ncit_id": "C38713",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3759,
                            "name": "EID3759",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Woodman et al., 2009, Mol. Cancer Ther.",
                                "full_journal_title": "Molecular cancer therapeutics",
                                "id": 74,
                                "is_review": False,
                                "journal": "Mol. Cancer Ther.",
                                "name": "Activity of dasatinib against L576P KIT mutant melanoma: molecular, cellular, and clinical correlates.",
                                "open_access": True,
                                "pmc_id": "PMC3346953",
                                "publication_date": {"month": 8, "year": 2009},
                                "pubmed": 19671763,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19671763",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:00.047Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, K2, a papillary thyroid carcinoma cell line expressing the BRAFV600E mutation, was associated with sensitivity to dasatinib treatment. Sensitivity was determined by assessing cell growth inhibition. In an in vivo experiment, dasatinib also inhibited the growth of K2 thyroid carcinoma xenografts in 7 of 13 mice.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Sprycel",
                                        "Dasatinib Monohydrate",
                                        "Dasatinib Hydrate",
                                        "BMS-354825",
                                        "5-Thiazolecarboxamide, N-(2-chloro-6-methylphenyl)-2-((6-(4-(2-hydroxyethyl)-1-piperazinyl)-2-methyl-4-pyrimidinyl)amino)-, Monohydrate",
                                    ],
                                    "id": 20,
                                    "name": "Dasatinib",
                                    "ncit_id": "C38713",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3775,
                            "name": "EID3775",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Henderson et al., 2014, Head Neck",
                                "full_journal_title": "Head & neck",
                                "id": 1972,
                                "is_review": False,
                                "journal": "Head Neck",
                                "name": "Src inhibitors in suppression of papillary thyroid carcinoma growth.",
                                "open_access": True,
                                "pmc_id": "PMC4401074",
                                "publication_date": {"month": 3, "year": 2014},
                                "pubmed": 23729178,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23729178",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:13.303Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In a patient with V600E-positive NSCLC, KRAS G12D seemed to confer resistance to dabrafenib.",
                            "disease": {
                                "display_name": "Lung Non-small Cell Carcinoma",
                                "doid": "DOID:3908",
                                "id": 8,
                                "name": "Lung Non-small Cell Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3908",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 91,
                            "name": "EID91",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Rudin et al., 2013, J Thorac Oncol",
                                "full_journal_title": "Journal of thoracic oncology : official publication of the International Association for the Study of Lung Cancer",
                                "id": 101,
                                "is_review": False,
                                "journal": "J Thorac Oncol",
                                "name": "Molecular characterization of acquired resistance to the BRAF inhibitor dabrafenib in a patient with BRAF-mutant non-small-cell lung cancer.",
                                "open_access": True,
                                "pmc_id": "PMC3634121",
                                "publication_date": {"month": 5, "year": 2013},
                                "pubmed": 23524406,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23524406",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-02-17T19:49:55.547Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In trial NCT00880321, dabrafenib was tested in various solid tumor types harboring mutant BRAF after establishing dosage of 150 mg twice daily. In nine colorectal cancer patients with established V600E mutation, 1 confirmed response, 7 instances of stable disease, and 1 case of progressive disease was seen, which contrasted strongly with a 56% confirmed response rate seen in metastatic V600E melanoma patients similarly treated in the same study.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1406,
                            "name": "EID1406",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Falchook et al., 2012, Lancet",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT00880321",
                                        "description": "BRF112680 is a first-time-in-human study to establish the recommended dose and schedule of the orally administered GSK2118436. The recommended dose and regimen will be selected based on the safety, pharmacokinetic, and pharmacodynamic profiles observed after the treatment of subjects with solid tumors. This is a two-part study. Part 1 will identify the recommended Part 2 dose using a dose-escalation procedure. Escalation may proceed until either a maximum tolerated dose is established, or the toxicokinetic safety limit is reached. The recommended Part 2 dose will be expanded to up to 12 patients. Part 2 will explore further the safety, tolerability, and clinical activity of GSK2118436 in subjects with BRAF mutation-positive tumors. In addition, the effect of GSK2118436 on midazolam will be assessed in a subset of patients in Part 2. Biologically active doses will be identified by measurement of pharmacodynamic markers in tumor tissue and blood across a range of doses and these doses may be explored in Part 2.",
                                        "name": "A Phase I Study to Investigate the Safety, Pharmacokinetics, and Pharmacodynamics of GSK2118436 in Subjects With Solid Tumors",
                                        "nct_id": "NCT00880321",
                                    }
                                ],
                                "full_journal_title": "Lancet (London, England)",
                                "id": 345,
                                "is_review": False,
                                "journal": "Lancet",
                                "name": "Dabrafenib in patients with melanoma, untreated brain metastases, and other solid tumours: a phase 1 dose-escalation trial.",
                                "open_access": True,
                                "pmc_id": "PMC4109288",
                                "publication_date": {
                                    "day": 19,
                                    "month": 5,
                                    "year": 2012,
                                },
                                "pubmed": 22608338,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22608338",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-27T23:30:32.965Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Patients with BRAF mutations who were treated with the specific RAF inhibitor dabrafenib had an improved overall survival (P<0.003) compared to untreated patients with BRAF mutations. Patients harboring BRAF mutations were associated with reduced overall survival (11.1mo vs. 46.1mo for wildtype, P=0.006).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2126,
                            "name": "EID2126",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Long et al., 2011, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 1488,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Prognostic and clinicopathologic associations of oncogenic BRAF in metastatic melanoma.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 4,
                                    "year": 2011,
                                },
                                "pubmed": 21343559,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21343559",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:01.038Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Acquired resistance to vemurafenib in BRAF-V600E positive melanomas frequently confound vemurafenib therapy.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2127,
                            "name": "EID2127",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Flaherty et al., 2010, N. Engl. J. Med.",
                                "full_journal_title": "The New England journal of medicine",
                                "id": 352,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "Inhibition of mutated, activated BRAF in metastatic melanoma.",
                                "open_access": True,
                                "pmc_id": "PMC3724529",
                                "publication_date": {
                                    "day": 26,
                                    "month": 8,
                                    "year": 2010,
                                },
                                "pubmed": 20818844,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20818844",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:01.157Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An inducible BRAF-V600E mouse melanoma model shows a tight correlation between activated BRAF and disease progression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2128,
                            "name": "EID2128",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hoeflich et al., 2006, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1485,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF is required for tumor growth and maintenance in melanoma models.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16424035,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16424035",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:01.292Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Proposed resistance mechanisms include PDGFRB upregulation or NRAS mutations resulting in MAPK pathway reactivation, but not secondary mutations in BRAF. MEK inhibitors may demonstrate clinical benefit in vemurafenib-resistant melanoma patients.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2132,
                            "name": "EID2132",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Nazarian et al., 2010, Nature",
                                "full_journal_title": "Nature",
                                "id": 1491,
                                "is_review": False,
                                "journal": "Nature",
                                "name": "Melanomas acquire resistance to B-RAF(V600E) inhibition by RTK or N-RAS upregulation.",
                                "open_access": True,
                                "pmc_id": "PMC3143360",
                                "publication_date": {
                                    "day": 16,
                                    "month": 12,
                                    "year": 2010,
                                },
                                "pubmed": 21107323,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21107323",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:02.860Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Acquired resistance to vemurafenib in BRAF-V600E positive melanomas frequently confound vemurafenib therapy.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2133,
                            "name": "EID2133",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Johannessen et al., 2010, Nature",
                                "full_journal_title": "Nature",
                                "id": 1492,
                                "is_review": False,
                                "journal": "Nature",
                                "name": "COT drives resistance to RAF inhibition through MAP kinase pathway reactivation.",
                                "open_access": True,
                                "pmc_id": "PMC3058384",
                                "publication_date": {
                                    "day": 16,
                                    "month": 12,
                                    "year": 2010,
                                },
                                "pubmed": 21107320,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21107320",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:03.083Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase 2 clinical trial  with 250 metastatic melanoma BRAF-V600E patients, treatment groups were randomly assigned to either dabrafenib, BRAF specific inhibitor, (n=187) or dacarbazine, a standard chemotherapeutic agent (n=63). Patients treated with dabrafenib were associated with improved progression-free survival (5.1mo vs. 2.7mo, HR:0.30, 95% CI:0.18-0.51, P<0.0001) compared with patients undergoing dacarbazine therapy.",
                            "disease": {
                                "display_name": "Skin Melanoma",
                                "doid": "DOID:8923",
                                "id": 206,
                                "name": "Skin Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:8923",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2146,
                            "name": "EID2146",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hauschild et al., 2012, Lancet",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01227889",
                                        "description": "BRF113683 is a Phase III, randomized, open-label study comparing the efficacy, safety, and tolerability of GSK2118436 to dacarbazine (DTIC), in subjects with BRAF mutant advanced (Stage III) or metastatic (Stage IV) melanoma. Subjects will be randomized to receive 150 mg of GSK2118436 twice daily or 1000 mg/m2 DTIC every 3 weeks and continue on treatment until disease progression, death, or unacceptable adverse event. Subjects who progress on DTIC will be allowed to crossover to an optional extension arm of the study to receive GSK2118436.",
                                        "name": "A Study Comparing GSK2118436 to Dacarbazine (DTIC) in Previously Untreated Subjects With BRAF Mutation Positive Advanced (Stage III) or Metastatic (Stage IV) Melanoma",
                                        "nct_id": "NCT01227889",
                                    }
                                ],
                                "full_journal_title": "Lancet (London, England)",
                                "id": 1500,
                                "is_review": False,
                                "journal": "Lancet",
                                "name": "Dabrafenib in BRAF-mutated metastatic melanoma: a multicentre, open-label, phase 3 randomised controlled trial.",
                                "publication_date": {
                                    "day": 28,
                                    "month": 7,
                                    "year": 2012,
                                },
                                "pubmed": 22735384,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22735384",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:08.437Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase 2 trial, patients with radioiodine refractory papillary thyroid carcinoma harboring BRAF mutation were treated with dabrafenib alone or combination with trametinib. 94% patients havd BRAF V600E.\nResponse rate was 50% (11/22) for dabrafenib and 54% (13/24) for dabrafenb and trametinib combination.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "GSK2118436",
                                        "GSK-2118436A",
                                        "GSK-2118436",
                                        "BRAF Inhibitor GSK2118436",
                                        "Benzenesulfonamide, N-(3-(5-(2-amino-4-pyrimidinyl)-2-(1,1-dimethylethyl)-4-thiazolyl)-2-fluorophenyl)-2,6-difluoro-",
                                    ],
                                    "id": 22,
                                    "name": "Dabrafenib",
                                    "ncit_id": "C82386",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7761,
                            "name": "EID7761",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "asco": 145877,
                                "asco_abstract_id": 6022,
                                "citation": "Manisha H. Shah, 2017, ASCO Annual Meeting, Abstract 6022",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01723202",
                                        "description": "This randomized phase II trial studies how well dabrafenib works with or without trametinib in treating patients with recurrent thyroid cancer. Dabrafenib and trametinib may stop the growth of tumor cells by blocking some of the enzymes needed for cell growth. It is not yet known whether dabrafenib is more effective when given with or without trametinib in treating thyroid cancer",
                                        "name": "Dabrafenib With or Without Trametinib in Treating Patients With Recurrent Thyroid Cancer",
                                        "nct_id": "NCT01723202",
                                    }
                                ],
                                "full_journal_title": "Journal of Clinical Oncology",
                                "id": 3096,
                                "is_review": False,
                                "journal": "J Clin Oncol 35, 2017 (suppl; abstr 6022)",
                                "name": "Results of randomized phase II trial of dabrafenib versus dabrafenib plus trametinib in BRAF-mutated papillary thyroid carcinoma.",
                                "publication_date": {
                                    "day": 12,
                                    "month": 1,
                                    "year": 2017,
                                },
                                "source_url": "https://meetinglibrary.asco.org/record/145877/abstract",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2019-12-05T12:50:14.195Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In an in vitro study, WiDr, HT-29 and RKO cell lines expressing BRAF V600E mutation was associated with sensitivity to regorafenib treatment, as compared to Caco-2 and KM12SM cells expressing wild-type BRAF. Resistance was determined by assessing cell proliferation and migration.",
                            "disease": {
                                "display_name": "Colon Cancer",
                                "doid": "DOID:219",
                                "id": 119,
                                "name": "Colon Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:219",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Stivarga",
                                        "BAY 73-4506",
                                        "4-(4-(((4-chloro-3-(trifluoromethyl)phenyl)carbamoyl)amino)-3-fluorophenoxy)-N-methylpyridine-2-carboxamide",
                                    ],
                                    "id": 27,
                                    "name": "Regorafenib",
                                    "ncit_id": "C78204",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3776,
                            "name": "EID3776",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Takigawa et al., 2016, Cancer Sci.",
                                "full_journal_title": "Cancer science",
                                "id": 1973,
                                "is_review": False,
                                "journal": "Cancer Sci.",
                                "name": "Multikinase inhibitor regorafenib inhibits the growth and metastasis of colon cancer with abundant stroma.",
                                "open_access": True,
                                "pmc_id": "PMC5001714",
                                "publication_date": {"month": 5, "year": 2016},
                                "pubmed": 26865419,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26865419",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-06-02T04:35:13.999Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "One patient participating in a large retrospective study of EGFR monoclonal antibodies in metastatic colorectal cancer had a tumor which harbored BRAF V600E, was wildtype for NRAS, KRAS and PIK3CA, and had individual response data. This patient was was a male treated with panitumumab monotherapy as 1st line therapy who experienced progressive disease (PFS: 7 weeks; OS: 10 weeks).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {"id": 28, "name": "Panitumumab", "ncit_id": "C1857"}
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 3827,
                            "name": "EID3827",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "De Roock et al., 2010, Lancet Oncol.",
                                "full_journal_title": "The Lancet. Oncology",
                                "id": 76,
                                "is_review": False,
                                "journal": "Lancet Oncol.",
                                "name": "Effects of KRAS, BRAF, NRAS, and PIK3CA mutations on the efficacy of cetuximab plus chemotherapy in chemotherapy-refractory metastatic colorectal cancer: a retrospective consortium analysis.",
                                "publication_date": {"month": 8, "year": 2010},
                                "pubmed": 20619739,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20619739",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-12-02T00:05:58.697Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An inducible BRAF-V600E mouse melanoma model shows a tight correlation between activated BRAF and disease progression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "PD 901",
                                        "MEK Inhibitor PD0325901",
                                        "PD0325901",
                                        "PD-0325901",
                                    ],
                                    "id": 29,
                                    "name": "Mirdametinib",
                                    "ncit_id": "C52195",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2125,
                            "name": "EID2125",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hoeflich et al., 2006, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1485,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF is required for tumor growth and maintenance in melanoma models.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16424035,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16424035",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:00.923Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a genetic screen of 87 lung cancer cell lines, one MEK-dependent cell line HCC364 contained a BRAF-V600E mutation. In growth assays, the MEK inhibitor PD-0325901 reduced proliferation in growth assays of the HCC364 cell line (IC50=3.2 nmol/L). Additionally, cells exposed to PD-0325901 exhibited an increase in apoptosis, as measured by induction of PARP cleavage.",
                            "disease": {
                                "display_name": "Lung Non-small Cell Carcinoma",
                                "doid": "DOID:3908",
                                "id": 8,
                                "name": "Lung Non-small Cell Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3908",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "PD 901",
                                        "MEK Inhibitor PD0325901",
                                        "PD0325901",
                                        "PD-0325901",
                                    ],
                                    "id": 29,
                                    "name": "Mirdametinib",
                                    "ncit_id": "C52195",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2143,
                            "name": "EID2143",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Pratilas et al., 2008, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 341,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Genetic predictors of MEK dependence in non-small cell lung cancer.",
                                "open_access": True,
                                "pmc_id": "PMC2649746",
                                "publication_date": {
                                    "day": 15,
                                    "month": 11,
                                    "year": 2008,
                                },
                                "pubmed": 19010912,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19010912",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:06.635Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a mouse in vivo study of MEK protein inhibitor, PD-0325901, was able to suppress growth of SKMEL28 BRAF-V600E xenograft tumors (P<0.01). The reduction of growth was associated with loss of D-cyclin expression and induction of p27.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "PD 901",
                                        "MEK Inhibitor PD0325901",
                                        "PD0325901",
                                        "PD-0325901",
                                    ],
                                    "id": 29,
                                    "name": "Mirdametinib",
                                    "ncit_id": "C52195",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2124,
                            "name": "EID2124",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Solit et al., 2006, Nature",
                                "full_journal_title": "Nature",
                                "id": 1487,
                                "is_review": False,
                                "journal": "Nature",
                                "name": "BRAF mutation predicts sensitivity to MEK inhibition.",
                                "open_access": True,
                                "pmc_id": "PMC3306236",
                                "publication_date": {
                                    "day": 19,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16273091,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16273091",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:00.820Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Ghosh et al. provide compelling evidence that thyroid cancers with a BRAFV600E mutation are sensitive to combined PLX4720 and Ponatinib treatment. They predicted a synergistic effect using HTS of active drugs and validated this prediction both in vitro and in vivo. The treatment combination significantly inhibited the growth of BRAFV600E mutant cancer cell lines, as well as reduced tumor growth, decreased metastases, and increased survival in a thyroid cancer mouse model. The authors recommend that this combination be tested in clinical trials.",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 30, "name": "PLX4720"},
                                {
                                    "aliases": [
                                        "Benzamide, 3-(2-Imidazo(1,2-B)Pyridazin-3-Ylethynyl)-4-Methyl-N-(4-((4-Methyl-1- Piperazinyl)Methyl)-3-(Trifluoromethyl)Phenyl)",
                                        "AP24534",
                                        "AP-24534",
                                    ],
                                    "id": 55,
                                    "name": "Ponatinib",
                                    "ncit_id": "C95777",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 8033,
                            "name": "EID8033",
                            "open_change_count": 1,
                            "rating": 4,
                            "source": {
                                "citation": "Kebebew et al., 2020, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 3168,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "A combinatorial strategy for targeting BRAF V600E mutant cancers with BRAF V600E inhibitor (PLX4720) and tyrosine kinase inhibitor (ponatinib).",
                                "publication_date": {
                                    "day": 14,
                                    "month": 1,
                                    "year": 2020,
                                },
                                "pubmed": 31937621,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/31937621",
                                "status": "submitted",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-03-24T21:35:06.653Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Combined nutlin-3 and PLX4720 administration to athymic nude mice subcutanousely injected with the A357 colorectal cell line with a BRAF V600E mutation effectively inhibited tumor growth significantly more than single agent therapy.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 30, "name": "PLX4720"},
                                {"id": 31, "name": "Nutlin-3"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 97,
                            "name": "EID97",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Ji et al., 2013, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 107,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "Vemurafenib synergizes with nutlin-3 to deplete survivin and suppresses melanoma viability and tumor growth.",
                                "open_access": True,
                                "pmc_id": "PMC3777641",
                                "publication_date": {
                                    "day": 15,
                                    "month": 8,
                                    "year": 2013,
                                },
                                "pubmed": 23812671,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23812671",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2017-05-31T00:11:36.426Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Combined PI3K inhibitor GDC0941 and BRAF inhibitor PLX4720 administration to NSG mice subcutanousely injected with colorectal cell lines with a BRAF V600E mutation effectively inhibited tumor growth and reduced cellular proliferation.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 30, "name": "PLX4720"},
                                {
                                    "aliases": [
                                        "Thieno(3,2-d)pyrimidine, 2-(1H-indazol-4-yl)-6-((4-(methylsulfonyl)-1-piperazinyl)methyl)-4-(4-morpholinyl)-, Methanesulfonate (1:2)",
                                        "Pictilisib Dimesylate",
                                        "GDC-0941 Dimesylate",
                                        "GDC-0941 Bismesylate",
                                        "2-(1H-indazol-4-yl)-6-(4-methanesulfonyl-piperazin-1- Ylmethyl)-4-morpholin-4-yl-thieno[3,2-d]pyrimidine, Bimesylate Salt",
                                    ],
                                    "id": 477,
                                    "name": "Pictilisib Bismesylate",
                                    "ncit_id": "C82380",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 96,
                            "name": "EID96",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Rad et al., 2013, Cancer Cell",
                                "full_journal_title": "Cancer cell",
                                "id": 106,
                                "is_review": False,
                                "journal": "Cancer Cell",
                                "name": "A genetic progression model of Braf(V600E)-induced intestinal tumorigenesis reveals targets for therapeutic intervention.",
                                "open_access": True,
                                "pmc_id": "PMC3706745",
                                "publication_date": {
                                    "day": 8,
                                    "month": 7,
                                    "year": 2013,
                                },
                                "pubmed": 23845441,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23845441",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2019-08-22T21:32:55.400Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Both in vitro and in vivo models in Kebebew et al. provide evidence that a combinatorial treatment of PLX4720 (a BRAF inhibitor) and ponatinib (a multi targeting tyrosine kinase inhibitor) shows potential efficacy for treatment of thyroid cancer harboring a BRAF V600E mutation. The authors use in vitro data to show that combinatorial therapy of PLX4720 + ponatinib causes less colony formation, increased apoptosis, and reduced MEK and ERK phosphorylation in thyroid cancer cell lines containing a BRAF V600E mutation when compared to the single agents alone and DMSO control as well as compared to WT BRAF thyroid cancer lines. The authors' in vivo model suggests that a combinatorial therapy reduces tumor burden of BRAF V600E thyroid cancer tumors without a significant loss of body weight. They also show that at 6 weeks of treatment, significantly more mice are surviving on the combinatorial treatment when compared to the single agents alone and the control. Lastly, the authors show that in a BRAF inhibitor resistant cell line model, they also find less colony formation capability, increased apoptosis, and reduced MEK and ERK phosphorylation with the combination therapy. Both the in vitro and in vivo data is convincing. However, the in vivo data would be more convincing if the authors had followed the progression of the mice past 6 weeks of treatment and if they had used a WT BRAF model as an additional control. The authors claim that PLX4720 and ponatinib ought to be considered for a clinical trial and their data seems to suggest a similar conclusion and thus validates this claim.",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {"id": 30, "name": "PLX4720"},
                                {
                                    "aliases": [
                                        "Benzamide, 3-(2-Imidazo(1,2-B)Pyridazin-3-Ylethynyl)-4-Methyl-N-(4-((4-Methyl-1- Piperazinyl)Methyl)-3-(Trifluoromethyl)Phenyl)",
                                        "AP24534",
                                        "AP-24534",
                                    ],
                                    "id": 55,
                                    "name": "Ponatinib",
                                    "ncit_id": "C95777",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 8040,
                            "name": "EID8040",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Kebebew et al., 2020, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 3168,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "A combinatorial strategy for targeting BRAF V600E mutant cancers with BRAF V600E inhibitor (PLX4720) and tyrosine kinase inhibitor (ponatinib).",
                                "publication_date": {
                                    "day": 14,
                                    "month": 1,
                                    "year": 2020,
                                },
                                "pubmed": 31937621,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/31937621",
                                "status": "submitted",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-03-25T18:36:24.929Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In a study of metastatic colorectal cancer patients treated with capecitabine, oxaliplatin, and bevacizumab, those with BRAF V600E mutations had reduced progression-free survival (5.9mo vs. 12.2mo, P=0.003) and reduced overall survival (15.0mo vs. 24.6mo, P=0.002) compared to those with wildtype BRAF.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "Xeloda",
                                        "Ro 09-1978/000",
                                        "5'-Deoxy-5-fluoro-N-[(pentyloxy)carbonyl]-cytidine",
                                    ],
                                    "id": 32,
                                    "name": "Capecitabine",
                                    "ncit_id": "C1794",
                                },
                                {
                                    "aliases": [
                                        "MYL-1402O",
                                        "Bevacizumab Biosimilar MYL-1402O",
                                        "Bevacizumab Biosimilar ABP 215",
                                        "ABP 215",
                                        "Zirabev",
                                        "Mvasi",
                                        "Bevacizumab-bvzr",
                                        "Bevacizumab-awwb",
                                        "Bevacizumab Biosimilar Zirabev",
                                        "Bevacizumab Biosimilar Mvasi",
                                        "Bevacizumab Biosimilar GB-222",
                                        "SCT501",
                                        "RhuMab-VEGF",
                                        "Recombinant Humanized Anti-VEGF Monoclonal Antibody",
                                        "Immunoglobulin G1 (Human-Mouse Monoclonal RhuMab-VEGF Gamma-Chain Anti-Human Vascular Endothelial Growth Factor), Disulfide With Human-Mouse Monoclonal RhuMab-VEGF Light Chain, Dimer",
                                        "HD204",
                                        "BP102 Biosimilar",
                                        "BP102",
                                        "Bevacizumab Biosimilar SCT501",
                                        "Bevacizumab Biosimilar RPH-001",
                                        "Bevacizumab Biosimilar QL 1101",
                                        "Bevacizumab Biosimilar MIL60",
                                        "Bevacizumab Biosimilar LY01008",
                                        "Bevacizumab Biosimilar IBI305",
                                        "Bevacizumab Biosimilar HLX04",
                                        "Bevacizumab Biosimilar HD204",
                                        "Bevacizumab Biosimilar FKB238",
                                        "Bevacizumab Biosimilar CT-P16",
                                        "Bevacizumab Biosimilar CBT 124",
                                        "Bevacizumab Biosimilar BI 695502",
                                        "Bevacizumab Biosimilar BEVZ92",
                                        "Bevacizumab Awwb",
                                        "Avastin",
                                        "Anti-VEGF RhuMAb",
                                        "Anti-VEGF Humanized Monoclonal Antibody",
                                        "Anti-VEGF",
                                    ],
                                    "id": 33,
                                    "name": "Bevacizumab",
                                    "ncit_id": "C2039",
                                },
                                {
                                    "aliases": [
                                        "Trans-l Diaminocyclohexane Oxalatoplatinum",
                                        "Trans-l DACH Oxalatoplatinum",
                                        "SR-96669",
                                        "RP-54780",
                                        "RP 54780",
                                        "Oxalatoplatinum",
                                        "Oxalatoplatin",
                                        "Oxalato (trans-l-1,2-diaminocyclohexane)platinum(II)",
                                        "Oxalato (1R,2R-cyclohexanediamine)platinum(II)",
                                        "JM-83",
                                        "Eloxatine",
                                        "ELOXATIN",
                                        "Diaminocyclohexane Oxalatoplatinum",
                                        "DACPLAT",
                                        "Dacotin",
                                        "Aiheng",
                                        "Ai Heng",
                                        "[SP-4-2-(1R-trans)]-(1,2,cyclohexanediamine-N,N')[ethanedioato(2--)-O,O']platinum",
                                        "[(1R,-2R)-1,2-cyclohexanediamine-N,N'][oxalato (2--)-O,O']platinum",
                                        "1-OHP",
                                    ],
                                    "id": 237,
                                    "name": "Oxaliplatin",
                                    "ncit_id": "C1181",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2121,
                            "name": "EID2121",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Tol et al., 2009, N. Engl. J. Med.",
                                "full_journal_title": "The New England journal of medicine",
                                "id": 1481,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "BRAF mutation in metastatic colorectal cancer.",
                                "publication_date": {
                                    "day": 2,
                                    "month": 7,
                                    "year": 2009,
                                },
                                "pubmed": 19571295,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19571295",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-10-29T23:48:39.214Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a mouse in vivo study, the MEK protein inhibitor selumetinib suppressed the growth of 1205Lu xenograft tumors, which contains the BRAF-V600Emutation (0.91 +/- 0.10-fold volume increase vs. 9.47 +/- 2.14-fold for non-treated mice). These tumors had a concomitant reduction of BrdU positive cells (P=0.009) but no increase in apoptosis. Selumetinib, in combination with docetaxel, a chemotherapeutic agent, produced cycle arrest and elevated apoptosis.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "MEK Inhibitor AZD6244",
                                        "AZD6244",
                                        "ARRY-142886",
                                    ],
                                    "id": 63,
                                    "name": "Selumetinib",
                                    "ncit_id": "C66939",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2129,
                            "name": "EID2129",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Haass et al., 2008, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 1489,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "The mitogen-activated protein/extracellular signal-regulated kinase kinase inhibitor AZD6244 (ARRY-142886) induces growth arrest in melanoma cells and tumor regression when combined with docetaxel.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 1,
                                    "year": 2008,
                                },
                                "pubmed": 18172275,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/18172275",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:01.449Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "49 BRAF-mutant melanoma cell lines from patients not previously treated with BRAF inhibition were analyzed. 21 exhibited primary resistance to BRAF inhibition using PLX4720. Inhibition of MEK1/2 (AZD6244 [selumetinib]) and PI3K/mTOR (BEZ235 [dactolisib]) was the most effective approach to counteract resistance in comparison to inhibition with the PLX4720 (progenitor of vemurafenib)-BEZ235 (where response was assessed by apoptosis, viability, p-ERK, p-Akt inhibition).",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "MEK Inhibitor AZD6244",
                                        "AZD6244",
                                        "ARRY-142886",
                                    ],
                                    "id": 63,
                                    "name": "Selumetinib",
                                    "ncit_id": "C66939",
                                },
                                {
                                    "aliases": [
                                        "NVPBEZ235",
                                        "BEZ235",
                                        "Benzeneacetonitrile, 4-(2,3-Dihydro-3-methyl-2-oxo-8-(3-quinolinyl)-1H-imidazo(4,5-c)quinolin-1-yl)-alpha,alpha-dimethyl-",
                                    ],
                                    "id": 343,
                                    "name": "Dactolisib",
                                    "ncit_id": "C74072",
                                },
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1005,
                            "name": "EID1005",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Penna et al., 2016, Oncotarget",
                                "full_journal_title": "Oncotarget",
                                "id": 694,
                                "is_review": False,
                                "journal": "Oncotarget",
                                "name": "Primary cross-resistance to BRAFV600E-, MEK1/2- and PI3K/mTOR-specific inhibitors in BRAF-mutant melanoma cells counteracted by dual pathway blockade.",
                                "open_access": True,
                                "pmc_id": "PMC4826182",
                                "publication_date": {
                                    "day": 26,
                                    "month": 1,
                                    "year": 2016,
                                },
                                "pubmed": 26678033,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/26678033",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2019-10-01T05:41:11.248Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "An inducible BRAF-V600E mouse melanoma model has shown a tight correlation between activated BRAF and disease progression.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "MEK Inhibitor AZD6244",
                                        "AZD6244",
                                        "ARRY-142886",
                                    ],
                                    "id": 63,
                                    "name": "Selumetinib",
                                    "ncit_id": "C66939",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2130,
                            "name": "EID2130",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Hoeflich et al., 2006, Cancer Res.",
                                "full_journal_title": "Cancer research",
                                "id": 1485,
                                "is_review": False,
                                "journal": "Cancer Res.",
                                "name": "Oncogenic BRAF is required for tumor growth and maintenance in melanoma models.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 1,
                                    "year": 2006,
                                },
                                "pubmed": 16424035,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16424035",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:01.623Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a mouse xenograft model, tumors derived from pilocytic astrocytoma cells that expressed BRAF V600E experienced a complete response to treatment with selumetinib, whereas tumors derived from a wildtype BRAF pilocytic astrocytoma cell line were resistant to selumetinib.",
                            "disease": {
                                "display_name": "High Grade Glioma",
                                "doid": "DOID:3070",
                                "id": 695,
                                "name": "High Grade Glioma",
                                "url": "http://disease-ontology.org/?id=DOID:3070",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "MEK Inhibitor AZD6244",
                                        "AZD6244",
                                        "ARRY-142886",
                                    ],
                                    "id": 63,
                                    "name": "Selumetinib",
                                    "ncit_id": "C66939",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2144,
                            "name": "EID2144",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Kolb et al., 2010, Pediatr Blood Cancer",
                                "full_journal_title": "Pediatric blood & cancer",
                                "id": 1498,
                                "is_review": False,
                                "journal": "Pediatr Blood Cancer",
                                "name": "Initial testing (stage 1) of AZD6244 (ARRY-142886) by the Pediatric Preclinical Testing Program.",
                                "open_access": True,
                                "pmc_id": "PMC3004092",
                                "publication_date": {"month": 10, "year": 2010},
                                "pubmed": 20806365,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20806365",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:07.023Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a study of pediatric low-grade gliomas, BRAF V600E mutation was associated with a strong trend toward reduced progression free survival (HR:2.39, 95%CI:0.93-6.15, P=0.07, multivariate analysis).",
                            "disease": {
                                "display_name": "High Grade Glioma",
                                "doid": "DOID:3070",
                                "id": 695,
                                "name": "High Grade Glioma",
                                "url": "http://disease-ontology.org/?id=DOID:3070",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "MEK Inhibitor AZD6244",
                                        "AZD6244",
                                        "ARRY-142886",
                                    ],
                                    "id": 63,
                                    "name": "Selumetinib",
                                    "ncit_id": "C66939",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2145,
                            "name": "EID2145",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Horbinski et al., 2012, Neuro-oncology",
                                "full_journal_title": "Neuro-oncology",
                                "id": 1499,
                                "is_review": False,
                                "journal": "Neuro-oncology",
                                "name": "Interplay among BRAF, p16, p53, and MIB1 in pediatric low-grade gliomas.",
                                "open_access": True,
                                "pmc_id": "PMC3367847",
                                "publication_date": {"month": 6, "year": 2012},
                                "pubmed": 22492957,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/22492957",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:07.173Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a phase 2 trial, patients with pediatric low-grade glioma after at least one standard therapy were treated with MEK1/2 inhibitor selumetinib.\nIn stratum 1, nine patients with WHO grade  I pilocytic astrocytoma harboring KIAA1549-BRAF fusion or BRAF V600E mutation showed tumor response. The response rate was 36% (9/25), with 2/7 (29%) patients with the BRAF V600E variant showing partial response. Also, PFS was shorter in patients with BRAF V600E than those harboring KIAA1549-BRAF fusions.\nIn stratum 3, ten patients with neurofibromatosis type 1 associated pediatric low-grade glioma showed tumor response. The response rate was 40% (10/25).",
                            "disease": {
                                "display_name": "Childhood Pilocytic Astrocytoma",
                                "doid": "DOID:6812",
                                "id": 1673,
                                "name": "Childhood Pilocytic Astrocytoma",
                                "url": "http://disease-ontology.org/?id=DOID:6812",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "MEK Inhibitor AZD6244",
                                        "AZD6244",
                                        "ARRY-142886",
                                    ],
                                    "id": 63,
                                    "name": "Selumetinib",
                                    "ncit_id": "C66939",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7485,
                            "name": "EID7485",
                            "open_change_count": 1,
                            "rating": 3,
                            "source": {
                                "citation": "Fangusaro et al., 2019, Lancet Oncol.",
                                "clinical_trials": [
                                    {
                                        "clinical_trial_url": "https://clinicaltrials.gov/show/NCT01089101",
                                        "description": "This phase I/II trial studies the side effects and the best dose of selumetinib and how well it works in treating or re-treating young patients with low grade glioma that has come back (recurrent) or does not respond to treatment (refractory). Selumetinib may stop the growth of tumor cells by blocking some of the enzymes needed for cell growth.",
                                        "name": "Selumetinib in Treating Young Patients With Recurrent or Refractory Low Grade Glioma",
                                        "nct_id": "NCT01089101",
                                    }
                                ],
                                "full_journal_title": "The Lancet. Oncology",
                                "id": 2973,
                                "is_review": False,
                                "journal": "Lancet Oncol.",
                                "name": "Selumetinib in paediatric patients with BRAF-aberrant or neurofibromatosis type 1-associated recurrent, refractory, or progressive low-grade glioma: a multicentre, phase 2 trial.",
                                "open_access": True,
                                "pmc_id": "PMC6628202",
                                "publication_date": {"month": 7, "year": 2019},
                                "pubmed": 31151904,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/31151904",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2021-03-02T23:16:40.676Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "Among metastatic colorectal cancer patients treated with cetuximab and irinotecan, those with BRAF V600E mutations were less likely to achieve a complete or partial response to therapy (0% , P=0.016, Fisher�s exact test) and had reduced median overall survival (4.1mo vs. 13.9mo, HR:0.51, 95%CI:0.18-0.95, P=0.037) than patients with wildtype BRAF.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "[1,4'-bipiperidine]-1'-carboxylic Acid (S)-4,11-diethyl-3,4,12,14-tetrahydro-4-hydroxy-3,14-dioxo-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinolin-9-yl Ester",
                                        "7-ethyl-10-[4-(1-piperidino)-1-piperidino]carbonyloxycamptothecin",
                                        "(+)-7-ethyl-10-hydroxycamptothecine 10-[1,4'-bipiperidine]-1'-carboxylate",
                                        "(+)-(4S)-4,11-diethyl-4-hydroxy-9-[(4-piperidino-piperidino)carbonyloxy]-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinol-3,14,(4H,12H)-dione",
                                    ],
                                    "id": 101,
                                    "name": "Irinotecan",
                                    "ncit_id": "C62040",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2119,
                            "name": "EID2119",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Loupakis et al., 2009, Br. J. Cancer",
                                "full_journal_title": "British journal of cancer",
                                "id": 1480,
                                "is_review": False,
                                "journal": "Br. J. Cancer",
                                "name": "KRAS codon 61, 146 and BRAF mutations predict resistance to cetuximab plus irinotecan in KRAS codon 12 and 13 wild-type metastatic colorectal cancer.",
                                "open_access": True,
                                "pmc_id": "PMC2736831",
                                "publication_date": {
                                    "day": 18,
                                    "month": 8,
                                    "year": 2009,
                                },
                                "pubmed": 19603018,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19603018",
                                "status": "partially curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:10:11.596Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "The presence of BRAF V600E or D594K was associated with reduced progression-free survival in 5 patients with metastatic colorectal cancer treated with irinotecan-based first line therapy (3.5mo vs. 12.8mo, HR:4.1, 95%CI:1.5-11.3, P=0.006) when compared to 39 patients with wildtype BRAF.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "[1,4'-bipiperidine]-1'-carboxylic Acid (S)-4,11-diethyl-3,4,12,14-tetrahydro-4-hydroxy-3,14-dioxo-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinolin-9-yl Ester",
                                        "7-ethyl-10-[4-(1-piperidino)-1-piperidino]carbonyloxycamptothecin",
                                        "(+)-7-ethyl-10-hydroxycamptothecine 10-[1,4'-bipiperidine]-1'-carboxylate",
                                        "(+)-(4S)-4,11-diethyl-4-hydroxy-9-[(4-piperidino-piperidino)carbonyloxy]-1H-pyrano[3',4':6,7]indolizino[1,2-b]quinol-3,14,(4H,12H)-dione",
                                    ],
                                    "id": 101,
                                    "name": "Irinotecan",
                                    "ncit_id": "C62040",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2118,
                            "name": "EID2118",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Souglakos et al., 2009, Br. J. Cancer",
                                "full_journal_title": "British journal of cancer",
                                "id": 1479,
                                "is_review": False,
                                "journal": "Br. J. Cancer",
                                "name": "Prognostic and predictive value of common mutations for treatment response and survival in patients with metastatic colorectal cancer.",
                                "open_access": True,
                                "pmc_id": "PMC2720232",
                                "publication_date": {
                                    "day": 4,
                                    "month": 8,
                                    "year": 2009,
                                },
                                "pubmed": 19603024,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19603024",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-07-19T22:53:18.986Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "One patient with BRAF V600E mutated melanoma (with no detected PI3K pathway deregulation) had a partial response on treatment with pictilisib, a PI3K inhibitor, for 9.5 months. Study was a phase-1 with 60 patients enrolled.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [{"id": 141, "name": "Pictilisib"}],
                            "evidence_direction": "Supports",
                            "evidence_level": "C",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 757,
                            "name": "EID757",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Sarker et al., 2015, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 500,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "First-in-human phase I study of pictilisib (GDC-0941), a potent pan-class I phosphatidylinositol-3-kinase (PI3K) inhibitor, in patients with advanced solid tumors.",
                                "open_access": True,
                                "pmc_id": "PMC4287394",
                                "publication_date": {
                                    "day": 1,
                                    "month": 1,
                                    "year": 2015,
                                },
                                "pubmed": 25370471,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25370471",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-02-17T19:49:55.184Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "Of 100 metastatic colorectal cancer patients treated with oxaliplatin-based first-line therapy, the 6 patients with either BRAF V600E or D594K had reduced progression-free survival compared to 94 patients with wildtype BRAF (5.0mo vs. 11.7mo, HR:6.4, 95%CI:2.6-15.6, P<0.0001).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Trans-l Diaminocyclohexane Oxalatoplatinum",
                                        "Trans-l DACH Oxalatoplatinum",
                                        "SR-96669",
                                        "RP-54780",
                                        "RP 54780",
                                        "Oxalatoplatinum",
                                        "Oxalatoplatin",
                                        "Oxalato (trans-l-1,2-diaminocyclohexane)platinum(II)",
                                        "Oxalato (1R,2R-cyclohexanediamine)platinum(II)",
                                        "JM-83",
                                        "Eloxatine",
                                        "ELOXATIN",
                                        "Diaminocyclohexane Oxalatoplatinum",
                                        "DACPLAT",
                                        "Dacotin",
                                        "Aiheng",
                                        "Ai Heng",
                                        "[SP-4-2-(1R-trans)]-(1,2,cyclohexanediamine-N,N')[ethanedioato(2--)-O,O']platinum",
                                        "[(1R,-2R)-1,2-cyclohexanediamine-N,N'][oxalato (2--)-O,O']platinum",
                                        "1-OHP",
                                    ],
                                    "id": 237,
                                    "name": "Oxaliplatin",
                                    "ncit_id": "C1181",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2117,
                            "name": "EID2117",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Souglakos et al., 2009, Br. J. Cancer",
                                "full_journal_title": "British journal of cancer",
                                "id": 1479,
                                "is_review": False,
                                "journal": "Br. J. Cancer",
                                "name": "Prognostic and predictive value of common mutations for treatment response and survival in patients with metastatic colorectal cancer.",
                                "open_access": True,
                                "pmc_id": "PMC2720232",
                                "publication_date": {
                                    "day": 4,
                                    "month": 8,
                                    "year": 2009,
                                },
                                "pubmed": 19603024,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19603024",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-07-19T23:02:19.124Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "This was a phase I expansion and pharmacodynamic study of oral MEK inhibitor RO4987655 on advanced cancer. Of 17 patients with BRAF V600E melanoma, 4 achieved partial response, 5 experienced stable disease lasting longer than 16 weeks, and 8 experienced disease progression (including 2 with prior vemurafenib treatment). One of the partial responders had a concomitant EGFR mutation, and two of the stable disease patients had other concomitant mutations (in RET or MET). The median days on treatment was 113 (18-366) for BRAF V600E melanoma patients and 107 (17-323) for BRAF V600 wildtype patients (n=23). Patients with BRAF V600E mutant melanoma experienced similar response rates (24% vs 20%) and rates of metabolic response measured by decrease in FDG uptake assessed by FDG-PET (86% vs 75%) compared to non-BRAF mutant patients. Patients with melanoma, either BRAF wt or V600E, experienced significant decreases in Ki67 expression by day 15 of MEK inhibitor treatment (P<0.02). The authors conclude that RO4987655 has clinical activity in BRAF V600E and BRAF wt melanoma.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "drugs": [
                                {
                                    "aliases": ["RO4987655"],
                                    "id": 243,
                                    "name": "MEK Inhibitor RO4987655",
                                    "ncit_id": "C82696",
                                }
                            ],
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 994,
                            "name": "EID994",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Zimmer et al., 2014, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 688,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "Phase I expansion and pharmacodynamic study of the oral MEK inhibitor RO4987655 (CH4987655) in selected patients with advanced cancer with RAS-RAF mutations.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 8,
                                    "year": 2014,
                                },
                                "pubmed": 24947927,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24947927",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-09-25T00:05:15.495Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Preclinical study analyzing the differential response to MEK inhibitors in KRAS and BRAF mutant cancer cell lines and mouse xenografts. Inhibition of active, phosphorylated MEK by GDC-0973 (cobimetinib) is required for strong inhibition of the MAPK pathway in BRAF-mutant tumours. This study provides mechanistic rationale for improved efficacy of cobimetinib in BRAF-mutant models compared to MEK inhibitors acting through an alternative mechanism (GDC-0623 and G-573).",
                            "disease": {
                                "display_name": "Cancer",
                                "doid": "DOID:162",
                                "id": 216,
                                "name": "Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:162",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "XL518",
                                        "MEK Inhibitor GDC-0973",
                                        "GDC-0973",
                                        "Cotellic",
                                    ],
                                    "id": 342,
                                    "name": "Cobimetinib",
                                    "ncit_id": "C68923",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1141,
                            "name": "EID1141",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Hatzivassiliou et al., 2013, Nature",
                                "full_journal_title": "Nature",
                                "id": 790,
                                "is_review": False,
                                "journal": "Nature",
                                "name": "Mechanism of MEK inhibition determines efficacy in mutant KRAS- versus BRAF-driven cancers.",
                                "publication_date": {
                                    "day": 12,
                                    "month": 9,
                                    "year": 2013,
                                },
                                "pubmed": 23934108,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23934108",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-06-29T21:04:10.177Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a mouse model of BRAF V600E colorectal cancer, western blots from tumors in mice treated with BRAF inhibitor GDC-0879 and PI3K/mTOR inhibitor BEZ235 showed stronger reduction in phospho-Akt and phospho-S6 than PI3K/mTOR inhibitor alone, and combination inhibition also resulted in stronger phospho-ERK inhibition in tumors than did BRAF inhibition alone. Increased apoptosis in tumors was seen in dual treatment conditions with increased TUNEL-positive cells. In vehicle treated mice, area of colon covered by tumor increased, while treatment with single agent inhibitors caused growth inhibition resulting in no change in colon area covered by tumors. Administration of dual inhibitors induced tumor regression apparent in a decrease of colonic area covered by tumors over the course of treatment.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drug_interaction_type": "Combination",
                            "drugs": [
                                {
                                    "aliases": [
                                        "NVPBEZ235",
                                        "BEZ235",
                                        "Benzeneacetonitrile, 4-(2,3-Dihydro-3-methyl-2-oxo-8-(3-quinolinyl)-1H-imidazo(4,5-c)quinolin-1-yl)-alpha,alpha-dimethyl-",
                                    ],
                                    "id": 343,
                                    "name": "Dactolisib",
                                    "ncit_id": "C74072",
                                },
                                {"id": 344, "name": "GDC-0879"},
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 1428,
                            "name": "EID1428",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Coffee et al., 2013, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 967,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "Concomitant BRAF and PI3K/mTOR blockade is required for effective treatment of BRAF(V600E) colorectal cancer.",
                                "open_access": True,
                                "pmc_id": "PMC3815598",
                                "publication_date": {
                                    "day": 15,
                                    "month": 5,
                                    "year": 2013,
                                },
                                "pubmed": 23549875,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23549875",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-07-08T18:00:38.330Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Thyroid cancer cell lines with BRAF V600E mutations were more sensitive to the MAPK inhibitor CI-1040 than those with wildtype BRAF (IC50: 0.031-1.251 uM vs. 44.376-278.286 uM). In a mouse xenograft model, the growth of tumors derived from KAT10 cells, which carries the BRAF V600E mutation, was inhibited following treatment with CI-1040 (P<0.01), but drug treatment had no effect on growth of tumors derived from the MRO cell line, which expresses wildtype BRAF.",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "PD-184352",
                                        "PD 184352/CI-1040",
                                        "CI-1040",
                                        "2-(2-Chloro-4-iodophenylamino)-N-cyclopropylmethoxy-3,4-difluorobenzamide",
                                    ],
                                    "id": 462,
                                    "name": "MEK Inhibitor CI-1040",
                                    "ncit_id": "C2670",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2136,
                            "name": "EID2136",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Liu et al., 2007, J. Clin. Endocrinol. Metab.",
                                "full_journal_title": "The Journal of clinical endocrinology and metabolism",
                                "id": 1493,
                                "is_review": False,
                                "journal": "J. Clin. Endocrinol. Metab.",
                                "name": "Inhibitory effects of the mitogen-activated protein kinase kinase inhibitor CI-1040 on the proliferation and tumor growth of thyroid cancer cells with BRAF or RAS mutations.",
                                "publication_date": {"month": 12, "year": 2007},
                                "pubmed": 17911174,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/17911174",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:05.149Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a meta-analysis of 8 studies, papillary thyroid cancer patients with BRAF V600E mutation had a higher frequency of recurrence and persistent disease compared to those with wildtype BRAF (28.5%  vs. 12.8% ,  Risk ratio:2.14, 95%CI:1.67-2.74, P<0.00001).",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "PD-184352",
                                        "PD 184352/CI-1040",
                                        "CI-1040",
                                        "2-(2-Chloro-4-iodophenylamino)-N-cyclopropylmethoxy-3,4-difluorobenzamide",
                                    ],
                                    "id": 462,
                                    "name": "MEK Inhibitor CI-1040",
                                    "ncit_id": "C2670",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2138,
                            "name": "EID2138",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Kim et al., 2012, Cancer",
                                "full_journal_title": "Cancer",
                                "id": 1495,
                                "is_review": False,
                                "journal": "Cancer",
                                "name": "The association of the BRAF(V600E) mutation with prognostic factors and poor clinical outcome in papillary thyroid cancer: a meta-analysis.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 4,
                                    "year": 2012,
                                },
                                "pubmed": 21882184,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21882184",
                                "status": "partially curated",
                            },
                            "status": "rejected",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:49:20.156Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a study of 102 papillary thyroid cancer patients with a 15 year median follow-up time, those with BRAF V600E mutations had reduced overall survival compared to those with wildtype BRAF (P=0.015, log-rank test). The presence of BRAF V600E was associated with poorer outcome as defined by persistent disease or death (Odds ratio:14.63, 95%CI:1.28-167.29, P=0.03, multivariate analysis.",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [{"id": 463, "name": "RDEA 119"}],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2141,
                            "name": "EID2141",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Elisei et al., 2008, J. Clin. Endocrinol. Metab.",
                                "full_journal_title": "The Journal of clinical endocrinology and metabolism",
                                "id": 1494,
                                "is_review": False,
                                "journal": "J. Clin. Endocrinol. Metab.",
                                "name": "BRAF(V600E) mutation and outcome of patients with papillary thyroid carcinoma: a 15-year median follow-up study.",
                                "publication_date": {"month": 10, "year": 2008},
                                "pubmed": 18682506,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/18682506",
                                "status": "partially curated",
                            },
                            "status": "rejected",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:35:38.517Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "Thyroid cancer cell lines with BRAF V600E mutations were more sensitive to the MEK inhibitor RDEA119 than those with wildtype BRAF (IC50: 0.034-0.217 uM vs. 1.413-34.120 uM).",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [{"id": 463, "name": "RDEA 119"}],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2139,
                            "name": "EID2139",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Liu et al., 2010, Int. J. Cancer",
                                "full_journal_title": "International journal of cancer",
                                "id": 1496,
                                "is_review": False,
                                "journal": "Int. J. Cancer",
                                "name": "BRAF mutation-selective inhibition of thyroid cancer cells by the novel MEK inhibitor RDEA119 and genetic-potentiated synergism with the mTOR inhibitor temsirolimus.",
                                "open_access": True,
                                "pmc_id": "PMC2916062",
                                "publication_date": {
                                    "day": 15,
                                    "month": 12,
                                    "year": 2010,
                                },
                                "pubmed": 21351275,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21351275",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2017-03-30T22:00:05.597Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Sensitivity/Response",
                            "description": "In a meta-analysis of 8 studies, papillary thyroid cancer patients with BRAF V600E mutation had a higher frequency of recurrence and persistent disease compared to those with wildtype BRAF (28.5%  vs. 12.8% ,  Risk ratio:2.14, 95%CI:1.67-2.74, P<0.00001).",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "drugs": [{"id": 463, "name": "RDEA 119"}],
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 2140,
                            "name": "EID2140",
                            "open_change_count": 0,
                            "source": {
                                "citation": "Kim et al., 2012, Cancer",
                                "full_journal_title": "Cancer",
                                "id": 1495,
                                "is_review": False,
                                "journal": "Cancer",
                                "name": "The association of the BRAF(V600E) mutation with prognostic factors and poor clinical outcome in papillary thyroid cancer: a meta-analysis.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 4,
                                    "year": 2012,
                                },
                                "pubmed": 21882184,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21882184",
                                "status": "partially curated",
                            },
                            "status": "rejected",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:49:07.201Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "In a preclinical study, Diffuse large B-cell lymphoma cell lines expressing BRAF V600E were resistant to a BCL-2 inhibitor, venetoclax, demonstrating cell growth inhibition at half-maximal growth inhibitory concentration (GI50) larger than 10 μM when compared to cells expressing vector control (GI50 = 0.43 μM).",
                            "disease": {
                                "display_name": "Diffuse Large B-cell Lymphoma",
                                "doid": "DOID:0050745",
                                "id": 45,
                                "name": "Diffuse Large B-cell Lymphoma",
                                "url": "http://disease-ontology.org/?id=DOID:0050745",
                            },
                            "drugs": [
                                {
                                    "aliases": [
                                        "Venclyxto",
                                        "Venclexta",
                                        "RG7601",
                                        "GDC-0199",
                                        "ABT199",
                                        "ABT-199",
                                        "ABT-0199",
                                        "4-(4-((2-(4-Chlorophenyl)-4,4-dimethylcyclohex-1-en-1-yl)methyl)piperazin-1-yl)-N-((3-nitro-4-((tetrahydro-2H-pyran-4-ylmethyl)amino)phenyl)sulfonyl)-2-(1H-pyrrolo(2,3-b)pyridin-5-yloxy)benzamide",
                                    ],
                                    "id": 574,
                                    "name": "Venetoclax",
                                    "ncit_id": "C103147",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 8952,
                            "name": "EID8952",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Herling et al., 2018, Nat Commun",
                                "full_journal_title": "Nature communications",
                                "id": 3501,
                                "is_review": False,
                                "journal": "Nat Commun",
                                "name": "Clonal dynamics towards the development of venetoclax resistance in chronic lymphocytic leukemia.",
                                "open_access": True,
                                "pmc_id": "PMC5820258",
                                "publication_date": {"day": 20, "year": 2018},
                                "pubmed": 29463802,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29463802",
                                "status": "submitted",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2020-12-15T12:19:07.679Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Resistance",
                            "description": "The results showed that cell lines with BRAF(V600E) or KRAS(G13D) mutation were resistant, whereas cell lines with wild-type of both KRAS and BRAF were particularly sensitive to BMS-754807 if they have either higher RNA expression levels of IR-A or lower levels of IGFBP6.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "drugs": [
                                {
                                    "aliases": ["BMS-754807"],
                                    "id": 617,
                                    "name": "Dual IGF-1R/InsR Inhibitor BMS-754807",
                                    "ncit_id": "C74043",
                                }
                            ],
                            "evidence_direction": "Supports",
                            "evidence_level": "D",
                            "evidence_type": "Predictive",
                            "flagged": False,
                            "id": 7077,
                            "name": "EID7077",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Huang et al., 2015, Mol. Cancer Ther.",
                                "full_journal_title": "Molecular cancer therapeutics",
                                "id": 2752,
                                "is_review": False,
                                "journal": "Mol. Cancer Ther.",
                                "name": "IRS2 copy number gain, KRAS and BRAF mutation status as predictive biomarkers for response to the IGF-1R/IR inhibitor BMS-754807 in colorectal cancer cell lines.",
                                "publication_date": {"month": 2, "year": 2015},
                                "pubmed": 25527633,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25527633",
                                "status": "fully curated",
                            },
                            "status": "submitted",
                            "type": "evidence",
                            "updated_at": "2019-02-08T13:21:03.028Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "BRAF V600E is correlated with poor prognosis in papillary thyroid cancer in a study of 187 patients with PTC and other thyroid diseases.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 106,
                            "name": "EID106",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "He et al., 2014, Oncol Lett",
                                "full_journal_title": "Oncology letters",
                                "id": 112,
                                "is_review": False,
                                "journal": "Oncol Lett",
                                "name": "Prognostic value of the BRAF V600E mutation in papillary thyroid carcinoma.",
                                "open_access": True,
                                "pmc_id": "PMC3881916",
                                "publication_date": {"month": 2, "year": 2014},
                                "pubmed": 24396464,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24396464",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:30:00.735Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "Patients with completely resected colorectal adenocarcinoma (Stage II-III) were treated with fluorouracil and leucovorin +/- ironotecan. Of the 1,307 FFPE samples tested, V600E was observed in 31 Stage II samples (7.6%) and 72 Stage III samples (7.9%). V600E was prognostic for overall survival, but not for relapse-free survival, in patients with stages II and III combined, and in stage III alone. For all MSI low and stable tumors, BRAF V600E positive samples had a hazard ratio (HR) of 2.19 (95% CI, 1.43 to 3.37, P=0.00034). For all samples in the cohort (MSI-H and MSI-L) BRAF V600E positive samples had a 1.66 HR (95% CI, 1.15 to 2.40, P=0.0069). The authors note prognostic value for BRAF V600E, especially in non-MSI high tumors.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 7156,
                            "name": "EID7156",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Roth et al., 2010, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 2783,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Prognostic role of KRAS and BRAF in stage II and III resected colon cancer: results of the translational study on the PETACC-3, EORTC 40993, SAKK 60-00 trial.",
                                "publication_date": {
                                    "day": 20,
                                    "month": 1,
                                    "year": 2010,
                                },
                                "pubmed": 20008640,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/20008640",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2019-02-28T18:46:30.554Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "BRAF status does not predict outcome in patients treated with dacarbazine or temozolomide.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 82,
                            "name": "EID82",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "Meckbach et al., 2014, PLoS ONE",
                                "full_journal_title": "PloS one",
                                "id": 96,
                                "is_review": False,
                                "journal": "PLoS ONE",
                                "name": "BRAF-V600 mutations have no prognostic impact in stage IV melanoma patients treated with monochemotherapy.",
                                "open_access": True,
                                "pmc_id": "PMC3930670",
                                "publication_date": {"year": 2014},
                                "pubmed": 24586605,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24586605",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2019-03-22T01:52:45.924Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "In a meta-analysis of 8 studies, papillary thyroid cancer patients with BRAF V600E mutation had a higher frequency of recurrence and persistent disease compared to those with wildtype BRAF (28.5%  vs. 12.8% ,  Risk ratio:2.14, 95%CI:1.67-2.74, P<0.00001).",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 2503,
                            "name": "EID2503",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Kim et al., 2012, Cancer",
                                "full_journal_title": "Cancer",
                                "id": 1495,
                                "is_review": False,
                                "journal": "Cancer",
                                "name": "The association of the BRAF(V600E) mutation with prognostic factors and poor clinical outcome in papillary thyroid cancer: a meta-analysis.",
                                "publication_date": {
                                    "day": 1,
                                    "month": 4,
                                    "year": 2012,
                                },
                                "pubmed": 21882184,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21882184",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:48:39.029Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "Using Sanger sequencing, BRAFV600E mutations were identified in 21 of 285 patients with PLGGs (7.4%). This mutation was enriched in hemispheric tumors (p<0.007) and was associated with shorter progression-free survival (p=0.011) and overall survival (p=0.032) [mt (n=18) vs wt (n=166)].",
                            "disease": {
                                "display_name": "Childhood Low-grade Glioma",
                                "doid": "DOID:0080830",
                                "id": 3048,
                                "name": "Childhood Low-grade Glioma",
                                "url": "http://disease-ontology.org/?id=DOID:0080830",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 7191,
                            "name": "EID7191",
                            "open_change_count": 0,
                            "phenotypes": [
                                {
                                    "hpo_class": "Early young adult onset",
                                    "hpo_id": "HP:0025708",
                                    "id": 16642,
                                    "url": "https://hpo.jax.org/app/browse/term/HP:0025708",
                                },
                                {
                                    "hpo_class": "Pediatric onset",
                                    "hpo_id": "HP:0410280",
                                    "id": 15320,
                                    "url": "https://hpo.jax.org/app/browse/term/HP:0410280",
                                },
                            ],
                            "rating": 4,
                            "source": {
                                "citation": "Yang et al., 2018, Acta Neuropathol.",
                                "full_journal_title": "Acta neuropathologica",
                                "id": 2816,
                                "is_review": False,
                                "journal": "Acta Neuropathol.",
                                "name": "Pediatric low-grade gliomas can be molecularly stratified for risk.",
                                "publication_date": {"year": 2018},
                                "pubmed": 29948154,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/29948154",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-12-10T20:17:35.066Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "Clinical study including 219 patients with papillary thyroid cancer (PTC) to determine a correlation between the BRAF V600E mutation and poor oncological outcome. This study found that 107 of the 219 (49%) patients had this mutation signifying that the BRAF V600E mutation is one of the most commonly occurring among PTC patients. This cohort was split into two groups—BRAF+ and BRAF-. Of the 107 patients that were BRAF+, 25% had tumor reoccurrence compared with 9% in the BRAF- group (P=0.004). Multivariate analysis was performed to assess BRAF correlation independent of known contributing factors to cancer such as age, gender, and multifocality. The results showed that the BRAF mutation is indicative/contributes to lymph node metastasis, associated with tumor reoccurrence, stage, and that recurrent disease was more extensive and required more aggressive treatments in BRAF+ patients compared with BRAF- patients. The authors conclude that PTC patients with the BRAF V600E mutation have worse clinicopathological outcomes, and that the BRAF mutation can be used to assess risk stratification in patients with PTC.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 9170,
                            "name": "EID9170",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Xing et al., 2005, J Clin Endocrinol Metab",
                                "full_journal_title": "The Journal of clinical endocrinology and metabolism",
                                "id": 3893,
                                "is_review": False,
                                "journal": "J Clin Endocrinol Metab",
                                "name": "BRAF mutation predicts a poorer clinical prognosis for papillary thyroid cancer.",
                                "publication_date": {"month": 12, "year": 2005},
                                "pubmed": 16174717,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/16174717",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2021-03-23T18:31:15.989Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "BRAF V600E is correlated with shorter disease-free and overall Survival in a Spanish cohort of melanoma patients.",
                            "disease": {
                                "display_name": "Melanoma",
                                "doid": "DOID:1909",
                                "id": 7,
                                "name": "Melanoma",
                                "url": "http://disease-ontology.org/?id=DOID:1909",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 104,
                            "name": "EID104",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Nagore et al., 2014, J. Am. Acad. Dermatol.",
                                "full_journal_title": "Journal of the American Academy of Dermatology",
                                "id": 111,
                                "is_review": False,
                                "journal": "J. Am. Acad. Dermatol.",
                                "name": "Prognostic value of BRAF mutations in localized cutaneous melanoma.",
                                "publication_date": {"month": 5, "year": 2014},
                                "pubmed": 24388723,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24388723",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2015-06-21T16:49:43.135Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "Unlike other studies that suggest a poorer outcome, BRAF mutation in this study was not correlated with poorer prognosis in papillary thyroid cancer.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 102,
                            "name": "EID102",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Walczyk et al., 2014, Clin. Endocrinol. (Oxf)",
                                "full_journal_title": "Clinical endocrinology",
                                "id": 109,
                                "is_review": False,
                                "journal": "Clin. Endocrinol. (Oxf)",
                                "name": "The BRAF(V600E) mutation in papillary thyroid microcarcinoma: does the mutation have an impact on clinical outcome?",
                                "publication_date": {"month": 6, "year": 2014},
                                "pubmed": 24354346,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24354346",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:28:30.571Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "The CRYSTAL Phase III Trial evaluated efficacy of irinotecan, fluorouracil, and leucovorin (FOLFIRI) with or without Cetuximab for colorectal cancer patients who presented with unresectable metastatic disease. BRAF mutation status (V600E) was analyzed via LightMix BRAF V600E Kit. V600E mutations were detected in 60/999 tumor samples (6%), 59 of which were wild-type for KRAS. When comparing patients with wildtype KRAS (n=625), BRAF V600E tumors had worse outcomes relative to BRAF wildtype. For patients with BRAF V600E tumors (n=566), median overall survival (OS) was 25.1 months with cetuximab and 21.6 months without cetuximab. For patients with wildtype BRAF (n=59), median OS was 14.1 months with cetuximab and 10.3 months without cetuximab.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 7157,
                            "name": "EID7157",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Van Cutsem et al., 2011, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 1931,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "Cetuximab plus irinotecan, fluorouracil, and leucovorin as first-line treatment for metastatic colorectal cancer: updated analysis of overall survival according to tumor KRAS and BRAF mutation status.",
                                "publication_date": {
                                    "day": 20,
                                    "month": 5,
                                    "year": 2011,
                                },
                                "pubmed": 21502544,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21502544",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2019-02-28T18:42:15.336Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "In patients with papillary thyroid cancer harboring both BRAF V600E and the TERT promotor mutation C228T (N=35), recurrence-free survival is worse than in patients harboring one of these mutations (N=159 BRAF, N=26 TERT promoter mutated) or no mutations in either gene (N=287)(P<0.001).",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 656,
                            "name": "EID656",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Xing et al., 2014, J. Clin. Oncol.",
                                "full_journal_title": "Journal of clinical oncology : official journal of the American Society of Clinical Oncology",
                                "id": 413,
                                "is_review": False,
                                "journal": "J. Clin. Oncol.",
                                "name": "BRAF V600E and TERT promoter mutations cooperatively identify the most aggressive papillary thyroid cancer with highest recurrence.",
                                "open_access": True,
                                "pmc_id": "PMC4145183",
                                "publication_date": {
                                    "day": 1,
                                    "month": 9,
                                    "year": 2014,
                                },
                                "pubmed": 25024077,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/25024077",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:41:15.610Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "In a study of 468 colorectal cancer samples, 61 patients had micro-satellite instability and there was a statistically significantly better prognosis for BRAF WT patients relative to BRAF (V600E)-mutated patients (Log-rank P=0.0903).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 1940,
                            "name": "EID1940",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Schell et al., 2016, Nat Commun",
                                "full_journal_title": "Nature communications",
                                "id": 1367,
                                "is_review": False,
                                "journal": "Nat Commun",
                                "name": "A multigene mutation classification of 468 colorectal cancers reveals a prognostic role for APC.",
                                "open_access": True,
                                "pmc_id": "PMC4912618",
                                "publication_date": {
                                    "day": 15,
                                    "month": 6,
                                    "year": 2016,
                                },
                                "pubmed": 27302369,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27302369",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-01-22T18:08:41.761Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Positive",
                            "description": "Thyroid nodule with BRAF V600E mutation is highly correlated with papillary thyroid cancer.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Diagnostic",
                            "flagged": False,
                            "id": 80,
                            "name": "EID80",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Crescenzi et al., 2014, Horm. Metab. Res.",
                                "full_journal_title": "Hormone and metabolic research = Hormon- und Stoffwechselforschung = Hormones et métabolisme",
                                "id": 94,
                                "is_review": False,
                                "journal": "Horm. Metab. Res.",
                                "name": "Immunohistochemistry for BRAF(V600E) antibody VE1 performed in core needle biopsy samples identifies mutated papillary thyroid cancers.",
                                "publication_date": {"month": 5, "year": 2014},
                                "pubmed": 24570209,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24570209",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:29:05.109Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "BRAF mutation correlated with poor prognosis in papillary thyroid cancer in both older (>65 yo) and younger (<65 yo) cohorts.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 105,
                            "name": "EID105",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Howell et al., 2011, Ann. Surg. Oncol.",
                                "full_journal_title": "Annals of surgical oncology",
                                "id": 93,
                                "is_review": False,
                                "journal": "Ann. Surg. Oncol.",
                                "name": "Both BRAF V600E mutation and older age (≥ 65 years) are associated with recurrent papillary thyroid cancer.",
                                "publication_date": {"month": 12, "year": 2011},
                                "pubmed": 21594703,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21594703",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:31:06.333Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "V600E is associated with adverse pathological features of colorectal cancer. This can be concluded as a marker of poor prognosis.",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 103,
                            "name": "EID103",
                            "open_change_count": 0,
                            "rating": 5,
                            "source": {
                                "citation": "Chen et al., 2014, PLoS ONE",
                                "full_journal_title": "PloS one",
                                "id": 110,
                                "is_review": False,
                                "journal": "PLoS ONE",
                                "name": "BRAFV600E mutation and its association with clinicopathological features of colorectal cancer: a systematic review and meta-analysis.",
                                "open_access": True,
                                "pmc_id": "PMC3940924",
                                "publication_date": {"year": 2014},
                                "pubmed": 24594804,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/24594804",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-07-17T22:57:55.680Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Positive",
                            "description": "In 47 patients with Hairy Cell Leukemia, sequencing discovered a V600E mutation in all 47 of the sequenced patients.",
                            "disease": {
                                "display_name": "Hairy Cell Leukemia",
                                "doid": "DOID:285",
                                "id": 665,
                                "name": "Hairy Cell Leukemia",
                                "url": "http://disease-ontology.org/?id=DOID:285",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Diagnostic",
                            "flagged": False,
                            "id": 1127,
                            "name": "EID1127",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Tiacci et al., 2011, N. Engl. J. Med.",
                                "full_journal_title": "The New England journal of medicine",
                                "id": 780,
                                "is_review": False,
                                "journal": "N. Engl. J. Med.",
                                "name": "BRAF mutations in hairy-cell leukemia.",
                                "open_access": True,
                                "pmc_id": "PMC3689585",
                                "publication_date": {
                                    "day": 16,
                                    "month": 6,
                                    "year": 2011,
                                },
                                "pubmed": 21663470,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21663470",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-03-22T16:40:00.957Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "V600E is correlated with disease recurrence in both age cohorts (>65 and <65 yo).",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 107,
                            "name": "EID107",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Howell et al., 2011, Ann. Surg. Oncol.",
                                "full_journal_title": "Annals of surgical oncology",
                                "id": 93,
                                "is_review": False,
                                "journal": "Ann. Surg. Oncol.",
                                "name": "Both BRAF V600E mutation and older age (≥ 65 years) are associated with recurrent papillary thyroid cancer.",
                                "publication_date": {"month": 12, "year": 2011},
                                "pubmed": 21594703,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21594703",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2018-10-24T15:30:48.222Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "In a study of 102 papillary thyroid cancer patients with a 15 year median follow-up time, those with BRAF V600E mutations had reduced overall survival compared to those with wildtype BRAF (P=0.015, log-rank test). The presence of BRAF V600E was associated with poorer outcome as defined by persistent disease or death (Odds ratio:14.63, 95%CI:1.28-167.29, P=0.03, multivariate analysis.",
                            "disease": {
                                "display_name": "Thyroid Gland Papillary Carcinoma",
                                "doid": "DOID:3969",
                                "id": 156,
                                "name": "Thyroid Gland Papillary Carcinoma",
                                "url": "http://disease-ontology.org/?id=DOID:3969",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 2137,
                            "name": "EID2137",
                            "open_change_count": 0,
                            "rating": 4,
                            "source": {
                                "citation": "Elisei et al., 2008, J. Clin. Endocrinol. Metab.",
                                "full_journal_title": "The Journal of clinical endocrinology and metabolism",
                                "id": 1494,
                                "is_review": False,
                                "journal": "J. Clin. Endocrinol. Metab.",
                                "name": "BRAF(V600E) mutation and outcome of patients with papillary thyroid carcinoma: a 15-year median follow-up study.",
                                "publication_date": {"month": 10, "year": 2008},
                                "pubmed": 18682506,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/18682506",
                                "status": "partially curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2019-02-09T23:46:48.965Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "This study examined outcomes of 240 rectum cancer patients treated with total mesorectal excision therapy. Tumor samples were obtained at the time of surgery and genotyped for BRAF exon 15 mutations. BRAF V600E was identified in 5 cases. The authors reported that no differences were found in overall survival between patients with and without BRAF mutations (P > 0.1).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "evidence_direction": "Does Not Support",
                            "evidence_level": "C",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 2362,
                            "name": "EID2362",
                            "open_change_count": 0,
                            "rating": 2,
                            "source": {
                                "citation": "He et al., 2009, Clin. Cancer Res.",
                                "full_journal_title": "Clinical cancer research : an official journal of the American Association for Cancer Research",
                                "id": 1475,
                                "is_review": False,
                                "journal": "Clin. Cancer Res.",
                                "name": "PIK3CA mutations predict local recurrences in rectal cancer patients.",
                                "publication_date": {
                                    "day": 15,
                                    "month": 11,
                                    "year": 2009,
                                },
                                "pubmed": 19903786,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/19903786",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-07-09T22:08:52.525Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "In a study of 908 patients with colorectal cancer, 45 patients had BRAF V600E mutations and 589 patients were BRAF wild type.  BRAF V600E mutations were more likely to be proximal tumors (68.9%, 20.7%; p<0.0001), they were more likely to be poorly differentiated (17.7%, 1.9%; p<0.0001), they were more likely to be mucinous carcinoma type (20.0%, 4.2%; p=0.0003), they were more likely to have lymphatic invasion (77.6%, 49.9%; p=0.0003), and they had a shorter survival time (31.1 mo, 41.6 mo; p=0.001).  The 3-year survival rate was significantly poorer in the V600E group when compared to the wild type group (63.8%, 87.9%; p<0.0001).",
                            "disease": {
                                "display_name": "Colorectal Cancer",
                                "doid": "DOID:9256",
                                "id": 11,
                                "name": "Colorectal Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:9256",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 1552,
                            "name": "EID1552",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Amaki-Takao et al., 2016, Oncology",
                                "full_journal_title": "Oncology",
                                "id": 1027,
                                "is_review": False,
                                "journal": "Oncology",
                                "name": "Colorectal Cancer with BRAF D594G Mutation Is Not Associated with Microsatellite Instability or Poor Prognosis.",
                                "publication_date": {
                                    "day": 13,
                                    "month": 7,
                                    "year": 2016,
                                },
                                "pubmed": 27404270,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/27404270",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-07-19T12:00:47.662Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Poor Outcome",
                            "description": "In patients with multiple myeloma, those with BRAF V600E had shorter overall survival than wild-type.",
                            "disease": {
                                "display_name": "Multiple Myeloma",
                                "doid": "DOID:9538",
                                "id": 41,
                                "name": "Multiple Myeloma",
                                "url": "http://disease-ontology.org/?id=DOID:9538",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Prognostic",
                            "flagged": False,
                            "id": 463,
                            "name": "EID463",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Andrulis et al., 2013, Cancer Discov",
                                "full_journal_title": "Cancer discovery",
                                "id": 278,
                                "is_review": False,
                                "journal": "Cancer Discov",
                                "name": "Targeting the BRAF V600E mutation in multiple myeloma.",
                                "publication_date": {"month": 8, "year": 2013},
                                "pubmed": 23612012,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/23612012",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2020-04-08T22:38:19.626Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                        {
                            "clinical_significance": "Positive",
                            "description": "BRAF V600E is shown to be associated with the tall-cell variant of papillary thyroid cancer.",
                            "disease": {
                                "display_name": "Thyroid Gland Cancer",
                                "doid": "DOID:1781",
                                "id": 16,
                                "name": "Thyroid Gland Cancer",
                                "url": "http://disease-ontology.org/?id=DOID:1781",
                            },
                            "evidence_direction": "Supports",
                            "evidence_level": "B",
                            "evidence_type": "Diagnostic",
                            "flagged": False,
                            "id": 79,
                            "name": "EID79",
                            "open_change_count": 0,
                            "rating": 3,
                            "source": {
                                "citation": "Howell et al., 2011, Ann. Surg. Oncol.",
                                "full_journal_title": "Annals of surgical oncology",
                                "id": 93,
                                "is_review": False,
                                "journal": "Ann. Surg. Oncol.",
                                "name": "Both BRAF V600E mutation and older age (≥ 65 years) are associated with recurrent papillary thyroid cancer.",
                                "publication_date": {"month": 12, "year": 2011},
                                "pubmed": 21594703,
                                "source_url": "http://www.ncbi.nlm.nih.gov/pubmed/21594703",
                                "status": "fully curated",
                            },
                            "status": "accepted",
                            "type": "evidence",
                            "updated_at": "2016-03-16T22:09:27.538Z",
                            "variant_id": 12,
                            "variant_origin": "Somatic",
                        },
                    ],
                    "flagged": False,
                    "gene_id": 5,
                    "hgvs_expressions": [
                        "NM_004333.4:c.1799T>A",
                        "NP_004324.2:p.Val600Glu",
                        "NC_000007.13:g.140453136A>T",
                        "ENST00000288602.6:c.1799T>A",
                    ],
                    "lifecycle_actions": {
                        "last_commented_on": {
                            "organization": {
                                "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                "id": 12,
                                "name": "Washington University in Saint Louis",
                                "profile_image": {
                                    "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                    "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                    "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                    "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                    "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                },
                                "url": "https://wustl.edu/",
                            },
                            "timestamp": "2022-01-13T05:39:29.409Z",
                            "user": {
                                "area_of_expertise": "Research Scientist",
                                "avatar_url": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                "avatars": {
                                    "x128": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=128",
                                    "x14": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=14",
                                    "x32": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                    "x64": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=64",
                                },
                                "bio": "Dr. Danos is a Postdoctoral Researcher in the Griffith Lab, with research interests in developing data and knowledge models which can describe and give structure to clinical and preclinical cancer variant knowledge, and in developing standards to enable efficient trasnfer and communication of this information between groups who are generating and curating this data, as well as with the medical and research community at large, in order to address the curation bottleneck which has arisen with increasing incorporation of NGS technology into clinical as well as research contexts. Dr. Danos is also interested in elucidation of the regulatory structure of the genome, and the role of non-coding mutations in cancer.",
                                "conflict_of_interest": {
                                    "coi_valid": "expired",
                                    "details": {
                                        "coi_present": False,
                                        "created_at": "2021-10-20T09:19:34.199Z",
                                        "expires_at": "2022-10-20T09:19:34.199Z",
                                    },
                                },
                                "country": {
                                    "id": 214,
                                    "iso": "US",
                                    "name": "United States",
                                },
                                "created_at": "2016-01-27T00:20:51.218Z",
                                "display_name": "ArpadDanos",
                                "featured_expert": True,
                                "id": 110,
                                "last_seen_at": "2022-04-08T09:33:34.645Z",
                                "most_recent_organization": {
                                    "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                    "id": 1,
                                    "name": "The McDonnell Genome Institute",
                                    "parent": {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    "profile_image": {
                                        "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                        "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                        "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                        "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                        "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                    },
                                    "url": "http://genome.wustl.edu/",
                                },
                                "name": "Arpad Danos",
                                "orcid": "0000-0001-9815-2288",
                                "organizations": [
                                    {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    {
                                        "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                        "id": 1,
                                        "name": "The McDonnell Genome Institute",
                                        "parent": {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                            "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                            "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                            "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                            "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                        },
                                        "url": "http://genome.wustl.edu/",
                                    },
                                    {
                                        "description": "Pediatric Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically relevant somatic variants in pediatric cancers. ",
                                        "id": 9,
                                        "name": "Pediatric Cancer Taskforce",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/009/x128/clingen-vcep-1.png?1596737215",
                                            "x14": "/system/organizations/profile_images/000/000/009/x14/clingen-vcep-1.png?1596737215",
                                            "x256": "/system/organizations/profile_images/000/000/009/x256/clingen-vcep-1.png?1596737215",
                                            "x32": "/system/organizations/profile_images/000/000/009/x32/clingen-vcep-1.png?1596737215",
                                            "x64": "/system/organizations/profile_images/000/000/009/x64/clingen-vcep-1.png?1596737215",
                                        },
                                        "url": "https://www.clinicalgenome.org/working-groups/somatic/pediatric-task-team/\r\n",
                                    },
                                    {
                                        "description": "The Hematologic Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically significant somatic variants in hematological malignancies.",
                                        "id": 11,
                                        "name": "Hematologic Cancer Taskforce",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/011/x128/clingen-vcep-3.png?1596737121",
                                            "x14": "/system/organizations/profile_images/000/000/011/x14/clingen-vcep-3.png?1596737121",
                                            "x256": "/system/organizations/profile_images/000/000/011/x256/clingen-vcep-3.png?1596737121",
                                            "x32": "/system/organizations/profile_images/000/000/011/x32/clingen-vcep-3.png?1596737121",
                                            "x64": "/system/organizations/profile_images/000/000/011/x64/clingen-vcep-3.png?1596737121",
                                        },
                                        "url": "https://clinicalgenome.org/working-groups/somatic/hematological-cancers/",
                                    },
                                    {
                                        "description": "Dedicated to the systematic curation of the genes and variants associated with the BCR-ABL1-like (Philadelphia (Ph)-like) genetics subtype of B-lymphoblastic leukemia (B-ALL).",
                                        "id": 16,
                                        "name": "Ph-like B-ALL",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/016/x128/clingen-vcep-4.png?1616506588",
                                            "x14": "/system/organizations/profile_images/000/000/016/x14/clingen-vcep-4.png?1616506588",
                                            "x256": "/system/organizations/profile_images/000/000/016/x256/clingen-vcep-4.png?1616506588",
                                            "x32": "/system/organizations/profile_images/000/000/016/x32/clingen-vcep-4.png?1616506588",
                                            "x64": "/system/organizations/profile_images/000/000/016/x64/clingen-vcep-4.png?1616506588",
                                        },
                                        "url": "https://clinicalgenome.org/working-groups/somatic/",
                                    },
                                    {
                                        "description": "The ClinGen NTRK expert panel will develop a sustainable process for systematic consensus review of fusions and associated secondary alterations in NTRK1, NTRK2, and NTRK3 genes that drive oncogenesis and response to targeted therapy. The group will focus on further specifying and piloting the AMP/ASCO/CAP guidelines (PMID: 27993330) for somatic variant classification and the diagnostic and therapeutic significance of NTRK fusions in cancers. After consensus classification, the panel will make these interpretations publicly available through the CIViC knowledgebase.",
                                        "id": 14,
                                        "name": "NTRK SC-VCEP",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/014/x128/clingen-vcep-2.png?1596737246",
                                            "x14": "/system/organizations/profile_images/000/000/014/x14/clingen-vcep-2.png?1596737246",
                                            "x256": "/system/organizations/profile_images/000/000/014/x256/clingen-vcep-2.png?1596737246",
                                            "x32": "/system/organizations/profile_images/000/000/014/x32/clingen-vcep-2.png?1596737246",
                                            "x64": "/system/organizations/profile_images/000/000/014/x64/clingen-vcep-2.png?1596737246",
                                        },
                                        "url": "https://clinicalgenome.org/affiliation/50089/",
                                    },
                                    {
                                        "description": "The Genitourinary Cancer Taskforce will embark on variant curation for FGFR and AR genes, using Clinical Interpretations of Variants in Cancer (CIViC) platform for variant curation.  The somatic variants should be examined and curated for the clinical significance/clinical management of patients, i.e. their role in the diagnosis, prognosis, therapeutic outcomes, prevention of the disease, or disease surveillance.",
                                        "id": 13,
                                        "name": "FGFR mutation SC-VCEP",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/013/x128/clingen-vcep-6.png?1596737087",
                                            "x14": "/system/organizations/profile_images/000/000/013/x14/clingen-vcep-6.png?1596737087",
                                            "x256": "/system/organizations/profile_images/000/000/013/x256/clingen-vcep-6.png?1596737087",
                                            "x32": "/system/organizations/profile_images/000/000/013/x32/clingen-vcep-6.png?1596737087",
                                            "x64": "/system/organizations/profile_images/000/000/013/x64/clingen-vcep-6.png?1596737087",
                                        },
                                        "url": "https://clinicalgenome.org/affiliation/50098/",
                                    },
                                    {
                                        "description": "\r\nDedicated to the systematic curation of the Histone H3 mutations in brain cancer.",
                                        "id": 19,
                                        "name": "Histone H3 mutations",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/019/x128/grey.png?1635440615",
                                            "x14": "/system/organizations/profile_images/000/000/019/x14/grey.png?1635440615",
                                            "x256": "/system/organizations/profile_images/000/000/019/x256/grey.png?1635440615",
                                            "x32": "/system/organizations/profile_images/000/000/019/x32/grey.png?1635440615",
                                            "x64": "/system/organizations/profile_images/000/000/019/x64/grey.png?1635440615",
                                        },
                                    },
                                ],
                                "role": "admin",
                                "username": "ArpadDanos",
                            },
                        },
                        "last_modified": {
                            "organization": {
                                "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                "id": 12,
                                "name": "Washington University in Saint Louis",
                                "profile_image": {
                                    "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                    "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                    "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                    "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                    "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                },
                                "url": "https://wustl.edu/",
                            },
                            "timestamp": "2022-01-10T19:43:00.067Z",
                            "user": {
                                "area_of_expertise": "Research Scientist",
                                "avatar_url": "https://secure.gravatar.com/avatar/a4d9fc3b05d58cf3d3ba51dc30bb61d6.png?d=identicon&r=pg&s=32",
                                "avatars": {
                                    "x128": "https://secure.gravatar.com/avatar/a4d9fc3b05d58cf3d3ba51dc30bb61d6.png?d=identicon&r=pg&s=128",
                                    "x14": "https://secure.gravatar.com/avatar/a4d9fc3b05d58cf3d3ba51dc30bb61d6.png?d=identicon&r=pg&s=14",
                                    "x32": "https://secure.gravatar.com/avatar/a4d9fc3b05d58cf3d3ba51dc30bb61d6.png?d=identicon&r=pg&s=32",
                                    "x64": "https://secure.gravatar.com/avatar/a4d9fc3b05d58cf3d3ba51dc30bb61d6.png?d=identicon&r=pg&s=64",
                                },
                                "bio": "Dr. Griffith is an Associate Professor of Medicine, Associate Professor of Genetics, and Assistant Director of the McDonnell Genome Institute at Washington University School of Medicine. Dr Griffith has extensive experience in the fields of genomics, bioinformatics, data mining, and cancer research. His research is focused on improving the understanding of cancer biology and the development of personalized medicine strategies for cancer using genomics and informatics technologies. The Griffith lab develops bioinformatics and statistical methods for the analysis of high throughput sequence data and identification of biomarkers for diagnostic, prognostic and drug response prediction. The Griffith lab uses CIViC to interpret variants identified in cases examined by the WASHU Genomics Tumor Board and elsewhere. He is a co-creator of the CIViC resource.",
                                "conflict_of_interest": {
                                    "coi_valid": "expired",
                                    "details": {
                                        "coi_present": False,
                                        "created_at": "2021-10-07T19:25:55.009Z",
                                        "expires_at": "2022-10-07T19:25:55.009Z",
                                    },
                                },
                                "country": {
                                    "id": 214,
                                    "iso": "US",
                                    "name": "United States",
                                },
                                "created_at": "2015-02-26T22:25:34.692Z",
                                "display_name": "MalachiGriffith",
                                "featured_expert": True,
                                "id": 15,
                                "last_seen_at": "2022-04-07T19:47:25.617Z",
                                "linkedin_profile": "malachigriffith",
                                "most_recent_organization": {
                                    "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                    "id": 12,
                                    "name": "Washington University in Saint Louis",
                                    "profile_image": {
                                        "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                        "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                        "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                        "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                        "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                    },
                                    "url": "https://wustl.edu/",
                                },
                                "name": "Malachi Griffith",
                                "orcid": "0000-0002-6388-446X",
                                "organizations": [
                                    {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    {
                                        "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                        "id": 2,
                                        "name": "ClinGen",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                            "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                            "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                            "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                            "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                        },
                                        "url": "https://www.clinicalgenome.org/",
                                    },
                                    {
                                        "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                        "id": 1,
                                        "name": "The McDonnell Genome Institute",
                                        "parent": {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                            "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                            "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                            "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                            "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                        },
                                        "url": "http://genome.wustl.edu/",
                                    },
                                    {
                                        "description": "The ClinGen NTRK expert panel will develop a sustainable process for systematic consensus review of fusions and associated secondary alterations in NTRK1, NTRK2, and NTRK3 genes that drive oncogenesis and response to targeted therapy. The group will focus on further specifying and piloting the AMP/ASCO/CAP guidelines (PMID: 27993330) for somatic variant classification and the diagnostic and therapeutic significance of NTRK fusions in cancers. After consensus classification, the panel will make these interpretations publicly available through the CIViC knowledgebase.",
                                        "id": 14,
                                        "name": "NTRK SC-VCEP",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/014/x128/clingen-vcep-2.png?1596737246",
                                            "x14": "/system/organizations/profile_images/000/000/014/x14/clingen-vcep-2.png?1596737246",
                                            "x256": "/system/organizations/profile_images/000/000/014/x256/clingen-vcep-2.png?1596737246",
                                            "x32": "/system/organizations/profile_images/000/000/014/x32/clingen-vcep-2.png?1596737246",
                                            "x64": "/system/organizations/profile_images/000/000/014/x64/clingen-vcep-2.png?1596737246",
                                        },
                                        "url": "https://clinicalgenome.org/affiliation/50089/",
                                    },
                                    {
                                        "description": "The Genitourinary Cancer Taskforce will embark on variant curation for FGFR and AR genes, using Clinical Interpretations of Variants in Cancer (CIViC) platform for variant curation.  The somatic variants should be examined and curated for the clinical significance/clinical management of patients, i.e. their role in the diagnosis, prognosis, therapeutic outcomes, prevention of the disease, or disease surveillance.",
                                        "id": 13,
                                        "name": "FGFR mutation SC-VCEP",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/013/x128/clingen-vcep-6.png?1596737087",
                                            "x14": "/system/organizations/profile_images/000/000/013/x14/clingen-vcep-6.png?1596737087",
                                            "x256": "/system/organizations/profile_images/000/000/013/x256/clingen-vcep-6.png?1596737087",
                                            "x32": "/system/organizations/profile_images/000/000/013/x32/clingen-vcep-6.png?1596737087",
                                            "x64": "/system/organizations/profile_images/000/000/013/x64/clingen-vcep-6.png?1596737087",
                                        },
                                        "url": "https://clinicalgenome.org/affiliation/50098/",
                                    },
                                    {
                                        "description": "\r\nDedicated to the systematic curation of the Histone H3 mutations in brain cancer.",
                                        "id": 19,
                                        "name": "Histone H3 mutations",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/019/x128/grey.png?1635440615",
                                            "x14": "/system/organizations/profile_images/000/000/019/x14/grey.png?1635440615",
                                            "x256": "/system/organizations/profile_images/000/000/019/x256/grey.png?1635440615",
                                            "x32": "/system/organizations/profile_images/000/000/019/x32/grey.png?1635440615",
                                            "x64": "/system/organizations/profile_images/000/000/019/x64/grey.png?1635440615",
                                        },
                                    },
                                ],
                                "role": "admin",
                                "twitter_handle": "malachigriffith",
                                "url": "http://griffithlab.org/",
                                "username": "MalachiGriffith",
                            },
                        },
                        "last_reviewed": {
                            "organization": {
                                "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                "id": 12,
                                "name": "Washington University in Saint Louis",
                                "profile_image": {
                                    "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                    "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                    "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                    "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                    "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                },
                                "url": "https://wustl.edu/",
                            },
                            "timestamp": "2022-01-13T05:39:29.409Z",
                            "user": {
                                "area_of_expertise": "Research Scientist",
                                "avatar_url": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                "avatars": {
                                    "x128": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=128",
                                    "x14": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=14",
                                    "x32": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=32",
                                    "x64": "https://secure.gravatar.com/avatar/45c2db32371a9f86e1f6190f57758d77.png?d=identicon&r=pg&s=64",
                                },
                                "bio": "Dr. Danos is a Postdoctoral Researcher in the Griffith Lab, with research interests in developing data and knowledge models which can describe and give structure to clinical and preclinical cancer variant knowledge, and in developing standards to enable efficient trasnfer and communication of this information between groups who are generating and curating this data, as well as with the medical and research community at large, in order to address the curation bottleneck which has arisen with increasing incorporation of NGS technology into clinical as well as research contexts. Dr. Danos is also interested in elucidation of the regulatory structure of the genome, and the role of non-coding mutations in cancer.",
                                "conflict_of_interest": {
                                    "coi_valid": "expired",
                                    "details": {
                                        "coi_present": False,
                                        "created_at": "2021-10-20T09:19:34.199Z",
                                        "expires_at": "2022-10-20T09:19:34.199Z",
                                    },
                                },
                                "country": {
                                    "id": 214,
                                    "iso": "US",
                                    "name": "United States",
                                },
                                "created_at": "2016-01-27T00:20:51.218Z",
                                "display_name": "ArpadDanos",
                                "featured_expert": True,
                                "id": 110,
                                "last_seen_at": "2022-04-08T09:33:34.645Z",
                                "most_recent_organization": {
                                    "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                    "id": 1,
                                    "name": "The McDonnell Genome Institute",
                                    "parent": {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    "profile_image": {
                                        "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                        "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                        "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                        "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                        "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                    },
                                    "url": "http://genome.wustl.edu/",
                                },
                                "name": "Arpad Danos",
                                "orcid": "0000-0001-9815-2288",
                                "organizations": [
                                    {
                                        "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                        "id": 12,
                                        "name": "Washington University in Saint Louis",
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                            "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                            "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                            "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                            "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                        },
                                        "url": "https://wustl.edu/",
                                    },
                                    {
                                        "description": "The McDonnell Genome Institute (MGI) is a world leader in the fast-paced, constantly changing field of genomics. A truly unique institution, we are pushing the limits of academic research by creating, testing, and implementing new approaches to the study of biology with the goal of understanding human health and disease, as well as evolution and the biology of other organisms.",
                                        "id": 1,
                                        "name": "The McDonnell Genome Institute",
                                        "parent": {
                                            "description": "Washington University in St. Louis’ mission is to discover and disseminate knowledge, and protect the freedom of inquiry through research, teaching and learning. Washington University creates an environment to encourage and support an ethos of wide-ranging exploration. Washington University’s faculty and staff strive to enhance the lives and livelihoods of students, the people of the greater St. Louis community, the country and the world.",
                                            "id": 12,
                                            "name": "Washington University in Saint Louis",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/012/x128/wustl-org.png?1592506215",
                                                "x14": "/system/organizations/profile_images/000/000/012/x14/wustl-org.png?1592506215",
                                                "x256": "/system/organizations/profile_images/000/000/012/x256/wustl-org.png?1592506215",
                                                "x32": "/system/organizations/profile_images/000/000/012/x32/wustl-org.png?1592506215",
                                                "x64": "/system/organizations/profile_images/000/000/012/x64/wustl-org.png?1592506215",
                                            },
                                            "url": "https://wustl.edu/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/001/x128/mgi-org.png?1592507909",
                                            "x14": "/system/organizations/profile_images/000/000/001/x14/mgi-org.png?1592507909",
                                            "x256": "/system/organizations/profile_images/000/000/001/x256/mgi-org.png?1592507909",
                                            "x32": "/system/organizations/profile_images/000/000/001/x32/mgi-org.png?1592507909",
                                            "x64": "/system/organizations/profile_images/000/000/001/x64/mgi-org.png?1592507909",
                                        },
                                        "url": "http://genome.wustl.edu/",
                                    },
                                    {
                                        "description": "Pediatric Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically relevant somatic variants in pediatric cancers. ",
                                        "id": 9,
                                        "name": "Pediatric Cancer Taskforce",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/009/x128/clingen-vcep-1.png?1596737215",
                                            "x14": "/system/organizations/profile_images/000/000/009/x14/clingen-vcep-1.png?1596737215",
                                            "x256": "/system/organizations/profile_images/000/000/009/x256/clingen-vcep-1.png?1596737215",
                                            "x32": "/system/organizations/profile_images/000/000/009/x32/clingen-vcep-1.png?1596737215",
                                            "x64": "/system/organizations/profile_images/000/000/009/x64/clingen-vcep-1.png?1596737215",
                                        },
                                        "url": "https://www.clinicalgenome.org/working-groups/somatic/pediatric-task-team/\r\n",
                                    },
                                    {
                                        "description": "The Hematologic Cancer Taskforce within the ClinGen Somatic Work Group focuses on curation of clinically significant somatic variants in hematological malignancies.",
                                        "id": 11,
                                        "name": "Hematologic Cancer Taskforce",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/011/x128/clingen-vcep-3.png?1596737121",
                                            "x14": "/system/organizations/profile_images/000/000/011/x14/clingen-vcep-3.png?1596737121",
                                            "x256": "/system/organizations/profile_images/000/000/011/x256/clingen-vcep-3.png?1596737121",
                                            "x32": "/system/organizations/profile_images/000/000/011/x32/clingen-vcep-3.png?1596737121",
                                            "x64": "/system/organizations/profile_images/000/000/011/x64/clingen-vcep-3.png?1596737121",
                                        },
                                        "url": "https://clinicalgenome.org/working-groups/somatic/hematological-cancers/",
                                    },
                                    {
                                        "description": "Dedicated to the systematic curation of the genes and variants associated with the BCR-ABL1-like (Philadelphia (Ph)-like) genetics subtype of B-lymphoblastic leukemia (B-ALL).",
                                        "id": 16,
                                        "name": "Ph-like B-ALL",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/016/x128/clingen-vcep-4.png?1616506588",
                                            "x14": "/system/organizations/profile_images/000/000/016/x14/clingen-vcep-4.png?1616506588",
                                            "x256": "/system/organizations/profile_images/000/000/016/x256/clingen-vcep-4.png?1616506588",
                                            "x32": "/system/organizations/profile_images/000/000/016/x32/clingen-vcep-4.png?1616506588",
                                            "x64": "/system/organizations/profile_images/000/000/016/x64/clingen-vcep-4.png?1616506588",
                                        },
                                        "url": "https://clinicalgenome.org/working-groups/somatic/",
                                    },
                                    {
                                        "description": "The ClinGen NTRK expert panel will develop a sustainable process for systematic consensus review of fusions and associated secondary alterations in NTRK1, NTRK2, and NTRK3 genes that drive oncogenesis and response to targeted therapy. The group will focus on further specifying and piloting the AMP/ASCO/CAP guidelines (PMID: 27993330) for somatic variant classification and the diagnostic and therapeutic significance of NTRK fusions in cancers. After consensus classification, the panel will make these interpretations publicly available through the CIViC knowledgebase.",
                                        "id": 14,
                                        "name": "NTRK SC-VCEP",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/014/x128/clingen-vcep-2.png?1596737246",
                                            "x14": "/system/organizations/profile_images/000/000/014/x14/clingen-vcep-2.png?1596737246",
                                            "x256": "/system/organizations/profile_images/000/000/014/x256/clingen-vcep-2.png?1596737246",
                                            "x32": "/system/organizations/profile_images/000/000/014/x32/clingen-vcep-2.png?1596737246",
                                            "x64": "/system/organizations/profile_images/000/000/014/x64/clingen-vcep-2.png?1596737246",
                                        },
                                        "url": "https://clinicalgenome.org/affiliation/50089/",
                                    },
                                    {
                                        "description": "The Genitourinary Cancer Taskforce will embark on variant curation for FGFR and AR genes, using Clinical Interpretations of Variants in Cancer (CIViC) platform for variant curation.  The somatic variants should be examined and curated for the clinical significance/clinical management of patients, i.e. their role in the diagnosis, prognosis, therapeutic outcomes, prevention of the disease, or disease surveillance.",
                                        "id": 13,
                                        "name": "FGFR mutation SC-VCEP",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/013/x128/clingen-vcep-6.png?1596737087",
                                            "x14": "/system/organizations/profile_images/000/000/013/x14/clingen-vcep-6.png?1596737087",
                                            "x256": "/system/organizations/profile_images/000/000/013/x256/clingen-vcep-6.png?1596737087",
                                            "x32": "/system/organizations/profile_images/000/000/013/x32/clingen-vcep-6.png?1596737087",
                                            "x64": "/system/organizations/profile_images/000/000/013/x64/clingen-vcep-6.png?1596737087",
                                        },
                                        "url": "https://clinicalgenome.org/affiliation/50098/",
                                    },
                                    {
                                        "description": "\r\nDedicated to the systematic curation of the Histone H3 mutations in brain cancer.",
                                        "id": 19,
                                        "name": "Histone H3 mutations",
                                        "parent": {
                                            "description": "ClinGen is a National Institutes of Health (NIH)-funded resource dedicated to building an authoritative central resource that defines the clinical relevance of genes and variants for use in precision medicine and research. ",
                                            "id": 2,
                                            "name": "ClinGen",
                                            "profile_image": {
                                                "x128": "/system/organizations/profile_images/000/000/002/x128/clingen-parent.png?1592507884",
                                                "x14": "/system/organizations/profile_images/000/000/002/x14/clingen-parent.png?1592507884",
                                                "x256": "/system/organizations/profile_images/000/000/002/x256/clingen-parent.png?1592507884",
                                                "x32": "/system/organizations/profile_images/000/000/002/x32/clingen-parent.png?1592507884",
                                                "x64": "/system/organizations/profile_images/000/000/002/x64/clingen-parent.png?1592507884",
                                            },
                                            "url": "https://www.clinicalgenome.org/",
                                        },
                                        "profile_image": {
                                            "x128": "/system/organizations/profile_images/000/000/019/x128/grey.png?1635440615",
                                            "x14": "/system/organizations/profile_images/000/000/019/x14/grey.png?1635440615",
                                            "x256": "/system/organizations/profile_images/000/000/019/x256/grey.png?1635440615",
                                            "x32": "/system/organizations/profile_images/000/000/019/x32/grey.png?1635440615",
                                            "x64": "/system/organizations/profile_images/000/000/019/x64/grey.png?1635440615",
                                        },
                                    },
                                ],
                                "role": "admin",
                                "username": "ArpadDanos",
                            },
                        },
                    },
                    "name": "V600E",
                    "type": "variant",
                    "updated_at": "2022-04-01T23:37:24.798Z",
                    "variant_aliases": [
                        "RS113488022",
                        "VAL600GLU",
                        "V640E",
                        "VAL640GLU",
                    ],
                    "variant_id": 12,
                    "variant_types": {
                        "description": "A sequence variant, that changes one or more bases, resulting in a different amino acid sequence but where the length is preserved.",
                        "display_name": "Missense Variant",
                        "id": 47,
                        "name": "missense_variant",
                        "root_concept": {
                            "name": "Sequence Variant",
                            "so_id": "SO:0001060",
                        },
                        "so_id": "SO:0001583",
                        "url": "http://www.sequenceontology.org/browser/current_svn/term/SO:0001583",
                    },
                },
                "clinvar": {
                    "_license": "http://bit.ly/2SQdcI0",
                    "allele_id": 29000,
                    "alt": "T",
                    "chrom": "7",
                    "cytogenic": "7q34",
                    "gene": {"id": "673", "symbol": "BRAF"},
                    "hg19": {"end": 140453136, "start": 140453136},
                    "hg38": {"end": 140753336, "start": 140753336},
                    "hgvs": {
                        "coding": [
                            "LRG_299t1:c.1799T>A",
                            "NM_001354609.2:c.1799T>A",
                            "NM_001374244.1:c.1919T>A",
                            "NM_001374258.1:c.1919T>A",
                            "NM_001378467.1:c.1808T>A",
                            "NM_001378468.1:c.1799T>A",
                            "NM_001378469.1:c.1733T>A",
                            "NM_001378470.1:c.1697T>A",
                            "NM_001378471.1:c.1688T>A",
                            "NM_001378472.1:c.1643T>A",
                            "NM_001378473.1:c.1643T>A",
                            "NM_001378474.1:c.1799T>A",
                            "NM_001378475.1:c.1535T>A",
                            "NM_004333.6:c.1799T>A",
                        ],
                        "genomic": [
                            "LRG_299:g.176429T>A",
                            "NC_000007.12:g.140099605A>T",
                            "NC_000007.13:g.140453136A>T",
                            "NC_000007.14:g.140753336A>T",
                            "NG_007873.3:g.176429T>A",
                        ],
                        "protein": [
                            "LRG_299p1:p.Val600Glu",
                            "NP_001341538.1:p.Val600Glu",
                            "NP_001361173.1:p.Val640Glu",
                            "NP_001361187.1:p.Val640Glu",
                            "NP_001365396.1:p.Val603Glu",
                            "NP_001365397.1:p.Val600Glu",
                            "NP_001365398.1:p.Val578Glu",
                            "NP_001365399.1:p.Val566Glu",
                            "NP_001365400.1:p.Val563Glu",
                            "NP_001365401.1:p.Val548Glu",
                            "NP_001365402.1:p.Val548Glu",
                            "NP_001365403.1:p.Val600Glu",
                            "NP_001365404.1:p.Val512Glu",
                            "NP_004324.2:p.Val600Glu",
                            "NP_004324.2:p.Val600Glu",
                            "P15056:p.Val600Glu",
                            "p.V600E",
                        ],
                    },
                    "omim": "164757.0001",
                    "rcv": [
                        {
                            "accession": "RCV000014992",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C0699790",
                                    "mondo": "MONDO:0002032",
                                },
                                "name": "Carcinoma of colon (CRC)",
                                "synonyms": ["Colonic carcinoma", "Colon carcinoma"],
                            },
                            "last_evaluated": "2014-09-04",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000014993",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0002895",
                                    "medgen": "C0238463",
                                    "mesh": "D000077273",
                                    "mondo": "MONDO:0005075",
                                    "orphanet": "146",
                                },
                                "name": "Papillary thyroid carcinoma",
                                "synonyms": [
                                    "NONMEDULLARY THYROID CARCINOMA, PAPILLARY",
                                    "Thyroid carcinoma, papillary, somatic",
                                    "Thyroid gland papillary carcinoma",
                                ],
                            },
                            "last_evaluated": "2014-09-04",
                            "number_submitters": 2,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000014994",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {"medgen": "C2674727"},
                                "name": "Astrocytoma, low-grade, somatic",
                            },
                            "last_evaluated": "2014-09-04",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000022677",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C1266158",
                                    "mondo": "MONDO:0021656",
                                },
                                "name": "Nongerminomatous germ cell tumor",
                                "synonyms": [
                                    "NONSEMINOMATOUS GERM CELL TUMORS, SOMATIC",
                                    "Germ cell tumor, nonseminomatous",
                                    "Non-seminomatous germ-cell tumors",
                                ],
                            },
                            "last_evaluated": "2014-09-04",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000037936",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0030358",
                                    "medgen": "C0007131",
                                    "mesh": "D002289",
                                    "mondo": "MONDO:0005233",
                                },
                                "name": "Non-small cell lung carcinoma (NSCLC)",
                                "synonyms": ["Non-small cell lung cancer"],
                            },
                            "last_evaluated": "2009-05-29",
                            "number_submitters": 2,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000067669",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0007474",
                                    "medgen": "C0025202",
                                    "mesh": "D008545",
                                    "mondo": "MONDO:0005105",
                                },
                                "name": "Melanoma",
                            },
                            "last_evaluated": "2016-03-10",
                            "number_submitters": 2,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000080903",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {"medgen": "C3661900"},
                                "name": "not provided",
                                "synonyms": ["none provided"],
                            },
                            "last_evaluated": "2014-07-11",
                            "number_submitters": 4,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "criteria provided, multiple submitters, no conflicts",
                        },
                        {
                            "accession": "RCV000208763",
                            "clinical_significance": "not provided",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C1275081",
                                    "mondo": "MONDO:0015280",
                                    "omim": "PS115150",
                                    "orphanet": "1340",
                                },
                                "name": "Cardio-facio-cutaneous syndrome",
                                "synonyms": [
                                    "Cardiofaciocutaneous syndrome",
                                    "CFC syndrome",
                                ],
                            },
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion provided",
                        },
                        {
                            "accession": "RCV000417746",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0012056",
                                    "medgen": "C0151779",
                                    "mesh": "C562393",
                                    "mondo": "MONDO:0005012",
                                },
                                "name": "Malignant melanoma of skin (CMM)",
                                "synonyms": [
                                    "Malignant melanoma, somatic",
                                    "Cutaneous melanoma",
                                ],
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000420614",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0100273",
                                    "medgen": "C0009375",
                                    "mesh": "D003110",
                                    "mondo": "MONDO:0005401",
                                },
                                "name": "Colonic neoplasm",
                                "synonyms": [
                                    "Colonic Neoplasms",
                                    "Neoplasm of the colon",
                                ],
                            },
                            "last_evaluated": "2015-07-14",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000424470",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C1168401",
                                    "mesh": "D000077195",
                                    "mondo": "MONDO:0010150",
                                    "omim": "275355",
                                    "orphanet": "67037",
                                },
                                "name": "Squamous cell carcinoma of the head and neck (HNSCC)",
                                "synonyms": [
                                    "Head and neck squamous cell carcinoma",
                                    "Carcinoma, squamous cell of head and neck",
                                    "Squamous cell carcinoma, head and neck, somatic",
                                ],
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000425166",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0010796",
                                    "medgen": "C0677865",
                                    "mondo": "MONDO:0002911",
                                },
                                "name": "Brainstem glioma",
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000425847",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C0017636",
                                    "mesh": "D005909",
                                    "mondo": "MONDO:0018177",
                                },
                                "name": "Glioblastoma",
                                "synonyms": [
                                    "Giant cell glioblastoma (histologic variant)",
                                    "Gliosarcoma (histologic variant)",
                                ],
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000430562",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0006775",
                                    "medgen": "C0026764",
                                    "mesh": "D009101",
                                    "mondo": "MONDO:0009693",
                                    "omim": "254500",
                                    "orphanet": "85443",
                                },
                                "name": "Multiple myeloma (MM)",
                                "synonyms": [
                                    "Plasma cell myeloma",
                                    "Kahler disease",
                                    "Myelomatosis",
                                    "Plasma cell dyscrasia",
                                    "Multiple myeloma, somatic",
                                ],
                            },
                            "last_evaluated": "2019-08-31",
                            "number_submitters": 2,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000429915",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0030078",
                                    "medgen": "C0152013",
                                    "mesh": "D000077192",
                                    "mondo": "MONDO:0005061",
                                },
                                "name": "Lung adenocarcinoma",
                                "synonyms": [
                                    "Adenocarcinoma of lung",
                                    "Adenocarcinoma of lung, somatic",
                                ],
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000432628",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0100615",
                                    "medgen": "C0919267",
                                    "mesh": "D010051",
                                    "mondo": "MONDO:0021068",
                                    "omim": "167000",
                                },
                                "name": "Neoplasm of ovary",
                                "synonyms": [
                                    "Ovarian tumor",
                                    "OVARIAN CANCER, SOMATIC",
                                    "Ovarian neoplasm",
                                    "Ovarian Neoplasms",
                                ],
                            },
                            "last_evaluated": "2014-10-02",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000433305",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C0684249",
                                    "mondo": "MONDO:0005138",
                                },
                                "name": "Lung carcinoma",
                            },
                            "last_evaluated": "2014-10-02",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000435441",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0030692",
                                    "medgen": "C0006118",
                                    "mesh": "D001932",
                                    "mondo": "MONDO:0021211",
                                },
                                "name": "Neoplasm of brain",
                                "synonyms": [
                                    "Brain tumour",
                                    "Brain neoplasm",
                                    "Brain Neoplasms",
                                ],
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000440540",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0100723",
                                    "medgen": "C0238198",
                                    "mesh": "D046152",
                                    "mondo": "MONDO:0011719",
                                    "omim": "606764",
                                    "orphanet": "44890",
                                },
                                "name": "Gastrointestinal stroma tumor",
                                "synonyms": [
                                    "Gastrointestinal stromal tumor",
                                    "Gastrointestinal Stromal Sarcoma",
                                    "Gastrointestinal stromal tumor, somatic",
                                ],
                            },
                            "last_evaluated": "2014-10-02",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000440802",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C1336078",
                                    "mesh": "C538614",
                                },
                                "name": "Papillary renal cell carcinoma, sporadic",
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000443448",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0006741",
                                    "medgen": "C0027651",
                                    "mesh": "D009369",
                                    "mondo": "MONDO:0005070",
                                },
                                "name": "Neoplasm",
                                "synonyms": ["Neoplasms", "Neoplasm (disease)"],
                            },
                            "last_evaluated": "2016-05-13",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000443745",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0100834",
                                    "medgen": "C0009404",
                                    "mesh": "D015179",
                                    "mondo": "MONDO:0005335",
                                },
                                "name": "Neoplasm of the large intestine",
                                "synonyms": [
                                    "Colorectal Neoplasms",
                                    "Colorectal neoplasm",
                                ],
                            },
                            "last_evaluated": "2016-05-31",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000662278",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "name": "Cystic epithelial invagination containing papillae lined by columnar epithelium"
                            },
                            "last_evaluated": "2015-05-07",
                            "number_submitters": 2,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV000860020",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0002408",
                                    "medgen": "C0917804",
                                    "mondo": "MONDO:0007154",
                                    "omim": "108010",
                                    "orphanet": "46724",
                                },
                                "name": "Cerebral arteriovenous malformation (BAVM)",
                                "synonyms": [
                                    "CEREBRAL ARTERIOVENOUS MALFORMATIONS",
                                    "Arteriovenous malformations of the brain",
                                ],
                            },
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV001030018",
                            "clinical_significance": "drug response",
                            "conditions": {"name": "Trametinib-Dabrafenib Response"},
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "criteria provided, single submitter",
                        },
                        {
                            "accession": "RCV001030020",
                            "clinical_significance": "drug response",
                            "conditions": {"name": "Vemurafenib-Cobimetinib Response"},
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "criteria provided, single submitter",
                        },
                        {
                            "accession": "RCV001030023",
                            "clinical_significance": "other",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C0346629",
                                    "mondo": "MONDO:0005575",
                                    "omim": "114500",
                                },
                                "name": "Colorectal cancer",
                                "synonyms": [
                                    "Colorectal cancer, somatic",
                                    "Malignant Colorectal Neoplasm",
                                ],
                            },
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "criteria provided, single submitter",
                        },
                        {
                            "accession": "RCV001248834",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0000115",
                                    "medgen": "C0027708",
                                    "mesh": "D009396",
                                    "mondo": "MONDO:0006058",
                                },
                                "name": "Nephroblastoma",
                                "synonyms": ["Wilms tumor", "Wilms' tumor"],
                            },
                            "last_evaluated": "2019-02-15",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV001254874",
                            "clinical_significance": "Likely pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C0006826",
                                    "mondo": "MONDO:0004992",
                                },
                                "name": "Malignant neoplastic disease",
                                "synonyms": ["Cancer"],
                            },
                            "number_submitters": 1,
                            "origin": "unknown",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV002051586",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "human_phenotype_ontology": "HP:0100764",
                                    "medgen": "C0024221",
                                    "mondo": "MONDO:0002013",
                                },
                                "name": "Lymphangioma",
                            },
                            "last_evaluated": "2022-02-09",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "no assertion criteria provided",
                        },
                        {
                            "accession": "RCV003458334",
                            "clinical_significance": "Pathogenic",
                            "conditions": {
                                "identifiers": {
                                    "medgen": "C0158570",
                                    "mondo": "MONDO:0024291",
                                },
                                "name": "Vascular malformation",
                            },
                            "last_evaluated": "2023-10-22",
                            "number_submitters": 1,
                            "origin": "somatic",
                            "preferred_name": "NM_004333.6(BRAF):c.1799T>A (p.Val600Glu)",
                            "review_status": "criteria provided, single submitter",
                        },
                    ],
                    "ref": "A",
                    "rsid": "rs113488022",
                    "type": "single nucleotide variant",
                    "variant_id": 13961,
                },
                "cosmic": {
                    "_license": "http://bit.ly/2VMkY7R",
                    "alt": "A",
                    "chrom": "7",
                    "cosmic_id": "COSM476",
                    "hg19": {"end": 140453136, "start": 140453136},
                    "mut_freq": 2.83,
                    "mut_nt": "T>A",
                    "ref": "T",
                    "tumor_site": "biliary_tract",
                },
                "dbnsfp": {
                    "_license": "http://bit.ly/2VLnQBz",
                    "aa": {
                        "alt": "E",
                        "codon_degeneracy": [0, 0, 0, 0],
                        "codonpos": [2, 2, 2, 2],
                        "pos": [600, 640, 600, 640],
                        "ref": "V",
                        "refcodon": ["GTG", "GTG", "GTG", "GTG"],
                    },
                    "alphamissense": {
                        "pred": ["P", "P", "P", "P"],
                        "rankscore": 0.97238,
                        "score": [0.9853, 0.9978, 0.9927, 0.9941],
                    },
                    "alt": "T",
                    "ancestral_allele": "A",
                    "appris": [
                        "alternative2",
                        "alternative2",
                        "principal2",
                        "alternative2",
                    ],
                    "bayesdel": {
                        "add_af": {
                            "pred": "D",
                            "rankscore": 0.89859,
                            "score": 0.399079,
                        },
                        "no_af": {"pred": "D", "rankscore": 0.89732, "score": 0.335473},
                    },
                    "bstatistic": {"converted_rankscore": 0.46346, "score": 789.0},
                    "chrom": "7",
                    "clinpred": {
                        "pred": "D",
                        "rankscore": 0.84315,
                        "score": 0.993496775627136,
                    },
                    "clinvar": {
                        "clinvar_id": "13961",
                        "clnsig": ["Pathogenic", "drug_response", "other"],
                        "hgvs": "NC_000007.14:g.140753336A>T",
                        "medgen": [
                            "C0025202",
                            "C0027651",
                            "C0027708",
                            "C3661900",
                            "C0158570",
                            "C0024221",
                            "C0017636",
                            "C1275081",
                            "C0346629",
                            "C0006118",
                            "C1266158",
                            "C0238198",
                            "C0238463",
                            "C0151779",
                            "C0684249",
                            "C0919267",
                            "C0917804",
                            "C0026764",
                            "C0007131",
                            "C2674727",
                            "C0677865",
                            "C0006826",
                            "C0152013",
                            "C0009375",
                            "C1336078",
                            "C0009404",
                            "C0699790",
                            "C1168401",
                        ],
                        "omim": [
                            "PS115150",
                            "114500",
                            "606764",
                            "167000",
                            "108010",
                            "254500",
                            "275355",
                        ],
                        "orphanet": [
                            "654",
                            "2415",
                            "360",
                            "1340",
                            "44890",
                            "146",
                            "46724",
                            "29073",
                            "85443",
                            "67037",
                        ],
                        "review": "criteria_provided,_multiple_submitters,_no_conflicts",
                        "trait": [
                            "Melanoma",
                            "Neoplasm",
                            "Nephroblastoma",
                            "not_provided",
                            "Vascular_malformation",
                            "Lymphangioma",
                            "Glioblastoma",
                            "Cardio-facio-cutaneous_syndrome",
                            "Colorectal_cancer",
                            "Neoplasm_of_brain",
                            "Nongerminomatous_germ_cell_tumor",
                            "Gastrointestinal_stromal_tumor",
                            "Papillary_thyroid_carcinoma",
                            "Malignant_melanoma_of_skin",
                            "Lung_carcinoma",
                            "Neoplasm_of_ovary",
                            "Cerebral_arteriovenous_malformation",
                            "Multiple_myeloma",
                            "Non-small_cell_lung_carcinoma",
                            "Astrocytoma,_low-grade,_somatic",
                            "Brainstem_glioma",
                            "Malignant_neoplastic_disease",
                            "Lung_adenocarcinoma",
                            "Cystic_epithelial_invagination_containing_papillae_lined_by_columnar_epithelium",
                            "Colonic_neoplasm",
                            "Papillary_renal_cell_carcinoma,_sporadic",
                            "Neoplasm_of_the_large_intestine",
                            "Carcinoma_of_colon",
                            "Squamous_cell_carcinoma_of_the_head_and_neck",
                            "Vemurafenib-Cobimetinib_Response",
                            "Trametinib-Dabrafenib_Response",
                        ],
                        "var_source": [
                            "ClinGen:CA123643",
                            "Genetic_Testing_Registry_(GTR):GTR000522729",
                            "Genetic_Testing_Registry_(GTR):GTR000575664",
                            "Genetic_Testing_Registry_(GTR):GTR000575672",
                            "Genetic_Testing_Registry_(GTR):GTR000575677",
                            "OMIM:164757.0001",
                            "UniProtKB:P15056#VAR_018629",
                        ],
                    },
                    "dann": {"rankscore": 0.42049, "score": 0.9848685552251786},
                    "deogen2": {"pred": "D", "rankscore": 0.95953, "score": 0.830668},
                    "eigen": {
                        "phred_coding": 4.637965,
                        "raw_coding": 0.445381171133835,
                        "raw_coding_rankscore": 0.63941,
                    },
                    "eigen-pc": {
                        "phred_coding": 5.634784,
                        "raw_coding": 0.548689949287972,
                        "raw_coding_rankscore": 0.71304,
                    },
                    "ensembl": {
                        "geneid": [
                            "ENSG00000157764",
                            "ENSG00000157764",
                            "ENSG00000157764",
                            "ENSG00000157764",
                        ],
                        "proteinid": [
                            "ENSP00000419060",
                            "ENSP00000496776",
                            "ENSP00000493543",
                            "ENSP00000288602",
                        ],
                        "transcriptid": [
                            "ENST00000496384",
                            "ENST00000644969",
                            "ENST00000646891",
                            "ENST00000288602",
                        ],
                    },
                    "esm1b": {"pred": "D", "rankscore": 0.97691, "score": -15.954},
                    "eve": {
                        "class10_pred": "U",
                        "class20_pred": "U",
                        "class25_pred": "U",
                        "class30_pred": "U",
                        "class40_pred": "U",
                        "class50_pred": "U",
                        "class60_pred": "U",
                        "class70_pred": "U",
                        "class75_pred": "P",
                        "class80_pred": "P",
                        "class90_pred": "P",
                        "rankscore": 0.71581,
                        "score": 0.6445960741367582,
                    },
                    "exac": {
                        "ac": 2,
                        "adj_ac": 2,
                        "adj_af": 1.65e-05,
                        "af": 1.647e-05,
                        "afr": {"ac": 0, "af": 0.0},
                        "amr": {"ac": 1, "af": 8.715e-05},
                        "eas": {"ac": 0, "af": 0.0},
                        "fin": {"ac": 0, "af": 0.0},
                        "nfe": {"ac": 0, "af": 0.0},
                        "sas": {"ac": 1, "af": 6.06e-05},
                    },
                    "exac_nonpsych": {
                        "ac": 2,
                        "adj_ac": 2,
                        "adj_af": 2.208e-05,
                        "af": 2.204e-05,
                        "afr": {"ac": 0, "af": 0.0},
                        "amr": {"ac": 1, "af": 8.724e-05},
                        "eas": {"ac": 0, "af": 0.0},
                        "fin": {"ac": 0, "af": 0.0},
                        "nfe": {"ac": 0, "af": 0.0},
                        "sas": {"ac": 1, "af": 6.064e-05},
                    },
                    "exac_nontcga": {
                        "ac": 2,
                        "adj_ac": 2,
                        "adj_af": 1.886e-05,
                        "af": 1.883e-05,
                        "afr": {"ac": 0, "af": 0.0},
                        "amr": {"ac": 1, "af": 8.998e-05},
                        "eas": {"ac": 0, "af": 0.0},
                        "fin": {"ac": 0, "af": 0.0},
                        "nfe": {"ac": 0, "af": 0.0},
                        "sas": {"ac": 1, "af": 6.098e-05},
                    },
                    "fathmm-mkl": {
                        "coding_group": "AEFI",
                        "coding_pred": "D",
                        "coding_rankscore": 0.83898,
                        "coding_score": 0.98542,
                    },
                    "fathmm-xf": {
                        "coding_pred": "D",
                        "coding_rankscore": 0.87678,
                        "coding_score": 0.914006,
                    },
                    "fitcons": {
                        "gm12878": {
                            "confidence_value": 0,
                            "rankscore": 0.7944,
                            "score": 0.708844,
                        },
                        "h1-hesc": {
                            "confidence_value": 0,
                            "rankscore": 0.34648,
                            "score": 0.602189,
                        },
                        "huvec": {
                            "confidence_value": 0,
                            "rankscore": 0.65921,
                            "score": 0.6691,
                        },
                        "integrated": {
                            "confidence_value": 0,
                            "rankscore": 0.46895,
                            "score": 0.6512,
                        },
                    },
                    "gencode_basic": ["Y", "Y", "Y", "Y"],
                    "genename": ["BRAF", "BRAF", "BRAF", "BRAF"],
                    "genocanyon": {"rankscore": 0.74766, "score": 0.999999994558225},
                    "gerp++": {"nr": 5.65, "rs": 5.65, "rs_rankscore": 0.86881},
                    "gmvp": {"rankscore": 0.95276, "score": 0.9529287864278634},
                    "hg18": {"end": 140099605, "start": 140099605},
                    "hg19": {"end": 140453136, "start": 140453136},
                    "hg38": {"end": 140753336, "start": 140753336},
                    "hgvsc": ["c.620T>A", "c.1919T>A", "c.1799T>A"],
                    "hgvsp": ["p.V600E", "p.Val640Glu", "p.Val207Glu", "p.Val600Glu"],
                    "interpro": {
                        "domain": [
                            "Serine-threonine/tyrosine-protein kinase, catalytic domain|Protein kinase domain|Protein kinase domain",
                            "Serine-threonine/tyrosine-protein kinase, catalytic domain|Protein kinase domain|Protein kinase domain",
                            "Serine-threonine/tyrosine-protein kinase, catalytic domain|Protein kinase domain|Protein kinase domain",
                            "Serine-threonine/tyrosine-protein kinase, catalytic domain|Protein kinase domain|Protein kinase domain",
                        ]
                    },
                    "list-s2": {
                        "pred": ["T", "T", "T", "T"],
                        "rankscore": 0.29288,
                        "score": [0.684632, 0.684232, 0.684632, 0.684232],
                    },
                    "lrt": {
                        "converted_rankscore": 0.8433,
                        "omega": 0.0,
                        "pred": "D",
                        "score": 0.0,
                    },
                    "m-cap": {"pred": "D", "rankscore": 0.84885, "score": 0.171639},
                    "metalr": {"pred": "T", "rankscore": 0.6027, "score": 0.2357},
                    "metarnn": {
                        "pred": ["D", "D", "D", "D"],
                        "rankscore": 0.87655,
                        "score": [0.88336486, 0.88336486, 0.88336486, 0.88336486],
                    },
                    "metasvm": {"pred": "T", "rankscore": 0.5694, "score": -0.7685},
                    "mpc": {"rankscore": 0.98012, "score": 2.57041727597},
                    "mutationassessor": {
                        "pred": "N",
                        "rankscore": 0.16133,
                        "score": 0.65,
                    },
                    "mutationtaster": {
                        "aae": "V600E",
                        "converted_rankscore": 0.81001,
                        "model": "simple_aae",
                        "pred": "D",
                        "score": 1.0,
                    },
                    "mutpred": {
                        "aa_change": ["V600E", "V600E"],
                        "accession": ["P15056", "P15056"],
                        "pred": [
                            {"mechanism": "Gain of disorder", "p_val": 0.0057},
                            {"mechanism": "Gain of disorder", "p_val": 0.0057},
                        ],
                        "rankscore": 0.84872,
                        "score": [0.713, 0.713],
                    },
                    "mvp": {"rankscore": 0.9862, "score": 0.986356512902},
                    "phastcons": {
                        "100way_vertebrate": {"rankscore": 0.71638, "score": 1.0},
                        "17way_primate": {"rankscore": 0.91618, "score": 0.999},
                        "470way_mammalian": {"rankscore": 0.68203, "score": 1.0},
                    },
                    "phylop": {
                        "100way_vertebrate": {"rankscore": 0.94474, "score": 9.236},
                        "17way_primate": {"rankscore": 0.87069, "score": 0.75},
                        "470way_mammalian": {"rankscore": 0.89583, "score": 11.216},
                    },
                    "polyphen2": {
                        "hdiv": {"pred": "D", "rankscore": 0.57185, "score": 0.971},
                        "hvar": {"pred": "D", "rankscore": 0.67921, "score": 0.943},
                    },
                    "primateai": {
                        "pred": "D",
                        "rankscore": 0.9559,
                        "score": 0.892686009407,
                    },
                    "ref": "A",
                    "reliability_index": 10,
                    "revel": {"rankscore": 0.98378, "score": 0.931},
                    "rsid": "rs113488022",
                    "siphy_29way": {
                        "logodds_rankscore": 0.79463,
                        "logodds_score": 15.9326,
                        "pi": {"a": 1.0, "c": 0.0, "g": 0.0, "t": 0.0},
                    },
                    "tsl": [5, 1],
                    "uniprot": [
                        {"acc": "H7C560", "entry": "H7C560_HUMAN"},
                        {"acc": "A0A2R8Y8E0", "entry": "A0A2R8Y8E0_HUMAN"},
                        {"acc": "P15056", "entry": "BRAF_HUMAN"},
                        {"acc": "A0A2U3TZI2", "entry": "A0A2U3TZI2_HUMAN"},
                    ],
                    "varity": {
                        "er": {"rankscore": 0.98206, "score": 0.94685084},
                        "er_loo": {"rankscore": 0.98903, "score": 0.9587261},
                        "r": {"rankscore": 0.97515, "score": 0.9623422},
                        "r_loo": {"rankscore": 0.97053, "score": 0.9577461},
                    },
                    "vep_canonical": "YES",
                },
                "dbsnp": {
                    "_license": "http://bit.ly/2AqoLOc",
                    "alleles": [
                        {"allele": "A", "freq": {"exac": 1.0, "gnomad_exomes": 1.0}},
                        {"allele": "T", "freq": {"exac": 0.0, "gnomad_exomes": 0.0}},
                    ],
                    "alt": "T",
                    "chrom": "7",
                    "citations": [
                        12068308,
                        12460918,
                        12460919,
                        12960123,
                        14679157,
                        15035987,
                        19001320,
                        19010912,
                        19018267,
                        19238210,
                        19404918,
                        19537845,
                        19561230,
                        20350999,
                        20413299,
                        20619739,
                        20630094,
                        20735442,
                        20818844,
                        21129611,
                        21156289,
                        21163703,
                        21426297,
                        21483012,
                        21639808,
                        21683865,
                        21975775,
                        22038996,
                        22048237,
                        22180495,
                        22281684,
                        22351686,
                        22356324,
                        22389471,
                        22448344,
                        22536370,
                        22586120,
                        22608338,
                        22649091,
                        22663011,
                        22735384,
                        22743296,
                        22773810,
                        22805292,
                        22972589,
                        22997239,
                        23020132,
                        23031422,
                        23251002,
                        23325582,
                        23470635,
                        23524406,
                        23549875,
                        23614898,
                        23757202,
                        23812671,
                        23833300,
                        23845441,
                        23918947,
                        24107445,
                        24163374,
                        24388723,
                        24576830,
                        24583796,
                        24586605,
                        24594804,
                        25024077,
                        25157968,
                        25370471,
                        25989278,
                        26619011,
                        26678033,
                    ],
                    "dbsnp_build": 156,
                    "gene": {
                        "geneid": 673,
                        "is_pseudo": False,
                        "name": "B-Raf proto-oncogene, serine/threonine kinase",
                        "rnas": [
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2023,
                                    "seq_id": "NM_001354609.2",
                                },
                                "hgvs": "NM_001354609.2:c.1799=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 599,
                                            "seq_id": "NP_001341538.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001341538.1"},
                                "refseq": "NM_001354609.2",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2143,
                                    "seq_id": "NM_001374244.1",
                                },
                                "hgvs": "NM_001374244.1:c.1919=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 639,
                                            "seq_id": "NP_001361173.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001361173.1"},
                                "refseq": "NM_001374244.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2143,
                                    "seq_id": "NM_001374258.1",
                                },
                                "hgvs": "NM_001374258.1:c.1919=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 639,
                                            "seq_id": "NP_001361187.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001361187.1"},
                                "refseq": "NM_001374258.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2032,
                                    "seq_id": "NM_001378467.1",
                                },
                                "hgvs": "NM_001378467.1:c.1808=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 602,
                                            "seq_id": "NP_001365396.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365396.1"},
                                "refseq": "NM_001378467.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2023,
                                    "seq_id": "NM_001378468.1",
                                },
                                "hgvs": "NM_001378468.1:c.1799=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 599,
                                            "seq_id": "NP_001365397.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365397.1"},
                                "refseq": "NM_001378468.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1957,
                                    "seq_id": "NM_001378469.1",
                                },
                                "hgvs": "NM_001378469.1:c.1733=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 577,
                                            "seq_id": "NP_001365398.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365398.1"},
                                "refseq": "NM_001378469.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1921,
                                    "seq_id": "NM_001378470.1",
                                },
                                "hgvs": "NM_001378470.1:c.1697=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 565,
                                            "seq_id": "NP_001365399.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365399.1"},
                                "refseq": "NM_001378470.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1912,
                                    "seq_id": "NM_001378471.1",
                                },
                                "hgvs": "NM_001378471.1:c.1688=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 562,
                                            "seq_id": "NP_001365400.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365400.1"},
                                "refseq": "NM_001378471.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1742,
                                    "seq_id": "NM_001378472.1",
                                },
                                "hgvs": "NM_001378472.1:c.1643=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 547,
                                            "seq_id": "NP_001365401.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365401.1"},
                                "refseq": "NM_001378472.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1742,
                                    "seq_id": "NM_001378473.1",
                                },
                                "hgvs": "NM_001378473.1:c.1643=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 547,
                                            "seq_id": "NP_001365402.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365402.1"},
                                "refseq": "NM_001378473.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2023,
                                    "seq_id": "NM_001378474.1",
                                },
                                "hgvs": "NM_001378474.1:c.1799=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 599,
                                            "seq_id": "NP_001365403.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365403.1"},
                                "refseq": "NM_001378474.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1759,
                                    "seq_id": "NM_001378475.1",
                                },
                                "hgvs": "NM_001378475.1:c.1535=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 511,
                                            "seq_id": "NP_001365404.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_001365404.1"},
                                "refseq": "NM_001378475.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2023,
                                    "seq_id": "NM_004333.6",
                                },
                                "hgvs": "NM_004333.6:c.1799=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 599,
                                            "seq_id": "NP_004324.2",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "NP_004324.2"},
                                "refseq": "NM_004333.6",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2143,
                                    "seq_id": "XM_017012559.2",
                                },
                                "hgvs": "XM_017012559.2:c.1919=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 639,
                                            "seq_id": "XP_016868048.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "XP_016868048.1"},
                                "refseq": "XM_017012559.2",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1862,
                                    "seq_id": "XM_047420766.1",
                                },
                                "hgvs": "XM_047420766.1:c.1763=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 587,
                                            "seq_id": "XP_047276722.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "XP_047276722.1"},
                                "refseq": "XM_047420766.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 2143,
                                    "seq_id": "XM_047420767.1",
                                },
                                "hgvs": "XM_047420767.1:c.1919=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 639,
                                            "seq_id": "XP_047276723.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "XP_047276723.1"},
                                "refseq": "XM_047420767.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                            {
                                "hgvs": "XM_047420768.1:c.1815-3918=",
                                "protein_product": {"refseq": "XP_047276724.1"},
                                "refseq": "XM_047420768.1",
                                "so": [
                                    {
                                        "accession": "SO:0001627",
                                        "name": "intron_variant",
                                    }
                                ],
                            },
                            {
                                "hgvs": "XM_047420769.1:c.1695-3918=",
                                "protein_product": {"refseq": "XP_047276725.1"},
                                "refseq": "XM_047420769.1",
                                "so": [
                                    {
                                        "accession": "SO:0001627",
                                        "name": "intron_variant",
                                    }
                                ],
                            },
                            {
                                "codon_aligned_transcript_change": {
                                    "deleted_sequence": "GTG",
                                    "inserted_sequence": "GTG",
                                    "position": 1481,
                                    "seq_id": "XM_047420770.1",
                                },
                                "hgvs": "XM_047420770.1:c.1085=",
                                "protein": {
                                    "variant": {
                                        "spdi": {
                                            "deleted_sequence": "V",
                                            "inserted_sequence": "V",
                                            "position": 361,
                                            "seq_id": "XP_047276726.1",
                                        }
                                    }
                                },
                                "protein_product": {"refseq": "XP_047276726.1"},
                                "refseq": "XM_047420770.1",
                                "so": [
                                    {
                                        "accession": "SO:0001580",
                                        "name": "coding_sequence_variant",
                                    }
                                ],
                            },
                        ],
                        "strand": "-",
                        "symbol": "BRAF",
                    },
                    "hg19": {"end": 140453136, "start": 140453136},
                    "ref": "A",
                    "rsid": "rs113488022",
                    "vartype": "snv",
                },
                "docm": {
                    "aa_change": "p.V600E",
                    "all_domains": "pfam_Ser-Thr/Tyr_kinase_cat_dom,pfam_Prot_kinase_dom,pfam_Raf-like_ras-bd,pfam_Prot_Kinase_C-like_PE/DAG-bd,superfamily_Kinase-like_dom,smart_Raf-like_ras-bd,smart_Prot_Kinase_C-like_PE/DAG-bd,smart_Ser/Thr_dual-sp_kinase_dom,smart_Tyr_kinase_cat_dom,pfscan_Raf-like_ras-bd,pfscan_Prot_Kinase_C-like_PE/DAG-bd,pfscan_Prot_kinase_dom,prints_Ser-Thr/Tyr_kinase_cat_dom,prints_DAG/PE-bd",
                    "alt": "T",
                    "c_position": "c.1799",
                    "chrom": 7,
                    "default_gene_name": "BRAF",
                    "deletion_substructures": "-",
                    "disease": "Thyroid Cancer",
                    "doid": "DOID:1781",
                    "domain": "pfam_Ser-Thr/Tyr_kinase_cat_dom,pfam_Prot_kinase_dom,superfamily_Kinase-like_dom,smart_Ser/Thr_dual-sp_kinase_dom,smart_Tyr_kinase_cat_dom,pfscan_Prot_kinase_dom",
                    "ensembl_gene_id": "ENSG00000157764",
                    "genename": "BRAF",
                    "genename_source": "HGNC",
                    "hg19": {"end": 140453136, "start": 140453136},
                    "primary": 1,
                    "pubmed_id": "20818844, 19255327, 19773371, 12068308, 18541894, 19255327, 20368568, 19773371",
                    "ref": "A",
                    "source": "MyCancerGenome",
                    "strand": -1,
                    "transcript_error": "no_errors",
                    "transcript_name": "ENST00000288602",
                    "transcript_source": "ensembl",
                    "transcript_species": "human",
                    "transcript_status": "known",
                    "transcript_version": "74_37",
                    "trv_type": "missense",
                    "type": "SNP",
                    "ucsc_cons": 1,
                    "url": "http://www.mycancergenome.org/content/disease/thyroid-cancer/braf/54",
                },
                "emv": {
                    "_license": "http://bit.ly/2RieoY1",
                    "egl_classification": "Pathogenic",
                    "egl_classification_date": "10/08/2013",
                    "egl_protein": "p.Val600Glu | p.V600E",
                    "egl_variant": "NM_004333.4:c.1799T>A",
                    "exon": "Ex15",
                    "gene": "BRAF",
                    "hgvs": [
                        "LRG_299t1:c.1799T>A",
                        "NM_004333.4:c.1799T>A",
                        "XM_005250045.1:c.1799T>A",
                        "XM_005250046.1:c.1799T>A",
                        "XM_005250047.1:c.1799T>A",
                    ],
                    "variant_id": 15358,
                },
                "exac": {
                    "_license": "http://bit.ly/2H9c4hg",
                    "ac": {
                        "ac": 2,
                        "ac_adj": 2,
                        "ac_afr": 0,
                        "ac_amr": 1,
                        "ac_eas": 0,
                        "ac_female": 0,
                        "ac_fin": 0,
                        "ac_het": 2,
                        "ac_hom": 0,
                        "ac_male": 2,
                        "ac_nfe": 0,
                        "ac_oth": 0,
                        "ac_sas": 1,
                    },
                    "af": 1.647e-05,
                    "alleles": "T",
                    "alt": "T",
                    "an": {
                        "an": 121410,
                        "an_adj": 121220,
                        "an_afr": 10396,
                        "an_amr": 11474,
                        "an_eas": 8644,
                        "an_female": 54032,
                        "an_fin": 6610,
                        "an_male": 67188,
                        "an_nfe": 66688,
                        "an_oth": 906,
                        "an_sas": 16502,
                    },
                    "baseqranksum": 1.1,
                    "chrom": 7,
                    "clippingranksum": -0.323,
                    "culprit": "FS",
                    "fs": 0.0,
                    "het": {
                        "het_afr": 0,
                        "het_amr": 1,
                        "het_eas": 0,
                        "het_fin": 0,
                        "het_nfe": 0,
                        "het_oth": 0,
                        "het_sas": 1,
                    },
                    "hom": {
                        "hom_afr": 0,
                        "hom_amr": 0,
                        "hom_eas": 0,
                        "hom_fin": 0,
                        "hom_nfe": 0,
                        "hom_oth": 0,
                        "hom_sas": 0,
                    },
                    "inbreedingcoeff": 0.0343,
                    "mq": {"mq": 59.5, "mq0": 0, "mqranksum": -0.129},
                    "ncc": 11,
                    "pos": 140453136,
                    "qd": 12.29,
                    "readposranksum": 0.358,
                    "ref": "A",
                    "type": "snp",
                    "vqslod": 4.08,
                },
                "exac_nontcga": {
                    "_license": "http://bit.ly/2H9c4hg",
                    "ac": {
                        "ac": 2,
                        "ac_adj": 2,
                        "ac_afr": 0,
                        "ac_amr": 1,
                        "ac_eas": 0,
                        "ac_female": 0,
                        "ac_fin": 0,
                        "ac_het": 2,
                        "ac_hom": 0,
                        "ac_male": 2,
                        "ac_nfe": 0,
                        "ac_oth": 0,
                        "ac_sas": 1,
                    },
                    "af": 1.883e-05,
                    "alleles": "T",
                    "alt": "T",
                    "an": {
                        "an": 106208,
                        "an_adj": 106034,
                        "an_afr": 9058,
                        "an_amr": 11114,
                        "an_eas": 7860,
                        "an_female": 45794,
                        "an_fin": 6610,
                        "an_male": 60240,
                        "an_nfe": 54302,
                        "an_oth": 692,
                        "an_sas": 16398,
                    },
                    "baseqranksum": 1.1,
                    "chrom": 7,
                    "clippingranksum": -0.323,
                    "culprit": "FS",
                    "fs": 0.0,
                    "het": {
                        "het_afr": 0,
                        "het_amr": 1,
                        "het_eas": 0,
                        "het_fin": 0,
                        "het_nfe": 0,
                        "het_oth": 0,
                        "het_sas": 1,
                    },
                    "hom": {
                        "hom_afr": 0,
                        "hom_amr": 0,
                        "hom_eas": 0,
                        "hom_fin": 0,
                        "hom_nfe": 0,
                        "hom_oth": 0,
                        "hom_sas": 0,
                    },
                    "inbreedingcoeff": 0.0343,
                    "mq": {"mq": 59.5, "mq0": 0, "mqranksum": -0.129},
                    "ncc": 11,
                    "pos": 140453136,
                    "qd": 12.29,
                    "readposranksum": 0.358,
                    "ref": "A",
                    "type": "snp",
                    "vqslod": 4.08,
                },
                "gnomad_exome": {
                    "_license": "http://bit.ly/2I1cl1I",
                    "ac": {
                        "ac": 1,
                        "ac_afr": 0,
                        "ac_afr_female": 0,
                        "ac_afr_male": 0,
                        "ac_amr": 0,
                        "ac_amr_female": 0,
                        "ac_amr_male": 0,
                        "ac_asj": 0,
                        "ac_asj_female": 0,
                        "ac_asj_male": 0,
                        "ac_eas": 0,
                        "ac_eas_female": 0,
                        "ac_eas_jpn": 0,
                        "ac_eas_kor": 0,
                        "ac_eas_male": 0,
                        "ac_eas_oea": 0,
                        "ac_female": 0,
                        "ac_fin": 0,
                        "ac_fin_female": 0,
                        "ac_fin_male": 0,
                        "ac_male": 1,
                        "ac_nfe": 0,
                        "ac_nfe_bgr": 0,
                        "ac_nfe_est": 0,
                        "ac_nfe_female": 0,
                        "ac_nfe_male": 0,
                        "ac_nfe_nwe": 0,
                        "ac_nfe_onf": 0,
                        "ac_nfe_seu": 0,
                        "ac_nfe_swe": 0,
                        "ac_oth": 0,
                        "ac_oth_female": 0,
                        "ac_oth_male": 0,
                        "ac_sas": 1,
                        "ac_sas_female": 0,
                        "ac_sas_male": 1,
                    },
                    "af": {
                        "af": 3.97994e-06,
                        "af_afr": 0.0,
                        "af_afr_female": 0.0,
                        "af_afr_male": 0.0,
                        "af_amr": 0.0,
                        "af_amr_female": 0.0,
                        "af_amr_male": 0.0,
                        "af_asj": 0.0,
                        "af_asj_female": 0.0,
                        "af_asj_male": 0.0,
                        "af_eas": 0.0,
                        "af_eas_female": 0.0,
                        "af_eas_jpn": 0.0,
                        "af_eas_kor": 0.0,
                        "af_eas_male": 0.0,
                        "af_eas_oea": 0.0,
                        "af_female": 0.0,
                        "af_fin": 0.0,
                        "af_fin_female": 0.0,
                        "af_fin_male": 0.0,
                        "af_male": 7.3642e-06,
                        "af_nfe": 0.0,
                        "af_nfe_bgr": 0.0,
                        "af_nfe_est": 0.0,
                        "af_nfe_female": 0.0,
                        "af_nfe_male": 0.0,
                        "af_nfe_nwe": 0.0,
                        "af_nfe_onf": 0.0,
                        "af_nfe_seu": 0.0,
                        "af_nfe_swe": 0.0,
                        "af_oth": 0.0,
                        "af_oth_female": 0.0,
                        "af_oth_male": 0.0,
                        "af_sas": 3.26669e-05,
                        "af_sas_female": 0.0,
                        "af_sas_male": 4.33501e-05,
                    },
                    "alleles": "T",
                    "alt": "T",
                    "an": {
                        "an": 251260,
                        "an_afr": 16252,
                        "an_afr_female": 10070,
                        "an_afr_male": 6182,
                        "an_amr": 34528,
                        "an_amr_female": 20246,
                        "an_amr_male": 14282,
                        "an_asj": 10076,
                        "an_asj_female": 4900,
                        "an_asj_male": 5176,
                        "an_eas": 18392,
                        "an_eas_female": 9326,
                        "an_eas_jpn": 152,
                        "an_eas_kor": 3816,
                        "an_eas_male": 9066,
                        "an_eas_oea": 14424,
                        "an_female": 115468,
                        "an_fin": 21638,
                        "an_fin_female": 10364,
                        "an_fin_male": 11274,
                        "an_male": 135792,
                        "an_nfe": 113638,
                        "an_nfe_bgr": 2668,
                        "an_nfe_est": 240,
                        "an_nfe_female": 50102,
                        "an_nfe_male": 63536,
                        "an_nfe_nwe": 42154,
                        "an_nfe_onf": 30954,
                        "an_nfe_seu": 11496,
                        "an_nfe_swe": 26126,
                        "an_oth": 6124,
                        "an_oth_female": 2916,
                        "an_oth_male": 3208,
                        "an_sas": 30612,
                        "an_sas_female": 7544,
                        "an_sas_male": 23068,
                    },
                    "baseqranksum": 1.11,
                    "chrom": "7",
                    "clippingranksum": 0.007,
                    "dp": 10269946,
                    "fs": 0.0,
                    "hom": {
                        "hom": 0,
                        "hom_afr": 0,
                        "hom_afr_female": 0,
                        "hom_afr_male": 0,
                        "hom_amr": 0,
                        "hom_amr_female": 0,
                        "hom_amr_male": 0,
                        "hom_asj": 0,
                        "hom_asj_female": 0,
                        "hom_asj_male": 0,
                        "hom_eas": 0,
                        "hom_eas_female": 0,
                        "hom_eas_jpn": 0,
                        "hom_eas_kor": 0,
                        "hom_eas_male": 0,
                        "hom_eas_oea": 0,
                        "hom_female": 0,
                        "hom_fin": 0,
                        "hom_fin_female": 0,
                        "hom_fin_male": 0,
                        "hom_male": 0,
                        "hom_nfe": 0,
                        "hom_nfe_bgr": 0,
                        "hom_nfe_est": 0,
                        "hom_nfe_female": 0,
                        "hom_nfe_male": 0,
                        "hom_nfe_nwe": 0,
                        "hom_nfe_onf": 0,
                        "hom_nfe_seu": 0,
                        "hom_nfe_swe": 0,
                        "hom_oth": 0,
                        "hom_oth_female": 0,
                        "hom_oth_male": 0,
                        "hom_sas": 0,
                        "hom_sas_female": 0,
                        "hom_sas_male": 0,
                    },
                    "inbreedingcoeff": 0.06,
                    "mq": {"mq": 59.48, "mqranksum": 0.263},
                    "pab_max": 0.916129,
                    "pos": 140453136,
                    "qd": 14.92,
                    "readposranksum": 0.421,
                    "ref": "A",
                    "rf": 0.906237,
                    "rsid": "rs113488022",
                    "sor": 0.739,
                    "type": "snp",
                    "vqslod": 5.48,
                    "vqsr_culprit": "FS",
                },
                "hg19": {"end": 140453136, "start": 140453136},
                "mutdb": {
                    "_license": "http://bit.ly/2SQ6fXA",
                    "alt": "A",
                    "chrom": "7",
                    "cosmic_id": "476, 1131",
                    "hg19": {"end": 140453136, "start": 140453136},
                    "mutpred_score": 0.705,
                    "ref": "T",
                    "rsid": "rs113488022",
                    "strand": "m",
                    "uniprot_id": "VAR_018629",
                },
                "observed": True,
                "snpeff": {
                    "_license": "http://bit.ly/2suyRKt",
                    "ann": {
                        "cdna": {"length": "2946", "position": "1860"},
                        "cds": {"length": "2301", "position": "1799"},
                        "effect": "missense_variant",
                        "feature_id": "NM_004333.4",
                        "feature_type": "transcript",
                        "gene_id": "BRAF",
                        "genename": "BRAF",
                        "hgvs_c": "c.1799T>A",
                        "hgvs_p": "p.Val600Glu",
                        "protein": {"length": "766", "position": "600"},
                        "putative_impact": "MODERATE",
                        "rank": "15",
                        "total": "18",
                        "transcript_biotype": "protein_coding",
                    },
                },
                "vcf": {"alt": "T", "position": "140453136", "ref": "A"},
            },
        )
        self.assertEqual(expected, self.myvariant_annotation)
